	; IntyBASIC compiler v1.2.4 Sep/19/2015
        ;
        ; Prologue for IntyBASIC programs
        ; by Oscar Toledo G.  http://nanochess.org/
        ;
        ; Revision: Jan/30/2014. Spacing adjustment and more comments.
        ; Revision: Apr/01/2014. It now sets the starting screen pos. for PRINT
	; Revision: Aug/26/2014. Added PAL detection code.
	; Revision: Dec/12/2014. Added optimized constant multiplication routines
	;                        by James Pujals.
	; Revision: Jan/25/2015. Added marker for automatic title replacement.
	;                        (option --title of IntyBASIC)
	; Revision: Aug/06/2015. Turns off ECS sound. Seed random generator using
	;                        trash in 16-bit RAM. Solved bugs and optimized
	;                        macro for constant multiplication.
	; 

        ROMW 16
        ORG $5000

        ; This macro will 'eat' SRCFILE directives if the assembler doesn't support the directive.
        IF ( DEFINED __FEATURE.SRCFILE ) = 0
            MACRO SRCFILE x, y
            ; macro must be non-empty, but a comment works fine.
            ENDM
        ENDI

        ;
        ; ROM header
        ;
        BIDECLE _ZERO           ; MOB picture base
        BIDECLE _ZERO           ; Process table
        BIDECLE _MAIN           ; Program start
        BIDECLE _ZERO           ; Background base image
        BIDECLE _ONES           ; GRAM
        BIDECLE _TITLE          ; Cartridge title and date
        DECLE   $03C0           ; No ECS title, jump to code after title,
                                ; ... no clicks
                                
_ZERO:  DECLE   $0000           ; Border control
        DECLE   $0000           ; 0 = color stack, 1 = f/b mode
        
_ONES:  DECLE   $0001, $0001    ; Initial color stack 0 and 1: Blue
        DECLE   $0001, $0001    ; Initial color stack 2 and 3: Blue
        DECLE   $0001           ; Initial border color: Blue

C_WHT:  EQU $0007

CLRSCR: MVII #$200,R4           ; Used also for CLS
        MVII #$F0,R1
FILLZERO:
        CLRR R0
MEMSET:
        MVO@ R0,R4
        DECR R1
        BNE MEMSET
        JR R5

        ;
        ; Title, Intellivision EXEC will jump over it and start
        ; execution directly in _MAIN
        ;
	; Note mark is for automatic replacement by IntyBASIC
_TITLE:
	BYTE 115,'IntyBASIC program',0
        
        ;
        ; Main program
        ;
_MAIN:
        DIS
        MVII #STACK,R6

_MAIN0:
        ;
        ; Clean memory
        ;
        MVII #$00e,R1           ; 14 of sound (ECS)
        MVII #$0f0,R4           ; ECS PSG
        CALL FILLZERO
        MVII #$0fe,R1           ; 240 words of 8 bits plus 14 of sound
        MVII #$100,R4           ; 8-bit scratch RAM
        CALL FILLZERO

	; Seed random generator using 16 bit RAM (not cleared by EXEC)
	CLRR R0
	MVII #$02F0,R4
	MVII #$0110/4,R1        ; Includes phantom memory for extra randomness
_MAIN4:                         ; This loop is courtesy of GroovyBee
	ADD@ R4,R0
	ADD@ R4,R0
	ADD@ R4,R0
	ADD@ R4,R0
	DECR R1
	BNE _MAIN4
	MVO R0,_rand

        MVII #$058,R1           ; 88 words of 16 bits
        MVII #$308,R4           ; 16-bit scratch RAM
        CALL FILLZERO

        CALL CLRSCR             ; Clean up screen

        MVII #_pal1_vector,R0 ; Points to interrupt vector
        MVO R0,ISRVEC
        SWAP R0
        MVO R0,ISRVEC+1

        EIS

_MAIN1:	MVI _ntsc,R0
	CMPI #3,R0
	BNE _MAIN1
	CLRR R2
_MAIN2:	INCR R2
	MVI _ntsc,R0
	CMPI #4,R0
	BNE _MAIN2

        ; 387 for PAL in jzintv
        ; 444 for NTSC in jzintv
        CMPI #415,R2
        MVII #1,R0
        BGE _MAIN3
        CLRR R0
_MAIN3: MVO R0,_ntsc

        CALL _wait
	CALL _init_music
        MVII #1,R0
        MVO R0,_mode_select
        MVII #$038,R0
        MVO R0,$01F8            ; Configures sound
        MVO R0,$00F8            ; Configures sound (ECS)
        CALL _wait

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- James Pujals (DZ-Jay), 2014                              *;
;* ======================================================================== *;

; Modified by Oscar Toledo G. (nanochess), Aug/06/2015
; * Tested all multiplications with automated test.
; * Accelerated multiplication by 7,14,15,28,31,60,62,63,112,120,124
; * Solved bug in multiplication by 23,39,46,47,55,71,78,79,87,92,93,94,95,103,110,111,119
; * Improved sequence of instructions to be more interruptible.

;; ======================================================================== ;;
;;  MULT reg, tmp, const                                                    ;;
;;  Multiplies "reg" by constant "const" and using "tmp" for temporary      ;;
;;  calculations.  The result is placed in "reg."  The multiplication is    ;;
;;  performed by an optimal combination of shifts, additions, and           ;;
;;  subtractions.                                                           ;;
;;                                                                          ;;
;;  NOTE:   The resulting contents of the "tmp" are undefined.              ;;
;;                                                                          ;;
;;  ARGUMENTS                                                               ;;
;;      reg         A register containing the multiplicand.                 ;;
;;      tmp         A register for temporary calculations.                  ;;
;;      const       The constant multiplier.                                ;;
;;                                                                          ;;
;;  OUTPUT                                                                  ;;
;;      reg         Output value.                                           ;;
;;      tmp         Trashed.                                                ;;
;;      .ERR.Failed True if operation failed.                               ;;
;; ======================================================================== ;;
MACRO   MULT reg, tmp, const
;
    LISTING "code"

_mul.const      QSET    %const%
_mul.done       QSET    0

        IF (%const% > $7F)
_mul.const      QSET    (_mul.const SHR 1)
                SLL     %reg%,  1
        ENDI

        ; Multiply by $00 (0)
        IF (_mul.const = $00)
_mul.done       QSET    -1
                CLRR    %reg%
        ENDI

        ; Multiply by $01 (1)
        IF (_mul.const = $01)
_mul.done       QSET    -1
                ; Nothing to do
        ENDI

        ; Multiply by $02 (2)
        IF (_mul.const = $02)
_mul.done       QSET    -1
                SLL     %reg%,  1
        ENDI

        ; Multiply by $03 (3)
        IF (_mul.const = $03)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $04 (4)
        IF (_mul.const = $04)
_mul.done       QSET    -1
                SLL     %reg%,  2
        ENDI

        ; Multiply by $05 (5)
        IF (_mul.const = $05)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $06 (6)
        IF (_mul.const = $06)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $07 (7)
        IF (_mul.const = $07)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $08 (8)
        IF (_mul.const = $08)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
        ENDI

        ; Multiply by $09 (9)
        IF (_mul.const = $09)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0A (10)
        IF (_mul.const = $0A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0B (11)
        IF (_mul.const = $0B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0C (12)
        IF (_mul.const = $0C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0D (13)
        IF (_mul.const = $0D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0E (14)
        IF (_mul.const = $0E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0F (15)
        IF (_mul.const = $0F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $10 (16)
        IF (_mul.const = $10)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
        ENDI

        ; Multiply by $11 (17)
        IF (_mul.const = $11)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $12 (18)
        IF (_mul.const = $12)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $13 (19)
        IF (_mul.const = $13)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $14 (20)
        IF (_mul.const = $14)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $15 (21)
        IF (_mul.const = $15)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $16 (22)
        IF (_mul.const = $16)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $17 (23)
        IF (_mul.const = $17)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $18 (24)
        IF (_mul.const = $18)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $19 (25)
        IF (_mul.const = $19)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1A (26)
        IF (_mul.const = $1A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1B (27)
        IF (_mul.const = $1B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1C (28)
        IF (_mul.const = $1C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1D (29)
        IF (_mul.const = $1D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1E (30)
        IF (_mul.const = $1E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1F (31)
        IF (_mul.const = $1F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $20 (32)
        IF (_mul.const = $20)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
        ENDI

        ; Multiply by $21 (33)
        IF (_mul.const = $21)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $22 (34)
        IF (_mul.const = $22)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $23 (35)
        IF (_mul.const = $23)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $24 (36)
        IF (_mul.const = $24)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $25 (37)
        IF (_mul.const = $25)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $26 (38)
        IF (_mul.const = $26)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $27 (39)
        IF (_mul.const = $27)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $28 (40)
        IF (_mul.const = $28)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $29 (41)
        IF (_mul.const = $29)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2A (42)
        IF (_mul.const = $2A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2B (43)
        IF (_mul.const = $2B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2C (44)
        IF (_mul.const = $2C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2D (45)
        IF (_mul.const = $2D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2E (46)
        IF (_mul.const = $2E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,  %reg%
        ENDI

        ; Multiply by $2F (47)
        IF (_mul.const = $2F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,  %reg%
        ENDI

        ; Multiply by $30 (48)
        IF (_mul.const = $30)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $31 (49)
        IF (_mul.const = $31)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $32 (50)
        IF (_mul.const = $32)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $33 (51)
        IF (_mul.const = $33)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $34 (52)
        IF (_mul.const = $34)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $35 (53)
        IF (_mul.const = $35)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $36 (54)
        IF (_mul.const = $36)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $37 (55)
        IF (_mul.const = $37)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
		SLL	%reg%,	1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $38 (56)
        IF (_mul.const = $38)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $39 (57)
        IF (_mul.const = $39)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3A (58)
        IF (_mul.const = $3A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3B (59)
        IF (_mul.const = $3B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3C (60)
        IF (_mul.const = $3C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3D (61)
        IF (_mul.const = $3D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3E (62)
        IF (_mul.const = $3E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3F (63)
        IF (_mul.const = $3F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $40 (64)
        IF (_mul.const = $40)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
        ENDI

        ; Multiply by $41 (65)
        IF (_mul.const = $41)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $42 (66)
        IF (_mul.const = $42)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $43 (67)
        IF (_mul.const = $43)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $44 (68)
        IF (_mul.const = $44)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $45 (69)
        IF (_mul.const = $45)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $46 (70)
        IF (_mul.const = $46)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $47 (71)
        IF (_mul.const = $47)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $48 (72)
        IF (_mul.const = $48)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $49 (73)
        IF (_mul.const = $49)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4A (74)
        IF (_mul.const = $4A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4B (75)
        IF (_mul.const = $4B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4C (76)
        IF (_mul.const = $4C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4D (77)
        IF (_mul.const = $4D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4E (78)
        IF (_mul.const = $4E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $4F (79)
        IF (_mul.const = $4F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $50 (80)
        IF (_mul.const = $50)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $51 (81)
        IF (_mul.const = $51)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $52 (82)
        IF (_mul.const = $52)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $53 (83)
        IF (_mul.const = $53)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $54 (84)
        IF (_mul.const = $54)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $55 (85)
        IF (_mul.const = $55)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $56 (86)
        IF (_mul.const = $56)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $57 (87)
        IF (_mul.const = $57)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR    %reg%,	%tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $58 (88)
        IF (_mul.const = $58)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $59 (89)
        IF (_mul.const = $59)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $5A (90)
        IF (_mul.const = $5A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $5B (91)
        IF (_mul.const = $5B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $5C (92)
        IF (_mul.const = $5C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $5D (93)
        IF (_mul.const = $5D)
_mul.done       QSET    -1
		MOVR	%reg%,	%tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $5E (94)
        IF (_mul.const = $5E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $5F (95)
        IF (_mul.const = $5F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                ADDR	%reg%,	%reg%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $60 (96)
        IF (_mul.const = $60)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $61 (97)
        IF (_mul.const = $61)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $62 (98)
        IF (_mul.const = $62)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $63 (99)
        IF (_mul.const = $63)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $64 (100)
        IF (_mul.const = $64)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $65 (101)
        IF (_mul.const = $65)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $66 (102)
        IF (_mul.const = $66)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $67 (103)
        IF (_mul.const = $67)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $68 (104)
        IF (_mul.const = $68)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $69 (105)
        IF (_mul.const = $69)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6A (106)
        IF (_mul.const = $6A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6B (107)
        IF (_mul.const = $6B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6C (108)
        IF (_mul.const = $6C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6D (109)
        IF (_mul.const = $6D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6E (110)
        IF (_mul.const = $6E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $6F (111)
        IF (_mul.const = $6F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $70 (112)
        IF (_mul.const = $70)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $71 (113)
        IF (_mul.const = $71)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $72 (114)
        IF (_mul.const = $72)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $73 (115)
        IF (_mul.const = $73)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $74 (116)
        IF (_mul.const = $74)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $75 (117)
        IF (_mul.const = $75)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $76 (118)
        IF (_mul.const = $76)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $77 (119)
        IF (_mul.const = $77)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $78 (120)
        IF (_mul.const = $78)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $79 (121)
        IF (_mul.const = $79)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7A (122)
        IF (_mul.const = $7A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7B (123)
        IF (_mul.const = $7B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7C (124)
        IF (_mul.const = $7C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7D (125)
        IF (_mul.const = $7D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7E (126)
        IF (_mul.const = $7E)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SWAP    %reg%,  1
                SLR     %reg%,  1
		ADDR    %tmp%,  %tmp%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7F (127)
        IF (_mul.const = $7F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SWAP    %reg%, 1
                SLR     %reg%, 1
                SUBR    %tmp%,  %reg%
        ENDI

        IF  (_mul.done = 0)
            ERR $("Invalid multiplication constant \'%const%\', must be between 0 and ", $#($7F), ".")
        ENDI

    LISTING "prev"
ENDM

;; ======================================================================== ;;
;;  EOF: pm:mac:lang:mult                                                   ;;
;; ======================================================================== ;;

	;FILE goatcontest.bas
	;[1] 	REM Goatnom v1.0
	SRCFILE "goatcontest.bas",1
	;[2] 	REM IntyBASIC contest build
	SRCFILE "goatcontest.bas",2
	;[3] 	REM Dec 21, 2015
	SRCFILE "goatcontest.bas",3
	;[4] 	REM @ 2015 freewheel
	SRCFILE "goatcontest.bas",4
	;[5] 	
	SRCFILE "goatcontest.bas",5
	;[6] 	'disable ECS ROMs as needed
	SRCFILE "goatcontest.bas",6
	;[7] 	SOUND 5,0,0
	SRCFILE "goatcontest.bas",7
	CLRR R0
	MVO R0,240
	SWAP R0
	MVO R0,244
	CLRR R0
	MVO R0,251
	;[8] 	
	SRCFILE "goatcontest.bas",8
	;[9] begin_game:
	SRCFILE "goatcontest.bas",9
	; BEGIN_GAME
Q3:	;[10] 	'always clear the MOBs here, just in case
	SRCFILE "goatcontest.bas",10
	;[11] 	GOSUB reset_sprites
	SRCFILE "goatcontest.bas",11
	CALL Q4
	;[12] 	
	SRCFILE "goatcontest.bas",12
	;[13] 	'define and reset various variables that may change
	SRCFILE "goatcontest.bas",13
	;[14] 	GOSUB reset_vals
	SRCFILE "goatcontest.bas",14
	CALL Q5
	;[15] 	
	SRCFILE "goatcontest.bas",15
	;[16] 	'boundaries of the playfield, for the player
	SRCFILE "goatcontest.bas",16
	;[17] 	CONST ytop=10
	SRCFILE "goatcontest.bas",17
	;[18] 	CONST ybot=88
	SRCFILE "goatcontest.bas",18
	;[19] 	CONST xleft=10
	SRCFILE "goatcontest.bas",19
	;[20] 	CONST xright=110
	SRCFILE "goatcontest.bas",20
	;[21] 
	SRCFILE "goatcontest.bas",21
	;[22] 	'point scores for objects
	SRCFILE "goatcontest.bas",22
	;[23] 	CONST point4val=40 ' shirt, is big
	SRCFILE "goatcontest.bas",23
	;[24] 	CONST point5val=60 ' can, is medium
	SRCFILE "goatcontest.bas",24
	;[25] 	CONST point6val=90 ' fish, is small
	SRCFILE "goatcontest.bas",25
	;[26] 	CONST point7val=250 'rock - major points!
	SRCFILE "goatcontest.bas",26
	;[27] 	
	SRCFILE "goatcontest.bas",27
	;[28] 	'how many points (in thousands) each level needs
	SRCFILE "goatcontest.bas",28
	;[29] 	CONST level0score=0
	SRCFILE "goatcontest.bas",29
	;[30] 	CONST level1score=1
	SRCFILE "goatcontest.bas",30
	;[31] 	CONST level2score=2
	SRCFILE "goatcontest.bas",31
	;[32] 	CONST level3score=4
	SRCFILE "goatcontest.bas",32
	;[33] 	CONST level4score=8
	SRCFILE "goatcontest.bas",33
	;[34] 	CONST level5score=10
	SRCFILE "goatcontest.bas",34
	;[35] 	
	SRCFILE "goatcontest.bas",35
	;[36] 	'how many points it takes to finish a stage
	SRCFILE "goatcontest.bas",36
	;[37] 	'powers of 64 only, to speed up calculations for meter. this is divided by 64 later to produce div,
	SRCFILE "goatcontest.bas",37
	;[38] 	'which is repeatedly used as #score divisor. so we don't want slow math.
	SRCFILE "goatcontest.bas",38
	;[39] 	'default 8192. but change on a per season basis to mess with the difficulty. do with consts so we can set it all here.
	SRCFILE "goatcontest.bas",39
	;[40] 	#stagescore=8192
	SRCFILE "goatcontest.bas",40
	MVII #8192,R0
	MVO R0,V1
	;[41] 	CONST springscore=4096
	SRCFILE "goatcontest.bas",41
	;[42] 	CONST summerscore=8192
	SRCFILE "goatcontest.bas",42
	;[43] 	CONST fallscore=12288
	SRCFILE "goatcontest.bas",43
	;[44] 	CONST winterscore=12288
	SRCFILE "goatcontest.bas",44
	;[45] 	
	SRCFILE "goatcontest.bas",45
	;[46] 	'other CONSTs go here
	SRCFILE "goatcontest.bas",46
	;[47] 	CONST goat_idle_limit=400
	SRCFILE "goatcontest.bas",47
	;[48] 	
	SRCFILE "goatcontest.bas",48
	;[49] 	'timers to control main sprite animations
	SRCFILE "goatcontest.bas",49
	;[50] 	spritetimer=0
	SRCFILE "goatcontest.bas",50
	CLRR R0
	MVO R0,V2
	;[51] 	movetimer=0
	SRCFILE "goatcontest.bas",51
	MVO R0,V3
	;[52] 	fliptimer=0
	SRCFILE "goatcontest.bas",52
	NOP
	MVO R0,V4
	;[53] 	flipcooldown=0
	SRCFILE "goatcontest.bas",53
	MVO R0,V5
	;[54] 	goatwalk=0
	SRCFILE "goatcontest.bas",54
	NOP
	MVO R0,V6
	;[55] 	
	SRCFILE "goatcontest.bas",55
	;[56] 	'timer to control goat bleating when idle
	SRCFILE "goatcontest.bas",56
	;[57] 	#idletimer=0
	SRCFILE "goatcontest.bas",57
	MVO R0,V7
	;[58] 	
	SRCFILE "goatcontest.bas",58
	;[59] 	randseed=0 ' seed for randomization
	SRCFILE "goatcontest.bas",59
	NOP
	MVO R0,V8
	;[60] 	farmermove=0
	SRCFILE "goatcontest.bas",60
	MVO R0,V9
	;[61] 
	SRCFILE "goatcontest.bas",61
	;[62] 	'parameters for objects that get thrown
	SRCFILE "goatcontest.bas",62
	;[63] 	objlive=255
	SRCFILE "goatcontest.bas",63
	MVII #255,R0
	MVO R0,V10
	;[64] 	DIM objtype(4)
	SRCFILE "goatcontest.bas",64
	;[65] 	DIM objx(4)
	SRCFILE "goatcontest.bas",65
	;[66] 	DIM objy(4)
	SRCFILE "goatcontest.bas",66
	;[67] 	
	SRCFILE "goatcontest.bas",67
	;[68] 	'this is the object the goat ate
	SRCFILE "goatcontest.bas",68
	;[69] 	objhit=0
	SRCFILE "goatcontest.bas",69
	CLRR R0
	MVO R0,V11
	;[70] 		
	SRCFILE "goatcontest.bas",70
	;[71] 	'score tracking
	SRCFILE "goatcontest.bas",71
	;[72] 	#score=0 ' actual score
	SRCFILE "goatcontest.bas",72
	MVO R0,V12
	;[73] 	#score1k=0 ' score in thousands, for level calcs
	SRCFILE "goatcontest.bas",73
	NOP
	MVO R0,V13
	;[74] 	#topscore=0 ' highest score of the game
	SRCFILE "goatcontest.bas",74
	MVO R0,V14
	;[75] 	#points=0 ' points scored/lost
	SRCFILE "goatcontest.bas",75
	NOP
	MVO R0,V15
	;[76] 	scorefactor=1 ' this is how much we divide the points by, when objects are missed. lower=easier game
	SRCFILE "goatcontest.bas",76
	MVII #1,R0
	MVO R0,V16
	;[77] 	
	SRCFILE "goatcontest.bas",77
	;[78] 	lives=3 ' start with 3 lives by default
	SRCFILE "goatcontest.bas",78
	MVII #3,R0
	MVO R0,V17
	;[79] 	level=0 ' this is the difficulty level within a stage. points are *(level+1).
	SRCFILE "goatcontest.bas",79
	CLRR R0
	MVO R0,V18
	;[80] 	stage=0 ' stage (season) - changes objects thrown
	SRCFILE "goatcontest.bas",80
	MVO R0,V19
	;[81] 	
	SRCFILE "goatcontest.bas",81
	;[82] 	'various movement tables based on difficulty level
	SRCFILE "goatcontest.bas",82
	;[83] 	DIM obj4mov(6)
	SRCFILE "goatcontest.bas",83
	;[84] 	DIM obj5mov(6)
	SRCFILE "goatcontest.bas",84
	;[85] 	DIM obj6mov(6)
	SRCFILE "goatcontest.bas",85
	;[86] 	DIM obj7mov(6)
	SRCFILE "goatcontest.bas",86
	;[87] 	DIM p1mov(6)
	SRCFILE "goatcontest.bas",87
	;[88] 	DIM p2mov(6)
	SRCFILE "goatcontest.bas",88
	;[89] 	
	SRCFILE "goatcontest.bas",89
	;[90] 	'large object
	SRCFILE "goatcontest.bas",90
	;[91] 	obj4mov(0)=1
	SRCFILE "goatcontest.bas",91
	MVII #1,R0
	MVO R0,Q9
	;[92] 	obj4mov(1)=1
	SRCFILE "goatcontest.bas",92
	MVO R0,Q9+1
	;[93] 	obj4mov(2)=1
	SRCFILE "goatcontest.bas",93
	NOP
	MVO R0,Q9+2
	;[94] 	obj4mov(3)=1
	SRCFILE "goatcontest.bas",94
	MVO R0,Q9+3
	;[95] 	obj4mov(4)=2
	SRCFILE "goatcontest.bas",95
	MVII #2,R0
	MVO R0,Q9+4
	;[96] 	obj4mov(5)=2
	SRCFILE "goatcontest.bas",96
	MVO R0,Q9+5
	;[97] 
	SRCFILE "goatcontest.bas",97
	;[98] 	'medium object
	SRCFILE "goatcontest.bas",98
	;[99] 	obj5mov(0)=1
	SRCFILE "goatcontest.bas",99
	MVII #1,R0
	MVO R0,Q10
	;[100] 	obj5mov(1)=1
	SRCFILE "goatcontest.bas",100
	MVO R0,Q10+1
	;[101] 	obj5mov(2)=1
	SRCFILE "goatcontest.bas",101
	NOP
	MVO R0,Q10+2
	;[102] 	obj5mov(3)=2
	SRCFILE "goatcontest.bas",102
	MVII #2,R0
	MVO R0,Q10+3
	;[103] 	obj5mov(4)=2
	SRCFILE "goatcontest.bas",103
	MVO R0,Q10+4
	;[104] 	obj5mov(5)=3
	SRCFILE "goatcontest.bas",104
	MVII #3,R0
	MVO R0,Q10+5
	;[105] 	
	SRCFILE "goatcontest.bas",105
	;[106] 	'small object
	SRCFILE "goatcontest.bas",106
	;[107] 	obj6mov(0)=1
	SRCFILE "goatcontest.bas",107
	MVII #1,R0
	MVO R0,Q11
	;[108] 	obj6mov(1)=1
	SRCFILE "goatcontest.bas",108
	MVO R0,Q11+1
	;[109] 	obj6mov(2)=2
	SRCFILE "goatcontest.bas",109
	MVII #2,R0
	MVO R0,Q11+2
	;[110] 	obj6mov(3)=2
	SRCFILE "goatcontest.bas",110
	MVO R0,Q11+3
	;[111] 	obj6mov(4)=2
	SRCFILE "goatcontest.bas",111
	NOP
	MVO R0,Q11+4
	;[112] 	obj6mov(5)=3
	SRCFILE "goatcontest.bas",112
	MVII #3,R0
	MVO R0,Q11+5
	;[113] 	
	SRCFILE "goatcontest.bas",113
	;[114] 	'rock
	SRCFILE "goatcontest.bas",114
	;[115] 	obj7mov(0)=1
	SRCFILE "goatcontest.bas",115
	MVII #1,R0
	MVO R0,Q12
	;[116] 	obj7mov(1)=2
	SRCFILE "goatcontest.bas",116
	MVII #2,R0
	MVO R0,Q12+1
	;[117] 	obj7mov(2)=2
	SRCFILE "goatcontest.bas",117
	MVO R0,Q12+2
	;[118] 	obj7mov(3)=2
	SRCFILE "goatcontest.bas",118
	NOP
	MVO R0,Q12+3
	;[119] 	obj7mov(4)=2
	SRCFILE "goatcontest.bas",119
	MVO R0,Q12+4
	;[120] 	obj7mov(5)=3
	SRCFILE "goatcontest.bas",120
	MVII #3,R0
	MVO R0,Q12+5
	;[121] 	
	SRCFILE "goatcontest.bas",121
	;[122] 	'movement speed of player
	SRCFILE "goatcontest.bas",122
	;[123] 	p1mov(0)=1
	SRCFILE "goatcontest.bas",123
	MVII #1,R0
	MVO R0,Q13
	;[124] 	p1mov(1)=1
	SRCFILE "goatcontest.bas",124
	MVO R0,Q13+1
	;[125] 	p1mov(2)=1
	SRCFILE "goatcontest.bas",125
	NOP
	MVO R0,Q13+2
	;[126] 	p1mov(3)=2
	SRCFILE "goatcontest.bas",126
	MVII #2,R0
	MVO R0,Q13+3
	;[127] 	p1mov(4)=2
	SRCFILE "goatcontest.bas",127
	MVO R0,Q13+4
	;[128] 	p1mov(5)=2
	SRCFILE "goatcontest.bas",128
	NOP
	MVO R0,Q13+5
	;[129] 	
	SRCFILE "goatcontest.bas",129
	;[130] 	'movement speed of farmer
	SRCFILE "goatcontest.bas",130
	;[131] 	p2mov(0)=1
	SRCFILE "goatcontest.bas",131
	MVII #1,R0
	MVO R0,Q14
	;[132] 	p2mov(1)=1
	SRCFILE "goatcontest.bas",132
	MVO R0,Q14+1
	;[133] 	p2mov(2)=2
	SRCFILE "goatcontest.bas",133
	MVII #2,R0
	MVO R0,Q14+2
	;[134] 	p2mov(3)=2
	SRCFILE "goatcontest.bas",134
	MVO R0,Q14+3
	;[135] 	p2mov(4)=2
	SRCFILE "goatcontest.bas",135
	NOP
	MVO R0,Q14+4
	;[136] 	p2mov(5)=2
	SRCFILE "goatcontest.bas",136
	MVO R0,Q14+5
	;[137] 	
	SRCFILE "goatcontest.bas",137
	;[138] 	'this is used to have objects not change speed mid-flight
	SRCFILE "goatcontest.bas",138
	;[139]  	obj4speed=0
	SRCFILE "goatcontest.bas",139
	CLRR R0
	MVO R0,V20
	;[140]  	obj5speed=0
	SRCFILE "goatcontest.bas",140
	MVO R0,V21
	;[141]  	obj6speed=0
	SRCFILE "goatcontest.bas",141
	NOP
	MVO R0,V22
	;[142]  	obj7speed=0
	SRCFILE "goatcontest.bas",142
	MVO R0,V23
	;[143] 	
	SRCFILE "goatcontest.bas",143
	;[144] 	goatflip=0 ' 0 faces right, 4 is kicking motion (for easy math)
	SRCFILE "goatcontest.bas",144
	NOP
	MVO R0,V24
	;[145] 	buttonflag=0 ' try to prevent holding down the fire button
	SRCFILE "goatcontest.bas",145
	MVO R0,V25
	;[146] 	
	SRCFILE "goatcontest.bas",146
	;[147] 	#goat1sprite=$0800 'sprite 0, default black (000) - goat left half
	SRCFILE "goatcontest.bas",147
	MVII #2048,R0
	MVO R0,V26
	;[148] 	#goat2sprite=$0810 'sprite 1, default black (000) - goat right half
	SRCFILE "goatcontest.bas",148
	MVII #2064,R0
	MVO R0,V27
	;[149] 	#goat3sprite=$0840 'sprite 2, default black (000) - goat eye
	SRCFILE "goatcontest.bas",149
	MVII #2112,R0
	MVO R0,V28
	;[150] 	#farmersprite=$0850 'alt is $0860
	SRCFILE "goatcontest.bas",150
	MVII #2128,R0
	MVO R0,V29
	;[151] 	
	SRCFILE "goatcontest.bas",151
	;[152] 	objbaseaddr=32 ' object cards start at card addr 32. incremented by stage*4.
	SRCFILE "goatcontest.bas",152
	MVII #32,R0
	MVO R0,V30
	;[153] 
	SRCFILE "goatcontest.bas",153
	;[154] 	#goat1color=$7
	SRCFILE "goatcontest.bas",154
	MVII #7,R0
	MVO R0,V31
	;[155] 	#farmersprite=$0850 OR level+1
	SRCFILE "goatcontest.bas",155
	MVII #2128,R0
	MVI V18,R1
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVO R0,V29
	;[156] 
	SRCFILE "goatcontest.bas",156
	;[157] 	'initial screen setup
	SRCFILE "goatcontest.bas",157
	;[158] 	CLS 
	SRCFILE "goatcontest.bas",158
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[159] 	WAIT
	SRCFILE "goatcontest.bas",159
	CALL _wait
	;[160] 	MODE 1
	SRCFILE "goatcontest.bas",160
	MVII #2,R0
	MVO R0,_mode_select
	;[161] 	WAIT
	SRCFILE "goatcontest.bas",161
	CALL _wait
	;[162] 	
	SRCFILE "goatcontest.bas",162
	;[163] 	'intro ditty
	SRCFILE "goatcontest.bas",163
	;[164] 	PLAY SIMPLE
	SRCFILE "goatcontest.bas",164
	MVII #1,R3
	MVO R3,_music_mode
	;[165] 	PLAY intro_song
	SRCFILE "goatcontest.bas",165
	MVII #Q15,R0
	CALL _play_music
	;[166] 	WAIT
	SRCFILE "goatcontest.bas",166
	CALL _wait
	;[167] 
	SRCFILE "goatcontest.bas",167
	;[168] 	'title screen
	SRCFILE "goatcontest.bas",168
	;[169] 	DEFINE 0,16,titlescreen_bitmaps_0
	SRCFILE "goatcontest.bas",169
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q16,R0
	MVO R0,_gram_bitmap
	;[170] 	WAIT
	SRCFILE "goatcontest.bas",170
	CALL _wait
	;[171] 	DEFINE 16,16,titlescreen_bitmaps_1
	SRCFILE "goatcontest.bas",171
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q17,R0
	MVO R0,_gram_bitmap
	;[172] 	WAIT
	SRCFILE "goatcontest.bas",172
	CALL _wait
	;[173] 	DEFINE 32,16,titlescreen_bitmaps_2
	SRCFILE "goatcontest.bas",173
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q18,R0
	MVO R0,_gram_bitmap
	;[174] 	WAIT
	SRCFILE "goatcontest.bas",174
	CALL _wait
	;[175] 	DEFINE 48,5,titlescreen_bitmaps_3
	SRCFILE "goatcontest.bas",175
	MVII #48,R0
	MVO R0,_gram_target
	MVII #5,R0
	MVO R0,_gram_total
	MVII #Q19,R0
	MVO R0,_gram_bitmap
	;[176] 	WAIT
	SRCFILE "goatcontest.bas",176
	CALL _wait
	;[177] 	
	SRCFILE "goatcontest.bas",177
	;[178] 	'define the sky filler bits (5 MOBs)
	SRCFILE "goatcontest.bas",178
	;[179] 	DEFINE 53, 5, skyfiller1
	SRCFILE "goatcontest.bas",179
	MVII #53,R0
	MVO R0,_gram_target
	MVII #5,R0
	MVO R0,_gram_total
	MVII #Q20,R0
	MVO R0,_gram_bitmap
	;[180] 	WAIT
	SRCFILE "goatcontest.bas",180
	CALL _wait
	;[181] 	
	SRCFILE "goatcontest.bas",181
	;[182] 	'and now the goat hisself
	SRCFILE "goatcontest.bas",182
	;[183] 	DEFINE 58,4,drawings1
	SRCFILE "goatcontest.bas",183
	MVII #58,R0
	MVO R0,_gram_target
	MVII #4,R0
	MVO R0,_gram_total
	MVII #Q21,R0
	MVO R0,_gram_bitmap
	;[184] 	WAIT
	SRCFILE "goatcontest.bas",184
	CALL _wait
	;[185] 	DEFINE 62,1,horns
	SRCFILE "goatcontest.bas",185
	MVII #62,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q22,R0
	MVO R0,_gram_bitmap
	;[186] 	WAIT
	SRCFILE "goatcontest.bas",186
	CALL _wait
	;[187] 
	SRCFILE "goatcontest.bas",187
	;[188] 	SCREEN titlescreen_cards
	SRCFILE "goatcontest.bas",188
	MVII #Q23,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[189] 	
	SRCFILE "goatcontest.bas",189
	;[190] 	'sky filler MOBs
	SRCFILE "goatcontest.bas",190
	;[191] 	SPRITE 0,96+$0300+$0400,16+$0100,((256+53)*8)+$1001 
	SRCFILE "goatcontest.bas",191
	MVII #1888,R0
	MVO R0,_mobs
	MVII #272,R0
	MVO R0,_mobs+8
	MVII #6569,R0
	MVO R0,_mobs+16
	;[192] 	SPRITE 1,80+$0300,8+$0100,((256+54)*8)+$1001
	SRCFILE "goatcontest.bas",192
	MVII #848,R0
	MVO R0,_mobs+1
	MVII #264,R0
	MVO R0,_mobs+9
	MVII #6577,R0
	MVO R0,_mobs+17
	;[193] 	SPRITE 2,72+$0300,8+$0200,((256+55)*8)+$1001 
	SRCFILE "goatcontest.bas",193
	MVII #840,R0
	MVO R0,_mobs+2
	MVII #520,R0
	MVO R0,_mobs+10
	MVII #6585,R0
	MVO R0,_mobs+18
	;[194] 	SPRITE 3,64+$0300,24+$0100,((256+56)*8)+$1001 
	SRCFILE "goatcontest.bas",194
	MVII #832,R0
	MVO R0,_mobs+3
	MVII #280,R0
	MVO R0,_mobs+11
	MVII #6593,R0
	MVO R0,_mobs+19
	;[195] 	SPRITE 4,56+$0300,32+$0200, ((256+57)*8)+$1001 
	SRCFILE "goatcontest.bas",195
	MVII #824,R0
	MVO R0,_mobs+4
	MVII #544,R0
	MVO R0,_mobs+12
	MVII #6601,R0
	MVO R0,_mobs+20
	;[196] 	
	SRCFILE "goatcontest.bas",196
	;[197] title_anim:
	SRCFILE "goatcontest.bas",197
	; TITLE_ANIM
Q24:	;[198]       
	SRCFILE "goatcontest.bas",198
	;[199] 	FOR i = 1 to 255
	SRCFILE "goatcontest.bas",199
	MVII #1,R0
	MVO R0,V32
T1:
	;[200] 	  SPRITE 5,p1x+$300,78+(i/64)+$100+$0080,((256+58)*8)+#goat1color ' goat sprite #1
	SRCFILE "goatcontest.bas",200
	MVI V33,R0
	ADDI #768,R0
	MVO R0,_mobs+5
	MVI V32,R0
	SLR R0,2
	SLR R0,2
	SLR R0,2
	ADDI #462,R0
	MVO R0,_mobs+13
	MVII #2512,R0
	ADD V31,R0
	MVO R0,_mobs+21
	;[201] 	  SPRITE 6,p1x+$300+8,78+(i/64)+$100+$0080,((256+60)*8)+#goat1color ' goat sprite #2, 8 pixels to the right
	SRCFILE "goatcontest.bas",201
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+6
	MVI V32,R0
	SLR R0,2
	SLR R0,2
	SLR R0,2
	ADDI #462,R0
	MVO R0,_mobs+14
	MVII #2528,R0
	ADD V31,R0
	MVO R0,_mobs+22
	;[202] 	  SPRITE 7,p1x+$300+8,78+(i/64)+$100,((256+62)*8)+$1003 ' goat sprite #3, 8 pixels to the right
	SRCFILE "goatcontest.bas",202
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+7
	MVI V32,R0
	SLR R0,2
	SLR R0,2
	SLR R0,2
	ADDI #334,R0
	MVO R0,_mobs+15
	MVII #6643,R0
	MVO R0,_mobs+23
	;[203] 
	SRCFILE "goatcontest.bas",203
	;[204] 	 c1=CONT
	SRCFILE "goatcontest.bas",204
	MVI 510,R0
	XOR 511,R0
	MVO R0,V34
	;[205] 	 IF c1 THEN
	SRCFILE "goatcontest.bas",205
	MVI V34,R0
	TSTR R0
	BEQ T2
	;[206] 	    'allow for stage selection, or to skip directly to the ending animation
	SRCFILE "goatcontest.bas",206
	;[207] 	    IF c1=129 THEN stage=0:GOTO init_game
	SRCFILE "goatcontest.bas",207
	MVI V34,R0
	CMPI #129,R0
	BNE T3
	CLRR R0
	MVO R0,V19
	B Q25
T3:
	;[208] 	    IF c1=65 THEN stage=1:GOTO init_game
	SRCFILE "goatcontest.bas",208
	MVI V34,R0
	CMPI #65,R0
	BNE T4
	MVII #1,R0
	MVO R0,V19
	B Q25
T4:
	;[209] 	    IF c1=33 THEN stage=2:GOTO init_game
	SRCFILE "goatcontest.bas",209
	MVI V34,R0
	CMPI #33,R0
	BNE T5
	MVII #2,R0
	MVO R0,V19
	B Q25
T5:
	;[210] 	    IF c1=130 THEN stage=3:GOTO init_game
	SRCFILE "goatcontest.bas",210
	MVI V34,R0
	CMPI #130,R0
	BNE T6
	MVII #3,R0
	MVO R0,V19
	B Q25
T6:
	;[211] 	    IF c1=66 THEN GOTO end_cheat
	SRCFILE "goatcontest.bas",211
	MVI V34,R0
	CMPI #66,R0
	BEQ Q26
	;[212] 	    GOTO init_game ' any other input starts the game
	SRCFILE "goatcontest.bas",212
	B Q25
	;[213] 	 END IF
	SRCFILE "goatcontest.bas",213
T2:
	;[214] 
	SRCFILE "goatcontest.bas",214
	;[215] 	NEXT i
	SRCFILE "goatcontest.bas",215
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #255,R0
	BLE T1
	;[216] 
	SRCFILE "goatcontest.bas",216
	;[217] 	GOTO title_anim
	SRCFILE "goatcontest.bas",217
	B Q24
	;[218] 	
	SRCFILE "goatcontest.bas",218
	;[219] init_game:
	SRCFILE "goatcontest.bas",219
	; INIT_GAME
Q25:	;[220] 	GOSUB debounce_input
	SRCFILE "goatcontest.bas",220
	CALL Q28
	;[221] 	GOSUB reset_sprites
	SRCFILE "goatcontest.bas",221
	CALL Q4
	;[222] 	CLS
	SRCFILE "goatcontest.bas",222
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[223] 	PLAY off
	SRCFILE "goatcontest.bas",223
	CLRR R0
	CALL _play_music
	;[224] 	WAIT
	SRCFILE "goatcontest.bas",224
	CALL _wait
	;[225] 	
	SRCFILE "goatcontest.bas",225
	;[226] new_stage:
	SRCFILE "goatcontest.bas",226
	; NEW_STAGE
Q29:	;[227] 	
	SRCFILE "goatcontest.bas",227
	;[228] 	CLS
	SRCFILE "goatcontest.bas",228
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[229] 	PLAY off
	SRCFILE "goatcontest.bas",229
	CLRR R0
	CALL _play_music
	;[230] 	WAIT
	SRCFILE "goatcontest.bas",230
	CALL _wait
	;[231] 	
	SRCFILE "goatcontest.bas",231
	;[232] 	GOSUB reset_vals
	SRCFILE "goatcontest.bas",232
	CALL Q5
	;[233] 	GOSUB reset_sprites
	SRCFILE "goatcontest.bas",233
	CALL Q4
	;[234] 	
	SRCFILE "goatcontest.bas",234
	;[235] 	'define objects for the stage, color is set individually
	SRCFILE "goatcontest.bas",235
	;[236] 	#obj4sprite=((256+objbaseaddr+(4*stage)+0)*8)
	SRCFILE "goatcontest.bas",236
	MVII #256,R0
	ADD V30,R0
	MVI V19,R1
	SLL R1,2
	ADDR R1,R0
	SLL R0,2
	ADDR R0,R0
	NOP
	MVO R0,V35
	;[237] 	#obj5sprite=((256+objbaseaddr+(4*stage)+1)*8)
	SRCFILE "goatcontest.bas",237
	MVII #256,R0
	ADD V30,R0
	MVI V19,R1
	SLL R1,2
	ADDR R1,R0
	INCR R0
	SLL R0,2
	ADDR R0,R0
	MVO R0,V36
	;[238] 	#obj6sprite=((256+objbaseaddr+(4*stage)+2)*8)
	SRCFILE "goatcontest.bas",238
	MVII #256,R0
	ADD V30,R0
	MVI V19,R1
	SLL R1,2
	ADDR R1,R0
	ADDI #2,R0
	SLL R0,2
	ADDR R0,R0
	MVO R0,V37
	;[239] 	#rocksprite=((256+objbaseaddr+(4*stage)+3)*8)
	SRCFILE "goatcontest.bas",239
	MVII #256,R0
	ADD V30,R0
	MVI V19,R1
	SLL R1,2
	ADDR R1,R0
	ADDI #3,R0
	SLL R0,2
	ADDR R0,R0
	MVO R0,V38
	;[240] 	
	SRCFILE "goatcontest.bas",240
	;[241] 	'and select the stage itself
	SRCFILE "goatcontest.bas",241
	;[242] 	IF stage=0 THEN GOSUB stage_spring
	SRCFILE "goatcontest.bas",242
	MVI V19,R0
	TSTR R0
	BNE T8
	CALL Q30
T8:
	;[243] 	IF stage=1 THEN GOSUB stage_summer
	SRCFILE "goatcontest.bas",243
	MVI V19,R0
	CMPI #1,R0
	BNE T9
	CALL Q31
T9:
	;[244] 	IF stage=2 THEN GOSUB stage_fall
	SRCFILE "goatcontest.bas",244
	MVI V19,R0
	CMPI #2,R0
	BNE T10
	CALL Q32
T10:
	;[245] 	IF stage=3 THEN GOSUB stage_winter
	SRCFILE "goatcontest.bas",245
	MVI V19,R0
	CMPI #3,R0
	BNE T11
	CALL Q33
T11:
	;[246] 	
	SRCFILE "goatcontest.bas",246
	;[247] 	'set up environment for nom meter:
	SRCFILE "goatcontest.bas",247
	;[248] 	'divide max stage score into 64 ticks - CONVERT THIS TO 16 BIT VAR LATER!!!!!! (why?)
	SRCFILE "goatcontest.bas",248
	;[249] 	div=#stagescore/64
	SRCFILE "goatcontest.bas",249
	MVI V1,R0
	SLR R0,2
	SLR R0,2
	SLR R0,2
	NOP
	MVO R0,V39
	;[250] 	
	SRCFILE "goatcontest.bas",250
	;[251] 	'now make 8 bit versions of the small stage score, that maxes at 64
	SRCFILE "goatcontest.bas",251
	;[252] 	smallstagescore=#stagescore/div
	SRCFILE "goatcontest.bas",252
	MVI V1,R0
	MVI V39,R1
	CALL uf_udiv16
	MVO R0,V40
	;[253] 
	SRCFILE "goatcontest.bas",253
	;[254] 	'and divide the max state score into 8 larger chunks (for full cards)
	SRCFILE "goatcontest.bas",254
	;[255] 	segdiv=smallstagescore/8
	SRCFILE "goatcontest.bas",255
	MVI V40,R0
	SLR R0,2
	SLR R0,1
	NOP
	MVO R0,V41
	;[256] 	
	SRCFILE "goatcontest.bas",256
	;[257] 	'reset this, to black out the nom meter
	SRCFILE "goatcontest.bas",257
	;[258] 	smallscore=0
	SRCFILE "goatcontest.bas",258
	CLRR R0
	MVO R0,V42
	;[259] 	
	SRCFILE "goatcontest.bas",259
	;[260] 	WAIT
	SRCFILE "goatcontest.bas",260
	CALL _wait
	;[261] 	DEFINE 0,16,drawings1 ' we can only safely load 16 cards per DEFINE statement
	SRCFILE "goatcontest.bas",261
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q21,R0
	MVO R0,_gram_bitmap
	;[262] 	WAIT
	SRCFILE "goatcontest.bas",262
	CALL _wait
	;[263] 	DEFINE 16,16,drawings2 ' so split it up into groups of 16 as necessary
	SRCFILE "goatcontest.bas",263
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q34,R0
	MVO R0,_gram_bitmap
	;[264] 	WAIT
	SRCFILE "goatcontest.bas",264
	CALL _wait
	;[265] 	DEFINE 32,16,drawings3 
	SRCFILE "goatcontest.bas",265
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q35,R0
	MVO R0,_gram_bitmap
	;[266] 	WAIT
	SRCFILE "goatcontest.bas",266
	CALL _wait
	;[267] 	DEFINE 48,12,drawings4
	SRCFILE "goatcontest.bas",267
	MVII #48,R0
	MVO R0,_gram_target
	MVII #12,R0
	MVO R0,_gram_total
	MVII #Q36,R0
	MVO R0,_gram_bitmap
	;[268] 	WAIT
	SRCFILE "goatcontest.bas",268
	CALL _wait
	;[269] 	
	SRCFILE "goatcontest.bas",269
	;[270] 	'the earlier we start randomization the better
	SRCFILE "goatcontest.bas",270
	;[271] 	GOSUB rand_farmer
	SRCFILE "goatcontest.bas",271
	CALL Q37
	;[272] 	
	SRCFILE "goatcontest.bas",272
	;[273] 	' made it past winter and beat the game
	SRCFILE "goatcontest.bas",273
	;[274] 	IF stage=4 THEN GOTO ending
	SRCFILE "goatcontest.bas",274
	MVI V19,R0
	CMPI #4,R0
	BEQ Q38
	;[275]   
	SRCFILE "goatcontest.bas",275
	;[276] 	' set goat colors according to stage
	SRCFILE "goatcontest.bas",276
	;[277] 	#goat1sprite=$800 OR #goat1color 'sprite 0, set to arbitrary color 
	SRCFILE "goatcontest.bas",277
	MVII #2048,R0
	MVI V31,R4
	COMR R4
	ANDR R4,R0
	XOR V31,R0
	MVO R0,V26
	;[278] 	#goat2sprite=$810 OR #goat1color 'sprite 1, set to arbitrary color 
	SRCFILE "goatcontest.bas",278
	MVII #2064,R0
	MVI V31,R4
	COMR R4
	ANDR R4,R0
	XOR V31,R0
	MVO R0,V27
	;[279] 	#goat3sprite=$840 OR $1003 'sprite 2, set to brown 
	SRCFILE "goatcontest.bas",279
	MVII #6211,R0
	MVO R0,V28
	;[280] 
	SRCFILE "goatcontest.bas",280
	;[281] 	'draw our gameboard
	SRCFILE "goatcontest.bas",281
	;[282] 	IF stage=0 THEN MODE 0,0,14,0,0:WAIT:SCREEN screen_spring:WAIT
	SRCFILE "goatcontest.bas",282
	MVI V19,R0
	TSTR R0
	BNE T13
	MVII #3584,R0
	MVO R0,_color
	MVII #1,R0
	MVO R0,_mode_select
	CALL _wait
	MVII #Q39,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	CALL _wait
T13:
	;[283] 	IF stage=1 THEN MODE 0,0,4,0,0:WAIT:SCREEN screen_spring:WAIT
	SRCFILE "goatcontest.bas",283
	MVI V19,R0
	CMPI #1,R0
	BNE T14
	MVII #1024,R0
	MVO R0,_color
	MVII #1,R0
	MVO R0,_mode_select
	CALL _wait
	MVII #Q39,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	CALL _wait
T14:
	;[284] 	IF stage=2 THEN MODE 0,0,3,0,0:WAIT:SCREEN screen_fall:WAIT
	SRCFILE "goatcontest.bas",284
	MVI V19,R0
	CMPI #2,R0
	BNE T15
	MVII #768,R0
	MVO R0,_color
	MVII #1,R0
	MVO R0,_mode_select
	CALL _wait
	MVII #Q40,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	CALL _wait
T15:
	;[285] 	IF stage=3 THEN MODE 0,0,7,0,0:WAIT:SCREEN screen_winter:WAIT
	SRCFILE "goatcontest.bas",285
	MVI V19,R0
	CMPI #3,R0
	BNE T16
	MVII #1792,R0
	MVO R0,_color
	MVII #1,R0
	MVO R0,_mode_select
	CALL _wait
	MVII #Q41,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	CALL _wait
T16:
	;[286] 	
	SRCFILE "goatcontest.bas",286
	;[287] 	
	SRCFILE "goatcontest.bas",287
	;[288] main_goat:
	SRCFILE "goatcontest.bas",288
	; MAIN_GOAT
Q42:	;[289] 	PRINT AT 0 COLOR 6,"NOM"
	SRCFILE "goatcontest.bas",289
	MVII #512,R0
	MVO R0,_screen
	MVII #6,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #368,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[290] 	'print start and end segments of the nom meter
	SRCFILE "goatcontest.bas",290
	;[291] 	PRINT AT 3,((256+59)*8)+6
	SRCFILE "goatcontest.bas",291
	MVII #515,R0
	MVO R0,_screen
	MVII #2526,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[292] 	PRINT AT 12,((256+51)*8)+6
	SRCFILE "goatcontest.bas",292
	MVII #524,R0
	MVO R0,_screen
	MVII #2462,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[293] 
	SRCFILE "goatcontest.bas",293
	;[294] 	GOSUB draw_nom_meter
	SRCFILE "goatcontest.bas",294
	CALL Q43
	;[295] 	GOSUB draw_lives
	SRCFILE "goatcontest.bas",295
	CALL Q44
	;[296] 	
	SRCFILE "goatcontest.bas",296
	;[297] 	'stage advance check here
	SRCFILE "goatcontest.bas",297
	;[298] 	IF #score>=#stagescore THEN #score=0:stage=stage+1:GOSUB stage_complete:GOTO new_stage
	SRCFILE "goatcontest.bas",298
	MVI V12,R0
	CMP V1,R0
	BLT T17
	CLRR R0
	MVO R0,V12
	MVI V19,R0
	INCR R0
	MVO R0,V19
	CALL Q45
	B Q29
T17:
	;[299] 	
	SRCFILE "goatcontest.bas",299
	;[300] 	'when the button is pressed, KICK! plus set a flag to force the player to release the button before they can kick again
	SRCFILE "goatcontest.bas",300
	;[301] 	IF CONT1.BUTTON AND fliptimer=0 AND flipcooldown=0 AND buttonflag=0 THEN goatflip=4:buttonflag=1 
	SRCFILE "goatcontest.bas",301
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	MVI V4,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	MVI V5,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	MVI V25,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T18
	MVII #4,R0
	MVO R0,V24
	MVII #1,R0
	MVO R0,V25
T18:
	;[302] 	IF CONT1.BUTTON = 0 THEN buttonflag=0
	SRCFILE "goatcontest.bas",302
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE T19
	CLRR R0
	MVO R0,V25
T19:
	;[303] 
	SRCFILE "goatcontest.bas",303
	;[304] 	IF goatflip=0 THEN GOSUB draw_goat_plain ELSE GOSUB draw_goat_kick
	SRCFILE "goatcontest.bas",304
	MVI V24,R0
	TSTR R0
	BNE T20
	CALL Q46
	B T21
T20:
	CALL Q47
T21:
	;[305] 
	SRCFILE "goatcontest.bas",305
	;[306] 	SPRITE 3,p2x+$300,p2y+$100+$0080,#farmersprite ' farmer dan sprite 
	SRCFILE "goatcontest.bas",306
	MVI V43,R0
	ADDI #768,R0
	MVO R0,_mobs+3
	MVI V44,R0
	ADDI #384,R0
	MVO R0,_mobs+11
	MVI V29,R0
	MVO R0,_mobs+19
	;[307] 	
	SRCFILE "goatcontest.bas",307
	;[308] 	WAIT ' col det wait - very NB to have here (ish)
	SRCFILE "goatcontest.bas",308
	CALL _wait
	;[309] 	'goat ate sprite 4
	SRCFILE "goatcontest.bas",309
	;[310] 	IF COL1 AND $10 THEN IF goatflip=0 THEN IF objy(0) < (p1y+9) THEN objhit=1:#points=point4val*(level+1):GOSUB point_scored 
	SRCFILE "goatcontest.bas",310
	MVI _col1,R0
	ANDI #16,R0
	BEQ T22
	MVI V24,R0
	TSTR R0
	BNE T23
	MVI Q8,R0
	MVI V45,R1
	ADDI #9,R1
	CMPR R1,R0
	BGE T24
	MVII #1,R0
	MVO R0,V11
	MVI V18,R0
	INCR R0
	MULT R0,R4,40
	MVO R0,V15
	CALL Q48
T24:
T23:
T22:
	;[311] 	'goat ate sprite 5
	SRCFILE "goatcontest.bas",311
	;[312] 	IF COL1 AND $20 THEN IF goatflip=0 THEN IF objy(1) < (p1y+8) THEN objhit=2:#points=point5val*(level+1):GOSUB point_scored 
	SRCFILE "goatcontest.bas",312
	MVI _col1,R0
	ANDI #32,R0
	BEQ T25
	MVI V24,R0
	TSTR R0
	BNE T26
	MVI Q8+1,R0
	MVI V45,R1
	ADDI #8,R1
	CMPR R1,R0
	BGE T27
	MVII #2,R0
	MVO R0,V11
	MVI V18,R0
	INCR R0
	MULT R0,R4,60
	MVO R0,V15
	CALL Q48
T27:
T26:
T25:
	;[313] 	'goat ate sprite 6
	SRCFILE "goatcontest.bas",313
	;[314] 	IF COL1 AND $40 THEN IF goatflip=0 THEN IF objy(2) < (p1y+8) THEN objhit=3:#points=point6val*(level+1):GOSUB point_scored 
	SRCFILE "goatcontest.bas",314
	MVI _col1,R0
	ANDI #64,R0
	BEQ T28
	MVI V24,R0
	TSTR R0
	BNE T29
	MVI Q8+2,R0
	MVI V45,R1
	ADDI #8,R1
	CMPR R1,R0
	BGE T30
	MVII #3,R0
	MVO R0,V11
	MVI V18,R0
	INCR R0
	MULT R0,R4,90
	MVO R0,V15
	CALL Q48
T30:
T29:
T28:
	;[315] 	'goat (right side, ie: front) got hit by a rock
	SRCFILE "goatcontest.bas",315
	;[316] 	IF COL1 AND $80 THEN IF goatflip=0 THEN objhit=4:#points=point7val*stage:GOTO rock_hit 
	SRCFILE "goatcontest.bas",316
	MVI _col1,R0
	ANDI #128,R0
	BEQ T31
	MVI V24,R0
	TSTR R0
	BNE T32
	MVII #4,R0
	MVO R0,V11
	MVI V19,R0
	MVII #250,R5
	CLRR R4
	CLRC
	RRC R0,1
	BEQ T34
T33:
	BNC $+3
	ADDR R5,R4
	ADDR R5,R5
	SARC R0,1
	BNE T33
T34:
	BNC $+3
	ADDR R5,R4
	MOVR R4,R0
	MVO R0,V15
	B Q49
T32:
T31:
	;[317] 	'goat (left side, ie: back, ie: he kicked it) got hit by a rock, IF flipped (ie: kicking)
	SRCFILE "goatcontest.bas",317
	;[318] 	IF COL0 AND $80 THEN IF goatflip=0 THEN objhit=4:#points=point7val*stage:GOTO rock_hit ELSE #points=point7val*(level+1):GOTO rock_point
	SRCFILE "goatcontest.bas",318
	MVI _col0,R0
	ANDI #128,R0
	BEQ T35
	MVI V24,R0
	TSTR R0
	BNE T36
	MVII #4,R0
	MVO R0,V11
	MVI V19,R0
	MVII #250,R5
	CLRR R4
	CLRC
	RRC R0,1
	BEQ T38
T37:
	BNC $+3
	ADDR R5,R4
	ADDR R5,R5
	SARC R0,1
	BNE T37
T38:
	BNC $+3
	ADDR R5,R4
	MOVR R4,R0
	MVO R0,V15
	B Q49
	B T39
T36:
	MVI V18,R0
	INCR R0
	MVII #250,R5
	CLRR R4
	CLRC
	RRC R0,1
	BEQ T41
T40:
	BNC $+3
	ADDR R5,R4
	ADDR R5,R5
	SARC R0,1
	BNE T40
T41:
	BNC $+3
	ADDR R5,R4
	MOVR R4,R0
	MVO R0,V15
	B Q50
T39:
T35:
	;[319] 	
	SRCFILE "goatcontest.bas",319
	;[320] 	'move the objects - unfortunately can't iterate SPRITE number (yet?)
	SRCFILE "goatcontest.bas",320
	;[321] 	IF objtype(0)>0 THEN SPRITE 4,objx(0)+$300,objy(0)+$100,#obj4sprite:objx(0)=objx(0)-obj4speed
	SRCFILE "goatcontest.bas",321
	MVI Q6,R0
	CMPI #0,R0
	BLE T42
	MVI Q7,R0
	ADDI #768,R0
	MVO R0,_mobs+4
	MVI Q8,R0
	ADDI #256,R0
	MVO R0,_mobs+12
	MVI V35,R0
	MVO R0,_mobs+20
	MVI Q7,R0
	SUB V20,R0
	MVO R0,Q7
T42:
	;[322] 	IF objx(0) > 170 THEN objx(0)=0:objtype(0)=0:objlive=objlive-1:#points=point4val/scorefactor*(level+1):GOSUB sub_points
	SRCFILE "goatcontest.bas",322
	MVI Q7,R0
	CMPI #170,R0
	BLE T43
	CLRR R0
	MVO R0,Q7
	MVO R0,Q6
	MVI V10,R0
	DECR R0
	MVO R0,V10
	MVII #40,R0
	MVI V16,R4
	MOVR R0,R5
	TSTR R4
	BEQ T44
	MVII #-1,R0
T45:
	INCR R0
	SUBR R4,R5
	BC T45
T44:
	MVI V18,R1
	INCR R1
	CLRR R4
	CLRC
	RRC R0,1
	BEQ T47
T46:
	BNC $+3
	ADDR R1,R4
	ADDR R1,R1
	SARC R0,1
	BNE T46
T47:
	BNC $+3
	ADDR R1,R4
	MOVR R4,R0
	MVO R0,V15
	CALL Q51
T43:
	;[323] 	
	SRCFILE "goatcontest.bas",323
	;[324] 	IF objtype(1)>0 THEN SPRITE 5,objx(1)+$300,objy(1)+$100,#obj5sprite:objx(1)=objx(1)-obj5speed
	SRCFILE "goatcontest.bas",324
	MVI Q6+1,R0
	CMPI #0,R0
	BLE T48
	MVI Q7+1,R0
	ADDI #768,R0
	MVO R0,_mobs+5
	MVI Q8+1,R0
	ADDI #256,R0
	MVO R0,_mobs+13
	MVI V36,R0
	MVO R0,_mobs+21
	MVI Q7+1,R0
	SUB V21,R0
	MVO R0,Q7+1
T48:
	;[325] 	IF objx(1) > 170 THEN objx(1)=0:objtype(1)=0:objlive=objlive-1:#points=point5val/scorefactor*(level+1):GOSUB sub_points
	SRCFILE "goatcontest.bas",325
	MVI Q7+1,R0
	CMPI #170,R0
	BLE T49
	CLRR R0
	MVO R0,Q7+1
	MVO R0,Q6+1
	MVI V10,R0
	DECR R0
	MVO R0,V10
	MVII #60,R0
	MVI V16,R4
	MOVR R0,R5
	TSTR R4
	BEQ T50
	MVII #-1,R0
T51:
	INCR R0
	SUBR R4,R5
	BC T51
T50:
	MVI V18,R1
	INCR R1
	CLRR R4
	CLRC
	RRC R0,1
	BEQ T53
T52:
	BNC $+3
	ADDR R1,R4
	ADDR R1,R1
	SARC R0,1
	BNE T52
T53:
	BNC $+3
	ADDR R1,R4
	MOVR R4,R0
	MVO R0,V15
	CALL Q51
T49:
	;[326] 	
	SRCFILE "goatcontest.bas",326
	;[327] 	IF objtype(2)>0 THEN SPRITE 6,objx(2)+$300,objy(2)+$100,#obj6sprite:objx(2)=objx(2)-obj6speed
	SRCFILE "goatcontest.bas",327
	MVI Q6+2,R0
	CMPI #0,R0
	BLE T54
	MVI Q7+2,R0
	ADDI #768,R0
	MVO R0,_mobs+6
	MVI Q8+2,R0
	ADDI #256,R0
	MVO R0,_mobs+14
	MVI V37,R0
	MVO R0,_mobs+22
	MVI Q7+2,R0
	SUB V22,R0
	MVO R0,Q7+2
T54:
	;[328] 	IF objx(2) > 170 THEN objx(2)=0:objtype(2)=0:objlive=objlive-1:#points=point6val/scorefactor*(level+1):GOSUB sub_points
	SRCFILE "goatcontest.bas",328
	MVI Q7+2,R0
	CMPI #170,R0
	BLE T55
	CLRR R0
	MVO R0,Q7+2
	MVO R0,Q6+2
	MVI V10,R0
	DECR R0
	MVO R0,V10
	MVII #90,R0
	MVI V16,R4
	MOVR R0,R5
	TSTR R4
	BEQ T56
	MVII #-1,R0
T57:
	INCR R0
	SUBR R4,R5
	BC T57
T56:
	MVI V18,R1
	INCR R1
	CLRR R4
	CLRC
	RRC R0,1
	BEQ T59
T58:
	BNC $+3
	ADDR R1,R4
	ADDR R1,R1
	SARC R0,1
	BNE T58
T59:
	BNC $+3
	ADDR R1,R4
	MOVR R4,R0
	MVO R0,V15
	CALL Q51
T55:
	;[329] 	
	SRCFILE "goatcontest.bas",329
	;[330] 	IF objtype(3)>0 THEN SPRITE 7,objx(3)+$300,objy(3)+$100,#rocksprite:objx(3)=objx(3)-obj7speed
	SRCFILE "goatcontest.bas",330
	MVI Q6+3,R0
	CMPI #0,R0
	BLE T60
	MVI Q7+3,R0
	ADDI #768,R0
	MVO R0,_mobs+7
	MVI Q8+3,R0
	ADDI #256,R0
	MVO R0,_mobs+15
	MVI V38,R0
	MVO R0,_mobs+23
	MVI Q7+3,R0
	SUB V23,R0
	MVO R0,Q7+3
T60:
	;[331] 	IF objx(3) > 170 THEN objx(3)=0:objtype(3)=0:SPRITE 7,0,0,0:objlive=objlive-1:IF stage=3 THEN #points=point7val/scorefactor*(level+1):GOSUB sub_points 
	SRCFILE "goatcontest.bas",331
	MVI Q7+3,R0
	CMPI #170,R0
	BLE T61
	CLRR R0
	MVO R0,Q7+3
	MVO R0,Q6+3
	NOP
	MVO R0,_mobs+7
	MVO R0,_mobs+15
	NOP
	MVO R0,_mobs+23
	MVI V10,R0
	DECR R0
	MVO R0,V10
	MVI V19,R0
	CMPI #3,R0
	BNE T62
	MVII #250,R0
	MVI V16,R4
	MOVR R0,R5
	TSTR R4
	BEQ T63
	MVII #-1,R0
T64:
	INCR R0
	SUBR R4,R5
	BC T64
T63:
	MVI V18,R1
	INCR R1
	CLRR R4
	CLRC
	RRC R0,1
	BEQ T66
T65:
	BNC $+3
	ADDR R1,R4
	ADDR R1,R1
	SARC R0,1
	BNE T65
T66:
	BNC $+3
	ADDR R1,R4
	MOVR R4,R0
	MVO R0,V15
	CALL Q51
T62:
T61:
	;[332] 	' ^ have to de-sprite the rock here. also drop points for missing the rock on the final stage
	SRCFILE "goatcontest.bas",332
	;[333] 	
	SRCFILE "goatcontest.bas",333
	;[334] 	'move the goat
	SRCFILE "goatcontest.bas",334
	;[335] 	IF CONT1.UP THEN p1y=p1y-p1mov(level):goatwalk=1
	SRCFILE "goatcontest.bas",335
	MVI 511,R0
	COMR R0
	ANDI #4,R0
	BEQ T67
	MVI V45,R0
	MVII #Q13,R3
	ADD V18,R3
	SUB@ R3,R0
	MVO R0,V45
	MVII #1,R0
	MVO R0,V6
T67:
	;[336] 	IF CONT1.DOWN THEN p1y=p1y+p1mov(level):goatwalk=1
	SRCFILE "goatcontest.bas",336
	MVI 511,R0
	COMR R0
	ANDI #1,R0
	BEQ T68
	MVII #Q13,R3
	ADD V18,R3
	MVI@ R3,R0
	ADD V45,R0
	MVO R0,V45
	MVII #1,R0
	MVO R0,V6
T68:
	;[337] 	IF CONT1.LEFT THEN p1x=p1x-p1mov(level):goatwalk=1
	SRCFILE "goatcontest.bas",337
	MVI 511,R0
	COMR R0
	ANDI #8,R0
	BEQ T69
	MVI V33,R0
	MVII #Q13,R3
	ADD V18,R3
	SUB@ R3,R0
	MVO R0,V33
	MVII #1,R0
	MVO R0,V6
T69:
	;[338] 	IF CONT1.RIGHT THEN p1x=p1x+p1mov(level):goatwalk=1
	SRCFILE "goatcontest.bas",338
	MVI 511,R0
	COMR R0
	ANDI #2,R0
	BEQ T70
	MVII #Q13,R3
	ADD V18,R3
	MVI@ R3,R0
	ADD V33,R0
	MVO R0,V33
	MVII #1,R0
	MVO R0,V6
T70:
	;[339] 	IF p1x<=xleft THEN p1x=xleft
	SRCFILE "goatcontest.bas",339
	MVI V33,R0
	CMPI #10,R0
	BGT T71
	MVII #10,R0
	MVO R0,V33
T71:
	;[340] 	IF p1x>=xright THEN p1x=xright
	SRCFILE "goatcontest.bas",340
	MVI V33,R0
	CMPI #110,R0
	BLT T72
	MVII #110,R0
	MVO R0,V33
T72:
	;[341] 	IF p1y<=ytop THEN p1y=ytop
	SRCFILE "goatcontest.bas",341
	MVI V45,R0
	CMPI #10,R0
	BGT T73
	MVII #10,R0
	MVO R0,V45
T73:
	;[342] 	IF p1y>=ybot THEN p1y=ybot
	SRCFILE "goatcontest.bas",342
	MVI V45,R0
	CMPI #88,R0
	BLT T74
	MVII #88,R0
	MVO R0,V45
T74:
	;[343] 	
	SRCFILE "goatcontest.bas",343
	;[344] 	'make sure farmer color is correct for the level
	SRCFILE "goatcontest.bas",344
	;[345] 	#farmersprite=$0850 OR level+1
	SRCFILE "goatcontest.bas",345
	MVII #2128,R0
	MVI V18,R1
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVO R0,V29
	;[346] 	'and make sure he does not disappear into the background color (kludge kludge kludge)
	SRCFILE "goatcontest.bas",346
	;[347] 	IF stage=1 and level=3 THEN #farmersprite=$0850 OR $1000
	SRCFILE "goatcontest.bas",347
	MVI V19,R0
	CMPI #1,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V18,R1
	CMPI #3,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T75
	MVII #6224,R0
	MVO R0,V29
T75:
	;[348] 	IF stage=2 and level=2 THEN #farmersprite=$0850 OR $1001
	SRCFILE "goatcontest.bas",348
	MVI V19,R0
	CMPI #2,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V18,R1
	CMPI #2,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T76
	MVII #6225,R0
	MVO R0,V29
T76:
	;[349] 
	SRCFILE "goatcontest.bas",349
	;[350] 	' alternate sprites for goat and farmer
	SRCFILE "goatcontest.bas",350
	;[351] 	IF spritetimer>=7 AND goatwalk=1 THEN #goat1sprite=#goat1sprite XOR $0020:#goat2sprite=#goat2sprite XOR $0020:goatwalk=0
	SRCFILE "goatcontest.bas",351
	MVI V2,R0
	CMPI #7,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI V6,R1
	CMPI #1,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T77
	MVI V26,R0
	XORI #32,R0
	MVO R0,V26
	MVI V27,R0
	XORI #32,R0
	MVO R0,V27
	CLRR R0
	MVO R0,V6
T77:
	;[352] 	IF spritetimer>=7 THEN #farmersprite=#farmersprite XOR $0030: spritetimer=0
	SRCFILE "goatcontest.bas",352
	MVI V2,R0
	CMPI #7,R0
	BLT T78
	MVI V29,R0
	XORI #48,R0
	MVO R0,V29
	CLRR R0
	MVO R0,V2
T78:
	;[353] 		
	SRCFILE "goatcontest.bas",353
	;[354] 	'this controls how quickly the farmer fires objects, too small is too clustered
	SRCFILE "goatcontest.bas",354
	;[355] 	IF movetimer>25 THEN GOSUB rand_farmer
	SRCFILE "goatcontest.bas",355
	MVI V3,R0
	CMPI #25,R0
	BLE T79
	CALL Q37
T79:
	;[356] 	GOSUB move_farmer
	SRCFILE "goatcontest.bas",356
	CALL Q52
	;[357] 	
	SRCFILE "goatcontest.bas",357
	;[358] 	spritetimer=spritetimer+1
	SRCFILE "goatcontest.bas",358
	MVI V2,R0
	INCR R0
	MVO R0,V2
	;[359] 	movetimer=movetimer+1
	SRCFILE "goatcontest.bas",359
	MVI V3,R0
	INCR R0
	MVO R0,V3
	;[360] 
	SRCFILE "goatcontest.bas",360
	;[361] 	'sanity check. very rare situations can have this go to -1
	SRCFILE "goatcontest.bas",361
	;[362] 	IF objlive>100 THEN objlive=0
	SRCFILE "goatcontest.bas",362
	MVI V10,R0
	CMPI #100,R0
	BLE T80
	CLRR R0
	MVO R0,V10
T80:
	;[363] 	
	SRCFILE "goatcontest.bas",363
	;[364] 	'reset the flip/kick after a certain amount of time
	SRCFILE "goatcontest.bas",364
	;[365] 	IF goatflip=4 THEN fliptimer=fliptimer+1
	SRCFILE "goatcontest.bas",365
	MVI V24,R0
	CMPI #4,R0
	BNE T81
	MVI V4,R0
	INCR R0
	MVO R0,V4
T81:
	;[366] 	IF fliptimer > 7 THEN fliptimer=0:goatflip=0:flipcooldown=flipcooldown+1
	SRCFILE "goatcontest.bas",366
	MVI V4,R0
	CMPI #7,R0
	BLE T82
	CLRR R0
	MVO R0,V4
	MVO R0,V24
	MVI V5,R0
	INCR R0
	MVO R0,V5
T82:
	;[367] 	
	SRCFILE "goatcontest.bas",367
	;[368] 	'we just kicked. make sure we can't kick immediately afterwards
	SRCFILE "goatcontest.bas",368
	;[369] 	IF flipcooldown > 0 THEN flipcooldown=flipcooldown+1
	SRCFILE "goatcontest.bas",369
	MVI V5,R0
	CMPI #0,R0
	BLE T83
	INCR R0
	MVO R0,V5
T83:
	;[370] 	'enough time has passed, let's let him kick again. 
	SRCFILE "goatcontest.bas",370
	;[371] 	IF flipcooldown > 3 THEN flipcooldown=0
	SRCFILE "goatcontest.bas",371
	MVI V5,R0
	CMPI #3,R0
	BLE T84
	CLRR R0
	MVO R0,V5
T84:
	;[372] 	
	SRCFILE "goatcontest.bas",372
	;[373] 	'keep track of how long the goat stands still
	SRCFILE "goatcontest.bas",373
	;[374] 	#idletimer=#idletimer+1
	SRCFILE "goatcontest.bas",374
	MVI V7,R0
	INCR R0
	MVO R0,V7
	;[375] 	IF goatwalk=1 THEN #idletimer=0
	SRCFILE "goatcontest.bas",375
	MVI V6,R0
	CMPI #1,R0
	BNE T85
	CLRR R0
	MVO R0,V7
T85:
	;[376] 	
	SRCFILE "goatcontest.bas",376
	;[377] 	'if long enough, make a sound!
	SRCFILE "goatcontest.bas",377
	;[378] 	IF goatwalk=0 THEN GOSUB goat_idle ELSE #idletimer=0
	SRCFILE "goatcontest.bas",378
	MVI V6,R0
	TSTR R0
	BNE T86
	CALL Q53
	B T87
T86:
	CLRR R0
	MVO R0,V7
T87:
	;[379] 	
	SRCFILE "goatcontest.bas",379
	;[380] 	GOTO main_goat
	SRCFILE "goatcontest.bas",380
	B Q42
	;[381] 	
	SRCFILE "goatcontest.bas",381
	;[382] 
	SRCFILE "goatcontest.bas",382
	;[383] goat_idle:	PROCEDURE
	SRCFILE "goatcontest.bas",383
	; GOAT_IDLE
Q53:	PROC
	BEGIN
	;[384] 	'keep track of how long the goat stands still
	SRCFILE "goatcontest.bas",384
	;[385] 	#idletimer=#idletimer+1
	SRCFILE "goatcontest.bas",385
	MVI V7,R0
	INCR R0
	MVO R0,V7
	;[386] '	IF goatwalk=1 THEN #idletimer=0
	SRCFILE "goatcontest.bas",386
	;[387] 
	SRCFILE "goatcontest.bas",387
	;[388] 	'if long enough, make a sound!
	SRCFILE "goatcontest.bas",388
	;[389] 	IF #idletimer=goat_idle_limit THEN GOSUB goat_bleat:goatwalk=1:#idletimer=0
	SRCFILE "goatcontest.bas",389
	CMPI #400,R0
	BNE T88
	CALL Q55
	MVII #1,R0
	MVO R0,V6
	CLRR R0
	MVO R0,V7
T88:
	;[390] 	
	SRCFILE "goatcontest.bas",390
	;[391] 	END
	SRCFILE "goatcontest.bas",391
	RETURN
	ENDP
	;[392] 	
	SRCFILE "goatcontest.bas",392
	;[393] draw_lives:	PROCEDURE
	SRCFILE "goatcontest.bas",393
	; DRAW_LIVES
Q44:	PROC
	BEGIN
	;[394] 	'print goat heads for each extra life remaining (lives-1)
	SRCFILE "goatcontest.bas",394
	;[395] 	FOR i = 1 to lives-1
	SRCFILE "goatcontest.bas",395
	MVII #1,R0
	MVO R0,V32
T89:
	;[396] 	  PRINT AT 12+i,((256+48)*8)+7
	SRCFILE "goatcontest.bas",396
	MVI V32,R0
	ADDI #524,R0
	MVO R0,_screen
	MVII #2439,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[397] 	NEXT i
	SRCFILE "goatcontest.bas",397
	MVI V32,R0
	INCR R0
	MVO R0,V32
	MVI V17,R1
	DECR R1
	CMPR R1,R0
	BLE T89
	;[398] 	
	SRCFILE "goatcontest.bas",398
	;[399] 	'blank out anything afterwards
	SRCFILE "goatcontest.bas",399
	;[400] 	FOR i = lives to 5
	SRCFILE "goatcontest.bas",400
	MVI V17,R0
	MVO R0,V32
T90:
	;[401] 	  PRINT AT 12+i,((256+48)*8)
	SRCFILE "goatcontest.bas",401
	MVI V32,R0
	ADDI #524,R0
	MVO R0,_screen
	MVII #2432,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[402] 	NEXT i
	SRCFILE "goatcontest.bas",402
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #5,R0
	BLE T90
	;[403] 	  
	SRCFILE "goatcontest.bas",403
	;[404]       	END
	SRCFILE "goatcontest.bas",404
	RETURN
	ENDP
	;[405] 	
	SRCFILE "goatcontest.bas",405
	;[406] 	
	SRCFILE "goatcontest.bas",406
	;[407] draw_nom_meter:	PROCEDURE
	SRCFILE "goatcontest.bas",407
	; DRAW_NOM_METER
Q43:	PROC
	BEGIN
	;[408] 	 smallscoretemp=smallscore
	SRCFILE "goatcontest.bas",408
	MVI V42,R0
	MVO R0,V46
	;[409] 	  
	SRCFILE "goatcontest.bas",409
	;[410] 	'at this point, smallstagescore is always 64 and segdiv is always 8. smallscore is the score value out of 64 max, or how many ticks 
	SRCFILE "goatcontest.bas",410
	;[411] 	'should be displayed. smallscoretemp decrements by 8 each time, to check remainders for un or partially filled segments.
	SRCFILE "goatcontest.bas",411
	;[412] 	'smallstagescore and segdiv could obviously be CONST or magic numbers, but left as is for future possibilities
	SRCFILE "goatcontest.bas",412
	;[413] 	
	SRCFILE "goatcontest.bas",413
	;[414] 	FOR i = 1 to 8
	SRCFILE "goatcontest.bas",414
	MVII #1,R0
	MVO R0,V32
T91:
	;[415] 	    IF smallscoretemp >= segdiv THEN PRINT AT 3+i,((256+58)*8)+2:smallscoretemp=smallscoretemp-segdiv ELSE IF smallscoretemp=0 THEN PRINT AT 3+i,((256+58)*8) ELSE PRINT AT 3+i,((256+51+smallscoretemp)*8)+2:smallscoretemp=0
	SRCFILE "goatcontest.bas",415
	MVI V46,R0
	CMP V41,R0
	BLT T92
	MVI V32,R0
	ADDI #515,R0
	MVO R0,_screen
	MVII #2514,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	MVI V46,R0
	SUB V41,R0
	MVO R0,V46
	B T93
T92:
	MVI V46,R0
	TSTR R0
	BNE T94
	MVI V32,R0
	ADDI #515,R0
	MVO R0,_screen
	MVII #2512,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	B T95
T94:
	MVI V32,R0
	ADDI #515,R0
	MVO R0,_screen
	MVII #307,R0
	ADD V46,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	CLRR R0
	MVO R0,V46
T95:
T93:
	;[416] 	NEXT i
	SRCFILE "goatcontest.bas",416
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #8,R0
	BLE T91
	;[417] 	
	SRCFILE "goatcontest.bas",417
	;[418] 	END
	SRCFILE "goatcontest.bas",418
	RETURN
	ENDP
	;[419] 
	SRCFILE "goatcontest.bas",419
	;[420] move_farmer:	PROCEDURE
	SRCFILE "goatcontest.bas",420
	; MOVE_FARMER
Q52:	PROC
	BEGIN
	;[421] 	IF farmermove>31 THEN p2y=p2y+p2mov(level)
	SRCFILE "goatcontest.bas",421
	MVI V9,R0
	CMPI #31,R0
	BLE T96
	MVII #Q14,R3
	ADD V18,R3
	MVI@ R3,R0
	ADD V44,R0
	MVO R0,V44
T96:
	;[422] 	IF farmermove<31 THEN p2y=p2y-p2mov(level)
	SRCFILE "goatcontest.bas",422
	MVI V9,R0
	CMPI #31,R0
	BGE T97
	MVI V44,R0
	MVII #Q14,R3
	ADD V18,R3
	SUB@ R3,R0
	MVO R0,V44
T97:
	;[423] 	if p2y>=ybot then p2y=ybot:farmermove=0
	SRCFILE "goatcontest.bas",423
	MVI V44,R0
	CMPI #88,R0
	BLT T98
	MVII #88,R0
	MVO R0,V44
	CLRR R0
	MVO R0,V9
T98:
	;[424] 	if p2y<=ytop+6 then p2y=ytop+6:farmermove=0
	SRCFILE "goatcontest.bas",424
	MVI V44,R0
	CMPI #16,R0
	BGT T99
	MVII #16,R0
	MVO R0,V44
	CLRR R0
	MVO R0,V9
T99:
	;[425] 	
	SRCFILE "goatcontest.bas",425
	;[426] 	END
	SRCFILE "goatcontest.bas",426
	RETURN
	ENDP
	;[427] 	
	SRCFILE "goatcontest.bas",427
	;[428] rand_farmer:	PROCEDURE
	SRCFILE "goatcontest.bas",428
	; RAND_FARMER
Q37:	PROC
	BEGIN
	;[429] 	randseed=randseed + RAND + #score
	SRCFILE "goatcontest.bas",429
	MVI _rand,R0
	ADD V8,R0
	ADD V12,R0
	MVO R0,V8
	;[430] 	farmermove=randseed/4
	SRCFILE "goatcontest.bas",430
	MVI V8,R0
	SLR R0,2
	MVO R0,V9
	;[431] 	movetimer=0
	SRCFILE "goatcontest.bas",431
	CLRR R0
	MVO R0,V3
	;[432] 	IF objlive<4 THEN GOSUB fire_object
	SRCFILE "goatcontest.bas",432
	MVI V10,R0
	CMPI #4,R0
	BGE T100
	CALL Q60
T100:
	;[433] 	    
	SRCFILE "goatcontest.bas",433
	;[434] 	END
	SRCFILE "goatcontest.bas",434
	RETURN
	ENDP
	;[435] 	
	SRCFILE "goatcontest.bas",435
	;[436] fire_object:	PROCEDURE
	SRCFILE "goatcontest.bas",436
	; FIRE_OBJECT
Q60:	PROC
	BEGIN
	;[437] 	'pick an object to fire, 4 possible on screen at any time
	SRCFILE "goatcontest.bas",437
	;[438] 	objpick=RAND/64
	SRCFILE "goatcontest.bas",438
	MVI _rand,R0
	SLR R0,2
	SLR R0,2
	SLR R0,2
	NOP
	MVO R0,V47
	;[439] 	IF objtype(objpick)>0 THEN RETURN ' picked an existing object. don't bother firing
	SRCFILE "goatcontest.bas",439
	MVII #Q6,R3
	ADD V47,R3
	MVI@ R3,R0
	CMPI #0,R0
	BLE T101
	RETURN
T101:
	;[440] 	
	SRCFILE "goatcontest.bas",440
	;[441] 	objlive=objlive+1
	SRCFILE "goatcontest.bas",441
	MVI V10,R0
	INCR R0
	MVO R0,V10
	;[442] 	objtype(objpick)=RAND/64+1:objx(objpick)=p2x:objy(objpick)=p2y
	SRCFILE "goatcontest.bas",442
	MVI _rand,R0
	SLR R0,2
	SLR R0,2
	SLR R0,2
	INCR R0
	MVII #Q6,R3
	ADD V47,R3
	MVO@ R0,R3
	MVI V43,R0
	MVII #Q7,R3
	ADD V47,R3
	MVO@ R0,R3
	MVI V44,R0
	MVII #Q8,R3
	ADD V47,R3
	MVO@ R0,R3
	;[443] 	
	SRCFILE "goatcontest.bas",443
	;[444] 	'this should ensure the speed of thrown objects does not change mid-flight.
	SRCFILE "goatcontest.bas",444
	;[445] 	IF objpick=0 THEN obj4speed=obj4mov(level)
	SRCFILE "goatcontest.bas",445
	MVI V47,R0
	TSTR R0
	BNE T102
	MVII #Q9,R3
	ADD V18,R3
	MVI@ R3,R0
	MVO R0,V20
T102:
	;[446] 	IF objpick=1 THEN obj5speed=obj5mov(level)
	SRCFILE "goatcontest.bas",446
	MVI V47,R0
	CMPI #1,R0
	BNE T103
	MVII #Q10,R3
	ADD V18,R3
	MVI@ R3,R0
	MVO R0,V21
T103:
	;[447] 	IF objpick=2 THEN obj6speed=obj6mov(level)
	SRCFILE "goatcontest.bas",447
	MVI V47,R0
	CMPI #2,R0
	BNE T104
	MVII #Q11,R3
	ADD V18,R3
	MVI@ R3,R0
	MVO R0,V22
T104:
	;[448] 	IF objpick=3 THEN obj7speed=obj7mov(level)
	SRCFILE "goatcontest.bas",448
	MVI V47,R0
	CMPI #3,R0
	BNE T105
	MVII #Q12,R3
	ADD V18,R3
	MVI@ R3,R0
	MVO R0,V23
T105:
	;[449] 	
	SRCFILE "goatcontest.bas",449
	;[450] 	END
	SRCFILE "goatcontest.bas",450
	RETURN
	ENDP
	;[451] 	
	SRCFILE "goatcontest.bas",451
	;[452] eat_sound:	PROCEDURE
	SRCFILE "goatcontest.bas",452
	; EAT_SOUND
Q62:	PROC
	BEGIN
	;[453] 	'play eating noise
	SRCFILE "goatcontest.bas",453
	;[454] 	SOUND 2,700,8
	SRCFILE "goatcontest.bas",454
	MVII #700,R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	MVII #8,R0
	MVO R0,509
	;[455] 	SOUND 3,$53f,7 ' set envelope
	SRCFILE "goatcontest.bas",455
	MVII #1343,R0
	MVO R0,499
	SWAP R0
	MVO R0,503
	MVII #7,R0
	MVO R0,506
	;[456] 	POKE $01fD,$38 ' use envelope for SOUND channel 2
	SRCFILE "goatcontest.bas",456
	MVII #56,R0
	MVII #509,R1
	MVO@ R0,R1
	;[457]  
	SRCFILE "goatcontest.bas",457
	;[458] 	END
	SRCFILE "goatcontest.bas",458
	RETURN
	ENDP
	;[459] 	
	SRCFILE "goatcontest.bas",459
	;[460] point_scored:	PROCEDURE
	SRCFILE "goatcontest.bas",460
	; POINT_SCORED
Q48:	PROC
	BEGIN
	;[461] 	GOSUB eat_sound
	SRCFILE "goatcontest.bas",461
	CALL Q62
	;[462] 		
	SRCFILE "goatcontest.bas",462
	;[463] 	IF objhit=1 THEN objtype(0)=0:SPRITE 4,0,0,0
	SRCFILE "goatcontest.bas",463
	MVI V11,R0
	CMPI #1,R0
	BNE T106
	CLRR R0
	MVO R0,Q6
	MVO R0,_mobs+4
	NOP
	MVO R0,_mobs+12
	MVO R0,_mobs+20
T106:
	;[464] 	IF objhit=2 THEN objtype(1)=0:SPRITE 5,0,0,0
	SRCFILE "goatcontest.bas",464
	MVI V11,R0
	CMPI #2,R0
	BNE T107
	CLRR R0
	MVO R0,Q6+1
	MVO R0,_mobs+5
	NOP
	MVO R0,_mobs+13
	MVO R0,_mobs+21
T107:
	;[465] 	IF objhit=3 THEN objtype(2)=0:SPRITE 6,0,0,0
	SRCFILE "goatcontest.bas",465
	MVI V11,R0
	CMPI #3,R0
	BNE T108
	CLRR R0
	MVO R0,Q6+2
	MVO R0,_mobs+6
	NOP
	MVO R0,_mobs+14
	MVO R0,_mobs+22
T108:
	;[466] 	
	SRCFILE "goatcontest.bas",466
	;[467] 	objhit=0
	SRCFILE "goatcontest.bas",467
	CLRR R0
	MVO R0,V11
	;[468] 	objlive=objlive-1	
	SRCFILE "goatcontest.bas",468
	MVI V10,R0
	DECR R0
	MVO R0,V10
	;[469] 	WAIT
	SRCFILE "goatcontest.bas",469
	CALL _wait
	;[470] 
	SRCFILE "goatcontest.bas",470
	;[471] 	GOSUB add_points
	SRCFILE "goatcontest.bas",471
	CALL Q64
	;[472] 	
	SRCFILE "goatcontest.bas",472
	;[473] 	END
	SRCFILE "goatcontest.bas",473
	RETURN
	ENDP
	;[474] 	
	SRCFILE "goatcontest.bas",474
	;[475] rock_hit:
	SRCFILE "goatcontest.bas",475
	; ROCK_HIT
Q49:	;[476] 	'ouch! got hit by a rock, lose a life
	SRCFILE "goatcontest.bas",476
	;[477] 	WAIT
	SRCFILE "goatcontest.bas",477
	CALL _wait
	;[478] 	lives=lives-1
	SRCFILE "goatcontest.bas",478
	MVI V17,R0
	DECR R0
	MVO R0,V17
	;[479] 	objtype(3)=0 ' remove it from the obj array
	SRCFILE "goatcontest.bas",479
	CLRR R0
	MVO R0,Q6+3
	;[480] 	
	SRCFILE "goatcontest.bas",480
	;[481] 	GOSUB sub_points
	SRCFILE "goatcontest.bas",481
	CALL Q51
	;[482] 	
	SRCFILE "goatcontest.bas",482
	;[483] 	rockhitbot=0
	SRCFILE "goatcontest.bas",483
	CLRR R0
	MVO R0,V48
	;[484] 	
	SRCFILE "goatcontest.bas",484
	;[485] 	' check if rock hit the top or bottom half of the goat
	SRCFILE "goatcontest.bas",485
	;[486] 	IF objy(3) > p1y+8 THEN rockhitbot=1
	SRCFILE "goatcontest.bas",486
	MVI Q8+3,R0
	MVI V45,R1
	ADDI #8,R1
	CMPR R1,R0
	BLE T109
	MVII #1,R0
	MVO R0,V48
T109:
	;[487] 	
	SRCFILE "goatcontest.bas",487
	;[488] 	'clear food objects
	SRCFILE "goatcontest.bas",488
	;[489] 	SPRITE 4,0,0,0
	SRCFILE "goatcontest.bas",489
	CLRR R0
	MVO R0,_mobs+4
	MVO R0,_mobs+12
	NOP
	MVO R0,_mobs+20
	;[490] 	SPRITE 5,0,0,0
	SRCFILE "goatcontest.bas",490
	MVO R0,_mobs+5
	NOP
	MVO R0,_mobs+13
	MVO R0,_mobs+21
	;[491] 	SPRITE 6,0,0,0
	SRCFILE "goatcontest.bas",491
	NOP
	MVO R0,_mobs+6
	MVO R0,_mobs+14
	NOP
	MVO R0,_mobs+22
	;[492] 	WAIT
	SRCFILE "goatcontest.bas",492
	CALL _wait
	;[493]   
	SRCFILE "goatcontest.bas",493
	;[494] 	'laying down dizzy death routine - multiple FOR loops to do the animation plus sound
	SRCFILE "goatcontest.bas",494
	;[495] 	FOR color = 0 TO 5
	SRCFILE "goatcontest.bas",495
	CLRR R0
	MVO R0,V49
T110:
	;[496] 	  WAIT
	SRCFILE "goatcontest.bas",496
	CALL _wait
	;[497]       
	SRCFILE "goatcontest.bas",497
	;[498] 	  'make rock fall off screen
	SRCFILE "goatcontest.bas",498
	;[499] 	  GOSUB rock_fall
	SRCFILE "goatcontest.bas",499
	CALL Q66
	;[500]      
	SRCFILE "goatcontest.bas",500
	;[501] 	  'goat standing
	SRCFILE "goatcontest.bas",501
	;[502] 	  SPRITE 0,p1x+$300,p1y+$100+$0080,#goat1sprite'+(color AND 7) ' goat sprite top left
	SRCFILE "goatcontest.bas",502
	MVI V33,R0
	ADDI #768,R0
	MVO R0,_mobs
	MVI V45,R0
	ADDI #384,R0
	MVO R0,_mobs+8
	MVI V26,R0
	MVO R0,_mobs+16
	;[503] 	  SPRITE 1,p1x+$300+8,p1y+$100+$0080,#goat2sprite'+(color AND 7) ' goat sprite top right, 8 pixels to the right
	SRCFILE "goatcontest.bas",503
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+1
	MVI V45,R0
	ADDI #384,R0
	MVO R0,_mobs+9
	MVI V27,R0
	MVO R0,_mobs+17
	;[504] 	  SPRITE 2,p1x+$300+8,p1y+$100,#goat3sprite ' goat sprite horns, 8 pixels to the right
	SRCFILE "goatcontest.bas",504
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+2
	MVI V45,R0
	ADDI #256,R0
	MVO R0,_mobs+10
	MVI V28,R0
	MVO R0,_mobs+18
	;[505] 	  
	SRCFILE "goatcontest.bas",505
	;[506] 	  'play rock death sound
	SRCFILE "goatcontest.bas",506
	;[507] 	  SOUND 2,500+color*40,15
	SRCFILE "goatcontest.bas",507
	MVI V49,R0
	MULT R0,R4,40
	ADDI #500,R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	MVII #15,R0
	MVO R0,509
	;[508] 	  
	SRCFILE "goatcontest.bas",508
	;[509]         NEXT color
	SRCFILE "goatcontest.bas",509
	MVI V49,R0
	INCR R0
	MVO R0,V49
	CMPI #5,R0
	BLE T110
	;[510]         
	SRCFILE "goatcontest.bas",510
	;[511]         p1x=p1x-3
	SRCFILE "goatcontest.bas",511
	MVI V33,R0
	SUBI #3,R0
	MVO R0,V33
	;[512]         
	SRCFILE "goatcontest.bas",512
	;[513]         FOR color = 6 TO 10
	SRCFILE "goatcontest.bas",513
	MVII #6,R0
	MVO R0,V49
T111:
	;[514] 	  WAIT
	SRCFILE "goatcontest.bas",514
	CALL _wait
	;[515] 	  
	SRCFILE "goatcontest.bas",515
	;[516] 	  'make rock fall off screen
	SRCFILE "goatcontest.bas",516
	;[517] 	  GOSUB rock_fall
	SRCFILE "goatcontest.bas",517
	CALL Q66
	;[518] 	  
	SRCFILE "goatcontest.bas",518
	;[519] 	  'goat falling down
	SRCFILE "goatcontest.bas",519
	;[520] 	  SPRITE 0,p1x+$300,p1y+$100+$0080+1,((256+24)*8)+#goat1color'+(color AND 7) ' goat sprite top left
	SRCFILE "goatcontest.bas",520
	MVI V33,R0
	ADDI #768,R0
	MVO R0,_mobs
	MVI V45,R0
	ADDI #385,R0
	MVO R0,_mobs+8
	MVII #2240,R0
	ADD V31,R0
	MVO R0,_mobs+16
	;[521] 	  SPRITE 1,p1x+$300+8,p1y+$100+$0080+1,((256+26)*8)+#goat1color'+(color AND 7) ' goat sprite top right, 8 pixels to the right
	SRCFILE "goatcontest.bas",521
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+1
	MVI V45,R0
	ADDI #385,R0
	MVO R0,_mobs+9
	MVII #2256,R0
	ADD V31,R0
	MVO R0,_mobs+17
	;[522] 	  SPRITE 2,p1x+$300+8,p1y+$100+1,#goat3sprite ' goat sprite horns, 8 pixels to the right
	SRCFILE "goatcontest.bas",522
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+2
	MVI V45,R0
	ADDI #257,R0
	MVO R0,_mobs+10
	MVI V28,R0
	MVO R0,_mobs+18
	;[523] 	  
	SRCFILE "goatcontest.bas",523
	;[524] 	  'play rock death sound
	SRCFILE "goatcontest.bas",524
	;[525] 	  SOUND 2,500+color*40,15
	SRCFILE "goatcontest.bas",525
	MVI V49,R0
	MULT R0,R4,40
	ADDI #500,R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	MVII #15,R0
	MVO R0,509
	;[526] 	  
	SRCFILE "goatcontest.bas",526
	;[527]         NEXT color
	SRCFILE "goatcontest.bas",527
	MVI V49,R0
	INCR R0
	MVO R0,V49
	CMPI #10,R0
	BLE T111
	;[528]         
	SRCFILE "goatcontest.bas",528
	;[529]         SOUND 2,0,0
	SRCFILE "goatcontest.bas",529
	CLRR R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	CLRR R0
	MVO R0,509
	;[530]         SOUND 3,0,0
	SRCFILE "goatcontest.bas",530
	MVO R0,499
	SWAP R0
	MVO R0,503
	CLRR R0
	MVO R0,506
	;[531]         SOUND 4,0,0
	SRCFILE "goatcontest.bas",531
	MVO R0,505
	NOP
	MVO R0,504
	;[532]         
	SRCFILE "goatcontest.bas",532
	;[533]         p1x=p1x-6
	SRCFILE "goatcontest.bas",533
	MVI V33,R0
	SUBI #6,R0
	MVO R0,V33
	;[534]         
	SRCFILE "goatcontest.bas",534
	;[535]         FOR color = 11 TO 80
	SRCFILE "goatcontest.bas",535
	MVII #11,R0
	MVO R0,V49
T112:
	;[536] 	  WAIT
	SRCFILE "goatcontest.bas",536
	CALL _wait
	;[537] 	  
	SRCFILE "goatcontest.bas",537
	;[538] 	  'make rock fall off screen
	SRCFILE "goatcontest.bas",538
	;[539] 	  GOSUB rock_fall
	SRCFILE "goatcontest.bas",539
	CALL Q66
	;[540] 	  
	SRCFILE "goatcontest.bas",540
	;[541] 	  'goat completely fallen down
	SRCFILE "goatcontest.bas",541
	;[542] 	  SPRITE 0,p1x+$300,p1y+$100+$0080+2,((256+28)*8)+#goat1color'+(color AND 7) ' goat sprite top left
	SRCFILE "goatcontest.bas",542
	MVI V33,R0
	ADDI #768,R0
	MVO R0,_mobs
	MVI V45,R0
	ADDI #386,R0
	MVO R0,_mobs+8
	MVII #2272,R0
	ADD V31,R0
	MVO R0,_mobs+16
	;[543] 	  SPRITE 1,p1x+$300+8,p1y+$100+$0080+2,((256+30)*8)+#goat1color'+(color AND 7) ' goat sprite top right, 8 pixels to the right
	SRCFILE "goatcontest.bas",543
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+1
	MVI V45,R0
	ADDI #386,R0
	MVO R0,_mobs+9
	MVII #2288,R0
	ADD V31,R0
	MVO R0,_mobs+17
	;[544] 	  SPRITE 3,p1x+$300+8,p1y+$100+2,#goat3sprite ' goat sprite horns, 8 pixels to the right
	SRCFILE "goatcontest.bas",544
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+3
	MVI V45,R0
	ADDI #258,R0
	MVO R0,_mobs+11
	MVI V28,R0
	MVO R0,_mobs+19
	;[545] 
	SRCFILE "goatcontest.bas",545
	;[546] 	  'alternate the dizzy halo
	SRCFILE "goatcontest.bas",546
	;[547] 	  IF color/8%2=0 THEN SPRITE 2, p1x+$300+8,p1y+$100+2,((256+18)*8)+6 ELSE SPRITE 2, p1x+$300+8,p1y+$100+2,((256+21)*8)+6
	SRCFILE "goatcontest.bas",547
	MVI V49,R0
	SLR R0,2
	SLR R0,1
	ANDI #1,R0
	BNE T113
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+2
	MVI V45,R0
	ADDI #258,R0
	MVO R0,_mobs+10
	MVII #2198,R0
	MVO R0,_mobs+18
	B T114
T113:
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+2
	MVI V45,R0
	ADDI #258,R0
	MVO R0,_mobs+10
	MVII #2222,R0
	MVO R0,_mobs+18
T114:
	;[548] 	  
	SRCFILE "goatcontest.bas",548
	;[549] 	  'play rock death sound
	SRCFILE "goatcontest.bas",549
	;[550] 	  SOUND 2,500+color*40,15
	SRCFILE "goatcontest.bas",550
	MVI V49,R0
	MULT R0,R4,40
	ADDI #500,R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	MVII #15,R0
	MVO R0,509
	;[551] 	  
	SRCFILE "goatcontest.bas",551
	;[552]         NEXT color
	SRCFILE "goatcontest.bas",552
	MVI V49,R0
	INCR R0
	MVO R0,V49
	CMPI #80,R0
	BLE T112
	;[553]         
	SRCFILE "goatcontest.bas",553
	;[554]         SOUND 2,0,0
	SRCFILE "goatcontest.bas",554
	CLRR R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	CLRR R0
	MVO R0,509
	;[555]         SOUND 3,0,0
	SRCFILE "goatcontest.bas",555
	MVO R0,499
	SWAP R0
	MVO R0,503
	CLRR R0
	MVO R0,506
	;[556]         SOUND 4,0,0
	SRCFILE "goatcontest.bas",556
	MVO R0,505
	NOP
	MVO R0,504
	;[557]         
	SRCFILE "goatcontest.bas",557
	;[558]         FOR color = 1 TO 50
	SRCFILE "goatcontest.bas",558
	MVII #1,R0
	MVO R0,V49
T115:
	;[559] 	  WAIT
	SRCFILE "goatcontest.bas",559
	CALL _wait
	;[560] 	  'let's extend the halo anim past the audio
	SRCFILE "goatcontest.bas",560
	;[561] 	  SPRITE 0,p1x+$300,p1y+$100+$0080+2,((256+28)*8)+#goat1color'+(color AND 7) ' goat sprite top left
	SRCFILE "goatcontest.bas",561
	MVI V33,R0
	ADDI #768,R0
	MVO R0,_mobs
	MVI V45,R0
	ADDI #386,R0
	MVO R0,_mobs+8
	MVII #2272,R0
	ADD V31,R0
	MVO R0,_mobs+16
	;[562] 	  SPRITE 1,p1x+$300+8,p1y+$100+$0080+2,((256+30)*8)+#goat1color'+(color AND 7) ' goat sprite top right, 8 pixels to the right
	SRCFILE "goatcontest.bas",562
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+1
	MVI V45,R0
	ADDI #386,R0
	MVO R0,_mobs+9
	MVII #2288,R0
	ADD V31,R0
	MVO R0,_mobs+17
	;[563] 	  SPRITE 3,p1x+$300+8,p1y+$100+2,#goat3sprite ' goat sprite horns, 8 pixels to the right
	SRCFILE "goatcontest.bas",563
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+3
	MVI V45,R0
	ADDI #258,R0
	MVO R0,_mobs+11
	MVI V28,R0
	MVO R0,_mobs+19
	;[564] 
	SRCFILE "goatcontest.bas",564
	;[565] 	  'alternate the dizzy halo
	SRCFILE "goatcontest.bas",565
	;[566] 	  IF color/8%2=0 THEN SPRITE 2, p1x+$300+8,p1y+$100+2,((256+18)*8)+6 ELSE SPRITE 2, p1x+$300+8,p1y+$100+2,((256+21)*8)+6
	SRCFILE "goatcontest.bas",566
	MVI V49,R0
	SLR R0,2
	SLR R0,1
	ANDI #1,R0
	BNE T116
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+2
	MVI V45,R0
	ADDI #258,R0
	MVO R0,_mobs+10
	MVII #2198,R0
	MVO R0,_mobs+18
	B T117
T116:
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+2
	MVI V45,R0
	ADDI #258,R0
	MVO R0,_mobs+10
	MVII #2222,R0
	MVO R0,_mobs+18
T117:
	;[567]         NEXT color
	SRCFILE "goatcontest.bas",567
	MVI V49,R0
	INCR R0
	MVO R0,V49
	CMPI #50,R0
	BLE T115
	;[568]        
	SRCFILE "goatcontest.bas",568
	;[569] 
	SRCFILE "goatcontest.bas",569
	;[570]         SOUND 2,,0
	SRCFILE "goatcontest.bas",570
	CLRR R0
	MVO R0,509
	;[571] 	SOUND 4,,0
	SRCFILE "goatcontest.bas",571
	MVO R0,504
	;[572]     
	SRCFILE "goatcontest.bas",572
	;[573]     	'reset player position for new 1UP
	SRCFILE "goatcontest.bas",573
	;[574] 	p1x=20
	SRCFILE "goatcontest.bas",574
	MVII #20,R0
	MVO R0,V33
	;[575] 	p1y=30
	SRCFILE "goatcontest.bas",575
	MVII #30,R0
	MVO R0,V45
	;[576] 	
	SRCFILE "goatcontest.bas",576
	;[577] 	'clear halo sprite for game over situation
	SRCFILE "goatcontest.bas",577
	;[578] 	SPRITE 2,0,0,0
	SRCFILE "goatcontest.bas",578
	CLRR R0
	MVO R0,_mobs+2
	MVO R0,_mobs+10
	NOP
	MVO R0,_mobs+18
	;[579] 	
	SRCFILE "goatcontest.bas",579
	;[580] 	' let's see if we're dead yet after getting hit by a rock
	SRCFILE "goatcontest.bas",580
	;[581] 	IF lives=0 THEN GOTO game_over
	SRCFILE "goatcontest.bas",581
	MVI V17,R0
	TSTR R0
	BEQ Q67
	;[582] 
	SRCFILE "goatcontest.bas",582
	;[583] 	'clear the board of objects
	SRCFILE "goatcontest.bas",583
	;[584] 	FOR i = 0 to 3
	SRCFILE "goatcontest.bas",584
	CLRR R0
	MVO R0,V32
T119:
	;[585] 	  objx(i)=0
	SRCFILE "goatcontest.bas",585
	CLRR R0
	MVII #Q7,R3
	ADD V32,R3
	MVO@ R0,R3
	;[586] 	  objy(i)=0
	SRCFILE "goatcontest.bas",586
	MVII #Q8,R3
	ADD V32,R3
	MVO@ R0,R3
	;[587] 	  objtype(i)=0
	SRCFILE "goatcontest.bas",587
	MVII #Q6,R3
	ADD V32,R3
	MVO@ R0,R3
	;[588] 	NEXT i
	SRCFILE "goatcontest.bas",588
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #3,R0
	BLE T119
	;[589] 	
	SRCFILE "goatcontest.bas",589
	;[590] 	GOSUB reset_sprites
	SRCFILE "goatcontest.bas",590
	CALL Q4
	;[591] 	objlive=0
	SRCFILE "goatcontest.bas",591
	CLRR R0
	MVO R0,V10
	;[592] 	
	SRCFILE "goatcontest.bas",592
	;[593] 	GOTO main_goat
	SRCFILE "goatcontest.bas",593
	B Q42
	;[594] 	
	SRCFILE "goatcontest.bas",594
	;[595] rock_fall:	PROCEDURE
	SRCFILE "goatcontest.bas",595
	; ROCK_FALL
Q66:	PROC
	BEGIN
	;[596] 	
	SRCFILE "goatcontest.bas",596
	;[597] 	' rock moves off depending on how it hit the goat
	SRCFILE "goatcontest.bas",597
	;[598] 	IF rockhitbot=1 THEN objy(3)=objy(3)+2 ELSE objy(3)=objy(3)-2
	SRCFILE "goatcontest.bas",598
	MVI V48,R0
	CMPI #1,R0
	BNE T120
	MVI Q8+3,R0
	ADDI #2,R0
	MVO R0,Q8+3
	B T121
T120:
	MVI Q8+3,R0
	SUBI #2,R0
	MVO R0,Q8+3
T121:
	;[599] 	
	SRCFILE "goatcontest.bas",599
	;[600] 	' rock continues moving left as well
	SRCFILE "goatcontest.bas",600
	;[601] 	objx(3)=objx(3)-2
	SRCFILE "goatcontest.bas",601
	MVI Q7+3,R0
	SUBI #2,R0
	MVO R0,Q7+3
	;[602] 	
	SRCFILE "goatcontest.bas",602
	;[603] 	' check for off screen, de-sprite if so
	SRCFILE "goatcontest.bas",603
	;[604] 	IF objy(3)>=ybot+8 OR objy(3)=1 OR objy(3)=2 THEN objy(3)=0
	SRCFILE "goatcontest.bas",604
	MVI Q8+3,R0
	CMPI #96,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI Q8+3,R1
	CMPI #1,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI Q8+3,R1
	CMPI #2,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T122
	CLRR R0
	MVO R0,Q8+3
T122:
	;[605] 	
	SRCFILE "goatcontest.bas",605
	;[606] 	' and draw it
	SRCFILE "goatcontest.bas",606
	;[607] 	SPRITE 7,objx(3)+$300,objy(3)+$100,#rocksprite
	SRCFILE "goatcontest.bas",607
	MVI Q7+3,R0
	ADDI #768,R0
	MVO R0,_mobs+7
	MVI Q8+3,R0
	ADDI #256,R0
	MVO R0,_mobs+15
	MVI V38,R0
	MVO R0,_mobs+23
	;[608]     
	SRCFILE "goatcontest.bas",608
	;[609] 	END
	SRCFILE "goatcontest.bas",609
	RETURN
	ENDP
	;[610] 	
	SRCFILE "goatcontest.bas",610
	;[611] rock_point:
	SRCFILE "goatcontest.bas",611
	; ROCK_POINT
Q50:	;[612] 	'successfully kicked the rock
	SRCFILE "goatcontest.bas",612
	;[613] 	
	SRCFILE "goatcontest.bas",613
	;[614] 	'add points to score
	SRCFILE "goatcontest.bas",614
	;[615] 	GOSUB add_points
	SRCFILE "goatcontest.bas",615
	CALL Q64
	;[616] 	
	SRCFILE "goatcontest.bas",616
	;[617] 	'flashing rock colors
	SRCFILE "goatcontest.bas",617
	;[618] 	FOR i = 1 to 7
	SRCFILE "goatcontest.bas",618
	MVII #1,R0
	MVO R0,V32
T123:
	;[619] 	  SPRITE 7,objx(3)+$300,objy(3)+$100,#rocksprite+i
	SRCFILE "goatcontest.bas",619
	MVI Q7+3,R0
	ADDI #768,R0
	MVO R0,_mobs+7
	MVI Q8+3,R0
	ADDI #256,R0
	MVO R0,_mobs+15
	MVI V38,R0
	ADD V32,R0
	MVO R0,_mobs+23
	;[620] 	  SOUND 2,1200,15
	SRCFILE "goatcontest.bas",620
	MVII #1200,R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	MVII #15,R0
	MVO R0,509
	;[621] 	  SOUND 4,6,0
	SRCFILE "goatcontest.bas",621
	MVII #6,R0
	MVO R0,505
	CLRR R0
	MVO R0,504
	;[622] 	  WAIT
	SRCFILE "goatcontest.bas",622
	CALL _wait
	;[623] 	NEXT i
	SRCFILE "goatcontest.bas",623
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #7,R0
	BLE T123
	;[624] 	
	SRCFILE "goatcontest.bas",624
	;[625] 	SOUND 2,0,0
	SRCFILE "goatcontest.bas",625
	CLRR R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	CLRR R0
	MVO R0,509
	;[626] 	SOUND 4,0,0
	SRCFILE "goatcontest.bas",626
	MVO R0,505
	NOP
	MVO R0,504
	;[627] 
	SRCFILE "goatcontest.bas",627
	;[628] 	objx(3)=0
	SRCFILE "goatcontest.bas",628
	MVO R0,Q7+3
	;[629] 	objy(3)=0
	SRCFILE "goatcontest.bas",629
	NOP
	MVO R0,Q8+3
	;[630] 	objtype(3)=0
	SRCFILE "goatcontest.bas",630
	MVO R0,Q6+3
	;[631] 	objlive=objlive-1
	SRCFILE "goatcontest.bas",631
	MVI V10,R0
	DECR R0
	MVO R0,V10
	;[632] 	
	SRCFILE "goatcontest.bas",632
	;[633] 	'clear the rock from the board
	SRCFILE "goatcontest.bas",633
	;[634] 	SPRITE 7,0,0,0
	SRCFILE "goatcontest.bas",634
	CLRR R0
	MVO R0,_mobs+7
	MVO R0,_mobs+15
	NOP
	MVO R0,_mobs+23
	;[635] 	WAIT ' THIS WAIT IS CRITICAL TO NOT HAVE THE ROCK SCORE TWICE
	SRCFILE "goatcontest.bas",635
	CALL _wait
	;[636] 	
	SRCFILE "goatcontest.bas",636
	;[637] 	GOTO main_goat
	SRCFILE "goatcontest.bas",637
	B Q42
	;[638] 	
	SRCFILE "goatcontest.bas",638
	;[639] add_points:	PROCEDURE
	SRCFILE "goatcontest.bas",639
	; ADD_POINTS
Q64:	PROC
	BEGIN
	;[640] 	' update score raw value
	SRCFILE "goatcontest.bas",640
	;[641] 	#score=#score+#points
	SRCFILE "goatcontest.bas",641
	MVI V12,R0
	ADD V15,R0
	MVO R0,V12
	;[642] 	IF #score>#topscore THEN #topscore=#score
	SRCFILE "goatcontest.bas",642
	CMP V14,R0
	BLE T124
	MVO R0,V14
T124:
	;[643] 	IF #score>#stagescore THEN #score=#stagescore
	SRCFILE "goatcontest.bas",643
	MVI V12,R0
	CMP V1,R0
	BLE T125
	MVI V1,R0
	MVO R0,V12
T125:
	;[644] 	'work out small score, for nom meter
	SRCFILE "goatcontest.bas",644
	;[645] 	smallscore=#score/div
	SRCFILE "goatcontest.bas",645
	MVI V12,R0
	MVI V39,R1
	CALL uf_udiv16
	MVO R0,V42
	;[646] 	
	SRCFILE "goatcontest.bas",646
	;[647] 	'sanity check
	SRCFILE "goatcontest.bas",647
	;[648] 	#points=0
	SRCFILE "goatcontest.bas",648
	CLRR R0
	MVO R0,V15
	;[649] 	
	SRCFILE "goatcontest.bas",649
	;[650] 	#score1k=#score/1000
	SRCFILE "goatcontest.bas",650
	MVI V12,R0
	MVII #-1,R4
T126:
	INCR R4
	SUBI #1000,R0
	BC T126
	MOVR R4,R0
	MVO R0,V13
	;[651] 
	SRCFILE "goatcontest.bas",651
	;[652] 	IF #score1k = level0score THEN level=0
	SRCFILE "goatcontest.bas",652
	TSTR R0
	BNE T127
	MVO R0,V18
T127:
	;[653] 	IF #score1k >= level1score THEN level=1
	SRCFILE "goatcontest.bas",653
	MVI V13,R0
	CMPI #1,R0
	BLT T128
	MVII #1,R0
	MVO R0,V18
T128:
	;[654] 	IF #score1k >= level2score THEN level=2
	SRCFILE "goatcontest.bas",654
	MVI V13,R0
	CMPI #2,R0
	BLT T129
	MVII #2,R0
	MVO R0,V18
T129:
	;[655] 	IF #score1k >= level3score THEN level=3
	SRCFILE "goatcontest.bas",655
	MVI V13,R0
	CMPI #4,R0
	BLT T130
	MVII #3,R0
	MVO R0,V18
T130:
	;[656] 	IF #score1k >= level4score THEN level=4
	SRCFILE "goatcontest.bas",656
	MVI V13,R0
	CMPI #8,R0
	BLT T131
	MVII #4,R0
	MVO R0,V18
T131:
	;[657] 	IF #score1k >= level5score THEN level=5
	SRCFILE "goatcontest.bas",657
	MVI V13,R0
	CMPI #10,R0
	BLT T132
	MVII #5,R0
	MVO R0,V18
T132:
	;[658] 	
	SRCFILE "goatcontest.bas",658
	;[659] 	END
	SRCFILE "goatcontest.bas",659
	RETURN
	ENDP
	;[660] 	
	SRCFILE "goatcontest.bas",660
	;[661] sub_points:	PROCEDURE
	SRCFILE "goatcontest.bas",661
	; SUB_POINTS
Q51:	PROC
	BEGIN
	;[662] 	
	SRCFILE "goatcontest.bas",662
	;[663] 	'work out small score, for nom meter - THIS ONE MAY BE OPTIONAL, leave it in anyway
	SRCFILE "goatcontest.bas",663
	;[664] 	smallscore=#score/div
	SRCFILE "goatcontest.bas",664
	MVI V12,R0
	MVI V39,R1
	CALL uf_udiv16
	MVO R0,V42
	;[665] 	
	SRCFILE "goatcontest.bas",665
	;[666] 	'first check for zero score. don't subtract if zero!
	SRCFILE "goatcontest.bas",666
	;[667] 	IF #score=0 THEN smallscore=0:RETURN
	SRCFILE "goatcontest.bas",667
	MVI V12,R0
	TSTR R0
	BNE T133
	MVO R0,V42
	RETURN
T133:
	;[668] 	'and check if we'll be below zero as well, just zero out score and exit this PROC
	SRCFILE "goatcontest.bas",668
	;[669] 	IF #points>#score THEN #score=0:smallscore=0:RETURN
	SRCFILE "goatcontest.bas",669
	MVI V15,R0
	CMP V12,R0
	BLE T134
	CLRR R0
	MVO R0,V12
	MVO R0,V42
	RETURN
T134:
	;[670] 	
	SRCFILE "goatcontest.bas",670
	;[671] 	#score=#score-#points ' keep track of raw score
	SRCFILE "goatcontest.bas",671
	MVI V12,R0
	SUB V15,R0
	MVO R0,V12
	;[672]       
	SRCFILE "goatcontest.bas",672
	;[673] 	'work out small score, for nom meter
	SRCFILE "goatcontest.bas",673
	;[674] 	smallscore=#score/div
	SRCFILE "goatcontest.bas",674
	MVI V39,R1
	CALL uf_udiv16
	MVO R0,V42
	;[675] 
	SRCFILE "goatcontest.bas",675
	;[676] 	'sanity check
	SRCFILE "goatcontest.bas",676
	;[677] 	#points=0
	SRCFILE "goatcontest.bas",677
	CLRR R0
	MVO R0,V15
	;[678] 	
	SRCFILE "goatcontest.bas",678
	;[679] 	#score1k=#score/1000 ' calculate score in 1k increments
	SRCFILE "goatcontest.bas",679
	MVI V12,R0
	MVII #-1,R4
T135:
	INCR R4
	SUBI #1000,R0
	BC T135
	MOVR R4,R0
	MVO R0,V13
	;[680] 	
	SRCFILE "goatcontest.bas",680
	;[681] 	IF #score1k = level0score THEN level=0
	SRCFILE "goatcontest.bas",681
	TSTR R0
	BNE T136
	MVO R0,V18
T136:
	;[682] 	IF #score1k >= level1score THEN level=1
	SRCFILE "goatcontest.bas",682
	MVI V13,R0
	CMPI #1,R0
	BLT T137
	MVII #1,R0
	MVO R0,V18
T137:
	;[683] 	IF #score1k >= level2score THEN level=2
	SRCFILE "goatcontest.bas",683
	MVI V13,R0
	CMPI #2,R0
	BLT T138
	MVII #2,R0
	MVO R0,V18
T138:
	;[684] 	IF #score1k >= level3score THEN level=3
	SRCFILE "goatcontest.bas",684
	MVI V13,R0
	CMPI #4,R0
	BLT T139
	MVII #3,R0
	MVO R0,V18
T139:
	;[685] 	IF #score1k >= level4score THEN level=4
	SRCFILE "goatcontest.bas",685
	MVI V13,R0
	CMPI #8,R0
	BLT T140
	MVII #4,R0
	MVO R0,V18
T140:
	;[686] 	IF #score1k >= level5score THEN level=5
	SRCFILE "goatcontest.bas",686
	MVI V13,R0
	CMPI #10,R0
	BLT T141
	MVII #5,R0
	MVO R0,V18
T141:
	;[687] 	
	SRCFILE "goatcontest.bas",687
	;[688] 	END
	SRCFILE "goatcontest.bas",688
	RETURN
	ENDP
	;[689] 	
	SRCFILE "goatcontest.bas",689
	;[690] 
	SRCFILE "goatcontest.bas",690
	;[691] reset_sprites:	PROCEDURE
	SRCFILE "goatcontest.bas",691
	; RESET_SPRITES
Q4:	PROC
	BEGIN
	;[692] 	SPRITE 0,0,0,0
	SRCFILE "goatcontest.bas",692
	CLRR R0
	MVO R0,_mobs
	MVO R0,_mobs+8
	NOP
	MVO R0,_mobs+16
	;[693] 	SPRITE 1,0,0,0
	SRCFILE "goatcontest.bas",693
	MVO R0,_mobs+1
	NOP
	MVO R0,_mobs+9
	MVO R0,_mobs+17
	;[694] 	SPRITE 2,0,0,0
	SRCFILE "goatcontest.bas",694
	NOP
	MVO R0,_mobs+2
	MVO R0,_mobs+10
	NOP
	MVO R0,_mobs+18
	;[695] 	SPRITE 3,0,0,0
	SRCFILE "goatcontest.bas",695
	MVO R0,_mobs+3
	NOP
	MVO R0,_mobs+11
	MVO R0,_mobs+19
	;[696] 	SPRITE 4,0,0,0
	SRCFILE "goatcontest.bas",696
	NOP
	MVO R0,_mobs+4
	MVO R0,_mobs+12
	NOP
	MVO R0,_mobs+20
	;[697] 	SPRITE 5,0,0,0
	SRCFILE "goatcontest.bas",697
	MVO R0,_mobs+5
	NOP
	MVO R0,_mobs+13
	MVO R0,_mobs+21
	;[698] 	SPRITE 6,0,0,0
	SRCFILE "goatcontest.bas",698
	NOP
	MVO R0,_mobs+6
	MVO R0,_mobs+14
	NOP
	MVO R0,_mobs+22
	;[699] 	SPRITE 7,0,0,0
	SRCFILE "goatcontest.bas",699
	MVO R0,_mobs+7
	NOP
	MVO R0,_mobs+15
	MVO R0,_mobs+23
	;[700] 	END
	SRCFILE "goatcontest.bas",700
	RETURN
	ENDP
	;[701] 	
	SRCFILE "goatcontest.bas",701
	;[702] draw_goat_plain:	PROCEDURE
	SRCFILE "goatcontest.bas",702
	; DRAW_GOAT_PLAIN
Q46:	PROC
	BEGIN
	;[703] 	SPRITE 0,p1x+$300,p1y+$100+$0080,#goat1sprite ' goat sprite #1
	SRCFILE "goatcontest.bas",703
	MVI V33,R0
	ADDI #768,R0
	MVO R0,_mobs
	MVI V45,R0
	ADDI #384,R0
	MVO R0,_mobs+8
	MVI V26,R0
	MVO R0,_mobs+16
	;[704] 	SPRITE 1,p1x+$300+8,p1y+$100+$0080+(goatflip*256),#goat2sprite ' goat sprite #2, 8 pixels to the right
	SRCFILE "goatcontest.bas",704
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+1
	MVI V45,R0
	ADDI #384,R0
	MVI V24,R1
	SWAP R1
	ANDI #65280,R1
	ADDR R1,R0
	MVO R0,_mobs+9
	MVI V27,R0
	MVO R0,_mobs+17
	;[705] 	SPRITE 2,p1x+$300+8,p1y+$100+(goatflip*256),#goat3sprite ' goat sprite #3, 8 pixels to the right
	SRCFILE "goatcontest.bas",705
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+2
	MVI V45,R0
	ADDI #256,R0
	MVI V24,R1
	SWAP R1
	ANDI #65280,R1
	ADDR R1,R0
	MVO R0,_mobs+10
	MVI V28,R0
	MVO R0,_mobs+18
	;[706] 	END
	SRCFILE "goatcontest.bas",706
	RETURN
	ENDP
	;[707] 	
	SRCFILE "goatcontest.bas",707
	;[708] draw_goat_kick:		PROCEDURE
	SRCFILE "goatcontest.bas",708
	; DRAW_GOAT_KICK
Q47:	PROC
	BEGIN
	;[709] 	SPRITE 0,p1x+$300+16,p1y+$100+$0080,((256+22)*8)+#goat1color
	SRCFILE "goatcontest.bas",709
	MVI V33,R0
	ADDI #784,R0
	MVO R0,_mobs
	MVI V45,R0
	ADDI #384,R0
	MVO R0,_mobs+8
	MVII #2224,R0
	ADD V31,R0
	MVO R0,_mobs+16
	;[710] 	SPRITE 1,p1x+$300+8,p1y+$100+$0080+(goatflip*256),#goat2sprite ' goat sprite #2, 8 pixels to the right
	SRCFILE "goatcontest.bas",710
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+1
	MVI V45,R0
	ADDI #384,R0
	MVI V24,R1
	SWAP R1
	ANDI #65280,R1
	ADDR R1,R0
	MVO R0,_mobs+9
	MVI V27,R0
	MVO R0,_mobs+17
	;[711] 	SPRITE 2,p1x+$300+8,p1y+$100+(goatflip*256),#goat3sprite ' goat sprite #3, 8 pixels to the right
	SRCFILE "goatcontest.bas",711
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+2
	MVI V45,R0
	ADDI #256,R0
	MVI V24,R1
	SWAP R1
	ANDI #65280,R1
	ADDR R1,R0
	MVO R0,_mobs+10
	MVI V28,R0
	MVO R0,_mobs+18
	;[712] 	END
	SRCFILE "goatcontest.bas",712
	RETURN
	ENDP
	;[713] 	
	SRCFILE "goatcontest.bas",713
	;[714] ' game is too big. let's split it up a bit
	SRCFILE "goatcontest.bas",714
	;[715] ASM ORG $C100	
	SRCFILE "goatcontest.bas",715
 ORG $C100	
	;[716] 	
	SRCFILE "goatcontest.bas",716
	;[717] ending:
	SRCFILE "goatcontest.bas",717
	; ENDING
Q38:	;[718] 
	SRCFILE "goatcontest.bas",718
	;[719] 	FOR i = 1 to 100
	SRCFILE "goatcontest.bas",719
	MVII #1,R0
	MVO R0,V32
T142:
	;[720] 	  WAIT
	SRCFILE "goatcontest.bas",720
	CALL _wait
	;[721] 	NEXT i
	SRCFILE "goatcontest.bas",721
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #100,R0
	BLE T142
	;[722] end_cheat:
	SRCFILE "goatcontest.bas",722
	; END_CHEAT
Q26:	;[723] 	CLS
	SRCFILE "goatcontest.bas",723
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[724] 	WAIT
	SRCFILE "goatcontest.bas",724
	CALL _wait
	;[725] 	MODE 0,0,0,0,0
	SRCFILE "goatcontest.bas",725
	CLRR R0
	MVO R0,_color
	MVII #1,R0
	MVO R0,_mode_select
	;[726] 	WAIT
	SRCFILE "goatcontest.bas",726
	CALL _wait
	;[727] 	#goat1color=7
	SRCFILE "goatcontest.bas",727
	MVII #7,R0
	MVO R0,V31
	;[728] 	
	SRCFILE "goatcontest.bas",728
	;[729] 	GOSUB reset_vals
	SRCFILE "goatcontest.bas",729
	CALL Q5
	;[730] 	GOSUB reset_sprites
	SRCFILE "goatcontest.bas",730
	CALL Q4
	;[731] 	
	SRCFILE "goatcontest.bas",731
	;[732] 	WAIT
	SRCFILE "goatcontest.bas",732
	CALL _wait
	;[733] 	DEFINE 0,16,drawings1 ' we can only safely load 16 cards per DEFINE statement
	SRCFILE "goatcontest.bas",733
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q21,R0
	MVO R0,_gram_bitmap
	;[734] 	WAIT
	SRCFILE "goatcontest.bas",734
	CALL _wait
	;[735] 	DEFINE 16,16,drawings2 ' so split it up into groups of 16 as necessary
	SRCFILE "goatcontest.bas",735
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q34,R0
	MVO R0,_gram_bitmap
	;[736] 	WAIT
	SRCFILE "goatcontest.bas",736
	CALL _wait
	;[737] 	DEFINE 32,16,drawings3 
	SRCFILE "goatcontest.bas",737
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q35,R0
	MVO R0,_gram_bitmap
	;[738] 	WAIT
	SRCFILE "goatcontest.bas",738
	CALL _wait
	;[739] 	DEFINE 48,3,drawings4
	SRCFILE "goatcontest.bas",739
	MVII #48,R0
	MVO R0,_gram_target
	MVII #3,R0
	MVO R0,_gram_total
	MVII #Q36,R0
	MVO R0,_gram_bitmap
	;[740] 	WAIT
	SRCFILE "goatcontest.bas",740
	CALL _wait
	;[741] 	
	SRCFILE "goatcontest.bas",741
	;[742] end_reset:
	SRCFILE "goatcontest.bas",742
	; END_RESET
Q77:	;[743] 	
	SRCFILE "goatcontest.bas",743
	;[744] 	#goat1sprite=((256+0)*8)+#goat1color
	SRCFILE "goatcontest.bas",744
	MVII #2048,R0
	ADD V31,R0
	MVO R0,V26
	;[745] 	#goat2sprite=((256+2)*8)+#goat1color
	SRCFILE "goatcontest.bas",745
	MVII #2064,R0
	ADD V31,R0
	MVO R0,V27
	;[746] 	
	SRCFILE "goatcontest.bas",746
	;[747] 	p1x=20
	SRCFILE "goatcontest.bas",747
	MVII #20,R0
	MVO R0,V33
	;[748] 	p1y=60
	SRCFILE "goatcontest.bas",748
	MVII #60,R0
	MVO R0,V45
	;[749] 	p2x=130
	SRCFILE "goatcontest.bas",749
	MVII #130,R0
	MVO R0,V43
	;[750] 	p2y=60
	SRCFILE "goatcontest.bas",750
	MVII #60,R0
	MVO R0,V44
	;[751] 	p3x=200
	SRCFILE "goatcontest.bas",751
	MVII #200,R0
	MVO R0,V50
	;[752] 	p3y=68
	SRCFILE "goatcontest.bas",752
	MVII #68,R0
	MVO R0,V51
	;[753] 	hearty=0
	SRCFILE "goatcontest.bas",753
	CLRR R0
	MVO R0,V52
	;[754] 	spritetimer=0
	SRCFILE "goatcontest.bas",754
	MVO R0,V2
	;[755] 	CLS
	SRCFILE "goatcontest.bas",755
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[756] 	WAIT
	SRCFILE "goatcontest.bas",756
	CALL _wait
	;[757] 	GOSUB reset_sprites
	SRCFILE "goatcontest.bas",757
	CALL Q4
	;[758] 	
	SRCFILE "goatcontest.bas",758
	;[759] 	PLAY victory_song
	SRCFILE "goatcontest.bas",759
	MVII #Q78,R0
	CALL _play_music
	;[760] 
	SRCFILE "goatcontest.bas",760
	;[761] 	GOSUB end_draw
	SRCFILE "goatcontest.bas",761
	CALL Q79
	;[762] 	
	SRCFILE "goatcontest.bas",762
	;[763] 	'bounce animation
	SRCFILE "goatcontest.bas",763
	;[764] 	FOR j = 1 to 2
	SRCFILE "goatcontest.bas",764
	MVII #1,R0
	MVO R0,V53
T143:
	;[765] 	  FOR i = 1 to 70
	SRCFILE "goatcontest.bas",765
	MVII #1,R0
	MVO R0,V32
T144:
	;[766] 	    WAIT
	SRCFILE "goatcontest.bas",766
	CALL _wait
	;[767] 	  NEXT i	
	SRCFILE "goatcontest.bas",767
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #70,R0
	BLE T144
	;[768] 	  
	SRCFILE "goatcontest.bas",768
	;[769] 	  'mr goat bounce
	SRCFILE "goatcontest.bas",769
	;[770] 	  FOR i = 1 to 5*j
	SRCFILE "goatcontest.bas",770
	MVII #1,R0
	MVO R0,V32
T145:
	;[771] 	    p1y=p1y-1
	SRCFILE "goatcontest.bas",771
	MVI V45,R0
	DECR R0
	MVO R0,V45
	;[772] 	    GOSUB end_draw
	SRCFILE "goatcontest.bas",772
	CALL Q79
	;[773] 	    WAIT
	SRCFILE "goatcontest.bas",773
	CALL _wait
	;[774] 	  NEXT i	
	SRCFILE "goatcontest.bas",774
	MVI V32,R0
	INCR R0
	MVO R0,V32
	MVI V53,R1
	MULT R1,R4,5
	CMPR R1,R0
	BLE T145
	;[775] 	  
	SRCFILE "goatcontest.bas",775
	;[776] 	  FOR i = 1 to 5*j
	SRCFILE "goatcontest.bas",776
	MVII #1,R0
	MVO R0,V32
T146:
	;[777] 	    p1y=p1y+1
	SRCFILE "goatcontest.bas",777
	MVI V45,R0
	INCR R0
	MVO R0,V45
	;[778] 	    GOSUB end_draw
	SRCFILE "goatcontest.bas",778
	CALL Q79
	;[779] 	    WAIT
	SRCFILE "goatcontest.bas",779
	CALL _wait
	;[780] 	  NEXT i	
	SRCFILE "goatcontest.bas",780
	MVI V32,R0
	INCR R0
	MVO R0,V32
	MVI V53,R1
	MULT R1,R4,5
	CMPR R1,R0
	BLE T146
	;[781] 	  
	SRCFILE "goatcontest.bas",781
	;[782] 	  FOR i = 1 to 20
	SRCFILE "goatcontest.bas",782
	MVII #1,R0
	MVO R0,V32
T147:
	;[783] 	    WAIT
	SRCFILE "goatcontest.bas",783
	CALL _wait
	;[784] 	  NEXT i	
	SRCFILE "goatcontest.bas",784
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #20,R0
	BLE T147
	;[785] 	  
	SRCFILE "goatcontest.bas",785
	;[786] 	  'ms goat bounce
	SRCFILE "goatcontest.bas",786
	;[787] 	  FOR i = 1 to 5*j
	SRCFILE "goatcontest.bas",787
	MVII #1,R0
	MVO R0,V32
T148:
	;[788] 	    p2y=p2y-1
	SRCFILE "goatcontest.bas",788
	MVI V44,R0
	DECR R0
	MVO R0,V44
	;[789] 	    GOSUB end_draw
	SRCFILE "goatcontest.bas",789
	CALL Q79
	;[790] 	    WAIT
	SRCFILE "goatcontest.bas",790
	CALL _wait
	;[791] 	  NEXT i	
	SRCFILE "goatcontest.bas",791
	MVI V32,R0
	INCR R0
	MVO R0,V32
	MVI V53,R1
	MULT R1,R4,5
	CMPR R1,R0
	BLE T148
	;[792] 	  
	SRCFILE "goatcontest.bas",792
	;[793] 	  FOR i = 1 to 5*j
	SRCFILE "goatcontest.bas",793
	MVII #1,R0
	MVO R0,V32
T149:
	;[794] 	    p2y=p2y+1
	SRCFILE "goatcontest.bas",794
	MVI V44,R0
	INCR R0
	MVO R0,V44
	;[795] 	    GOSUB end_draw
	SRCFILE "goatcontest.bas",795
	CALL Q79
	;[796] 	    WAIT
	SRCFILE "goatcontest.bas",796
	CALL _wait
	;[797] 	  NEXT i	
	SRCFILE "goatcontest.bas",797
	MVI V32,R0
	INCR R0
	MVO R0,V32
	MVI V53,R1
	MULT R1,R4,5
	CMPR R1,R0
	BLE T149
	;[798] 	NEXT j
	SRCFILE "goatcontest.bas",798
	MVI V53,R0
	INCR R0
	MVO R0,V53
	CMPI #2,R0
	BLE T143
	;[799] 	
	SRCFILE "goatcontest.bas",799
	;[800] 	'run towards each other
	SRCFILE "goatcontest.bas",800
	;[801] 	FOR i = 1 to 50
	SRCFILE "goatcontest.bas",801
	MVII #1,R0
	MVO R0,V32
T150:
	;[802] 	  spritetimer=spritetimer+1
	SRCFILE "goatcontest.bas",802
	MVI V2,R0
	INCR R0
	MVO R0,V2
	;[803] 	  IF spritetimer>=3 THEN spritetimer=0:#goat1sprite=#goat1sprite XOR $0020:#goat2sprite=#goat2sprite XOR $0020
	SRCFILE "goatcontest.bas",803
	MVI V2,R0
	CMPI #3,R0
	BLT T151
	CLRR R0
	MVO R0,V2
	MVI V26,R0
	XORI #32,R0
	MVO R0,V26
	MVI V27,R0
	XORI #32,R0
	MVO R0,V27
T151:
	;[804] 	  p1x=p1x+1
	SRCFILE "goatcontest.bas",804
	MVI V33,R0
	INCR R0
	MVO R0,V33
	;[805] 	  p2x=p2x-1
	SRCFILE "goatcontest.bas",805
	MVI V43,R0
	DECR R0
	MVO R0,V43
	;[806] 	  WAIT
	SRCFILE "goatcontest.bas",806
	CALL _wait
	;[807] 	  WAIT
	SRCFILE "goatcontest.bas",807
	CALL _wait
	;[808] 	  GOSUB end_draw
	SRCFILE "goatcontest.bas",808
	CALL Q79
	;[809] 	NEXT i
	SRCFILE "goatcontest.bas",809
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #50,R0
	BLE T150
	;[810] 	
	SRCFILE "goatcontest.bas",810
	;[811] 	FOR i = 1 to 10
	SRCFILE "goatcontest.bas",811
	MVII #1,R0
	MVO R0,V32
T152:
	;[812] 	    WAIT
	SRCFILE "goatcontest.bas",812
	CALL _wait
	;[813] 	NEXT i
	SRCFILE "goatcontest.bas",813
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #10,R0
	BLE T152
	;[814] 	
	SRCFILE "goatcontest.bas",814
	;[815] 	hearty=55
	SRCFILE "goatcontest.bas",815
	MVII #55,R0
	MVO R0,V52
	;[816] 	
	SRCFILE "goatcontest.bas",816
	;[817] 	'goats start to lie down
	SRCFILE "goatcontest.bas",817
	;[818] 	#goat1sprite=((256+24)*8)+#goat1color
	SRCFILE "goatcontest.bas",818
	MVII #2240,R0
	ADD V31,R0
	MVO R0,V26
	;[819] 	#goat2sprite=((256+26)*8)+#goat1color
	SRCFILE "goatcontest.bas",819
	MVII #2256,R0
	ADD V31,R0
	MVO R0,V27
	;[820] 	p1y=p1y+1
	SRCFILE "goatcontest.bas",820
	MVI V45,R0
	INCR R0
	MVO R0,V45
	;[821] 	p2y=p2y+1
	SRCFILE "goatcontest.bas",821
	MVI V44,R0
	INCR R0
	MVO R0,V44
	;[822] 	GOSUB end_draw
	SRCFILE "goatcontest.bas",822
	CALL Q79
	;[823] 	
	SRCFILE "goatcontest.bas",823
	;[824] 	FOR i = 1 to 10
	SRCFILE "goatcontest.bas",824
	MVII #1,R0
	MVO R0,V32
T153:
	;[825] 	  hearty=hearty-1
	SRCFILE "goatcontest.bas",825
	MVI V52,R0
	DECR R0
	MVO R0,V52
	;[826] 	  SPRITE 6,68+$300+16,hearty+$000,((256+49)*8)+2
	SRCFILE "goatcontest.bas",826
	MVII #852,R0
	MVO R0,_mobs+6
	MVI V52,R0
	MVO R0,_mobs+14
	MVII #2442,R0
	MVO R0,_mobs+22
	;[827] 	  WAIT
	SRCFILE "goatcontest.bas",827
	CALL _wait
	;[828] 	  WAIT
	SRCFILE "goatcontest.bas",828
	CALL _wait
	;[829] 	  WAIT
	SRCFILE "goatcontest.bas",829
	CALL _wait
	;[830] 	NEXT i
	SRCFILE "goatcontest.bas",830
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #10,R0
	BLE T153
	;[831] 	
	SRCFILE "goatcontest.bas",831
	;[832] 	'goats lying down
	SRCFILE "goatcontest.bas",832
	;[833] 	#goat1sprite=((256+28)*8)+#goat1color
	SRCFILE "goatcontest.bas",833
	MVII #2272,R0
	ADD V31,R0
	MVO R0,V26
	;[834] 	#goat2sprite=((256+30)*8)+#goat1color
	SRCFILE "goatcontest.bas",834
	MVII #2288,R0
	ADD V31,R0
	MVO R0,V27
	;[835] 	p1y=p1y+1
	SRCFILE "goatcontest.bas",835
	MVI V45,R0
	INCR R0
	MVO R0,V45
	;[836] 	p2y=p2y+1
	SRCFILE "goatcontest.bas",836
	MVI V44,R0
	INCR R0
	MVO R0,V44
	;[837] 	GOSUB end_draw
	SRCFILE "goatcontest.bas",837
	CALL Q79
	;[838] 	
	SRCFILE "goatcontest.bas",838
	;[839] 	FOR i = 1 to 10
	SRCFILE "goatcontest.bas",839
	MVII #1,R0
	MVO R0,V32
T154:
	;[840] 	  hearty=hearty-1
	SRCFILE "goatcontest.bas",840
	MVI V52,R0
	DECR R0
	MVO R0,V52
	;[841] 	  SPRITE 6,68+$300+16,hearty+$100,((256+49)*8)+2
	SRCFILE "goatcontest.bas",841
	MVII #852,R0
	MVO R0,_mobs+6
	MVI V52,R0
	ADDI #256,R0
	MVO R0,_mobs+14
	MVII #2442,R0
	MVO R0,_mobs+22
	;[842] 	  WAIT
	SRCFILE "goatcontest.bas",842
	CALL _wait
	;[843] 	  WAIT
	SRCFILE "goatcontest.bas",843
	CALL _wait
	;[844] 	  WAIT
	SRCFILE "goatcontest.bas",844
	CALL _wait
	;[845] 	NEXT i
	SRCFILE "goatcontest.bas",845
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #10,R0
	BLE T154
	;[846] 	
	SRCFILE "goatcontest.bas",846
	;[847] 	FOR i = 1 to 10
	SRCFILE "goatcontest.bas",847
	MVII #1,R0
	MVO R0,V32
T155:
	;[848] 	  hearty=hearty-1
	SRCFILE "goatcontest.bas",848
	MVI V52,R0
	DECR R0
	MVO R0,V52
	;[849] 	  SPRITE 6,68+$300+12+$400,hearty+$100,((256+49)*8)+2
	SRCFILE "goatcontest.bas",849
	MVII #1872,R0
	MVO R0,_mobs+6
	MVI V52,R0
	ADDI #256,R0
	MVO R0,_mobs+14
	MVII #2442,R0
	MVO R0,_mobs+22
	;[850] 	  WAIT
	SRCFILE "goatcontest.bas",850
	CALL _wait
	;[851] 	  WAIT
	SRCFILE "goatcontest.bas",851
	CALL _wait
	;[852] 	  WAIT
	SRCFILE "goatcontest.bas",852
	CALL _wait
	;[853] 	NEXT i
	SRCFILE "goatcontest.bas",853
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #10,R0
	BLE T155
	;[854] 	
	SRCFILE "goatcontest.bas",854
	;[855] 	FOR i = 1 to 10
	SRCFILE "goatcontest.bas",855
	MVII #1,R0
	MVO R0,V32
T156:
	;[856] 	  hearty=hearty-1
	SRCFILE "goatcontest.bas",856
	MVI V52,R0
	DECR R0
	MVO R0,V52
	;[857] 	  SPRITE 6,68+$300+12+$400,hearty+$100,((256+49)*8)+2
	SRCFILE "goatcontest.bas",857
	MVII #1872,R0
	MVO R0,_mobs+6
	MVI V52,R0
	ADDI #256,R0
	MVO R0,_mobs+14
	MVII #2442,R0
	MVO R0,_mobs+22
	;[858] 	  WAIT
	SRCFILE "goatcontest.bas",858
	CALL _wait
	;[859] 	  WAIT
	SRCFILE "goatcontest.bas",859
	CALL _wait
	;[860] 	  WAIT
	SRCFILE "goatcontest.bas",860
	CALL _wait
	;[861] 	NEXT i
	SRCFILE "goatcontest.bas",861
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #10,R0
	BLE T156
	;[862] 	
	SRCFILE "goatcontest.bas",862
	;[863] 	FOR i = 1 to 80
	SRCFILE "goatcontest.bas",863
	MVII #1,R0
	MVO R0,V32
T157:
	;[864] 	    WAIT
	SRCFILE "goatcontest.bas",864
	CALL _wait
	;[865] 	NEXT i
	SRCFILE "goatcontest.bas",865
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #80,R0
	BLE T157
	;[866] 	
	SRCFILE "goatcontest.bas",866
	;[867] 	PRINT AT 42 COLOR 2, "Congratulations!"   ' each PRINT uses about 300 bytes
	SRCFILE "goatcontest.bas",867
	MVII #554,R0
	MVO R0,_screen
	MVII #2,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #280,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #864,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #656,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[868] 	
	SRCFILE "goatcontest.bas",868
	;[869] 	FOR i = 1 to 80
	SRCFILE "goatcontest.bas",869
	MVII #1,R0
	MVO R0,V32
T158:
	;[870] 	    WAIT
	SRCFILE "goatcontest.bas",870
	CALL _wait
	;[871] 	NEXT i
	SRCFILE "goatcontest.bas",871
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #80,R0
	BLE T158
	;[872] 	
	SRCFILE "goatcontest.bas",872
	;[873] 	PRINT AT 82,"You have reunited"
	SRCFILE "goatcontest.bas",873
	MVII #594,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #456,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #944,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #680,R0
	MVO@ R0,R4
	XORI #576,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #552,R0
	MVO@ R0,R4
	XORI #656,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #128,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[874] 	PRINT AT 102," Mr. & Ms. Goat!"
	SRCFILE "goatcontest.bas",874
	MVII #614,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #360,R0
	MVO@ R0,R4
	XORI #1016,R0
	MVO@ R0,R4
	XORI #736,R0
	MVO@ R0,R4
	XORI #112,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #360,R0
	MVO@ R0,R4
	XORI #1008,R0
	MVO@ R0,R4
	XORI #744,R0
	MVO@ R0,R4
	XORI #112,R0
	MVO@ R0,R4
	XORI #312,R0
	MVO@ R0,R4
	XORI #832,R0
	MVO@ R0,R4
	XORI #112,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #680,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[875] 	
	SRCFILE "goatcontest.bas",875
	;[876] 	FOR i = 1 to 160
	SRCFILE "goatcontest.bas",876
	MVII #1,R0
	MVO R0,V32
T159:
	;[877] 	    WAIT
	SRCFILE "goatcontest.bas",877
	CALL _wait
	;[878] 	NEXT i
	SRCFILE "goatcontest.bas",878
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #160,R0
	BLE T159
	;[879] 	
	SRCFILE "goatcontest.bas",879
	;[880] 	CLS
	SRCFILE "goatcontest.bas",880
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[881] 	WAIT
	SRCFILE "goatcontest.bas",881
	CALL _wait
	;[882] 	
	SRCFILE "goatcontest.bas",882
	;[883] 	GOSUB reset_sprites
	SRCFILE "goatcontest.bas",883
	CALL Q4
	;[884] 		
	SRCFILE "goatcontest.bas",884
	;[885] 	FOR i = 1 to 40
	SRCFILE "goatcontest.bas",885
	MVII #1,R0
	MVO R0,V32
T160:
	;[886] 	    WAIT
	SRCFILE "goatcontest.bas",886
	CALL _wait
	;[887] 	NEXT i
	SRCFILE "goatcontest.bas",887
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #40,R0
	BLE T160
	;[888] 	
	SRCFILE "goatcontest.bas",888
	;[889] 	PRINT AT 22 COLOR 2, "Programmed by:"
	SRCFILE "goatcontest.bas",889
	MVII #534,R0
	MVO R0,_screen
	MVII #2,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #384,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #784,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #544,R0
	MVO@ R0,R4
	XORI #528,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #536,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[890] 	PRINT AT 42, "freewheel"
	SRCFILE "goatcontest.bas",890
	MVII #554,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #560,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #160,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[891] 	
	SRCFILE "goatcontest.bas",891
	;[892] 	FOR i = 1 to 120
	SRCFILE "goatcontest.bas",892
	MVII #1,R0
	MVO R0,V32
T161:
	;[893] 	    WAIT
	SRCFILE "goatcontest.bas",893
	CALL _wait
	;[894] 	NEXT i
	SRCFILE "goatcontest.bas",894
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #120,R0
	BLE T161
	;[895] 	
	SRCFILE "goatcontest.bas",895
	;[896] 	'CLS
	SRCFILE "goatcontest.bas",896
	;[897] 	WAIT
	SRCFILE "goatcontest.bas",897
	CALL _wait
	;[898] 	
	SRCFILE "goatcontest.bas",898
	;[899] 	FOR i = 1 to 40
	SRCFILE "goatcontest.bas",899
	MVII #1,R0
	MVO R0,V32
T162:
	;[900] 	    WAIT
	SRCFILE "goatcontest.bas",900
	CALL _wait
	;[901] 	NEXT i
	SRCFILE "goatcontest.bas",901
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #40,R0
	BLE T162
	;[902] 	
	SRCFILE "goatcontest.bas",902
	;[903] 	PRINT AT 82, "Intro screen by:"
	SRCFILE "goatcontest.bas",903
	MVII #594,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #328,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #824,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #632,R0
	MVO@ R0,R4
	XORI #664,R0
	MVO@ R0,R4
	XORI #128,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #624,R0
	MVO@ R0,R4
	XORI #528,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #536,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[904] 	PRINT AT 102, "Tarzilla"
	SRCFILE "goatcontest.bas",904
	MVII #614,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #416,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #936,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #40,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[905] 	
	SRCFILE "goatcontest.bas",905
	;[906] 	FOR i = 1 to 120
	SRCFILE "goatcontest.bas",906
	MVII #1,R0
	MVO R0,V32
T163:
	;[907] 	    WAIT
	SRCFILE "goatcontest.bas",907
	CALL _wait
	;[908] 	NEXT i
	SRCFILE "goatcontest.bas",908
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #120,R0
	BLE T163
	;[909] 	
	SRCFILE "goatcontest.bas",909
	;[910] 	FOR i = 1 to 40
	SRCFILE "goatcontest.bas",910
	MVII #1,R0
	MVO R0,V32
T164:
	;[911] 	    WAIT
	SRCFILE "goatcontest.bas",911
	CALL _wait
	;[912] 	NEXT i
	SRCFILE "goatcontest.bas",912
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #40,R0
	BLE T164
	;[913] 	
	SRCFILE "goatcontest.bas",913
	;[914] 	PRINT AT 142, "Special thanks to"
	SRCFILE "goatcontest.bas",914
	MVII #654,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #408,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #792,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #608,R0
	MVO@ R0,R4
	XORI #672,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	XORI #40,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #664,R0
	MVO@ R0,R4
	XORI #672,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[915] 	PRINT AT 166,  "EVERYONE"
	SRCFILE "goatcontest.bas",915
	MVII #678,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #296,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[916] 	PRINT AT 184, "at AtariAge!"
	SRCFILE "goatcontest.bas",916
	MVII #696,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #520,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #672,R0
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #936,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #832,R0
	MVO@ R0,R4
	XORI #816,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #544,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[917] 	
	SRCFILE "goatcontest.bas",917
	;[918] 	FOR i = 1 to 180
	SRCFILE "goatcontest.bas",918
	MVII #1,R0
	MVO R0,V32
T165:
	;[919] 	    WAIT
	SRCFILE "goatcontest.bas",919
	CALL _wait
	;[920] 	NEXT i
	SRCFILE "goatcontest.bas",920
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #180,R0
	BLE T165
	;[921] 	
	SRCFILE "goatcontest.bas",921
	;[922] 	CLS
	SRCFILE "goatcontest.bas",922
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[923] 	WAIT
	SRCFILE "goatcontest.bas",923
	CALL _wait
	;[924] 	
	SRCFILE "goatcontest.bas",924
	;[925] 	FOR i = 1 to 40
	SRCFILE "goatcontest.bas",925
	MVII #1,R0
	MVO R0,V32
T166:
	;[926] 	    WAIT
	SRCFILE "goatcontest.bas",926
	CALL _wait
	;[927] 	NEXT i
	SRCFILE "goatcontest.bas",927
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #40,R0
	BLE T166
	;[928] 	
	SRCFILE "goatcontest.bas",928
	;[929] 	PRINT AT 81, "Thanks for playing!"
	SRCFILE "goatcontest.bas",929
	MVII #593,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #416,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #992,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	XORI #40,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #664,R0
	MVO@ R0,R4
	XORI #560,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #656,R0
	MVO@ R0,R4
	XORI #640,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #128,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #560,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[930] 	
	SRCFILE "goatcontest.bas",930
	;[931] 	FOR i = 1 to 220
	SRCFILE "goatcontest.bas",931
	MVII #1,R0
	MVO R0,V32
T167:
	;[932] 	    WAIT
	SRCFILE "goatcontest.bas",932
	CALL _wait
	;[933] 	NEXT i
	SRCFILE "goatcontest.bas",933
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #220,R0
	BLE T167
	;[934] 	
	SRCFILE "goatcontest.bas",934
	;[935] 	'redraw adults
	SRCFILE "goatcontest.bas",935
	;[936] 	CLS
	SRCFILE "goatcontest.bas",936
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[937] 	WAIT
	SRCFILE "goatcontest.bas",937
	CALL _wait
	;[938] 	GOSUB end_draw
	SRCFILE "goatcontest.bas",938
	CALL Q79
	;[939] 	
	SRCFILE "goatcontest.bas",939
	;[940] 	FOR i = 1 to 40
	SRCFILE "goatcontest.bas",940
	MVII #1,R0
	MVO R0,V32
T168:
	;[941] 	    WAIT
	SRCFILE "goatcontest.bas",941
	CALL _wait
	;[942] 	NEXT i
	SRCFILE "goatcontest.bas",942
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #40,R0
	BLE T168
	;[943] 	
	SRCFILE "goatcontest.bas",943
	;[944] 	'bring out the baby	
	SRCFILE "goatcontest.bas",944
	;[945] 	FOR i = 1 to 80
	SRCFILE "goatcontest.bas",945
	MVII #1,R0
	MVO R0,V32
T169:
	;[946] 	  p3x=p3x-1
	SRCFILE "goatcontest.bas",946
	MVI V50,R0
	DECR R0
	MVO R0,V50
	;[947] 	  SPRITE 7,p3x+$300,p3y+$100+$400,((256+50)*8)+7
	SRCFILE "goatcontest.bas",947
	MVI V50,R0
	ADDI #768,R0
	MVO R0,_mobs+7
	MVI V51,R0
	ADDI #1280,R0
	MVO R0,_mobs+15
	MVII #2455,R0
	MVO R0,_mobs+23
	;[948] 	  WAIT
	SRCFILE "goatcontest.bas",948
	CALL _wait
	;[949] 	  WAIT
	SRCFILE "goatcontest.bas",949
	CALL _wait
	;[950] 	NEXT i
	SRCFILE "goatcontest.bas",950
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #80,R0
	BLE T169
	;[951] 	
	SRCFILE "goatcontest.bas",951
	;[952] 	'Mr. stands up
	SRCFILE "goatcontest.bas",952
	;[953] 	#goat1sprite=((256+24)*8)+#goat1color
	SRCFILE "goatcontest.bas",953
	MVII #2240,R0
	ADD V31,R0
	MVO R0,V26
	;[954] 	#goat2sprite=((256+26)*8)+#goat1color
	SRCFILE "goatcontest.bas",954
	MVII #2256,R0
	ADD V31,R0
	MVO R0,V27
	;[955] 	p1y=p1y-1
	SRCFILE "goatcontest.bas",955
	MVI V45,R0
	DECR R0
	MVO R0,V45
	;[956] 	SPRITE 0,p1x+$300,p1y+$100+$0080,#goat1sprite
	SRCFILE "goatcontest.bas",956
	MVI V33,R0
	ADDI #768,R0
	MVO R0,_mobs
	MVI V45,R0
	ADDI #384,R0
	MVO R0,_mobs+8
	MVI V26,R0
	MVO R0,_mobs+16
	;[957] 	SPRITE 1,p1x+$300+8,p1y+$100+$0080,#goat2sprite ' goat sprite #2, 8 pixels to the right
	SRCFILE "goatcontest.bas",957
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+1
	MVI V45,R0
	ADDI #384,R0
	MVO R0,_mobs+9
	MVI V27,R0
	MVO R0,_mobs+17
	;[958] 	SPRITE 2,p1x+$300+8,p1y+$100,((256+8)*8)+$1003 ' goat sprite #3, 8 pixels to the right
	SRCFILE "goatcontest.bas",958
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+2
	MVI V45,R0
	ADDI #256,R0
	MVO R0,_mobs+10
	MVII #6211,R0
	MVO R0,_mobs+18
	;[959] 
	SRCFILE "goatcontest.bas",959
	;[960] 	FOR i = 1 to 20
	SRCFILE "goatcontest.bas",960
	MVII #1,R0
	MVO R0,V32
T170:
	;[961] 	    WAIT
	SRCFILE "goatcontest.bas",961
	CALL _wait
	;[962] 	NEXT i
	SRCFILE "goatcontest.bas",962
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #20,R0
	BLE T170
	;[963] 	
	SRCFILE "goatcontest.bas",963
	;[964] 	#goat1sprite=((256+0)*8)+#goat1color
	SRCFILE "goatcontest.bas",964
	MVII #2048,R0
	ADD V31,R0
	MVO R0,V26
	;[965] 	#goat2sprite=((256+2)*8)+#goat1color
	SRCFILE "goatcontest.bas",965
	MVII #2064,R0
	ADD V31,R0
	MVO R0,V27
	;[966] 	p1y=p1y-1
	SRCFILE "goatcontest.bas",966
	MVI V45,R0
	DECR R0
	MVO R0,V45
	;[967] 	SPRITE 0,p1x+$300,p1y+$100+$0080,#goat1sprite
	SRCFILE "goatcontest.bas",967
	MVI V33,R0
	ADDI #768,R0
	MVO R0,_mobs
	MVI V45,R0
	ADDI #384,R0
	MVO R0,_mobs+8
	MVI V26,R0
	MVO R0,_mobs+16
	;[968] 	SPRITE 1,p1x+$300+8,p1y+$100+$0080,#goat2sprite ' goat sprite #2, 8 pixels to the right
	SRCFILE "goatcontest.bas",968
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+1
	MVI V45,R0
	ADDI #384,R0
	MVO R0,_mobs+9
	MVI V27,R0
	MVO R0,_mobs+17
	;[969] 	SPRITE 2,p1x+$300+8,p1y+$100,((256+8)*8)+$1003 ' goat sprite #3, 8 pixels to the right
	SRCFILE "goatcontest.bas",969
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+2
	MVI V45,R0
	ADDI #256,R0
	MVO R0,_mobs+10
	MVII #6211,R0
	MVO R0,_mobs+18
	;[970] 	
	SRCFILE "goatcontest.bas",970
	;[971] 	
	SRCFILE "goatcontest.bas",971
	;[972] 	FOR i = 1 to 40
	SRCFILE "goatcontest.bas",972
	MVII #1,R0
	MVO R0,V32
T171:
	;[973] 	    WAIT
	SRCFILE "goatcontest.bas",973
	CALL _wait
	;[974] 	NEXT i
	SRCFILE "goatcontest.bas",974
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #40,R0
	BLE T171
	;[975] 	
	SRCFILE "goatcontest.bas",975
	;[976] 	PRINT AT 183,"To be continued" 
	SRCFILE "goatcontest.bas",976
	MVII #695,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #416,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #984,R0
	MVO@ R0,R4
	XORI #632,R0
	MVO@ R0,R4
	XORI #528,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #552,R0
	MVO@ R0,R4
	XORI #536,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #128,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[977] 	FOR i = 1 to 40
	SRCFILE "goatcontest.bas",977
	MVII #1,R0
	MVO R0,V32
T172:
	;[978] 	    WAIT
	SRCFILE "goatcontest.bas",978
	CALL _wait
	;[979] 	NEXT i
	SRCFILE "goatcontest.bas",979
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #40,R0
	BLE T172
	;[980] 		
	SRCFILE "goatcontest.bas",980
	;[981] 	PRINT AT 214,"." 
	SRCFILE "goatcontest.bas",981
	MVII #726,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #112,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[982] 	FOR i = 1 to 10
	SRCFILE "goatcontest.bas",982
	MVII #1,R0
	MVO R0,V32
T173:
	;[983] 	    WAIT
	SRCFILE "goatcontest.bas",983
	CALL _wait
	;[984] 	NEXT i
	SRCFILE "goatcontest.bas",984
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #10,R0
	BLE T173
	;[985] 	
	SRCFILE "goatcontest.bas",985
	;[986] 	PRINT AT 215,"." 
	SRCFILE "goatcontest.bas",986
	MVII #727,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #112,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[987] 	FOR i = 1 to 10
	SRCFILE "goatcontest.bas",987
	MVII #1,R0
	MVO R0,V32
T174:
	;[988] 	    WAIT
	SRCFILE "goatcontest.bas",988
	CALL _wait
	;[989] 	NEXT i
	SRCFILE "goatcontest.bas",989
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #10,R0
	BLE T174
	;[990] 	
	SRCFILE "goatcontest.bas",990
	;[991] 	PRINT AT 216,"." 
	SRCFILE "goatcontest.bas",991
	MVII #728,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #112,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[992] 	FOR i = 1 to 40
	SRCFILE "goatcontest.bas",992
	MVII #1,R0
	MVO R0,V32
T175:
	;[993] 	    WAIT
	SRCFILE "goatcontest.bas",993
	CALL _wait
	;[994] 	NEXT i
	SRCFILE "goatcontest.bas",994
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #40,R0
	BLE T175
	;[995] 	
	SRCFILE "goatcontest.bas",995
	;[996] 	PRINT AT 217,"?" 
	SRCFILE "goatcontest.bas",996
	MVII #729,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #248,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[997] 	FOR i = 1 to 20
	SRCFILE "goatcontest.bas",997
	MVII #1,R0
	MVO R0,V32
T176:
	;[998] 	    WAIT
	SRCFILE "goatcontest.bas",998
	CALL _wait
	;[999] 	NEXT i
	SRCFILE "goatcontest.bas",999
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #20,R0
	BLE T176
	;[1000] 	
	SRCFILE "goatcontest.bas",1000
	;[1001] endloop:
	SRCFILE "goatcontest.bas",1001
	; ENDLOOP
Q80:	;[1002] 	c1 = CONT
	SRCFILE "goatcontest.bas",1002
	MVI 510,R0
	XOR 511,R0
	MVO R0,V34
	;[1003] 	IF c1 THEN GOSUB debounce_input:GOTO begin_game
	SRCFILE "goatcontest.bas",1003
	MVI V34,R0
	TSTR R0
	BEQ T177
	CALL Q28
	B Q3
T177:
	;[1004] 	GOTO endloop
	SRCFILE "goatcontest.bas",1004
	B Q80
	;[1005] 	
	SRCFILE "goatcontest.bas",1005
	;[1006] game_over:	
	SRCFILE "goatcontest.bas",1006
	; GAME_OVER
Q67:	;[1007] 	'slight pause to let last death sink in for player
	SRCFILE "goatcontest.bas",1007
	;[1008] 	FOR i = 1 TO 50
	SRCFILE "goatcontest.bas",1008
	MVII #1,R0
	MVO R0,V32
T178:
	;[1009] 	  WAIT
	SRCFILE "goatcontest.bas",1009
	CALL _wait
	;[1010] 	NEXT i
	SRCFILE "goatcontest.bas",1010
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #50,R0
	BLE T178
	;[1011] 	
	SRCFILE "goatcontest.bas",1011
	;[1012] 	CLS
	SRCFILE "goatcontest.bas",1012
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1013] 	WAIT
	SRCFILE "goatcontest.bas",1013
	CALL _wait
	;[1014] 	GOSUB reset_sprites
	SRCFILE "goatcontest.bas",1014
	CALL Q4
	;[1015] 	
	SRCFILE "goatcontest.bas",1015
	;[1016] 	MODE 1
	SRCFILE "goatcontest.bas",1016
	MVII #2,R0
	MVO R0,_mode_select
	;[1017] 	WAIT
	SRCFILE "goatcontest.bas",1017
	CALL _wait
	;[1018] 	DEFINE 0,16,gameover_goat_bitmaps_0
	SRCFILE "goatcontest.bas",1018
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q82,R0
	MVO R0,_gram_bitmap
	;[1019] 	WAIT
	SRCFILE "goatcontest.bas",1019
	CALL _wait
	;[1020] 	DEFINE 16,16,gameover_goat_bitmaps_1
	SRCFILE "goatcontest.bas",1020
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q83,R0
	MVO R0,_gram_bitmap
	;[1021] 	WAIT
	SRCFILE "goatcontest.bas",1021
	CALL _wait
	;[1022] 	DEFINE 32,16,gameover_goat_bitmaps_2
	SRCFILE "goatcontest.bas",1022
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q84,R0
	MVO R0,_gram_bitmap
	;[1023] 	WAIT
	SRCFILE "goatcontest.bas",1023
	CALL _wait
	;[1024] 	DEFINE 48,5,gameover_goat_bitmaps_3
	SRCFILE "goatcontest.bas",1024
	MVII #48,R0
	MVO R0,_gram_target
	MVII #5,R0
	MVO R0,_gram_total
	MVII #Q85,R0
	MVO R0,_gram_bitmap
	;[1025] 	WAIT
	SRCFILE "goatcontest.bas",1025
	CALL _wait
	;[1026] 	
	SRCFILE "goatcontest.bas",1026
	;[1027] 	SCREEN gameover_goat_screen
	SRCFILE "goatcontest.bas",1027
	MVII #Q86,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[1028] 
	SRCFILE "goatcontest.bas",1028
	;[1029] 	
	SRCFILE "goatcontest.bas",1029
	;[1030] 	PLAY tune_best_years
	SRCFILE "goatcontest.bas",1030
	MVII #Q87,R0
	CALL _play_music
	;[1031] 	
	SRCFILE "goatcontest.bas",1031
	;[1032] 	x_off=82
	SRCFILE "goatcontest.bas",1032
	MVII #82,R0
	MVO R0,V54
	;[1033] 	y_off=51
	SRCFILE "goatcontest.bas",1033
	MVII #51,R0
	MVO R0,V55
	;[1034] 	delay=3
	SRCFILE "goatcontest.bas",1034
	MVII #3,R0
	MVO R0,V56
	;[1035] 	
	SRCFILE "goatcontest.bas",1035
	;[1036] game_over_loop: 'draws the stars above the fallen goat's head
	SRCFILE "goatcontest.bas",1036
	; GAME_OVER_LOOP
Q88:	;[1037]     
	SRCFILE "goatcontest.bas",1037
	;[1038] 	SPRITE 0,x_off+$300+8,y_off+$100,((256+49)*8)+6  
	SRCFILE "goatcontest.bas",1038
	MVI V54,R0
	ADDI #776,R0
	MVO R0,_mobs
	MVI V55,R0
	ADDI #256,R0
	MVO R0,_mobs+8
	MVII #2446,R0
	MVO R0,_mobs+16
	;[1039] 	SPRITE 1,x_off+$300+16,y_off+$100,((256+50)*8)+6
	SRCFILE "goatcontest.bas",1039
	MVI V54,R0
	ADDI #784,R0
	MVO R0,_mobs+1
	MVI V55,R0
	ADDI #256,R0
	MVO R0,_mobs+9
	MVII #2454,R0
	MVO R0,_mobs+17
	;[1040] 	SPRITE 2,x_off+$300+24,y_off+$100+4,((256+49)*8)+6
	SRCFILE "goatcontest.bas",1040
	MVI V54,R0
	ADDI #792,R0
	MVO R0,_mobs+2
	MVI V55,R0
	ADDI #260,R0
	MVO R0,_mobs+10
	MVII #2446,R0
	MVO R0,_mobs+18
	;[1041] 	SPRITE 3,x_off+$300+16,y_off+$100+8,((256+50)*8)+6
	SRCFILE "goatcontest.bas",1041
	MVI V54,R0
	ADDI #784,R0
	MVO R0,_mobs+3
	MVI V55,R0
	ADDI #264,R0
	MVO R0,_mobs+11
	MVII #2454,R0
	MVO R0,_mobs+19
	;[1042] 	SPRITE 4,x_off+$300+8,y_off+$100+8,((256+49)*8)+6
	SRCFILE "goatcontest.bas",1042
	MVI V54,R0
	ADDI #776,R0
	MVO R0,_mobs+4
	MVI V55,R0
	ADDI #264,R0
	MVO R0,_mobs+12
	MVII #2446,R0
	MVO R0,_mobs+20
	;[1043] 	SPRITE 5,x_off+$300,y_off+$100+4,((256+50)*8)+6
	SRCFILE "goatcontest.bas",1043
	MVI V54,R0
	ADDI #768,R0
	MVO R0,_mobs+5
	MVI V55,R0
	ADDI #260,R0
	MVO R0,_mobs+13
	MVII #2454,R0
	MVO R0,_mobs+21
	;[1044]   
	SRCFILE "goatcontest.bas",1044
	;[1045] 	FOR i = 1 to delay
	SRCFILE "goatcontest.bas",1045
	MVII #1,R0
	MVO R0,V32
T179:
	;[1046] 	  WAIT
	SRCFILE "goatcontest.bas",1046
	CALL _wait
	;[1047] 	NEXT i
	SRCFILE "goatcontest.bas",1047
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMP V56,R0
	BLE T179
	;[1048]   
	SRCFILE "goatcontest.bas",1048
	;[1049]   	SPRITE 0,x_off+$300+10,y_off+$100,((256+49)*8)+6  
	SRCFILE "goatcontest.bas",1049
	MVI V54,R0
	ADDI #778,R0
	MVO R0,_mobs
	MVI V55,R0
	ADDI #256,R0
	MVO R0,_mobs+8
	MVII #2446,R0
	MVO R0,_mobs+16
	;[1050] 	SPRITE 1,x_off+$300+18,y_off+$100,((256+50)*8)+6
	SRCFILE "goatcontest.bas",1050
	MVI V54,R0
	ADDI #786,R0
	MVO R0,_mobs+1
	MVI V55,R0
	ADDI #256,R0
	MVO R0,_mobs+9
	MVII #2454,R0
	MVO R0,_mobs+17
	;[1051] 	SPRITE 2,x_off+$300+22,y_off+$100+6,((256+49)*8)+6
	SRCFILE "goatcontest.bas",1051
	MVI V54,R0
	ADDI #790,R0
	MVO R0,_mobs+2
	MVI V55,R0
	ADDI #262,R0
	MVO R0,_mobs+10
	MVII #2446,R0
	MVO R0,_mobs+18
	;[1052] 	SPRITE 3,x_off+$300+14,y_off+$100+8,((256+50)*8)+6
	SRCFILE "goatcontest.bas",1052
	MVI V54,R0
	ADDI #782,R0
	MVO R0,_mobs+3
	MVI V55,R0
	ADDI #264,R0
	MVO R0,_mobs+11
	MVII #2454,R0
	MVO R0,_mobs+19
	;[1053] 	SPRITE 4,x_off+$300+6,y_off+$100+8,((256+49)*8)+6
	SRCFILE "goatcontest.bas",1053
	MVI V54,R0
	ADDI #774,R0
	MVO R0,_mobs+4
	MVI V55,R0
	ADDI #264,R0
	MVO R0,_mobs+12
	MVII #2446,R0
	MVO R0,_mobs+20
	;[1054] 	SPRITE 5,x_off+$300+2,y_off+$100+2,((256+50)*8)+6
	SRCFILE "goatcontest.bas",1054
	MVI V54,R0
	ADDI #770,R0
	MVO R0,_mobs+5
	MVI V55,R0
	ADDI #258,R0
	MVO R0,_mobs+13
	MVII #2454,R0
	MVO R0,_mobs+21
	;[1055] 	
	SRCFILE "goatcontest.bas",1055
	;[1056] 	FOR i = 1 to delay
	SRCFILE "goatcontest.bas",1056
	MVII #1,R0
	MVO R0,V32
T180:
	;[1057] 	  WAIT
	SRCFILE "goatcontest.bas",1057
	CALL _wait
	;[1058] 	NEXT i
	SRCFILE "goatcontest.bas",1058
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMP V56,R0
	BLE T180
	;[1059] 	
	SRCFILE "goatcontest.bas",1059
	;[1060] 	SPRITE 0,x_off+$300+12,y_off+$100,((256+49)*8)+6  
	SRCFILE "goatcontest.bas",1060
	MVI V54,R0
	ADDI #780,R0
	MVO R0,_mobs
	MVI V55,R0
	ADDI #256,R0
	MVO R0,_mobs+8
	MVII #2446,R0
	MVO R0,_mobs+16
	;[1061] 	SPRITE 1,x_off+$300+20,y_off+$100,((256+50)*8)+6
	SRCFILE "goatcontest.bas",1061
	MVI V54,R0
	ADDI #788,R0
	MVO R0,_mobs+1
	MVI V55,R0
	ADDI #256,R0
	MVO R0,_mobs+9
	MVII #2454,R0
	MVO R0,_mobs+17
	;[1062] 	SPRITE 2,x_off+$300+20,y_off+$100+8,((256+49)*8)+6
	SRCFILE "goatcontest.bas",1062
	MVI V54,R0
	ADDI #788,R0
	MVO R0,_mobs+2
	MVI V55,R0
	ADDI #264,R0
	MVO R0,_mobs+10
	MVII #2446,R0
	MVO R0,_mobs+18
	;[1063] 	SPRITE 3,x_off+$300+12,y_off+$100+8,((256+50)*8)+6
	SRCFILE "goatcontest.bas",1063
	MVI V54,R0
	ADDI #780,R0
	MVO R0,_mobs+3
	MVI V55,R0
	ADDI #264,R0
	MVO R0,_mobs+11
	MVII #2454,R0
	MVO R0,_mobs+19
	;[1064] 	SPRITE 4,x_off+$300+4,y_off+$100+8,((256+49)*8)+6
	SRCFILE "goatcontest.bas",1064
	MVI V54,R0
	ADDI #772,R0
	MVO R0,_mobs+4
	MVI V55,R0
	ADDI #264,R0
	MVO R0,_mobs+12
	MVII #2446,R0
	MVO R0,_mobs+20
	;[1065] 	SPRITE 5,x_off+$300+4,y_off+$100,((256+50)*8)+6
	SRCFILE "goatcontest.bas",1065
	MVI V54,R0
	ADDI #772,R0
	MVO R0,_mobs+5
	MVI V55,R0
	ADDI #256,R0
	MVO R0,_mobs+13
	MVII #2454,R0
	MVO R0,_mobs+21
	;[1066] 	
	SRCFILE "goatcontest.bas",1066
	;[1067] 	FOR i = 1 to delay
	SRCFILE "goatcontest.bas",1067
	MVII #1,R0
	MVO R0,V32
T181:
	;[1068] 	  WAIT
	SRCFILE "goatcontest.bas",1068
	CALL _wait
	;[1069] 	NEXT i
	SRCFILE "goatcontest.bas",1069
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMP V56,R0
	BLE T181
	;[1070] 	
	SRCFILE "goatcontest.bas",1070
	;[1071] 	SPRITE 0,x_off+$300+14,y_off+$100,((256+49)*8)+6  
	SRCFILE "goatcontest.bas",1071
	MVI V54,R0
	ADDI #782,R0
	MVO R0,_mobs
	MVI V55,R0
	ADDI #256,R0
	MVO R0,_mobs+8
	MVII #2446,R0
	MVO R0,_mobs+16
	;[1072] 	SPRITE 1,x_off+$300+22,y_off+$100+2,((256+50)*8)+6
	SRCFILE "goatcontest.bas",1072
	MVI V54,R0
	ADDI #790,R0
	MVO R0,_mobs+1
	MVI V55,R0
	ADDI #258,R0
	MVO R0,_mobs+9
	MVII #2454,R0
	MVO R0,_mobs+17
	;[1073] 	SPRITE 2,x_off+$300+18,y_off+$100+8,((256+49)*8)+6
	SRCFILE "goatcontest.bas",1073
	MVI V54,R0
	ADDI #786,R0
	MVO R0,_mobs+2
	MVI V55,R0
	ADDI #264,R0
	MVO R0,_mobs+10
	MVII #2446,R0
	MVO R0,_mobs+18
	;[1074] 	SPRITE 3,x_off+$300+10,y_off+$100+8,((256+50)*8)+6
	SRCFILE "goatcontest.bas",1074
	MVI V54,R0
	ADDI #778,R0
	MVO R0,_mobs+3
	MVI V55,R0
	ADDI #264,R0
	MVO R0,_mobs+11
	MVII #2454,R0
	MVO R0,_mobs+19
	;[1075] 	SPRITE 4,x_off+$300+2,y_off+$100+6,((256+49)*8)+6
	SRCFILE "goatcontest.bas",1075
	MVI V54,R0
	ADDI #770,R0
	MVO R0,_mobs+4
	MVI V55,R0
	ADDI #262,R0
	MVO R0,_mobs+12
	MVII #2446,R0
	MVO R0,_mobs+20
	;[1076] 	SPRITE 5,x_off+$300+6,y_off+$100,((256+50)*8)+6
	SRCFILE "goatcontest.bas",1076
	MVI V54,R0
	ADDI #774,R0
	MVO R0,_mobs+5
	MVI V55,R0
	ADDI #256,R0
	MVO R0,_mobs+13
	MVII #2454,R0
	MVO R0,_mobs+21
	;[1077] 	
	SRCFILE "goatcontest.bas",1077
	;[1078] 	FOR i = 1 to delay
	SRCFILE "goatcontest.bas",1078
	MVII #1,R0
	MVO R0,V32
T182:
	;[1079] 	  WAIT
	SRCFILE "goatcontest.bas",1079
	CALL _wait
	;[1080] 	NEXT i
	SRCFILE "goatcontest.bas",1080
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMP V56,R0
	BLE T182
	;[1081] 	
	SRCFILE "goatcontest.bas",1081
	;[1082] 	c1=CONT
	SRCFILE "goatcontest.bas",1082
	MVI 510,R0
	XOR 511,R0
	MVO R0,V34
	;[1083] 	IF c1 THEN GOSUB debounce_input:GOTO begin_game
	SRCFILE "goatcontest.bas",1083
	MVI V34,R0
	TSTR R0
	BEQ T183
	CALL Q28
	B Q3
T183:
	;[1084] 	GOTO game_over_loop	
	SRCFILE "goatcontest.bas",1084
	B Q88
	;[1085] 
	SRCFILE "goatcontest.bas",1085
	;[1086] end_draw:	PROCEDURE
	SRCFILE "goatcontest.bas",1086
	; END_DRAW
Q79:	PROC
	BEGIN
	;[1087] 	' goat body is 0,2. horns is 8. ms goat bow is 20. heart is 49
	SRCFILE "goatcontest.bas",1087
	;[1088] 	SPRITE 0,p1x+$300,p1y+$100+$0080,#goat1sprite
	SRCFILE "goatcontest.bas",1088
	MVI V33,R0
	ADDI #768,R0
	MVO R0,_mobs
	MVI V45,R0
	ADDI #384,R0
	MVO R0,_mobs+8
	MVI V26,R0
	MVO R0,_mobs+16
	;[1089] 	SPRITE 1,p1x+$300+8,p1y+$100+$0080,#goat2sprite ' goat sprite #2, 8 pixels to the right
	SRCFILE "goatcontest.bas",1089
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+1
	MVI V45,R0
	ADDI #384,R0
	MVO R0,_mobs+9
	MVI V27,R0
	MVO R0,_mobs+17
	;[1090] 	SPRITE 2,p1x+$300+8,p1y+$100,((256+8)*8)+$1003 ' goat sprite #3, 8 pixels to the right
	SRCFILE "goatcontest.bas",1090
	MVI V33,R0
	ADDI #776,R0
	MVO R0,_mobs+2
	MVI V45,R0
	ADDI #256,R0
	MVO R0,_mobs+10
	MVII #6211,R0
	MVO R0,_mobs+18
	;[1091]  
	SRCFILE "goatcontest.bas",1091
	;[1092] 	SPRITE 5,p2x+$300+16,p2y+$100+$0080+$0400,#goat1sprite
	SRCFILE "goatcontest.bas",1092
	MVI V43,R0
	ADDI #784,R0
	MVO R0,_mobs+5
	MVI V44,R0
	ADDI #1408,R0
	MVO R0,_mobs+13
	MVI V26,R0
	MVO R0,_mobs+21
	;[1093] 	SPRITE 4,p2x+$300+8,p2y+$100+$0080+$0400,#goat2sprite ' goat sprite #2, 8 pixels to the right
	SRCFILE "goatcontest.bas",1093
	MVI V43,R0
	ADDI #776,R0
	MVO R0,_mobs+4
	MVI V44,R0
	ADDI #1408,R0
	MVO R0,_mobs+12
	MVI V27,R0
	MVO R0,_mobs+20
	;[1094] 	SPRITE 3,p2x+$300+9,p2y+$100+$0400+1,((256+20)*8)+2 ' goat sprite #3, 8 pixels to the right
	SRCFILE "goatcontest.bas",1094
	MVI V43,R0
	ADDI #777,R0
	MVO R0,_mobs+3
	MVI V44,R0
	ADDI #1281,R0
	MVO R0,_mobs+11
	MVII #2210,R0
	MVO R0,_mobs+19
	;[1095] 	
	SRCFILE "goatcontest.bas",1095
	;[1096] 	END
	SRCFILE "goatcontest.bas",1096
	RETURN
	ENDP
	;[1097] 	
	SRCFILE "goatcontest.bas",1097
	;[1098] 	
	SRCFILE "goatcontest.bas",1098
	;[1099] stage_complete:	PROCEDURE
	SRCFILE "goatcontest.bas",1099
	; STAGE_COMPLETE
Q45:	PROC
	BEGIN
	;[1100] 	' yay, you've completed a stage! play a quick tune and blink the nom meter
	SRCFILE "goatcontest.bas",1100
	;[1101] 	PLAY stage_complete_song
	SRCFILE "goatcontest.bas",1101
	MVII #Q91,R0
	CALL _play_music
	;[1102] 	
	SRCFILE "goatcontest.bas",1102
	;[1103] 	FOR j = 1 to 170
	SRCFILE "goatcontest.bas",1103
	MVII #1,R0
	MVO R0,V53
T184:
	;[1104] 	  FOR i = 1 to 8
	SRCFILE "goatcontest.bas",1104
	MVII #1,R0
	MVO R0,V32
T185:
	;[1105] 	    PRINT AT 3+i,((256+58)*8)+j%8 
	SRCFILE "goatcontest.bas",1105
	MVI V32,R0
	ADDI #515,R0
	MVO R0,_screen
	MVI V53,R0
	ANDI #7,R0
	ADDI #2512,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1106] 	  NEXT i
	SRCFILE "goatcontest.bas",1106
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #8,R0
	BLE T185
	;[1107] 	  WAIT
	SRCFILE "goatcontest.bas",1107
	CALL _wait
	;[1108] 	NEXT j
	SRCFILE "goatcontest.bas",1108
	MVI V53,R0
	INCR R0
	MVO R0,V53
	CMPI #170,R0
	BLE T184
	;[1109] 	
	SRCFILE "goatcontest.bas",1109
	;[1110] 	lives=lives+1
	SRCFILE "goatcontest.bas",1110
	MVI V17,R0
	INCR R0
	MVO R0,V17
	;[1111] 	
	SRCFILE "goatcontest.bas",1111
	;[1112] 	END
	SRCFILE "goatcontest.bas",1112
	RETURN
	ENDP
	;[1113] 
	SRCFILE "goatcontest.bas",1113
	;[1114] stage_spring:	PROCEDURE
	SRCFILE "goatcontest.bas",1114
	; STAGE_SPRING
Q30:	PROC
	BEGIN
	;[1115] 	#stagescore=springscore
	SRCFILE "goatcontest.bas",1115
	MVII #4096,R0
	MVO R0,V1
	;[1116] 
	SRCFILE "goatcontest.bas",1116
	;[1117] 	CLS 
	SRCFILE "goatcontest.bas",1117
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1118] 	WAIT
	SRCFILE "goatcontest.bas",1118
	CALL _wait
	;[1119] 
	SRCFILE "goatcontest.bas",1119
	;[1120] 	FOR i = 1 TO 50
	SRCFILE "goatcontest.bas",1120
	MVII #1,R0
	MVO R0,V32
T186:
	;[1121] 	  WAIT
	SRCFILE "goatcontest.bas",1121
	CALL _wait
	;[1122] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1122
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1123] 	NEXT i
	SRCFILE "goatcontest.bas",1123
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #50,R0
	BLE T186
	;[1124] 	CLS
	SRCFILE "goatcontest.bas",1124
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1125] 	WAIT
	SRCFILE "goatcontest.bas",1125
	CALL _wait
	;[1126] 
	SRCFILE "goatcontest.bas",1126
	;[1127] 	MODE 1
	SRCFILE "goatcontest.bas",1127
	MVII #2,R0
	MVO R0,_mode_select
	;[1128] 	WAIT
	SRCFILE "goatcontest.bas",1128
	CALL _wait
	;[1129] 	DEFINE 0,16,inter1_bitmaps_0
	SRCFILE "goatcontest.bas",1129
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q94,R0
	MVO R0,_gram_bitmap
	;[1130] 	WAIT
	SRCFILE "goatcontest.bas",1130
	CALL _wait
	;[1131] 	DEFINE 16,16,inter1_bitmaps_1
	SRCFILE "goatcontest.bas",1131
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q95,R0
	MVO R0,_gram_bitmap
	;[1132] 	WAIT
	SRCFILE "goatcontest.bas",1132
	CALL _wait
	;[1133] 	DEFINE 32,16,inter1_bitmaps_2
	SRCFILE "goatcontest.bas",1133
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q96,R0
	MVO R0,_gram_bitmap
	;[1134] 	WAIT
	SRCFILE "goatcontest.bas",1134
	CALL _wait
	;[1135] 	DEFINE 48,6,inter1_bitmaps_3
	SRCFILE "goatcontest.bas",1135
	MVII #48,R0
	MVO R0,_gram_target
	MVII #6,R0
	MVO R0,_gram_total
	MVII #Q97,R0
	MVO R0,_gram_bitmap
	;[1136] 	WAIT
	SRCFILE "goatcontest.bas",1136
	CALL _wait
	;[1137] 		
	SRCFILE "goatcontest.bas",1137
	;[1138] 	PLAY inter1_song1
	SRCFILE "goatcontest.bas",1138
	MVII #Q98,R0
	CALL _play_music
	;[1139] 		
	SRCFILE "goatcontest.bas",1139
	;[1140] 	SCREEN inter1_cards1
	SRCFILE "goatcontest.bas",1140
	MVII #Q99,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[1141] 	'ms goat bow, top left panel
	SRCFILE "goatcontest.bas",1141
	;[1142] 	SPRITE 0,63+$300,29+$100,((256+47)*8)+2
	SRCFILE "goatcontest.bas",1142
	MVII #831,R0
	MVO R0,_mobs
	MVII #285,R0
	MVO R0,_mobs+8
	MVII #2426,R0
	MVO R0,_mobs+16
	;[1143] 	
	SRCFILE "goatcontest.bas",1143
	;[1144] 	' first dramatic pause
	SRCFILE "goatcontest.bas",1144
	;[1145] 	FOR i = 1 to 60
	SRCFILE "goatcontest.bas",1145
	MVII #1,R0
	MVO R0,V32
T188:
	;[1146] 	  WAIT
	SRCFILE "goatcontest.bas",1146
	CALL _wait
	;[1147] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1147
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1148] 	NEXT i
	SRCFILE "goatcontest.bas",1148
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #60,R0
	BLE T188
	;[1149] 	
	SRCFILE "goatcontest.bas",1149
	;[1150] 	' make whistle notes appear
	SRCFILE "goatcontest.bas",1150
	;[1151] 	FOR i = 1 to 15
	SRCFILE "goatcontest.bas",1151
	MVII #1,R0
	MVO R0,V32
T190:
	;[1152] 	  WAIT
	SRCFILE "goatcontest.bas",1152
	CALL _wait
	;[1153] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1153
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1154] 	NEXT i
	SRCFILE "goatcontest.bas",1154
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #15,R0
	BLE T190
	;[1155] 	SPRITE 3,29+$300,20+$100,((256+49)*8)+$1004
	SRCFILE "goatcontest.bas",1155
	MVII #797,R0
	MVO R0,_mobs+3
	MVII #276,R0
	MVO R0,_mobs+11
	MVII #6540,R0
	MVO R0,_mobs+19
	;[1156] 	FOR i = 1 to 15
	SRCFILE "goatcontest.bas",1156
	MVII #1,R0
	MVO R0,V32
T192:
	;[1157] 	  WAIT
	SRCFILE "goatcontest.bas",1157
	CALL _wait
	;[1158] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1158
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1159] 	NEXT i
	SRCFILE "goatcontest.bas",1159
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #15,R0
	BLE T192
	;[1160] 	SPRITE 4,39+$300,17+$100,((256+48)*8)+$1001
	SRCFILE "goatcontest.bas",1160
	MVII #807,R0
	MVO R0,_mobs+4
	MVII #273,R0
	MVO R0,_mobs+12
	MVII #6529,R0
	MVO R0,_mobs+20
	;[1161] 	FOR i = 1 to 15
	SRCFILE "goatcontest.bas",1161
	MVII #1,R0
	MVO R0,V32
T194:
	;[1162] 	  WAIT
	SRCFILE "goatcontest.bas",1162
	CALL _wait
	;[1163] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1163
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1164] 	NEXT i
	SRCFILE "goatcontest.bas",1164
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #15,R0
	BLE T194
	;[1165] 	SPRITE 5,46+$300,14+$100,((256+49)*8)+6
	SRCFILE "goatcontest.bas",1165
	MVII #814,R0
	MVO R0,_mobs+5
	MVII #270,R0
	MVO R0,_mobs+13
	MVII #2446,R0
	MVO R0,_mobs+21
	;[1166] 	
	SRCFILE "goatcontest.bas",1166
	;[1167] 	' second dramatic pause
	SRCFILE "goatcontest.bas",1167
	;[1168] 	FOR i = 1 to 50
	SRCFILE "goatcontest.bas",1168
	MVII #1,R0
	MVO R0,V32
T196:
	;[1169] 	  WAIT
	SRCFILE "goatcontest.bas",1169
	CALL _wait
	;[1170] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1170
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1171] 	NEXT i
	SRCFILE "goatcontest.bas",1171
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #50,R0
	BLE T196
	;[1172] 	
	SRCFILE "goatcontest.bas",1172
	;[1173] 	'ms goat notices the attention
	SRCFILE "goatcontest.bas",1173
	;[1174] 	SPRITE 6,63+$300,20+$100,((256+52)*8)+$1004
	SRCFILE "goatcontest.bas",1174
	MVII #831,R0
	MVO R0,_mobs+6
	MVII #276,R0
	MVO R0,_mobs+14
	MVII #6564,R0
	MVO R0,_mobs+22
	;[1175] 	
	SRCFILE "goatcontest.bas",1175
	;[1176] 	FOR i = 1 to 40
	SRCFILE "goatcontest.bas",1176
	MVII #1,R0
	MVO R0,V32
T198:
	;[1177] 	  WAIT
	SRCFILE "goatcontest.bas",1177
	CALL _wait
	;[1178] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1178
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1179] 	NEXT i
	SRCFILE "goatcontest.bas",1179
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #40,R0
	BLE T198
	;[1180] 	
	SRCFILE "goatcontest.bas",1180
	;[1181] 	SPRITE 3,0,0,0
	SRCFILE "goatcontest.bas",1181
	CLRR R0
	MVO R0,_mobs+3
	MVO R0,_mobs+11
	NOP
	MVO R0,_mobs+19
	;[1182] 	SPRITE 4,0,0,0
	SRCFILE "goatcontest.bas",1182
	MVO R0,_mobs+4
	NOP
	MVO R0,_mobs+12
	MVO R0,_mobs+20
	;[1183] 	SPRITE 5,0,0,0
	SRCFILE "goatcontest.bas",1183
	NOP
	MVO R0,_mobs+5
	MVO R0,_mobs+13
	NOP
	MVO R0,_mobs+21
	;[1184] 	
	SRCFILE "goatcontest.bas",1184
	;[1185] 	' make whistle notes appear a second time
	SRCFILE "goatcontest.bas",1185
	;[1186] 	FOR i = 1 to 15
	SRCFILE "goatcontest.bas",1186
	MVII #1,R0
	MVO R0,V32
T200:
	;[1187] 	  WAIT
	SRCFILE "goatcontest.bas",1187
	CALL _wait
	;[1188] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1188
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1189] 	NEXT i
	SRCFILE "goatcontest.bas",1189
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #15,R0
	BLE T200
	;[1190] 	SPRITE 3,29+$300,20+$100,((256+48)*8)+$1002
	SRCFILE "goatcontest.bas",1190
	MVII #797,R0
	MVO R0,_mobs+3
	MVII #276,R0
	MVO R0,_mobs+11
	MVII #6530,R0
	MVO R0,_mobs+19
	;[1191] 	FOR i = 1 to 15
	SRCFILE "goatcontest.bas",1191
	MVII #1,R0
	MVO R0,V32
T202:
	;[1192] 	  WAIT
	SRCFILE "goatcontest.bas",1192
	CALL _wait
	;[1193] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1193
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1194] 	NEXT i
	SRCFILE "goatcontest.bas",1194
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #15,R0
	BLE T202
	;[1195] 	SPRITE 4,37+$300,17+$100,((256+49)*8)+$1007
	SRCFILE "goatcontest.bas",1195
	MVII #805,R0
	MVO R0,_mobs+4
	MVII #273,R0
	MVO R0,_mobs+12
	MVII #6543,R0
	MVO R0,_mobs+20
	;[1196] 	FOR i = 1 to 15
	SRCFILE "goatcontest.bas",1196
	MVII #1,R0
	MVO R0,V32
T204:
	;[1197] 	  WAIT
	SRCFILE "goatcontest.bas",1197
	CALL _wait
	;[1198] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1198
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1199] 	NEXT i
	SRCFILE "goatcontest.bas",1199
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #15,R0
	BLE T204
	;[1200] 	SPRITE 5,46+$300,14+$100,((256+48)*8)+4
	SRCFILE "goatcontest.bas",1200
	MVII #814,R0
	MVO R0,_mobs+5
	MVII #270,R0
	MVO R0,_mobs+13
	MVII #2436,R0
	MVO R0,_mobs+21
	;[1201] 	
	SRCFILE "goatcontest.bas",1201
	;[1202] 	SPRITE 6,0,0,0
	SRCFILE "goatcontest.bas",1202
	CLRR R0
	MVO R0,_mobs+6
	MVO R0,_mobs+14
	NOP
	MVO R0,_mobs+22
	;[1203] 	
	SRCFILE "goatcontest.bas",1203
	;[1204] 	FOR i = 1 TO 10
	SRCFILE "goatcontest.bas",1204
	MVII #1,R0
	MVO R0,V32
T206:
	;[1205] 	  WAIT
	SRCFILE "goatcontest.bas",1205
	CALL _wait
	;[1206] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1206
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1207] 	NEXT i
	SRCFILE "goatcontest.bas",1207
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #10,R0
	BLE T206
	;[1208] 	
	SRCFILE "goatcontest.bas",1208
	;[1209] 	'ms goat likes the attention
	SRCFILE "goatcontest.bas",1209
	;[1210] 	SPRITE 6,63+$300,20+$100,((256+53)*8)+$1004
	SRCFILE "goatcontest.bas",1210
	MVII #831,R0
	MVO R0,_mobs+6
	MVII #276,R0
	MVO R0,_mobs+14
	MVII #6572,R0
	MVO R0,_mobs+22
	;[1211] 	
	SRCFILE "goatcontest.bas",1211
	;[1212] 	FOR i = 1 TO 90
	SRCFILE "goatcontest.bas",1212
	MVII #1,R0
	MVO R0,V32
T208:
	;[1213] 	  WAIT
	SRCFILE "goatcontest.bas",1213
	CALL _wait
	;[1214] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1214
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1215] 	NEXT i
	SRCFILE "goatcontest.bas",1215
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #90,R0
	BLE T208
	;[1216]   
	SRCFILE "goatcontest.bas",1216
	;[1217] 	SPRITE 3,0,0,0
	SRCFILE "goatcontest.bas",1217
	CLRR R0
	MVO R0,_mobs+3
	MVO R0,_mobs+11
	NOP
	MVO R0,_mobs+19
	;[1218] 	SPRITE 4,0,0,0
	SRCFILE "goatcontest.bas",1218
	MVO R0,_mobs+4
	NOP
	MVO R0,_mobs+12
	MVO R0,_mobs+20
	;[1219] 	SPRITE 5,0,0,0
	SRCFILE "goatcontest.bas",1219
	NOP
	MVO R0,_mobs+5
	MVO R0,_mobs+13
	NOP
	MVO R0,_mobs+21
	;[1220] 	SPRITE 6,0,0,0
	SRCFILE "goatcontest.bas",1220
	MVO R0,_mobs+6
	NOP
	MVO R0,_mobs+14
	MVO R0,_mobs+22
	;[1221]   
	SRCFILE "goatcontest.bas",1221
	;[1222] 	SCREEN inter1_cards2
	SRCFILE "goatcontest.bas",1222
	MVII #Q100,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[1223] 	'ms goat bow, top right panel
	SRCFILE "goatcontest.bas",1223
	;[1224] 	SPRITE 1,137+$300,29+$100+$400,((256+47)*8)+2
	SRCFILE "goatcontest.bas",1224
	MVII #905,R0
	MVO R0,_mobs+1
	MVII #1309,R0
	MVO R0,_mobs+9
	MVII #2426,R0
	MVO R0,_mobs+17
	;[1225] 	FOR i = 1 TO 200
	SRCFILE "goatcontest.bas",1225
	MVII #1,R0
	MVO R0,V32
T210:
	;[1226] 	  WAIT
	SRCFILE "goatcontest.bas",1226
	CALL _wait
	;[1227] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1227
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1228] 	NEXT i
	SRCFILE "goatcontest.bas",1228
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #200,R0
	BLE T210
	;[1229] 	
	SRCFILE "goatcontest.bas",1229
	;[1230] 	SCREEN inter1_cards3
	SRCFILE "goatcontest.bas",1230
	MVII #Q101,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[1231] 	'ms goat bow, bot left panel
	SRCFILE "goatcontest.bas",1231
	;[1232] 	SPRITE 2,73+$300,77+$100+$400,((256+47)*8)+2
	SRCFILE "goatcontest.bas",1232
	MVII #841,R0
	MVO R0,_mobs+2
	MVII #1357,R0
	MVO R0,_mobs+10
	MVII #2426,R0
	MVO R0,_mobs+18
	;[1233] 	PLAY inter1_song2
	SRCFILE "goatcontest.bas",1233
	MVII #Q102,R0
	CALL _play_music
	;[1234] 	FOR i = 1 TO 140
	SRCFILE "goatcontest.bas",1234
	MVII #1,R0
	MVO R0,V32
T212:
	;[1235] 	  WAIT
	SRCFILE "goatcontest.bas",1235
	CALL _wait
	;[1236] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1236
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1237] 	NEXT i
	SRCFILE "goatcontest.bas",1237
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #140,R0
	BLE T212
	;[1238] 	
	SRCFILE "goatcontest.bas",1238
	;[1239] 	SCREEN inter1_cards4
	SRCFILE "goatcontest.bas",1239
	MVII #Q103,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[1240] 	
	SRCFILE "goatcontest.bas",1240
	;[1241] 	'goat gets mad
	SRCFILE "goatcontest.bas",1241
	;[1242] 	SPRITE 6,116+$300,70+$100,((256+50)*8)+2
	SRCFILE "goatcontest.bas",1242
	MVII #884,R0
	MVO R0,_mobs+6
	MVII #326,R0
	MVO R0,_mobs+14
	MVII #2450,R0
	MVO R0,_mobs+22
	;[1243] 	SPRITE 7,116+$300,70+$100,((256+51)*8)+0
	SRCFILE "goatcontest.bas",1243
	MVII #884,R0
	MVO R0,_mobs+7
	MVII #326,R0
	MVO R0,_mobs+15
	MVII #2456,R0
	MVO R0,_mobs+23
	;[1244] 	
	SRCFILE "goatcontest.bas",1244
	;[1245] 	FOR i = 1 to 50
	SRCFILE "goatcontest.bas",1245
	MVII #1,R0
	MVO R0,V32
T214:
	;[1246] 	  WAIT
	SRCFILE "goatcontest.bas",1246
	CALL _wait
	;[1247] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1247
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1248] 	NEXT i
	SRCFILE "goatcontest.bas",1248
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #50,R0
	BLE T214
	;[1249] 	
	SRCFILE "goatcontest.bas",1249
	;[1250] 	'goat swears, draw word balloon
	SRCFILE "goatcontest.bas",1250
	;[1251] 	PRINT AT 155,$08B7
	SRCFILE "goatcontest.bas",1251
	MVII #667,R0
	MVO R0,_screen
	MVII #2231,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1252] 	PRINT AT 156,$08BF
	SRCFILE "goatcontest.bas",1252
	MVII #668,R0
	MVO R0,_screen
	MVII #2239,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1253] 	PRINT AT 157,$08C7
	SRCFILE "goatcontest.bas",1253
	MVII #669,R0
	MVO R0,_screen
	MVII #2247,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1254] 	PRINT AT 158,$08CF
	SRCFILE "goatcontest.bas",1254
	MVII #670,R0
	MVO R0,_screen
	MVII #2255,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1255] 	PRINT AT 159,$08D7
	SRCFILE "goatcontest.bas",1255
	MVII #671,R0
	MVO R0,_screen
	MVII #2263,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1256] 	PRINT AT 175,$0907
	SRCFILE "goatcontest.bas",1256
	MVII #687,R0
	MVO R0,_screen
	MVII #2311,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1257] 	PRINT AT 176,$090F
	SRCFILE "goatcontest.bas",1257
	MVII #688,R0
	MVO R0,_screen
	MVII #2319,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1258] 	PRINT AT 177,$0917
	SRCFILE "goatcontest.bas",1258
	MVII #689,R0
	MVO R0,_screen
	MVII #2327,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1259] 	PRINT AT 178,$0917
	SRCFILE "goatcontest.bas",1259
	MVII #690,R0
	MVO R0,_screen
	MVII #2327,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1260] 	PRINT AT 179,$091F
	SRCFILE "goatcontest.bas",1260
	MVII #691,R0
	MVO R0,_screen
	MVII #2335,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1261] 	
	SRCFILE "goatcontest.bas",1261
	;[1262] 	'goat bleat noise
	SRCFILE "goatcontest.bas",1262
	;[1263] 	GOSUB goat_bleat
	SRCFILE "goatcontest.bas",1263
	CALL Q55
	;[1264] 	
	SRCFILE "goatcontest.bas",1264
	;[1265] 	FOR i = 1 to 50
	SRCFILE "goatcontest.bas",1265
	MVII #1,R0
	MVO R0,V32
T216:
	;[1266] 	  WAIT
	SRCFILE "goatcontest.bas",1266
	CALL _wait
	;[1267] 	NEXT i  
	SRCFILE "goatcontest.bas",1267
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #50,R0
	BLE T216
	;[1268] 	
	SRCFILE "goatcontest.bas",1268
	;[1269] 	
	SRCFILE "goatcontest.bas",1269
	;[1270] 	PLAY inter1_song3
	SRCFILE "goatcontest.bas",1270
	MVII #Q104,R0
	CALL _play_music
	;[1271] 	
	SRCFILE "goatcontest.bas",1271
	;[1272] 	FOR i = 1 TO 150
	SRCFILE "goatcontest.bas",1272
	MVII #1,R0
	MVO R0,V32
T217:
	;[1273] 	  WAIT
	SRCFILE "goatcontest.bas",1273
	CALL _wait
	;[1274] 	  IF CONT1.BUTTON THEN GOTO spring_title
	SRCFILE "goatcontest.bas",1274
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q93
	;[1275] 	NEXT i
	SRCFILE "goatcontest.bas",1275
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #150,R0
	BLE T217
	;[1276] 	
	SRCFILE "goatcontest.bas",1276
	;[1277] spring_title:
	SRCFILE "goatcontest.bas",1277
	; SPRING_TITLE
Q93:	;[1278] 
	SRCFILE "goatcontest.bas",1278
	;[1279] 	PLAY OFF
	SRCFILE "goatcontest.bas",1279
	CLRR R0
	CALL _play_music
	;[1280] 	CLS
	SRCFILE "goatcontest.bas",1280
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1281] 	MODE 0,0,0,0,0
	SRCFILE "goatcontest.bas",1281
	CLRR R0
	MVO R0,_color
	MVII #1,R0
	MVO R0,_mode_select
	;[1282] 	
	SRCFILE "goatcontest.bas",1282
	;[1283] 	WAIT
	SRCFILE "goatcontest.bas",1283
	CALL _wait
	;[1284] 
	SRCFILE "goatcontest.bas",1284
	;[1285] 	GOSUB reset_sprites	
	SRCFILE "goatcontest.bas",1285
	CALL Q4
	;[1286] 
	SRCFILE "goatcontest.bas",1286
	;[1287] 	PRINT AT 107 COLOR 5,"SPRING"
	SRCFILE "goatcontest.bas",1287
	MVII #619,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #408,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #24,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[1288] 	
	SRCFILE "goatcontest.bas",1288
	;[1289] 	VOICE INIT
	SRCFILE "goatcontest.bas",1289
	CALL IV_INIT
	;[1290] 	VOICE PLAY spring_voice
	SRCFILE "goatcontest.bas",1290
	MVII #Q106,R0
	CALL IV_PLAY.1
	;[1291] 	
	SRCFILE "goatcontest.bas",1291
	;[1292] 	FOR i = 1 TO 100
	SRCFILE "goatcontest.bas",1292
	MVII #1,R0
	MVO R0,V32
T219:
	;[1293] 	  WAIT
	SRCFILE "goatcontest.bas",1293
	CALL _wait
	;[1294] 	NEXT i
	SRCFILE "goatcontest.bas",1294
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #100,R0
	BLE T219
	;[1295] 	CLS
	SRCFILE "goatcontest.bas",1295
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1296] 	WAIT
	SRCFILE "goatcontest.bas",1296
	CALL _wait
	;[1297] 
	SRCFILE "goatcontest.bas",1297
	;[1298] 	'set object colors
	SRCFILE "goatcontest.bas",1298
	;[1299] 	#obj4sprite=#obj4sprite OR $0007 'white shirt
	SRCFILE "goatcontest.bas",1299
	MVI V35,R0
	ANDI #-8,R0
	XORI #7,R0
	MVO R0,V35
	;[1300] 	#obj5sprite=#obj5sprite OR $1004 'pink can
	SRCFILE "goatcontest.bas",1300
	MVI V36,R0
	ANDI #-4101,R0
	XORI #4100,R0
	MVO R0,V36
	;[1301] 	#obj6sprite=#obj6sprite OR $0001 'blue fish
	SRCFILE "goatcontest.bas",1301
	MVI V37,R0
	ANDI #-2,R0
	XORI #1,R0
	MVO R0,V37
	;[1302] 	#rocksprite=#rocksprite OR $0000 'black rock
	SRCFILE "goatcontest.bas",1302
	MVI V38,R0
	MVO R0,V38
	;[1303] 	
	SRCFILE "goatcontest.bas",1303
	;[1304] 	#goat1color=$7
	SRCFILE "goatcontest.bas",1304
	MVII #7,R0
	MVO R0,V31
	;[1305] 
	SRCFILE "goatcontest.bas",1305
	;[1306] 	
	SRCFILE "goatcontest.bas",1306
	;[1307] 	END
	SRCFILE "goatcontest.bas",1307
	RETURN
	ENDP
	;[1308] 	
	SRCFILE "goatcontest.bas",1308
	;[1309] stage_summer:	PROCEDURE
	SRCFILE "goatcontest.bas",1309
	; STAGE_SUMMER
Q31:	PROC
	BEGIN
	;[1310] 	#stagescore=summerscore
	SRCFILE "goatcontest.bas",1310
	MVII #8192,R0
	MVO R0,V1
	;[1311] 	CLS
	SRCFILE "goatcontest.bas",1311
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1312] 	WAIT
	SRCFILE "goatcontest.bas",1312
	CALL _wait
	;[1313] 	PRINT AT 107 COLOR 4,"SUMMER"
	SRCFILE "goatcontest.bas",1313
	MVII #619,R0
	MVO R0,_screen
	MVII #4,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #408,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[1314] 	
	SRCFILE "goatcontest.bas",1314
	;[1315] 	VOICE INIT
	SRCFILE "goatcontest.bas",1315
	CALL IV_INIT
	;[1316] 	VOICE PLAY summer_voice
	SRCFILE "goatcontest.bas",1316
	MVII #Q108,R0
	CALL IV_PLAY.1
	;[1317] 		
	SRCFILE "goatcontest.bas",1317
	;[1318] 	FOR i = 1 TO 100
	SRCFILE "goatcontest.bas",1318
	MVII #1,R0
	MVO R0,V32
T220:
	;[1319] 	  WAIT
	SRCFILE "goatcontest.bas",1319
	CALL _wait
	;[1320] 	NEXT i
	SRCFILE "goatcontest.bas",1320
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #100,R0
	BLE T220
	;[1321] 	CLS
	SRCFILE "goatcontest.bas",1321
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1322] 	WAIT
	SRCFILE "goatcontest.bas",1322
	CALL _wait
	;[1323] 	
	SRCFILE "goatcontest.bas",1323
	;[1324] 	'set object colors
	SRCFILE "goatcontest.bas",1324
	;[1325] 	#obj4sprite=#obj4sprite OR $0007 'white can
	SRCFILE "goatcontest.bas",1325
	MVI V35,R0
	ANDI #-8,R0
	XORI #7,R0
	MVO R0,V35
	;[1326] 	#obj5sprite=#obj5sprite OR $1005 'violet popsicle
	SRCFILE "goatcontest.bas",1326
	MVI V36,R0
	ANDI #-4102,R0
	XORI #4101,R0
	MVO R0,V36
	;[1327] 	#obj6sprite=#obj6sprite OR $0002 'red sausage
	SRCFILE "goatcontest.bas",1327
	MVI V37,R0
	ANDI #-3,R0
	XORI #2,R0
	MVO R0,V37
	;[1328] 	#rocksprite=#rocksprite OR $0000 'black tire
	SRCFILE "goatcontest.bas",1328
	MVI V38,R0
	MVO R0,V38
	;[1329] 	
	SRCFILE "goatcontest.bas",1329
	;[1330] 	#goat1color=$7
	SRCFILE "goatcontest.bas",1330
	MVII #7,R0
	MVO R0,V31
	;[1331] 	
	SRCFILE "goatcontest.bas",1331
	;[1332] 	END
	SRCFILE "goatcontest.bas",1332
	RETURN
	ENDP
	;[1333] 
	SRCFILE "goatcontest.bas",1333
	;[1334] stage_fall:	PROCEDURE
	SRCFILE "goatcontest.bas",1334
	; STAGE_FALL
Q32:	PROC
	BEGIN
	;[1335] 	#stagescore=fallscore
	SRCFILE "goatcontest.bas",1335
	MVII #12288,R0
	MVO R0,V1
	;[1336] 	CLS
	SRCFILE "goatcontest.bas",1336
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1337] 	WAIT
	SRCFILE "goatcontest.bas",1337
	CALL _wait
	;[1338] 	PRINT AT 108 COLOR 3,"FALL"
	SRCFILE "goatcontest.bas",1338
	MVII #620,R0
	MVO R0,_screen
	MVII #3,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #304,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
	;[1339] 	
	SRCFILE "goatcontest.bas",1339
	;[1340] 	VOICE INIT
	SRCFILE "goatcontest.bas",1340
	CALL IV_INIT
	;[1341] 	VOICE PLAY fall_voice
	SRCFILE "goatcontest.bas",1341
	MVII #Q110,R0
	CALL IV_PLAY.1
	;[1342] 		
	SRCFILE "goatcontest.bas",1342
	;[1343] 	FOR i = 1 TO 100
	SRCFILE "goatcontest.bas",1343
	MVII #1,R0
	MVO R0,V32
T221:
	;[1344] 	  WAIT
	SRCFILE "goatcontest.bas",1344
	CALL _wait
	;[1345] 	NEXT i
	SRCFILE "goatcontest.bas",1345
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #100,R0
	BLE T221
	;[1346] 	CLS
	SRCFILE "goatcontest.bas",1346
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1347] 	WAIT
	SRCFILE "goatcontest.bas",1347
	CALL _wait
	;[1348] 	
	SRCFILE "goatcontest.bas",1348
	;[1349] 	'set object colors
	SRCFILE "goatcontest.bas",1349
	;[1350] 	#obj4sprite=#obj4sprite OR $1002 'orange pumpkin
	SRCFILE "goatcontest.bas",1350
	MVI V35,R0
	ANDI #-4099,R0
	XORI #4098,R0
	MVO R0,V35
	;[1351] 	#obj5sprite=#obj5sprite OR $0002 'red apple
	SRCFILE "goatcontest.bas",1351
	MVI V36,R0
	ANDI #-3,R0
	XORI #2,R0
	MVO R0,V36
	;[1352] 	#obj6sprite=#obj6sprite OR $0007 'white bone
	SRCFILE "goatcontest.bas",1352
	MVI V37,R0
	ANDI #-8,R0
	XORI #7,R0
	MVO R0,V37
	;[1353] 	#rocksprite=#rocksprite OR $0000 'black hammer
	SRCFILE "goatcontest.bas",1353
	MVI V38,R0
	MVO R0,V38
	;[1354] 	
	SRCFILE "goatcontest.bas",1354
	;[1355] 	#goat1color=$7
	SRCFILE "goatcontest.bas",1355
	MVII #7,R0
	MVO R0,V31
	;[1356] 	
	SRCFILE "goatcontest.bas",1356
	;[1357] 	END
	SRCFILE "goatcontest.bas",1357
	RETURN
	ENDP
	;[1358] 
	SRCFILE "goatcontest.bas",1358
	;[1359] stage_winter:	PROCEDURE
	SRCFILE "goatcontest.bas",1359
	; STAGE_WINTER
Q33:	PROC
	BEGIN
	;[1360] 	#stagescore=winterscore
	SRCFILE "goatcontest.bas",1360
	MVII #12288,R0
	MVO R0,V1
	;[1361] 	CLS
	SRCFILE "goatcontest.bas",1361
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1362] 	WAIT
	SRCFILE "goatcontest.bas",1362
	CALL _wait
	;[1363] 	PRINT AT 107 COLOR 7,"WINTER"
	SRCFILE "goatcontest.bas",1363
	MVII #619,R0
	MVO R0,_screen
	MVII #7,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #440,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #240,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[1364] 	
	SRCFILE "goatcontest.bas",1364
	;[1365] 	VOICE INIT
	SRCFILE "goatcontest.bas",1365
	CALL IV_INIT
	;[1366] 	VOICE PLAY winter_voice
	SRCFILE "goatcontest.bas",1366
	MVII #Q112,R0
	CALL IV_PLAY.1
	;[1367] 		
	SRCFILE "goatcontest.bas",1367
	;[1368] 	FOR i = 1 TO 100
	SRCFILE "goatcontest.bas",1368
	MVII #1,R0
	MVO R0,V32
T222:
	;[1369] 	  WAIT
	SRCFILE "goatcontest.bas",1369
	CALL _wait
	;[1370] 	NEXT i
	SRCFILE "goatcontest.bas",1370
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #100,R0
	BLE T222
	;[1371] 	CLS
	SRCFILE "goatcontest.bas",1371
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1372] 	WAIT
	SRCFILE "goatcontest.bas",1372
	CALL _wait
	;[1373] 	
	SRCFILE "goatcontest.bas",1373
	;[1374]     	'set object colors
	SRCFILE "goatcontest.bas",1374
	;[1375] 	#obj4sprite=#obj4sprite OR $0002 'red stocking
	SRCFILE "goatcontest.bas",1375
	MVI V35,R0
	ANDI #-3,R0
	XORI #2,R0
	MVO R0,V35
	;[1376] 	#obj5sprite=#obj5sprite OR $1007 'magenta cane
	SRCFILE "goatcontest.bas",1376
	MVI V36,R0
	ANDI #-4104,R0
	XORI #4103,R0
	MVO R0,V36
	;[1377] 	#obj6sprite=#obj6sprite OR $0006 'yellow snowball
	SRCFILE "goatcontest.bas",1377
	MVI V37,R0
	ANDI #-7,R0
	XORI #6,R0
	MVO R0,V37
	;[1378] 	#rocksprite=#rocksprite OR $0000 'black grenado
	SRCFILE "goatcontest.bas",1378
	MVI V38,R0
	MVO R0,V38
	;[1379] 	
	SRCFILE "goatcontest.bas",1379
	;[1380] 	'grey shows up better over the snow (as opposed to invisible)
	SRCFILE "goatcontest.bas",1380
	;[1381] 	#goat1color=$1000
	SRCFILE "goatcontest.bas",1381
	MVII #4096,R0
	MVO R0,V31
	;[1382]     
	SRCFILE "goatcontest.bas",1382
	;[1383] 	END
	SRCFILE "goatcontest.bas",1383
	RETURN
	ENDP
	;[1384] 	
	SRCFILE "goatcontest.bas",1384
	;[1385] reset_vals:	PROCEDURE
	SRCFILE "goatcontest.bas",1385
	; RESET_VALS
Q5:	PROC
	BEGIN
	;[1386] 	'reset any variable in the game that we care about (ie: starting a new stage, etc)
	SRCFILE "goatcontest.bas",1386
	;[1387] 	'initial player position
	SRCFILE "goatcontest.bas",1387
	;[1388] 	p1x=20
	SRCFILE "goatcontest.bas",1388
	MVII #20,R0
	MVO R0,V33
	;[1389] 	p1y=30
	SRCFILE "goatcontest.bas",1389
	MVII #30,R0
	MVO R0,V45
	;[1390] 	
	SRCFILE "goatcontest.bas",1390
	;[1391] 	'initial farmer position
	SRCFILE "goatcontest.bas",1391
	;[1392] 	p2x=150
	SRCFILE "goatcontest.bas",1392
	MVII #150,R0
	MVO R0,V43
	;[1393] 	p2y=20
	SRCFILE "goatcontest.bas",1393
	MVII #20,R0
	MVO R0,V44
	;[1394] 	
	SRCFILE "goatcontest.bas",1394
	;[1395] 	objlive=255
	SRCFILE "goatcontest.bas",1395
	MVII #255,R0
	MVO R0,V10
	;[1396] 	FOR i = 0 TO 3
	SRCFILE "goatcontest.bas",1396
	CLRR R0
	MVO R0,V32
T223:
	;[1397] 	  objx(i)=0
	SRCFILE "goatcontest.bas",1397
	CLRR R0
	MVII #Q7,R3
	ADD V32,R3
	MVO@ R0,R3
	;[1398] 	  objy(i)=0
	SRCFILE "goatcontest.bas",1398
	MVII #Q8,R3
	ADD V32,R3
	MVO@ R0,R3
	;[1399] 	  objtype(i)=0
	SRCFILE "goatcontest.bas",1399
	MVII #Q6,R3
	ADD V32,R3
	MVO@ R0,R3
	;[1400] 	NEXT i
	SRCFILE "goatcontest.bas",1400
	MVI V32,R0
	INCR R0
	MVO R0,V32
	CMPI #3,R0
	BLE T223
	;[1401] 	
	SRCFILE "goatcontest.bas",1401
	;[1402] 	goatflip=0
	SRCFILE "goatcontest.bas",1402
	CLRR R0
	MVO R0,V24
	;[1403] 	buttonflag=0
	SRCFILE "goatcontest.bas",1403
	MVO R0,V25
	;[1404] 	flipcooldown=0
	SRCFILE "goatcontest.bas",1404
	NOP
	MVO R0,V5
	;[1405] 	fliptimer=0
	SRCFILE "goatcontest.bas",1405
	MVO R0,V4
	;[1406] 	
	SRCFILE "goatcontest.bas",1406
	;[1407] 	level=0
	SRCFILE "goatcontest.bas",1407
	NOP
	MVO R0,V18
	;[1408] 	
	SRCFILE "goatcontest.bas",1408
	;[1409] 	END
	SRCFILE "goatcontest.bas",1409
	RETURN
	ENDP
	;[1410] 	
	SRCFILE "goatcontest.bas",1410
	;[1411] goat_bleat:	PROCEDURE
	SRCFILE "goatcontest.bas",1411
	; GOAT_BLEAT
Q55:	PROC
	BEGIN
	;[1412] 	VOICE INIT
	SRCFILE "goatcontest.bas",1412
	CALL IV_INIT
	;[1413] 	VOICE PLAY bleat_voice
	SRCFILE "goatcontest.bas",1413
	MVII #Q115,R0
	CALL IV_PLAY.1
	;[1414] 	END
	SRCFILE "goatcontest.bas",1414
	RETURN
	ENDP
	;[1415] 
	SRCFILE "goatcontest.bas",1415
	;[1416] 'generic controller input debouncing
	SRCFILE "goatcontest.bas",1416
	;[1417] debounce_input: PROCEDURE
	SRCFILE "goatcontest.bas",1417
	; DEBOUNCE_INPUT
Q28:	PROC
	BEGIN
	;[1418] wait_for_zero:
	SRCFILE "goatcontest.bas",1418
	; WAIT_FOR_ZERO
Q117:	;[1419] 	c1=CONT
	SRCFILE "goatcontest.bas",1419
	MVI 510,R0
	XOR 511,R0
	MVO R0,V34
	;[1420] 	IF c1 > 0 THEN WAIT:GOTO wait_for_zero
	SRCFILE "goatcontest.bas",1420
	MVI V34,R0
	CMPI #0,R0
	BLE T224
	CALL _wait
	B Q117
T224:
	;[1421]         END
	SRCFILE "goatcontest.bas",1421
	RETURN
	ENDP
	;[1422] 
	SRCFILE "goatcontest.bas",1422
	;[1423] drawings1:	BITMAP "00000000"   	'0800 goat top left (address 0)
	SRCFILE "goatcontest.bas",1423
	; DRAWINGS1
Q21:		;[1424] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1424
	DECLE 0
	;[1425] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1425
	;[1426] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1426
	DECLE 0
	;[1427] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1427
	;[1428] 		BITMAP "01000000"
	SRCFILE "goatcontest.bas",1428
	DECLE 16384
	;[1429] 		BITMAP "10000000"
	SRCFILE "goatcontest.bas",1429
	;[1430] 		BITMAP "11000000"
	SRCFILE "goatcontest.bas",1430
	DECLE 49280
	;[1431] 		
	SRCFILE "goatcontest.bas",1431
	;[1432] 		BITMAP "01111111"   	'0808 goat bot left (address 1)
	SRCFILE "goatcontest.bas",1432
	;[1433] 		BITMAP "01111111"	
	SRCFILE "goatcontest.bas",1433
	DECLE 32639
	;[1434] 		BITMAP "01111111"
	SRCFILE "goatcontest.bas",1434
	;[1435] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1435
	DECLE 65407
	;[1436] 		BITMAP "11111001"
	SRCFILE "goatcontest.bas",1436
	;[1437] 		BITMAP "11011001"
	SRCFILE "goatcontest.bas",1437
	DECLE 55801
	;[1438] 		BITMAP "11011001"
	SRCFILE "goatcontest.bas",1438
	;[1439] 		BITMAP "11011001"
	SRCFILE "goatcontest.bas",1439
	DECLE 55769
	;[1440] 		
	SRCFILE "goatcontest.bas",1440
	;[1441] 		BITMAP "00000000"   	'0810 goat top right (address 2)
	SRCFILE "goatcontest.bas",1441
	;[1442] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1442
	DECLE 0
	;[1443] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1443
	;[1444] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1444
	DECLE 0
	;[1445] 		BITMAP "00111100"
	SRCFILE "goatcontest.bas",1445
	;[1446] 		BITMAP "00110100"
	SRCFILE "goatcontest.bas",1446
	DECLE 13372
	;[1447] 		BITMAP "00111111"
	SRCFILE "goatcontest.bas",1447
	;[1448] 		BITMAP "01111111"
	SRCFILE "goatcontest.bas",1448
	DECLE 32575
	;[1449] 		
	SRCFILE "goatcontest.bas",1449
	;[1450] 		BITMAP "11110110"   	'0818 goat bot right (address 3)
	SRCFILE "goatcontest.bas",1450
	;[1451] 		BITMAP "11110010"	
	SRCFILE "goatcontest.bas",1451
	DECLE 62198
	;[1452] 		BITMAP "11110000"
	SRCFILE "goatcontest.bas",1452
	;[1453] 		BITMAP "11110000"
	SRCFILE "goatcontest.bas",1453
	DECLE 61680
	;[1454] 		BITMAP "10110000"
	SRCFILE "goatcontest.bas",1454
	;[1455] 		BITMAP "10110000"
	SRCFILE "goatcontest.bas",1455
	DECLE 45232
	;[1456] 		BITMAP "10110000"
	SRCFILE "goatcontest.bas",1456
	;[1457] 		BITMAP "10110000"
	SRCFILE "goatcontest.bas",1457
	DECLE 45232
	;[1458] 		
	SRCFILE "goatcontest.bas",1458
	;[1459] 		BITMAP "00000000"   	'0820 alt goat top left (address 4)
	SRCFILE "goatcontest.bas",1459
	;[1460] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1460
	DECLE 0
	;[1461] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1461
	;[1462] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1462
	DECLE 0
	;[1463] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1463
	;[1464] 		BITMAP "10000000"
	SRCFILE "goatcontest.bas",1464
	DECLE 32768
	;[1465] 		BITMAP "10000000"
	SRCFILE "goatcontest.bas",1465
	;[1466] 		BITMAP "11000000"
	SRCFILE "goatcontest.bas",1466
	DECLE 49280
	;[1467] 		
	SRCFILE "goatcontest.bas",1467
	;[1468] 		BITMAP "01111111"   	'0828 alt goat bot left (address 5)
	SRCFILE "goatcontest.bas",1468
	;[1469] 		BITMAP "01111111"	
	SRCFILE "goatcontest.bas",1469
	DECLE 32639
	;[1470] 		BITMAP "01111111"
	SRCFILE "goatcontest.bas",1470
	;[1471] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1471
	DECLE 65407
	;[1472] 		BITMAP "11111001"
	SRCFILE "goatcontest.bas",1472
	;[1473] 		BITMAP "11011011"
	SRCFILE "goatcontest.bas",1473
	DECLE 56313
	;[1474] 		BITMAP "01101111"
	SRCFILE "goatcontest.bas",1474
	;[1475] 		BITMAP "01101111"
	SRCFILE "goatcontest.bas",1475
	DECLE 28527
	;[1476] 		
	SRCFILE "goatcontest.bas",1476
	;[1477] 		BITMAP "00000000"   	'0830 alt goat top right (address 6)
	SRCFILE "goatcontest.bas",1477
	;[1478] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1478
	DECLE 0
	;[1479] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1479
	;[1480] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1480
	DECLE 0
	;[1481] 		BITMAP "00111100"
	SRCFILE "goatcontest.bas",1481
	;[1482] 		BITMAP "00110100"
	SRCFILE "goatcontest.bas",1482
	DECLE 13372
	;[1483] 		BITMAP "00111111"
	SRCFILE "goatcontest.bas",1483
	;[1484] 		BITMAP "01111111"
	SRCFILE "goatcontest.bas",1484
	DECLE 32575
	;[1485] 		
	SRCFILE "goatcontest.bas",1485
	;[1486] 		BITMAP "11110110"   	'0838 alt goat bot right (address 7)
	SRCFILE "goatcontest.bas",1486
	;[1487] 		BITMAP "11110010"	
	SRCFILE "goatcontest.bas",1487
	DECLE 62198
	;[1488] 		BITMAP "11110000"
	SRCFILE "goatcontest.bas",1488
	;[1489] 		BITMAP "11110000"
	SRCFILE "goatcontest.bas",1489
	DECLE 61680
	;[1490] 		BITMAP "10110000"
	SRCFILE "goatcontest.bas",1490
	;[1491] 		BITMAP "01100000"
	SRCFILE "goatcontest.bas",1491
	DECLE 24752
	;[1492] 		BITMAP "01100000"
	SRCFILE "goatcontest.bas",1492
	;[1493] 		BITMAP "01100000"
	SRCFILE "goatcontest.bas",1493
	DECLE 24672
	;[1494] 	
	SRCFILE "goatcontest.bas",1494
	;[1495] horns:		BITMAP "00100000"   	'0840 goat eye/horns (address 8)
	SRCFILE "goatcontest.bas",1495
	; HORNS
Q22:		;[1496] 		BITMAP "10100000"	
	SRCFILE "goatcontest.bas",1496
	DECLE 40992
	;[1497] 		BITMAP "10110000"
	SRCFILE "goatcontest.bas",1497
	;[1498] 		BITMAP "11011000"
	SRCFILE "goatcontest.bas",1498
	DECLE 55472
	;[1499] 		BITMAP "01000000"
	SRCFILE "goatcontest.bas",1499
	;[1500] 		BITMAP "00001000"
	SRCFILE "goatcontest.bas",1500
	DECLE 2112
	;[1501] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1501
	;[1502] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1502
	DECLE 0
	;[1503] 		
	SRCFILE "goatcontest.bas",1503
	;[1504] 		BITMAP "00000000"   	'0848 snowflake (address 9)
	SRCFILE "goatcontest.bas",1504
	;[1505] 		BITMAP "00010000"	
	SRCFILE "goatcontest.bas",1505
	DECLE 4096
	;[1506] 		BITMAP "01010100"
	SRCFILE "goatcontest.bas",1506
	;[1507] 		BITMAP "00111000"
	SRCFILE "goatcontest.bas",1507
	DECLE 14420
	;[1508] 		BITMAP "00111000"
	SRCFILE "goatcontest.bas",1508
	;[1509] 		BITMAP "01010100"
	SRCFILE "goatcontest.bas",1509
	DECLE 21560
	;[1510] 		BITMAP "00010000"
	SRCFILE "goatcontest.bas",1510
	;[1511] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1511
	DECLE 16
	;[1512] 		
	SRCFILE "goatcontest.bas",1512
	;[1513] 		BITMAP "00000111"   	'0850 farmer dan top (address 10)
	SRCFILE "goatcontest.bas",1513
	;[1514] 		BITMAP "00001111"	
	SRCFILE "goatcontest.bas",1514
	DECLE 3847
	;[1515] 		BITMAP "00000111"
	SRCFILE "goatcontest.bas",1515
	;[1516] 		BITMAP "00000111"
	SRCFILE "goatcontest.bas",1516
	DECLE 1799
	;[1517] 		BITMAP "00000001"
	SRCFILE "goatcontest.bas",1517
	;[1518] 		BITMAP "00000001"
	SRCFILE "goatcontest.bas",1518
	DECLE 257
	;[1519] 		BITMAP "00000111"
	SRCFILE "goatcontest.bas",1519
	;[1520] 		BITMAP "00001111"
	SRCFILE "goatcontest.bas",1520
	DECLE 3847
	;[1521] 		
	SRCFILE "goatcontest.bas",1521
	;[1522] 		BITMAP "00001111"   	'0858 farmer dan bot (address 11)
	SRCFILE "goatcontest.bas",1522
	;[1523] 		BITMAP "00011011"	
	SRCFILE "goatcontest.bas",1523
	DECLE 6927
	;[1524] 		BITMAP "00110011"
	SRCFILE "goatcontest.bas",1524
	;[1525] 		BITMAP "00000011"
	SRCFILE "goatcontest.bas",1525
	DECLE 819
	;[1526] 		BITMAP "10010011"
	SRCFILE "goatcontest.bas",1526
	;[1527] 		BITMAP "10010011"
	SRCFILE "goatcontest.bas",1527
	DECLE 37779
	;[1528] 		BITMAP "10010111"
	SRCFILE "goatcontest.bas",1528
	;[1529] 		BITMAP "11110111"
	SRCFILE "goatcontest.bas",1529
	DECLE 63383
	;[1530] 
	SRCFILE "goatcontest.bas",1530
	;[1531] 		BITMAP "00000111"   	'0860 alt farmer dan top (address 12)
	SRCFILE "goatcontest.bas",1531
	;[1532] 		BITMAP "00001111"	
	SRCFILE "goatcontest.bas",1532
	DECLE 3847
	;[1533] 		BITMAP "00000111"
	SRCFILE "goatcontest.bas",1533
	;[1534] 		BITMAP "00000111"
	SRCFILE "goatcontest.bas",1534
	DECLE 1799
	;[1535] 		BITMAP "01100001"
	SRCFILE "goatcontest.bas",1535
	;[1536] 		BITMAP "00110001"
	SRCFILE "goatcontest.bas",1536
	DECLE 12641
	;[1537] 		BITMAP "00011111"
	SRCFILE "goatcontest.bas",1537
	;[1538] 		BITMAP "00001111"
	SRCFILE "goatcontest.bas",1538
	DECLE 3871
	;[1539] 		
	SRCFILE "goatcontest.bas",1539
	;[1540] 		BITMAP "00001111"   	'0868 alt farmer dan bot (address 13)
	SRCFILE "goatcontest.bas",1540
	;[1541] 		BITMAP "00000011"	
	SRCFILE "goatcontest.bas",1541
	DECLE 783
	;[1542] 		BITMAP "00000011"
	SRCFILE "goatcontest.bas",1542
	;[1543] 		BITMAP "00000011"
	SRCFILE "goatcontest.bas",1543
	DECLE 771
	;[1544] 		BITMAP "10010011"
	SRCFILE "goatcontest.bas",1544
	;[1545] 		BITMAP "10010011"
	SRCFILE "goatcontest.bas",1545
	DECLE 37779
	;[1546] 		BITMAP "10010111"
	SRCFILE "goatcontest.bas",1546
	;[1547] 		BITMAP "11110111"				
	SRCFILE "goatcontest.bas",1547
	DECLE 63383
	;[1548] 		
	SRCFILE "goatcontest.bas",1548
	;[1549] 		BITMAP "00000000"   	'0870 goat back top (address 14) - CURRENTLY UNUSED
	SRCFILE "goatcontest.bas",1549
	;[1550] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1550
	DECLE 0
	;[1551] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1551
	;[1552] 		BITMAP "00111000"
	SRCFILE "goatcontest.bas",1552
	DECLE 14336
	;[1553] 		BITMAP "00111000"
	SRCFILE "goatcontest.bas",1553
	;[1554] 		BITMAP "00111000"
	SRCFILE "goatcontest.bas",1554
	DECLE 14392
	;[1555] 		BITMAP "01111100"
	SRCFILE "goatcontest.bas",1555
	;[1556] 		BITMAP "11111110"
	SRCFILE "goatcontest.bas",1556
	DECLE 65148
	;[1557] 		
	SRCFILE "goatcontest.bas",1557
	;[1558] 		BITMAP "11111110"   	'0878 goat back bot (address 15) - CURRENTLY UNUSED
	SRCFILE "goatcontest.bas",1558
	;[1559] 		BITMAP "11111110"	
	SRCFILE "goatcontest.bas",1559
	DECLE 65278
	;[1560] 		BITMAP "11111110"
	SRCFILE "goatcontest.bas",1560
	;[1561] 		BITMAP "11111110"
	SRCFILE "goatcontest.bas",1561
	DECLE 65278
	;[1562] 		BITMAP "11000110"
	SRCFILE "goatcontest.bas",1562
	;[1563] 		BITMAP "11000110"
	SRCFILE "goatcontest.bas",1563
	DECLE 50886
	;[1564] 		BITMAP "11000110"
	SRCFILE "goatcontest.bas",1564
	;[1565] 		BITMAP "11000110"
	SRCFILE "goatcontest.bas",1565
	DECLE 50886
	;[1566] 		
	SRCFILE "goatcontest.bas",1566
	;[1567] drawings2:	BITMAP "00000000"   	'0880 snowball fence
	SRCFILE "goatcontest.bas",1567
	; DRAWINGS2
Q34:		;[1568] 		BITMAP "00111100"	
	SRCFILE "goatcontest.bas",1568
	DECLE 15360
	;[1569] 		BITMAP "01010110"
	SRCFILE "goatcontest.bas",1569
	;[1570] 		BITMAP "01111010"
	SRCFILE "goatcontest.bas",1570
	DECLE 31318
	;[1571] 		BITMAP "01001110"
	SRCFILE "goatcontest.bas",1571
	;[1572] 		BITMAP "01110110"
	SRCFILE "goatcontest.bas",1572
	DECLE 30286
	;[1573] 		BITMAP "00111100"
	SRCFILE "goatcontest.bas",1573
	;[1574] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1574
	DECLE 60
	;[1575] 		
	SRCFILE "goatcontest.bas",1575
	;[1576] 		BITMAP "01000010"   	'picket fence, card 18 (address 17)
	SRCFILE "goatcontest.bas",1576
	;[1577] 		BITMAP "11100111"	
	SRCFILE "goatcontest.bas",1577
	DECLE 59202
	;[1578] 		BITMAP "11100111"
	SRCFILE "goatcontest.bas",1578
	;[1579] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1579
	DECLE 65511
	;[1580] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1580
	;[1581] 		BITMAP "11100111"
	SRCFILE "goatcontest.bas",1581
	DECLE 59391
	;[1582] 		BITMAP "11100111"
	SRCFILE "goatcontest.bas",1582
	;[1583] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1583
	DECLE 231
	;[1584] 		
	SRCFILE "goatcontest.bas",1584
	;[1585] 		BITMAP "01010100"   	'dizzy animation 1 (address 18)
	SRCFILE "goatcontest.bas",1585
	;[1586] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1586
	DECLE 84
	;[1587] 		BITMAP "01010100"	
	SRCFILE "goatcontest.bas",1587
	;[1588] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1588
	DECLE 84
	;[1589] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1589
	;[1590] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1590
	DECLE 0
	;[1591] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1591
	;[1592] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1592
	DECLE 0
	;[1593] 				
	SRCFILE "goatcontest.bas",1593
	;[1594] 		BITMAP "00000000"   	'grass, card 20 (address 19)
	SRCFILE "goatcontest.bas",1594
	;[1595] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1595
	DECLE 0
	;[1596] 		BITMAP "00110100"	
	SRCFILE "goatcontest.bas",1596
	;[1597] 		BITMAP "00011000"	
	SRCFILE "goatcontest.bas",1597
	DECLE 6196
	;[1598] 		BITMAP "00001100"	
	SRCFILE "goatcontest.bas",1598
	;[1599] 		BITMAP "00001000"	
	SRCFILE "goatcontest.bas",1599
	DECLE 2060
	;[1600] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1600
	;[1601] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1601
	DECLE 0
	;[1602] 		
	SRCFILE "goatcontest.bas",1602
	;[1603] 		BITMAP "00011000"   	'ms goat bow (address 20)
	SRCFILE "goatcontest.bas",1603
	;[1604] 		BITMAP "00011100"	
	SRCFILE "goatcontest.bas",1604
	DECLE 7192
	;[1605] 		BITMAP "00101100"
	SRCFILE "goatcontest.bas",1605
	;[1606] 		BITMAP "11010000"
	SRCFILE "goatcontest.bas",1606
	DECLE 53292
	;[1607] 		BITMAP "11100000"
	SRCFILE "goatcontest.bas",1607
	;[1608] 		BITMAP "01100000"
	SRCFILE "goatcontest.bas",1608
	DECLE 24800
	;[1609] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1609
	;[1610] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1610
	DECLE 0
	;[1611] 		
	SRCFILE "goatcontest.bas",1611
	;[1612] 		BITMAP "00101000"   	'dizzy animation 2 (address 21)
	SRCFILE "goatcontest.bas",1612
	;[1613] 		BITMAP "10000010"	
	SRCFILE "goatcontest.bas",1613
	DECLE 33320
	;[1614] 		BITMAP "00101000"	
	SRCFILE "goatcontest.bas",1614
	;[1615] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1615
	DECLE 40
	;[1616] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1616
	;[1617] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1617
	DECLE 0
	;[1618] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1618
	;[1619] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1619
	DECLE 0
	;[1620] 		
	SRCFILE "goatcontest.bas",1620
	;[1621] 		BITMAP "00000000"   	' goat top, kicking (address 22)
	SRCFILE "goatcontest.bas",1621
	;[1622] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1622
	DECLE 0
	;[1623] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1623
	;[1624] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1624
	DECLE 0
	;[1625] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1625
	;[1626] 		BITMAP "00000100"
	SRCFILE "goatcontest.bas",1626
	DECLE 1024
	;[1627] 		BITMAP "00000010"
	SRCFILE "goatcontest.bas",1627
	;[1628] 		BITMAP "00000110"
	SRCFILE "goatcontest.bas",1628
	DECLE 1538
	;[1629] 		
	SRCFILE "goatcontest.bas",1629
	;[1630] 		BITMAP "11111100"   	' goat bottom, kicking (address 23)
	SRCFILE "goatcontest.bas",1630
	;[1631] 		BITMAP "11111111"	
	SRCFILE "goatcontest.bas",1631
	DECLE 65532
	;[1632] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1632
	;[1633] 		BITMAP "00011000"
	SRCFILE "goatcontest.bas",1633
	DECLE 6399
	;[1634] 		BITMAP "00011111"
	SRCFILE "goatcontest.bas",1634
	;[1635] 		BITMAP "00011111"
	SRCFILE "goatcontest.bas",1635
	DECLE 7967
	;[1636] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1636
	;[1637] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1637
	DECLE 0
	;[1638] 		
	SRCFILE "goatcontest.bas",1638
	;[1639] 		BITMAP "00000000"   	'goat top left, falling (address 24)
	SRCFILE "goatcontest.bas",1639
	;[1640] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1640
	DECLE 0
	;[1641] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1641
	;[1642] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1642
	DECLE 0
	;[1643] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1643
	;[1644] 		BITMAP "01000000"
	SRCFILE "goatcontest.bas",1644
	DECLE 16384
	;[1645] 		BITMAP "10000000"
	SRCFILE "goatcontest.bas",1645
	;[1646] 		BITMAP "11000000"
	SRCFILE "goatcontest.bas",1646
	DECLE 49280
	;[1647] 		
	SRCFILE "goatcontest.bas",1647
	;[1648] 		BITMAP "01111111"   	' goat bot left, falling (address 25)
	SRCFILE "goatcontest.bas",1648
	;[1649] 		BITMAP "01111111"	
	SRCFILE "goatcontest.bas",1649
	DECLE 32639
	;[1650] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1650
	;[1651] 		BITMAP "11111001"
	SRCFILE "goatcontest.bas",1651
	DECLE 63999
	;[1652] 		BITMAP "11111001"
	SRCFILE "goatcontest.bas",1652
	;[1653] 		BITMAP "11011011"
	SRCFILE "goatcontest.bas",1653
	DECLE 56313
	;[1654] 		BITMAP "01101111"
	SRCFILE "goatcontest.bas",1654
	;[1655] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1655
	DECLE 111
	;[1656] 		
	SRCFILE "goatcontest.bas",1656
	;[1657] 		BITMAP "00000000"   	' goat top right, falling (address 26)
	SRCFILE "goatcontest.bas",1657
	;[1658] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1658
	DECLE 0
	;[1659] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1659
	;[1660] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1660
	DECLE 0
	;[1661] 		BITMAP "00111100"
	SRCFILE "goatcontest.bas",1661
	;[1662] 		BITMAP "00110100"
	SRCFILE "goatcontest.bas",1662
	DECLE 13372
	;[1663] 		BITMAP "00111111"
	SRCFILE "goatcontest.bas",1663
	;[1664] 		BITMAP "01111111"
	SRCFILE "goatcontest.bas",1664
	DECLE 32575
	;[1665] 		
	SRCFILE "goatcontest.bas",1665
	;[1666] 		BITMAP "11110110"	' goat bot right, falling (address 27)
	SRCFILE "goatcontest.bas",1666
	;[1667] 		BITMAP "11110010"	
	SRCFILE "goatcontest.bas",1667
	DECLE 62198
	;[1668] 		BITMAP "11110000"
	SRCFILE "goatcontest.bas",1668
	;[1669] 		BITMAP "11110000"
	SRCFILE "goatcontest.bas",1669
	DECLE 61680
	;[1670] 		BITMAP "10110000"
	SRCFILE "goatcontest.bas",1670
	;[1671] 		BITMAP "10110000"
	SRCFILE "goatcontest.bas",1671
	DECLE 45232
	;[1672] 		BITMAP "01100000"
	SRCFILE "goatcontest.bas",1672
	;[1673] 		BITMAP "01100000"
	SRCFILE "goatcontest.bas",1673
	DECLE 24672
	;[1674] 		
	SRCFILE "goatcontest.bas",1674
	;[1675] 		BITMAP "00000000"   	'goat top left, fallen (address 28)
	SRCFILE "goatcontest.bas",1675
	;[1676] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1676
	DECLE 0
	;[1677] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1677
	;[1678] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1678
	DECLE 0
	;[1679] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1679
	;[1680] 		BITMAP "01000000"
	SRCFILE "goatcontest.bas",1680
	DECLE 16384
	;[1681] 		BITMAP "10000000"
	SRCFILE "goatcontest.bas",1681
	;[1682] 		BITMAP "11000000"
	SRCFILE "goatcontest.bas",1682
	DECLE 49280
	;[1683] 		
	SRCFILE "goatcontest.bas",1683
	;[1684] 		BITMAP "01111111"   	' goat bot left, fallen (address 29)
	SRCFILE "goatcontest.bas",1684
	;[1685] 		BITMAP "01111111"	
	SRCFILE "goatcontest.bas",1685
	DECLE 32639
	;[1686] 		BITMAP "01110111"
	SRCFILE "goatcontest.bas",1686
	;[1687] 		BITMAP "11101111"
	SRCFILE "goatcontest.bas",1687
	DECLE 61303
	;[1688] 		BITMAP "11100011"
	SRCFILE "goatcontest.bas",1688
	;[1689] 		BITMAP "11111100"
	SRCFILE "goatcontest.bas",1689
	DECLE 64739
	;[1690] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1690
	;[1691] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1691
	DECLE 0
	;[1692] 		
	SRCFILE "goatcontest.bas",1692
	;[1693] 		BITMAP "00000000"   	' goat top right, fallen (address 30)
	SRCFILE "goatcontest.bas",1693
	;[1694] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1694
	DECLE 0
	;[1695] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1695
	;[1696] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1696
	DECLE 0
	;[1697] 		BITMAP "00111100"
	SRCFILE "goatcontest.bas",1697
	;[1698] 		BITMAP "00110100"
	SRCFILE "goatcontest.bas",1698
	DECLE 13372
	;[1699] 		BITMAP "00111111"
	SRCFILE "goatcontest.bas",1699
	;[1700] 		BITMAP "01111111"
	SRCFILE "goatcontest.bas",1700
	DECLE 32575
	;[1701] 		
	SRCFILE "goatcontest.bas",1701
	;[1702] 		BITMAP "11110110"   	' goat bot right, fallen (address 31)
	SRCFILE "goatcontest.bas",1702
	;[1703] 		BITMAP "11110010"	
	SRCFILE "goatcontest.bas",1703
	DECLE 62198
	;[1704] 		BITMAP "11111000"
	SRCFILE "goatcontest.bas",1704
	;[1705] 		BITMAP "11111100"
	SRCFILE "goatcontest.bas",1705
	DECLE 64760
	;[1706] 		BITMAP "11001110"
	SRCFILE "goatcontest.bas",1706
	;[1707] 		BITMAP "00111100"
	SRCFILE "goatcontest.bas",1707
	DECLE 15566
	;[1708] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1708
	;[1709] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1709
	DECLE 0
	;[1710] 
	SRCFILE "goatcontest.bas",1710
	;[1711] drawings3:	BITMAP "00111100"   	' shirt - large size (address 32)
	SRCFILE "goatcontest.bas",1711
	; DRAWINGS3
Q35:		;[1712] 		BITMAP "01000010"	
	SRCFILE "goatcontest.bas",1712
	DECLE 16956
	;[1713] 		BITMAP "10100101"
	SRCFILE "goatcontest.bas",1713
	;[1714] 		BITMAP "01100110"
	SRCFILE "goatcontest.bas",1714
	DECLE 26277
	;[1715] 		BITMAP "00100100"
	SRCFILE "goatcontest.bas",1715
	;[1716] 		BITMAP "00100100"
	SRCFILE "goatcontest.bas",1716
	DECLE 9252
	;[1717] 		BITMAP "00100100"
	SRCFILE "goatcontest.bas",1717
	;[1718] 		BITMAP "00111100"
	SRCFILE "goatcontest.bas",1718
	DECLE 15396
	;[1719] 		
	SRCFILE "goatcontest.bas",1719
	;[1720] 		BITMAP "00111000"   	' can - medium size (address 33)
	SRCFILE "goatcontest.bas",1720
	;[1721] 		BITMAP "01000100"	
	SRCFILE "goatcontest.bas",1721
	DECLE 17464
	;[1722] 		BITMAP "01111100"
	SRCFILE "goatcontest.bas",1722
	;[1723] 		BITMAP "01000100"
	SRCFILE "goatcontest.bas",1723
	DECLE 17532
	;[1724] 		BITMAP "01000100"
	SRCFILE "goatcontest.bas",1724
	;[1725] 		BITMAP "01101100"
	SRCFILE "goatcontest.bas",1725
	DECLE 27716
	;[1726] 		BITMAP "00111000"
	SRCFILE "goatcontest.bas",1726
	;[1727] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1727
	DECLE 56
	;[1728] 		
	SRCFILE "goatcontest.bas",1728
	;[1729] 		BITMAP "00000000"   	' fish - small size (adddress 34)
	SRCFILE "goatcontest.bas",1729
	;[1730] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1730
	DECLE 0
	;[1731] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1731
	;[1732] 		BITMAP "01110100"
	SRCFILE "goatcontest.bas",1732
	DECLE 29696
	;[1733] 		BITMAP "11111000"
	SRCFILE "goatcontest.bas",1733
	;[1734] 		BITMAP "01110100"
	SRCFILE "goatcontest.bas",1734
	DECLE 29944
	;[1735] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1735
	;[1736] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1736
	DECLE 0
	;[1737] 		
	SRCFILE "goatcontest.bas",1737
	;[1738] 		BITMAP "01111110"   	' rock - weapon (address 35)
	SRCFILE "goatcontest.bas",1738
	;[1739] 		BITMAP "11101111"	
	SRCFILE "goatcontest.bas",1739
	DECLE 61310
	;[1740] 		BITMAP "11011011"
	SRCFILE "goatcontest.bas",1740
	;[1741] 		BITMAP "10111101"
	SRCFILE "goatcontest.bas",1741
	DECLE 48603
	;[1742] 		BITMAP "11000111"
	SRCFILE "goatcontest.bas",1742
	;[1743] 		BITMAP "11110101"
	SRCFILE "goatcontest.bas",1743
	DECLE 62919
	;[1744] 		BITMAP "11101111"
	SRCFILE "goatcontest.bas",1744
	;[1745] 		BITMAP "00111110"
	SRCFILE "goatcontest.bas",1745
	DECLE 16111
	;[1746] 		
	SRCFILE "goatcontest.bas",1746
	;[1747] 		BITMAP "00111000"   	' can - large size (address 36)
	SRCFILE "goatcontest.bas",1747
	;[1748] 		BITMAP "01001100"	
	SRCFILE "goatcontest.bas",1748
	DECLE 19512
	;[1749] 		BITMAP "10011010"
	SRCFILE "goatcontest.bas",1749
	;[1750] 		BITMAP "10100001"
	SRCFILE "goatcontest.bas",1750
	DECLE 41370
	;[1751] 		BITMAP "11000001"
	SRCFILE "goatcontest.bas",1751
	;[1752] 		BITMAP "01100011"
	SRCFILE "goatcontest.bas",1752
	DECLE 25537
	;[1753] 		BITMAP "00100010"
	SRCFILE "goatcontest.bas",1753
	;[1754] 		BITMAP "00011100"
	SRCFILE "goatcontest.bas",1754
	DECLE 7202
	;[1755] 		
	SRCFILE "goatcontest.bas",1755
	;[1756] 		BITMAP "00011000"   	' popsicle - medium size (address 37)
	SRCFILE "goatcontest.bas",1756
	;[1757] 		BITMAP "00111100"	
	SRCFILE "goatcontest.bas",1757
	DECLE 15384
	;[1758] 		BITMAP "00111100"
	SRCFILE "goatcontest.bas",1758
	;[1759] 		BITMAP "00111100"
	SRCFILE "goatcontest.bas",1759
	DECLE 15420
	;[1760] 		BITMAP "00011000"
	SRCFILE "goatcontest.bas",1760
	;[1761] 		BITMAP "00011000"
	SRCFILE "goatcontest.bas",1761
	DECLE 6168
	;[1762] 		BITMAP "00011000"
	SRCFILE "goatcontest.bas",1762
	;[1763] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1763
	DECLE 24
	;[1764] 		
	SRCFILE "goatcontest.bas",1764
	;[1765] 		BITMAP "00000000"   	' sausage - small size (adddress 38)
	SRCFILE "goatcontest.bas",1765
	;[1766] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1766
	DECLE 0
	;[1767] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1767
	;[1768] 		BITMAP "11000011"
	SRCFILE "goatcontest.bas",1768
	DECLE 49920
	;[1769] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1769
	;[1770] 		BITMAP "01111110"
	SRCFILE "goatcontest.bas",1770
	DECLE 32511
	;[1771] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1771
	;[1772] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1772
	DECLE 0
	;[1773] 		
	SRCFILE "goatcontest.bas",1773
	;[1774] 		BITMAP "00111100"   	' tire - weapon (address 39)
	SRCFILE "goatcontest.bas",1774
	;[1775] 		BITMAP "01111110"	
	SRCFILE "goatcontest.bas",1775
	DECLE 32316
	;[1776] 		BITMAP "11000011"
	SRCFILE "goatcontest.bas",1776
	;[1777] 		BITMAP "11011011"
	SRCFILE "goatcontest.bas",1777
	DECLE 56259
	;[1778] 		BITMAP "11011011"
	SRCFILE "goatcontest.bas",1778
	;[1779] 		BITMAP "11000011"
	SRCFILE "goatcontest.bas",1779
	DECLE 50139
	;[1780] 		BITMAP "01111110"
	SRCFILE "goatcontest.bas",1780
	;[1781] 		BITMAP "00111100"
	SRCFILE "goatcontest.bas",1781
	DECLE 15486
	;[1782] 		
	SRCFILE "goatcontest.bas",1782
	;[1783] 		BITMAP "00001000"   	' pumkpin - large size (address 40)
	SRCFILE "goatcontest.bas",1783
	;[1784] 		BITMAP "00011000"	
	SRCFILE "goatcontest.bas",1784
	DECLE 6152
	;[1785] 		BITMAP "01111110"
	SRCFILE "goatcontest.bas",1785
	;[1786] 		BITMAP "10111101"
	SRCFILE "goatcontest.bas",1786
	DECLE 48510
	;[1787] 		BITMAP "10011001"
	SRCFILE "goatcontest.bas",1787
	;[1788] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1788
	DECLE 65433
	;[1789] 		BITMAP "11000011"
	SRCFILE "goatcontest.bas",1789
	;[1790] 		BITMAP "01111110"
	SRCFILE "goatcontest.bas",1790
	DECLE 32451
	;[1791] 		
	SRCFILE "goatcontest.bas",1791
	;[1792] 		BITMAP "00001100"   	' apple - medium size (address 41)
	SRCFILE "goatcontest.bas",1792
	;[1793] 		BITMAP "00010000"	
	SRCFILE "goatcontest.bas",1793
	DECLE 4108
	;[1794] 		BITMAP "00111100"
	SRCFILE "goatcontest.bas",1794
	;[1795] 		BITMAP "01111110"
	SRCFILE "goatcontest.bas",1795
	DECLE 32316
	;[1796] 		BITMAP "01111000"
	SRCFILE "goatcontest.bas",1796
	;[1797] 		BITMAP "01111000"
	SRCFILE "goatcontest.bas",1797
	DECLE 30840
	;[1798] 		BITMAP "01111110"
	SRCFILE "goatcontest.bas",1798
	;[1799] 		BITMAP "00111100"
	SRCFILE "goatcontest.bas",1799
	DECLE 15486
	;[1800] 		
	SRCFILE "goatcontest.bas",1800
	;[1801] 		BITMAP "00000000"   	' bone - small size (adddress 42)
	SRCFILE "goatcontest.bas",1801
	;[1802] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1802
	DECLE 0
	;[1803] 		BITMAP "11000011"
	SRCFILE "goatcontest.bas",1803
	;[1804] 		BITMAP "10111101"
	SRCFILE "goatcontest.bas",1804
	DECLE 48579
	;[1805] 		BITMAP "01000010"
	SRCFILE "goatcontest.bas",1805
	;[1806] 		BITMAP "10111101"
	SRCFILE "goatcontest.bas",1806
	DECLE 48450
	;[1807] 		BITMAP "11000011"
	SRCFILE "goatcontest.bas",1807
	;[1808] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1808
	DECLE 195
	;[1809] 		
	SRCFILE "goatcontest.bas",1809
	;[1810] 		BITMAP "01011000"   	' hammer - weapon (address 43)
	SRCFILE "goatcontest.bas",1810
	;[1811] 		BITMAP "01111100"	
	SRCFILE "goatcontest.bas",1811
	DECLE 31832
	;[1812] 		BITMAP "01011010"
	SRCFILE "goatcontest.bas",1812
	;[1813] 		BITMAP "00011000"
	SRCFILE "goatcontest.bas",1813
	DECLE 6234
	;[1814] 		BITMAP "00011000"
	SRCFILE "goatcontest.bas",1814
	;[1815] 		BITMAP "00011000"
	SRCFILE "goatcontest.bas",1815
	DECLE 6168
	;[1816] 		BITMAP "00011000"
	SRCFILE "goatcontest.bas",1816
	;[1817] 		BITMAP "00011000"
	SRCFILE "goatcontest.bas",1817
	DECLE 6168
	;[1818] 		
	SRCFILE "goatcontest.bas",1818
	;[1819] 		BITMAP "00111111"   	' stocking - large size (address 44)
	SRCFILE "goatcontest.bas",1819
	;[1820] 		BITMAP "00111111"	
	SRCFILE "goatcontest.bas",1820
	DECLE 16191
	;[1821] 		BITMAP "00010010"
	SRCFILE "goatcontest.bas",1821
	;[1822] 		BITMAP "00010010"
	SRCFILE "goatcontest.bas",1822
	DECLE 4626
	;[1823] 		BITMAP "01110010"
	SRCFILE "goatcontest.bas",1823
	;[1824] 		BITMAP "10000010"
	SRCFILE "goatcontest.bas",1824
	DECLE 33394
	;[1825] 		BITMAP "10000010"
	SRCFILE "goatcontest.bas",1825
	;[1826] 		BITMAP "01111100"
	SRCFILE "goatcontest.bas",1826
	DECLE 31874
	;[1827] 		
	SRCFILE "goatcontest.bas",1827
	;[1828] 		BITMAP "00111000"   	' cane - medium size (address 45)
	SRCFILE "goatcontest.bas",1828
	;[1829] 		BITMAP "01111100"	
	SRCFILE "goatcontest.bas",1829
	DECLE 31800
	;[1830] 		BITMAP "01101100"
	SRCFILE "goatcontest.bas",1830
	;[1831] 		BITMAP "00001100"
	SRCFILE "goatcontest.bas",1831
	DECLE 3180
	;[1832] 		BITMAP "00001100"
	SRCFILE "goatcontest.bas",1832
	;[1833] 		BITMAP "00001100"
	SRCFILE "goatcontest.bas",1833
	DECLE 3084
	;[1834] 		BITMAP "00001100"
	SRCFILE "goatcontest.bas",1834
	;[1835] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1835
	DECLE 12
	;[1836] 		
	SRCFILE "goatcontest.bas",1836
	;[1837] 		BITMAP "00000000"   	' yellow snow - small size (adddress 46)
	SRCFILE "goatcontest.bas",1837
	;[1838] 		BITMAP "00000000"	
	SRCFILE "goatcontest.bas",1838
	DECLE 0
	;[1839] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1839
	;[1840] 		BITMAP "00010000"
	SRCFILE "goatcontest.bas",1840
	DECLE 4096
	;[1841] 		BITMAP "00111000"
	SRCFILE "goatcontest.bas",1841
	;[1842] 		BITMAP "01111100"
	SRCFILE "goatcontest.bas",1842
	DECLE 31800
	;[1843] 		BITMAP "00111000"
	SRCFILE "goatcontest.bas",1843
	;[1844] 		BITMAP "00010000"
	SRCFILE "goatcontest.bas",1844
	DECLE 4152
	;[1845] 		
	SRCFILE "goatcontest.bas",1845
	;[1846] 		BITMAP "00111110"   	' grenado - weapon (address 47)
	SRCFILE "goatcontest.bas",1846
	;[1847] 		BITMAP "01111001"	
	SRCFILE "goatcontest.bas",1847
	DECLE 31038
	;[1848] 		BITMAP "10110101"
	SRCFILE "goatcontest.bas",1848
	;[1849] 		BITMAP "11111101"
	SRCFILE "goatcontest.bas",1849
	DECLE 64949
	;[1850] 		BITMAP "10110101"
	SRCFILE "goatcontest.bas",1850
	;[1851] 		BITMAP "11111100"
	SRCFILE "goatcontest.bas",1851
	DECLE 64693
	;[1852] 		BITMAP "10110100"
	SRCFILE "goatcontest.bas",1852
	;[1853] 		BITMAP "01111000"
	SRCFILE "goatcontest.bas",1853
	DECLE 30900
	;[1854] 		
	SRCFILE "goatcontest.bas",1854
	;[1855] drawings4:	BITMAP "10010000"   	' goat head, for life counter (address 48)
	SRCFILE "goatcontest.bas",1855
	; DRAWINGS4
Q36:		;[1856] 		BITMAP "11011000"	
	SRCFILE "goatcontest.bas",1856
	DECLE 55440
	;[1857] 		BITMAP "01111100" 	
	SRCFILE "goatcontest.bas",1857
	;[1858] 		BITMAP "00110100"
	SRCFILE "goatcontest.bas",1858
	DECLE 13436
	;[1859] 		BITMAP "00111111"
	SRCFILE "goatcontest.bas",1859
	;[1860] 		BITMAP "00111111"
	SRCFILE "goatcontest.bas",1860
	DECLE 16191
	;[1861] 		BITMAP "00000110"
	SRCFILE "goatcontest.bas",1861
	;[1862] 		BITMAP "00000010"
	SRCFILE "goatcontest.bas",1862
	DECLE 518
	;[1863] 		
	SRCFILE "goatcontest.bas",1863
	;[1864] 		BITMAP "01101100"   	' heart (address 49)
	SRCFILE "goatcontest.bas",1864
	;[1865] 		BITMAP "11111110"	
	SRCFILE "goatcontest.bas",1865
	DECLE 65132
	;[1866] 		BITMAP "11111110" 	
	SRCFILE "goatcontest.bas",1866
	;[1867] 		BITMAP "11111110"
	SRCFILE "goatcontest.bas",1867
	DECLE 65278
	;[1868] 		BITMAP "01111100"
	SRCFILE "goatcontest.bas",1868
	;[1869] 		BITMAP "00111000"
	SRCFILE "goatcontest.bas",1869
	DECLE 14460
	;[1870] 		BITMAP "00010000"
	SRCFILE "goatcontest.bas",1870
	;[1871] 		BITMAP "00000000"
	SRCFILE "goatcontest.bas",1871
	DECLE 16
	;[1872] 		
	SRCFILE "goatcontest.bas",1872
	;[1873] 		BITMAP "00001000"   	' baby (address 50)
	SRCFILE "goatcontest.bas",1873
	;[1874] 		BITMAP "00001000"	
	SRCFILE "goatcontest.bas",1874
	DECLE 2056
	;[1875] 		BITMAP "00001110" 	
	SRCFILE "goatcontest.bas",1875
	;[1876] 		BITMAP "01001110"
	SRCFILE "goatcontest.bas",1876
	DECLE 19982
	;[1877] 		BITMAP "00111000"
	SRCFILE "goatcontest.bas",1877
	;[1878] 		BITMAP "00111000"
	SRCFILE "goatcontest.bas",1878
	DECLE 14392
	;[1879] 		BITMAP "00101000"
	SRCFILE "goatcontest.bas",1879
	;[1880] 		BITMAP "00101000"
	SRCFILE "goatcontest.bas",1880
	DECLE 10280
	;[1881] 		
	SRCFILE "goatcontest.bas",1881
	;[1882] 		BITMAP "10000000"   	' nom meter tick 1 (address 51)
	SRCFILE "goatcontest.bas",1882
	;[1883] 		BITMAP "10000000"	
	SRCFILE "goatcontest.bas",1883
	DECLE 32896
	;[1884] 		BITMAP "10000000" 	
	SRCFILE "goatcontest.bas",1884
	;[1885] 		BITMAP "10000000"
	SRCFILE "goatcontest.bas",1885
	DECLE 32896
	;[1886] 		BITMAP "10000000"
	SRCFILE "goatcontest.bas",1886
	;[1887] 		BITMAP "10000000"
	SRCFILE "goatcontest.bas",1887
	DECLE 32896
	;[1888] 		BITMAP "10000000"
	SRCFILE "goatcontest.bas",1888
	;[1889] 		BITMAP "10000000"
	SRCFILE "goatcontest.bas",1889
	DECLE 32896
	;[1890] 		
	SRCFILE "goatcontest.bas",1890
	;[1891] 		BITMAP "11000000"   	' nom meter tick 2 (address 52)
	SRCFILE "goatcontest.bas",1891
	;[1892] 		BITMAP "11000000"	
	SRCFILE "goatcontest.bas",1892
	DECLE 49344
	;[1893] 		BITMAP "11000000" 	
	SRCFILE "goatcontest.bas",1893
	;[1894] 		BITMAP "11000000"
	SRCFILE "goatcontest.bas",1894
	DECLE 49344
	;[1895] 		BITMAP "11000000"
	SRCFILE "goatcontest.bas",1895
	;[1896] 		BITMAP "11000000"
	SRCFILE "goatcontest.bas",1896
	DECLE 49344
	;[1897] 		BITMAP "11000000"
	SRCFILE "goatcontest.bas",1897
	;[1898] 		BITMAP "11000000"
	SRCFILE "goatcontest.bas",1898
	DECLE 49344
	;[1899] 		
	SRCFILE "goatcontest.bas",1899
	;[1900] 		BITMAP "11100000"   	' nom meter tick 3 (address 53)
	SRCFILE "goatcontest.bas",1900
	;[1901] 		BITMAP "11100000"	
	SRCFILE "goatcontest.bas",1901
	DECLE 57568
	;[1902] 		BITMAP "11100000" 	
	SRCFILE "goatcontest.bas",1902
	;[1903] 		BITMAP "11100000"
	SRCFILE "goatcontest.bas",1903
	DECLE 57568
	;[1904] 		BITMAP "11100000"
	SRCFILE "goatcontest.bas",1904
	;[1905] 		BITMAP "11100000"
	SRCFILE "goatcontest.bas",1905
	DECLE 57568
	;[1906] 		BITMAP "11100000"
	SRCFILE "goatcontest.bas",1906
	;[1907] 		BITMAP "11100000"
	SRCFILE "goatcontest.bas",1907
	DECLE 57568
	;[1908] 		
	SRCFILE "goatcontest.bas",1908
	;[1909] 		BITMAP "11110000"   	' nom meter tick 4 (address 54)
	SRCFILE "goatcontest.bas",1909
	;[1910] 		BITMAP "11110000"	
	SRCFILE "goatcontest.bas",1910
	DECLE 61680
	;[1911] 		BITMAP "11110000" 	
	SRCFILE "goatcontest.bas",1911
	;[1912] 		BITMAP "11110000"
	SRCFILE "goatcontest.bas",1912
	DECLE 61680
	;[1913] 		BITMAP "11110000"
	SRCFILE "goatcontest.bas",1913
	;[1914] 		BITMAP "11110000"
	SRCFILE "goatcontest.bas",1914
	DECLE 61680
	;[1915] 		BITMAP "11110000"
	SRCFILE "goatcontest.bas",1915
	;[1916] 		BITMAP "11110000"
	SRCFILE "goatcontest.bas",1916
	DECLE 61680
	;[1917] 		
	SRCFILE "goatcontest.bas",1917
	;[1918] 		BITMAP "11111000"   	' nom meter tick 5 (address 55)
	SRCFILE "goatcontest.bas",1918
	;[1919] 		BITMAP "11111000"	
	SRCFILE "goatcontest.bas",1919
	DECLE 63736
	;[1920] 		BITMAP "11111000" 	
	SRCFILE "goatcontest.bas",1920
	;[1921] 		BITMAP "11111000"
	SRCFILE "goatcontest.bas",1921
	DECLE 63736
	;[1922] 		BITMAP "11111000"
	SRCFILE "goatcontest.bas",1922
	;[1923] 		BITMAP "11111000"
	SRCFILE "goatcontest.bas",1923
	DECLE 63736
	;[1924] 		BITMAP "11111000"
	SRCFILE "goatcontest.bas",1924
	;[1925] 		BITMAP "11111000"
	SRCFILE "goatcontest.bas",1925
	DECLE 63736
	;[1926] 		
	SRCFILE "goatcontest.bas",1926
	;[1927] 		BITMAP "11111100"   	' nom meter tick 6 (address 56)
	SRCFILE "goatcontest.bas",1927
	;[1928] 		BITMAP "11111100"	
	SRCFILE "goatcontest.bas",1928
	DECLE 64764
	;[1929] 		BITMAP "11111100" 	
	SRCFILE "goatcontest.bas",1929
	;[1930] 		BITMAP "11111100"
	SRCFILE "goatcontest.bas",1930
	DECLE 64764
	;[1931] 		BITMAP "11111100"
	SRCFILE "goatcontest.bas",1931
	;[1932] 		BITMAP "11111100"
	SRCFILE "goatcontest.bas",1932
	DECLE 64764
	;[1933] 		BITMAP "11111100"
	SRCFILE "goatcontest.bas",1933
	;[1934] 		BITMAP "11111100"
	SRCFILE "goatcontest.bas",1934
	DECLE 64764
	;[1935] 				
	SRCFILE "goatcontest.bas",1935
	;[1936] 		BITMAP "11111110"   	' nom meter tick 7 (address 57)
	SRCFILE "goatcontest.bas",1936
	;[1937] 		BITMAP "11111110"	
	SRCFILE "goatcontest.bas",1937
	DECLE 65278
	;[1938] 		BITMAP "11111110" 	
	SRCFILE "goatcontest.bas",1938
	;[1939] 		BITMAP "11111110"
	SRCFILE "goatcontest.bas",1939
	DECLE 65278
	;[1940] 		BITMAP "11111110"
	SRCFILE "goatcontest.bas",1940
	;[1941] 		BITMAP "11111110"
	SRCFILE "goatcontest.bas",1941
	DECLE 65278
	;[1942] 		BITMAP "11111110"
	SRCFILE "goatcontest.bas",1942
	;[1943] 		BITMAP "11111110"
	SRCFILE "goatcontest.bas",1943
	DECLE 65278
	;[1944] 				
	SRCFILE "goatcontest.bas",1944
	;[1945] 		BITMAP "11111111"   	' nom meter tick 8 (address 58)
	SRCFILE "goatcontest.bas",1945
	;[1946] 		BITMAP "11111111"	
	SRCFILE "goatcontest.bas",1946
	DECLE 65535
	;[1947] 		BITMAP "11111111" 	
	SRCFILE "goatcontest.bas",1947
	;[1948] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1948
	DECLE 65535
	;[1949] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1949
	;[1950] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1950
	DECLE 65535
	;[1951] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1951
	;[1952] 		BITMAP "11111111"
	SRCFILE "goatcontest.bas",1952
	DECLE 65535
	;[1953] 		
	SRCFILE "goatcontest.bas",1953
	;[1954] 		BITMAP "00000001"   	' nom meter begin marker segment (address 59)
	SRCFILE "goatcontest.bas",1954
	;[1955] 		BITMAP "00000001"	
	SRCFILE "goatcontest.bas",1955
	DECLE 257
	;[1956] 		BITMAP "00011001" 	
	SRCFILE "goatcontest.bas",1956
	;[1957] 		BITMAP "00011001"
	SRCFILE "goatcontest.bas",1957
	DECLE 6425
	;[1958] 		BITMAP "00000001"
	SRCFILE "goatcontest.bas",1958
	;[1959] 		BITMAP "00011001"
	SRCFILE "goatcontest.bas",1959
	DECLE 6401
	;[1960] 		BITMAP "00011001"
	SRCFILE "goatcontest.bas",1960
	;[1961] 		BITMAP "00000001"
	SRCFILE "goatcontest.bas",1961
	DECLE 281
	;[1962] 	
	SRCFILE "goatcontest.bas",1962
	;[1963] stage_complete_song:	'song that plays when you complete a stage
	SRCFILE "goatcontest.bas",1963
	; STAGE_COMPLETE_SONG
Q91:	;[1964] 
	SRCFILE "goatcontest.bas",1964
	;[1965] 		DATA 5
	SRCFILE "goatcontest.bas",1965
	DECLE 5
	;[1966] 		
	SRCFILE "goatcontest.bas",1966
	;[1967] 		MUSIC D4w,D3y,-
	SRCFILE "goatcontest.bas",1967
	DECLE 36635,0
	;[1968] 		MUSIC E4,E3,-
	SRCFILE "goatcontest.bas",1968
	DECLE 37149,0
	;[1969] 		MUSIC F4,F3,-
	SRCFILE "goatcontest.bas",1969
	DECLE 37406,0
	;[1970] 		MUSIC -,-,-
	SRCFILE "goatcontest.bas",1970
	DECLE 0,0
	;[1971] 		
	SRCFILE "goatcontest.bas",1971
	;[1972] 		MUSIC E4,E3,-
	SRCFILE "goatcontest.bas",1972
	DECLE 37149,0
	;[1973] 		MUSIC F4,F3,-
	SRCFILE "goatcontest.bas",1973
	DECLE 37406,0
	;[1974] 		MUSIC G4,G3,-
	SRCFILE "goatcontest.bas",1974
	DECLE 37920,0
	;[1975] 		MUSIC -,-,-
	SRCFILE "goatcontest.bas",1975
	DECLE 0,0
	;[1976] 		
	SRCFILE "goatcontest.bas",1976
	;[1977] 		MUSIC F4,F3,-
	SRCFILE "goatcontest.bas",1977
	DECLE 37406,0
	;[1978] 		MUSIC G4,G3,-
	SRCFILE "goatcontest.bas",1978
	DECLE 37920,0
	;[1979] 		MUSIC A4,A3,-
	SRCFILE "goatcontest.bas",1979
	DECLE 38434,0
	;[1980] 		MUSIC -,-,-
	SRCFILE "goatcontest.bas",1980
	DECLE 0,0
	;[1981] 		
	SRCFILE "goatcontest.bas",1981
	;[1982] 		MUSIC G4,G3,-
	SRCFILE "goatcontest.bas",1982
	DECLE 37920,0
	;[1983] 		MUSIC A4,A3,-
	SRCFILE "goatcontest.bas",1983
	DECLE 38434,0
	;[1984] 		MUSIC B4,B3,-
	SRCFILE "goatcontest.bas",1984
	DECLE 38948,0
	;[1985] 		MUSIC -,-,-
	SRCFILE "goatcontest.bas",1985
	DECLE 0,0
	;[1986] 		
	SRCFILE "goatcontest.bas",1986
	;[1987] 		
	SRCFILE "goatcontest.bas",1987
	;[1988] 		MUSIC C5,C4,-
	SRCFILE "goatcontest.bas",1988
	DECLE 39205,0
	;[1989] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",1989
	DECLE 16191,0
	;[1990] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",1990
	DECLE 16191,0
	;[1991] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",1991
	DECLE 16191,0
	;[1992] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",1992
	DECLE 16191,0
	;[1993] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",1993
	DECLE 16191,0
	;[1994] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",1994
	DECLE 16191,0
	;[1995] 		
	SRCFILE "goatcontest.bas",1995
	;[1996] 		MUSIC STOP
	SRCFILE "goatcontest.bas",1996
	DECLE 254,0
	;[1997] 	
	SRCFILE "goatcontest.bas",1997
	;[1998] 		
	SRCFILE "goatcontest.bas",1998
	;[1999] inter1_song1: 	'intro love song
	SRCFILE "goatcontest.bas",1999
	; INTER1_SONG1
Q98:	;[2000] 		DATA 11
	SRCFILE "goatcontest.bas",2000
	DECLE 11
	;[2001] 		MUSIC G5z,G5y,-
	SRCFILE "goatcontest.bas",2001
	DECLE 44268,0
	;[2002] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2002
	DECLE 16191,0
	;[2003] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2003
	DECLE 16191,0
	;[2004] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2004
	DECLE 16191,0
	;[2005] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2005
	DECLE 16191,0
	;[2006] 
	SRCFILE "goatcontest.bas",2006
	;[2007] 		MUSIC A5,A5,-	
	SRCFILE "goatcontest.bas",2007
	DECLE 44782,0
	;[2008] 		MUSIC D5,D5,- 	
	SRCFILE "goatcontest.bas",2008
	DECLE 42983,0
	;[2009] 		MUSIC G5,G5,- 	
	SRCFILE "goatcontest.bas",2009
	DECLE 44268,0
	;[2010] 		MUSIC A5,A5,-	
	SRCFILE "goatcontest.bas",2010
	DECLE 44782,0
	;[2011] 		MUSIC D5,D5,- 	
	SRCFILE "goatcontest.bas",2011
	DECLE 42983,0
	;[2012] 		
	SRCFILE "goatcontest.bas",2012
	;[2013] 		MUSIC G5,G5,- 	
	SRCFILE "goatcontest.bas",2013
	DECLE 44268,0
	;[2014] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2014
	DECLE 16191,0
	;[2015] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2015
	DECLE 16191,0
	;[2016] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2016
	DECLE 16191,0
	;[2017] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2017
	DECLE 16191,0
	;[2018] 
	SRCFILE "goatcontest.bas",2018
	;[2019] 		MUSIC A5,A5,-	
	SRCFILE "goatcontest.bas",2019
	DECLE 44782,0
	;[2020] 		MUSIC D5,D5,- 	
	SRCFILE "goatcontest.bas",2020
	DECLE 42983,0
	;[2021] 		MUSIC G5,G5,- 	
	SRCFILE "goatcontest.bas",2021
	DECLE 44268,0
	;[2022] 		MUSIC A5,A5,-	
	SRCFILE "goatcontest.bas",2022
	DECLE 44782,0
	;[2023] 		MUSIC D5,D5,- 	
	SRCFILE "goatcontest.bas",2023
	DECLE 42983,0
	;[2024] 
	SRCFILE "goatcontest.bas",2024
	;[2025] 		MUSIC G5,G5,- 	
	SRCFILE "goatcontest.bas",2025
	DECLE 44268,0
	;[2026] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2026
	DECLE 16191,0
	;[2027] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2027
	DECLE 16191,0
	;[2028] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2028
	DECLE 16191,0
	;[2029] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2029
	DECLE 16191,0
	;[2030] 		
	SRCFILE "goatcontest.bas",2030
	;[2031] 		MUSIC B5,B5,-	
	SRCFILE "goatcontest.bas",2031
	DECLE 45296,0
	;[2032] 		MUSIC E6,E6,- 	
	SRCFILE "goatcontest.bas",2032
	DECLE 46581,0
	;[2033] 		MUSIC D6,D6,- 	
	SRCFILE "goatcontest.bas",2033
	DECLE 46067,0
	;[2034] 		MUSIC D5,D5,-	
	SRCFILE "goatcontest.bas",2034
	DECLE 42983,0
	;[2035] 		MUSIC B5,B5,- 
	SRCFILE "goatcontest.bas",2035
	DECLE 45296,0
	;[2036] 		
	SRCFILE "goatcontest.bas",2036
	;[2037] 		MUSIC A5,A5,- 	
	SRCFILE "goatcontest.bas",2037
	DECLE 44782,0
	;[2038] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2038
	DECLE 16191,0
	;[2039] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2039
	DECLE 16191,0
	;[2040] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2040
	DECLE 16191,0
	;[2041] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2041
	DECLE 16191,0
	;[2042] 		
	SRCFILE "goatcontest.bas",2042
	;[2043] 		MUSIC STOP
	SRCFILE "goatcontest.bas",2043
	DECLE 254,0
	;[2044] 		
	SRCFILE "goatcontest.bas",2044
	;[2045] inter1_song2: ' dum dum dum dum (descending)
	SRCFILE "goatcontest.bas",2045
	; INTER1_SONG2
Q102:	;[2046] 		DATA 8
	SRCFILE "goatcontest.bas",2046
	DECLE 8
	;[2047] 		
	SRCFILE "goatcontest.bas",2047
	;[2048] 		MUSIC G3y,G3z,-
	SRCFILE "goatcontest.bas",2048
	DECLE 54420,0
	;[2049] 		MUSIC E3,E3,-
	SRCFILE "goatcontest.bas",2049
	DECLE 53649,0
	;[2050] 		MUSIC C3,C3,-	
	SRCFILE "goatcontest.bas",2050
	DECLE 52621,0
	;[2051] 		MUSIC A2,A2,-
	SRCFILE "goatcontest.bas",2051
	DECLE 51850,0
	;[2052] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2052
	DECLE 16191,0
	;[2053] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2053
	DECLE 16191,0
	;[2054] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2054
	DECLE 16191,0
	;[2055] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2055
	DECLE 16191,0
	;[2056] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2056
	DECLE 16191,0
	;[2057] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2057
	DECLE 16191,0
	;[2058] 		MUSIC -,-,-
	SRCFILE "goatcontest.bas",2058
	DECLE 0,0
	;[2059] 		
	SRCFILE "goatcontest.bas",2059
	;[2060] 		MUSIC STOP
	SRCFILE "goatcontest.bas",2060
	DECLE 254,0
	;[2061] 		
	SRCFILE "goatcontest.bas",2061
	;[2062] inter1_song3:	'william tell finale fanfare (lone ranger theme)
	SRCFILE "goatcontest.bas",2062
	; INTER1_SONG3
Q104:	;[2063] 		DATA 5
	SRCFILE "goatcontest.bas",2063
	DECLE 5
	;[2064] 	
	SRCFILE "goatcontest.bas",2064
	;[2065] 		MUSIC G3w,G4y,-
	SRCFILE "goatcontest.bas",2065
	DECLE 40980,0
	;[2066] 		MUSIC G3,G4,-
	SRCFILE "goatcontest.bas",2066
	DECLE 40980,0
	;[2067] 		MUSIC G3,G4,-
	SRCFILE "goatcontest.bas",2067
	DECLE 40980,0
	;[2068] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2068
	DECLE 16191,0
	;[2069] 		
	SRCFILE "goatcontest.bas",2069
	;[2070] 		MUSIC G3,G4,-
	SRCFILE "goatcontest.bas",2070
	DECLE 40980,0
	;[2071] 		MUSIC G3,G4,-
	SRCFILE "goatcontest.bas",2071
	DECLE 40980,0
	;[2072] 		MUSIC G3,G4,-
	SRCFILE "goatcontest.bas",2072
	DECLE 40980,0
	;[2073] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2073
	DECLE 16191,0
	;[2074] 		
	SRCFILE "goatcontest.bas",2074
	;[2075] 		MUSIC G3,G4,-
	SRCFILE "goatcontest.bas",2075
	DECLE 40980,0
	;[2076] 		MUSIC G3,G4,-
	SRCFILE "goatcontest.bas",2076
	DECLE 40980,0
	;[2077] 		
	SRCFILE "goatcontest.bas",2077
	;[2078] 		MUSIC C4,C5,-
	SRCFILE "goatcontest.bas",2078
	DECLE 42265,0
	;[2079] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2079
	DECLE 16191,0
	;[2080] 		MUSIC D4,D5,-
	SRCFILE "goatcontest.bas",2080
	DECLE 42779,0
	;[2081] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2081
	DECLE 16191,0
	;[2082] 		MUSIC E4,E5,-
	SRCFILE "goatcontest.bas",2082
	DECLE 43293,0
	;[2083] 		MUSIC S,S,-
	SRCFILE "goatcontest.bas",2083
	DECLE 16191,0
	;[2084] 		
	SRCFILE "goatcontest.bas",2084
	;[2085] 		MUSIC STOP
	SRCFILE "goatcontest.bas",2085
	DECLE 254,0
	;[2086] 		
	SRCFILE "goatcontest.bas",2086
	;[2087] victory_song:	'endgame ditty
	SRCFILE "goatcontest.bas",2087
	; VICTORY_SONG
Q78:	;[2088] 		DATA 12
	SRCFILE "goatcontest.bas",2088
	DECLE 12
	;[2089] 		MUSIC D3x,-,-	'Bill
	SRCFILE "goatcontest.bas",2089
	DECLE 79,0
	;[2090]                 MUSIC E3,-,-	'Gro-
	SRCFILE "goatcontest.bas",2090
	DECLE 81,0
	;[2091]                 MUSIC B2,-,- 	'gan's
	SRCFILE "goatcontest.bas",2091
	DECLE 76,0
	;[2092]                 
	SRCFILE "goatcontest.bas",2092
	;[2093]                 MUSIC D3,-,- 	'goat
	SRCFILE "goatcontest.bas",2093
	DECLE 79,0
	;[2094]                 MUSIC S,B4y,-	
	SRCFILE "goatcontest.bas",2094
	DECLE 42047,0
	;[2095]                 MUSIC S,B4,-	
	SRCFILE "goatcontest.bas",2095
	DECLE 42047,0
	;[2096]                 MUSIC D3,B4,- 	
	SRCFILE "goatcontest.bas",2096
	DECLE 42063,0
	;[2097]                 MUSIC S,B4,- 	
	SRCFILE "goatcontest.bas",2097
	DECLE 42047,0
	;[2098]                 
	SRCFILE "goatcontest.bas",2098
	;[2099]                 MUSIC G3,-,-	'was
	SRCFILE "goatcontest.bas",2099
	DECLE 84,0
	;[2100]                 MUSIC A3,-,-	'feel-
	SRCFILE "goatcontest.bas",2100
	DECLE 86,0
	;[2101]                 MUSIC G3,-,- 	'ing
	SRCFILE "goatcontest.bas",2101
	DECLE 84,0
	;[2102]                 
	SRCFILE "goatcontest.bas",2102
	;[2103]                 MUSIC E3,-,- 	'fine
	SRCFILE "goatcontest.bas",2103
	DECLE 81,0
	;[2104]                 MUSIC S,C5,-	
	SRCFILE "goatcontest.bas",2104
	DECLE 42303,0
	;[2105]                 MUSIC E3,C5,-	
	SRCFILE "goatcontest.bas",2105
	DECLE 42321,0
	;[2106]                 MUSIC S,C5,- 	
	SRCFILE "goatcontest.bas",2106
	DECLE 42303,0
	;[2107]                 MUSIC -,C5,- 	
	SRCFILE "goatcontest.bas",2107
	DECLE 42240,0
	;[2108]                 
	SRCFILE "goatcontest.bas",2108
	;[2109]                 MUSIC G3,-,-	'ate
	SRCFILE "goatcontest.bas",2109
	DECLE 84,0
	;[2110]                 MUSIC G3,-,-	'three
	SRCFILE "goatcontest.bas",2110
	DECLE 84,0
	;[2111]                 MUSIC E3,-,- 	'red
	SRCFILE "goatcontest.bas",2111
	DECLE 81,0
	;[2112]                 
	SRCFILE "goatcontest.bas",2112
	;[2113]                 MUSIC F3#,-,- 	'shirts
	SRCFILE "goatcontest.bas",2113
	DECLE 83,0
	;[2114]                 MUSIC S,C5,-	
	SRCFILE "goatcontest.bas",2114
	DECLE 42303,0
	;[2115]                 MUSIC F3#,C5,-	
	SRCFILE "goatcontest.bas",2115
	DECLE 42323,0
	;[2116]                 MUSIC S,C5,- 	
	SRCFILE "goatcontest.bas",2116
	DECLE 42303,0
	;[2117]                 MUSIC -,C5,- 	
	SRCFILE "goatcontest.bas",2117
	DECLE 42240,0
	;[2118]                 
	SRCFILE "goatcontest.bas",2118
	;[2119]                 MUSIC E3,-,-	'from - was A3
	SRCFILE "goatcontest.bas",2119
	DECLE 81,0
	;[2120]                 MUSIC E3,-,-	'off - was G3
	SRCFILE "goatcontest.bas",2120
	DECLE 81,0
	;[2121]                 MUSIC B2,-,- 	'the - was F3
	SRCFILE "goatcontest.bas",2121
	DECLE 76,0
	;[2122]                 
	SRCFILE "goatcontest.bas",2122
	;[2123]                 MUSIC D3,-,- 	'line 
	SRCFILE "goatcontest.bas",2123
	DECLE 79,0
	;[2124]                 MUSIC S,B4,-	
	SRCFILE "goatcontest.bas",2124
	DECLE 42047,0
	;[2125]                 MUSIC D3,B4,-	
	SRCFILE "goatcontest.bas",2125
	DECLE 42063,0
	;[2126]                 MUSIC S,A4#,- 	 '- was B4
	SRCFILE "goatcontest.bas",2126
	DECLE 41791,0
	;[2127]                 MUSIC -,A4,- 	 ' - was B4
	SRCFILE "goatcontest.bas",2127
	DECLE 41472,0
	;[2128]                 
	SRCFILE "goatcontest.bas",2128
	;[2129]                 MUSIC D3,-,-	'Bill
	SRCFILE "goatcontest.bas",2129
	DECLE 79,0
	;[2130]                 MUSIC E3,-,-	'took
	SRCFILE "goatcontest.bas",2130
	DECLE 81,0
	;[2131]                 MUSIC B2,-,- 	'a
	SRCFILE "goatcontest.bas",2131
	DECLE 76,0
	;[2132]                 
	SRCFILE "goatcontest.bas",2132
	;[2133]                 MUSIC D3,-,- 	'stick
	SRCFILE "goatcontest.bas",2133
	DECLE 79,0
	;[2134]                 MUSIC S,B4,-	
	SRCFILE "goatcontest.bas",2134
	DECLE 42047,0
	;[2135]                 MUSIC D3,B4,-	
	SRCFILE "goatcontest.bas",2135
	DECLE 42063,0
	;[2136]                 MUSIC S,B4,- 	
	SRCFILE "goatcontest.bas",2136
	DECLE 42047,0
	;[2137]                 MUSIC -,B4,- 	
	SRCFILE "goatcontest.bas",2137
	DECLE 41984,0
	;[2138]                 
	SRCFILE "goatcontest.bas",2138
	;[2139]                 MUSIC G3,-,-	'gave
	SRCFILE "goatcontest.bas",2139
	DECLE 84,0
	;[2140]                 MUSIC A3,-,-	'him
	SRCFILE "goatcontest.bas",2140
	DECLE 86,0
	;[2141]                 MUSIC G3,-,- 	'a
	SRCFILE "goatcontest.bas",2141
	DECLE 84,0
	;[2142]                 
	SRCFILE "goatcontest.bas",2142
	;[2143]                 MUSIC E3,-,- 	'whack
	SRCFILE "goatcontest.bas",2143
	DECLE 81,0
	;[2144]                 MUSIC S,C5,-	
	SRCFILE "goatcontest.bas",2144
	DECLE 42303,0
	;[2145]                 MUSIC E3,C5,-	
	SRCFILE "goatcontest.bas",2145
	DECLE 42321,0
	;[2146]                 MUSIC S,C5,- 	
	SRCFILE "goatcontest.bas",2146
	DECLE 42303,0
	;[2147]                 MUSIC -,C5,- 	
	SRCFILE "goatcontest.bas",2147
	DECLE 42240,0
	;[2148]                 
	SRCFILE "goatcontest.bas",2148
	;[2149]                 MUSIC E3,-,-	'and
	SRCFILE "goatcontest.bas",2149
	DECLE 81,0
	;[2150]                 MUSIC F3#,-,-	'tied
	SRCFILE "goatcontest.bas",2150
	DECLE 83,0
	;[2151]                 MUSIC G3,-,- 	'him
	SRCFILE "goatcontest.bas",2151
	DECLE 84,0
	;[2152]                 
	SRCFILE "goatcontest.bas",2152
	;[2153]                 MUSIC F3#,-,- 	'to
	SRCFILE "goatcontest.bas",2153
	DECLE 83,0
	;[2154]                 MUSIC S,C5,-	
	SRCFILE "goatcontest.bas",2154
	DECLE 42303,0
	;[2155]                 MUSIC F3#,C5,-	
	SRCFILE "goatcontest.bas",2155
	DECLE 42323,0
	;[2156]                 MUSIC S,C5,- 	
	SRCFILE "goatcontest.bas",2156
	DECLE 42303,0
	;[2157]                 MUSIC -,C5,- 	
	SRCFILE "goatcontest.bas",2157
	DECLE 42240,0
	;[2158]                 
	SRCFILE "goatcontest.bas",2158
	;[2159]                 MUSIC D3,-,-	'the - was G3
	SRCFILE "goatcontest.bas",2159
	DECLE 79,0
	;[2160]                 MUSIC E3,-,-	'rail- - was F3
	SRCFILE "goatcontest.bas",2160
	DECLE 81,0
	;[2161]                 MUSIC F3,-,- 	'road - was E3
	SRCFILE "goatcontest.bas",2161
	DECLE 82,0
	;[2162]                 
	SRCFILE "goatcontest.bas",2162
	;[2163]                 MUSIC G3,-,- 	'track - was D3
	SRCFILE "goatcontest.bas",2163
	DECLE 84,0
	;[2164]                 MUSIC S,F4,-	
	SRCFILE "goatcontest.bas",2164
	DECLE 40511,0
	;[2165]                 MUSIC G3,E4,-	
	SRCFILE "goatcontest.bas",2165
	DECLE 40276,0
	;[2166]                 MUSIC S,D4#,- 	
	SRCFILE "goatcontest.bas",2166
	DECLE 39999,0
	;[2167]                 MUSIC S,D4,- 	
	SRCFILE "goatcontest.bas",2167
	DECLE 39743,0
	;[2168]                 MUSIC S,-,-
	SRCFILE "goatcontest.bas",2168
	DECLE 63,0
	;[2169] 
	SRCFILE "goatcontest.bas",2169
	;[2170]                 MUSIC REPEAT
	SRCFILE "goatcontest.bas",2170
	DECLE 253,0
	;[2171] 		
	SRCFILE "goatcontest.bas",2171
	;[2172] intro_song:	'intro screen ditty
	SRCFILE "goatcontest.bas",2172
	; INTRO_SONG
Q15:	;[2173] 		DATA 7
	SRCFILE "goatcontest.bas",2173
	DECLE 7
	;[2174]                 MUSIC C4y,C3y,F2y	'high
	SRCFILE "goatcontest.bas",2174
	DECLE 36249,134
	;[2175]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2175
	DECLE 16191,63
	;[2176] 
	SRCFILE "goatcontest.bas",2176
	;[2177]                 MUSIC C5,A4,-	'on
	SRCFILE "goatcontest.bas",2177
	DECLE 41637,0
	;[2178]                 MUSIC C5,A4,-	'a
	SRCFILE "goatcontest.bas",2178
	DECLE 41637,0
	;[2179]                 MUSIC C5,A4,- 	'hill
	SRCFILE "goatcontest.bas",2179
	DECLE 41637,0
	;[2180]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2180
	DECLE 16191,63
	;[2181] 
	SRCFILE "goatcontest.bas",2181
	;[2182]                 MUSIC C4,-,-	'was
	SRCFILE "goatcontest.bas",2182
	DECLE 153,0
	;[2183]                 MUSIC C4,-,-	'a
	SRCFILE "goatcontest.bas",2183
	DECLE 153,0
	;[2184]                 MUSIC C4,C3,F2	'lone-
	SRCFILE "goatcontest.bas",2184
	DECLE 36249,134
	;[2185]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2185
	DECLE 16191,63
	;[2186]                 
	SRCFILE "goatcontest.bas",2186
	;[2187]                 MUSIC G4,A4#,-	'ly
	SRCFILE "goatcontest.bas",2187
	DECLE 41888,0
	;[2188]                 MUSIC S,S,S	
	SRCFILE "goatcontest.bas",2188
	DECLE 16191,63
	;[2189]                 MUSIC G4,A4#,-	'goat
	SRCFILE "goatcontest.bas",2189
	DECLE 41888,0
	;[2190]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2190
	DECLE 16191,63
	;[2191]                 MUSIC F4,A4,-	'herd
	SRCFILE "goatcontest.bas",2191
	DECLE 41630,0
	;[2192]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2192
	DECLE 16191,63
	;[2193] 
	SRCFILE "goatcontest.bas",2193
	;[2194]                 MUSIC C4,C3,E2#
	SRCFILE "goatcontest.bas",2194
	DECLE 36249,134
	;[2195]                 MUSIC C5,-,-
	SRCFILE "goatcontest.bas",2195
	DECLE 165,0
	;[2196]                 MUSIC C4,-,-
	SRCFILE "goatcontest.bas",2196
	DECLE 153,0
	;[2197]                 MUSIC C4,-,-
	SRCFILE "goatcontest.bas",2197
	DECLE 153,0
	;[2198]                 
	SRCFILE "goatcontest.bas",2198
	;[2199]                 MUSIC C4,-,-
	SRCFILE "goatcontest.bas",2199
	DECLE 153,0
	;[2200]                 MUSIC C5,-,-
	SRCFILE "goatcontest.bas",2200
	DECLE 165,0
	;[2201]                 MUSIC C4,-,-
	SRCFILE "goatcontest.bas",2201
	DECLE 153,0
	;[2202]                 MUSIC C4,-,-
	SRCFILE "goatcontest.bas",2202
	DECLE 153,0
	;[2203]                 
	SRCFILE "goatcontest.bas",2203
	;[2204]                 MUSIC C4,C3,F2
	SRCFILE "goatcontest.bas",2204
	DECLE 36249,134
	;[2205]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2205
	DECLE 16191,63
	;[2206]                 MUSIC A4#,D5,-
	SRCFILE "goatcontest.bas",2206
	DECLE 42915,0
	;[2207]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2207
	DECLE 16191,63
	;[2208]                 MUSIC A4,C5,-
	SRCFILE "goatcontest.bas",2208
	DECLE 42402,0
	;[2209]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2209
	DECLE 16191,63
	;[2210]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2210
	DECLE 16191,63
	;[2211]                 MUSIC -,-,-
	SRCFILE "goatcontest.bas",2211
	DECLE 0,0
	;[2212]                 
	SRCFILE "goatcontest.bas",2212
	;[2213]                 'second stanza
	SRCFILE "goatcontest.bas",2213
	;[2214]                 MUSIC C4,C3,F2	
	SRCFILE "goatcontest.bas",2214
	DECLE 36249,134
	;[2215]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2215
	DECLE 16191,63
	;[2216] 
	SRCFILE "goatcontest.bas",2216
	;[2217]                 MUSIC C5,A4,-	
	SRCFILE "goatcontest.bas",2217
	DECLE 41637,0
	;[2218]                 MUSIC C5,A4,-
	SRCFILE "goatcontest.bas",2218
	DECLE 41637,0
	;[2219]                 MUSIC C5,A4,- 	
	SRCFILE "goatcontest.bas",2219
	DECLE 41637,0
	;[2220]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2220
	DECLE 16191,63
	;[2221] 
	SRCFILE "goatcontest.bas",2221
	;[2222]                 MUSIC C4,-,-	
	SRCFILE "goatcontest.bas",2222
	DECLE 153,0
	;[2223]                 MUSIC C4,-,-	
	SRCFILE "goatcontest.bas",2223
	DECLE 153,0
	;[2224]                 MUSIC C4,C3,F2	
	SRCFILE "goatcontest.bas",2224
	DECLE 36249,134
	;[2225]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2225
	DECLE 16191,63
	;[2226]                 
	SRCFILE "goatcontest.bas",2226
	;[2227]                 MUSIC G4,A4#,-	
	SRCFILE "goatcontest.bas",2227
	DECLE 41888,0
	;[2228]                 MUSIC S,S,S	
	SRCFILE "goatcontest.bas",2228
	DECLE 16191,63
	;[2229]                 MUSIC G4,A4#,-	
	SRCFILE "goatcontest.bas",2229
	DECLE 41888,0
	;[2230]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2230
	DECLE 16191,63
	;[2231]                 MUSIC F4,A4,-	
	SRCFILE "goatcontest.bas",2231
	DECLE 41630,0
	;[2232]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2232
	DECLE 16191,63
	;[2233] 
	SRCFILE "goatcontest.bas",2233
	;[2234]                 MUSIC C4,C3,E2#
	SRCFILE "goatcontest.bas",2234
	DECLE 36249,134
	;[2235]                 MUSIC C5,-,-
	SRCFILE "goatcontest.bas",2235
	DECLE 165,0
	;[2236]                 MUSIC C4,-,-
	SRCFILE "goatcontest.bas",2236
	DECLE 153,0
	;[2237]                 MUSIC C4#,-,-
	SRCFILE "goatcontest.bas",2237
	DECLE 154,0
	;[2238]                 
	SRCFILE "goatcontest.bas",2238
	;[2239]                 MUSIC D4,-,-
	SRCFILE "goatcontest.bas",2239
	DECLE 155,0
	;[2240]                 MUSIC D5,-,-
	SRCFILE "goatcontest.bas",2240
	DECLE 167,0
	;[2241]                 MUSIC D4,-,-
	SRCFILE "goatcontest.bas",2241
	DECLE 155,0
	;[2242]                 MUSIC E4,-,-
	SRCFILE "goatcontest.bas",2242
	DECLE 157,0
	;[2243]                 
	SRCFILE "goatcontest.bas",2243
	;[2244]                 MUSIC F4,C3,F2
	SRCFILE "goatcontest.bas",2244
	DECLE 36254,134
	;[2245]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2245
	DECLE 16191,63
	;[2246]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2246
	DECLE 16191,63
	;[2247]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2247
	DECLE 16191,63
	;[2248]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2248
	DECLE 16191,63
	;[2249]                 MUSIC S,S,S
	SRCFILE "goatcontest.bas",2249
	DECLE 16191,63
	;[2250] 	
	SRCFILE "goatcontest.bas",2250
	;[2251] 		'some silence for a clean break between repeats
	SRCFILE "goatcontest.bas",2251
	;[2252]                 MUSIC -,-,-
	SRCFILE "goatcontest.bas",2252
	DECLE 0,0
	;[2253]                 MUSIC -,-,-
	SRCFILE "goatcontest.bas",2253
	DECLE 0,0
	;[2254]                 MUSIC -,-,-
	SRCFILE "goatcontest.bas",2254
	DECLE 0,0
	;[2255]                 MUSIC -,-,-
	SRCFILE "goatcontest.bas",2255
	DECLE 0,0
	;[2256]                 
	SRCFILE "goatcontest.bas",2256
	;[2257] 		MUSIC REPEAT		
	SRCFILE "goatcontest.bas",2257
	DECLE 253,0
	;[2258] 
	SRCFILE "goatcontest.bas",2258
	;[2259] 
	SRCFILE "goatcontest.bas",2259
	;[2260] tune_best_years:
	SRCFILE "goatcontest.bas",2260
	; TUNE_BEST_YEARS
Q87:	;[2261] 	DATA 6
	SRCFILE "goatcontest.bas",2261
	DECLE 6
	;[2262] 	
	SRCFILE "goatcontest.bas",2262
	;[2263] 	MUSIC D4w,G3w,-,M1
	SRCFILE "goatcontest.bas",2263
	DECLE 5147,256
	;[2264] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2264
	DECLE 16191,0
	;[2265] 	MUSIC D4,G3,-,-
	SRCFILE "goatcontest.bas",2265
	DECLE 5147,0
	;[2266] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2266
	DECLE 16191,0
	;[2267] 	MUSIC C4,G3,-,M2
	SRCFILE "goatcontest.bas",2267
	DECLE 5145,512
	;[2268] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2268
	DECLE 16191,0
	;[2269] 	MUSIC B3,-,-,-
	SRCFILE "goatcontest.bas",2269
	DECLE 24,0
	;[2270] 	MUSIC C4,G3,-,-
	SRCFILE "goatcontest.bas",2270
	DECLE 5145,0
	;[2271] 	
	SRCFILE "goatcontest.bas",2271
	;[2272] 	MUSIC -,-,-,M1
	SRCFILE "goatcontest.bas",2272
	DECLE 0,256
	;[2273] 	MUSIC E4,-,-,-
	SRCFILE "goatcontest.bas",2273
	DECLE 29,0
	;[2274] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2274
	DECLE 63,0
	;[2275] 	MUSIC C4,-,-,-
	SRCFILE "goatcontest.bas",2275
	DECLE 25,0
	;[2276] 	MUSIC A3,C2,-,M2
	SRCFILE "goatcontest.bas",2276
	DECLE 278,512
	;[2277] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2277
	DECLE 63,0
	;[2278] 	MUSIC F3#,C2,-,-
	SRCFILE "goatcontest.bas",2278
	DECLE 275,0
	;[2279] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2279
	DECLE 63,0
	;[2280] 
	SRCFILE "goatcontest.bas",2280
	;[2281] 	MUSIC G3,D3,-,M1
	SRCFILE "goatcontest.bas",2281
	DECLE 3860,256
	;[2282] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2282
	DECLE 16191,0
	;[2283] 	MUSIC G3,D3,-,-
	SRCFILE "goatcontest.bas",2283
	DECLE 3860,0
	;[2284] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2284
	DECLE 63,0
	;[2285] 	MUSIC A3,D3,-,M2
	SRCFILE "goatcontest.bas",2285
	DECLE 3862,512
	;[2286] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2286
	DECLE 63,0
	;[2287] 	MUSIC B3,-,-,-
	SRCFILE "goatcontest.bas",2287
	DECLE 24,0
	;[2288] 	MUSIC A3,D3,-,-
	SRCFILE "goatcontest.bas",2288
	DECLE 3862,0
	;[2289] 	
	SRCFILE "goatcontest.bas",2289
	;[2290] 	MUSIC S,S,-,M1
	SRCFILE "goatcontest.bas",2290
	DECLE 16191,256
	;[2291] 	MUSIC D3,-,-,-
	SRCFILE "goatcontest.bas",2291
	DECLE 15,0
	;[2292] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2292
	DECLE 63,0
	;[2293] 	MUSIC D3,-,-,-
	SRCFILE "goatcontest.bas",2293
	DECLE 15,0
	;[2294] 	MUSIC D3,D2,-,M2
	SRCFILE "goatcontest.bas",2294
	DECLE 783,512
	;[2295] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2295
	DECLE 16191,0
	;[2296] 	MUSIC S,D2,-,-
	SRCFILE "goatcontest.bas",2296
	DECLE 831,0
	;[2297] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2297
	DECLE 16191,0
	;[2298] 	
	SRCFILE "goatcontest.bas",2298
	;[2299] 	MUSIC D4,G3,-,M1
	SRCFILE "goatcontest.bas",2299
	DECLE 5147,256
	;[2300] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2300
	DECLE 16191,0
	;[2301] 	MUSIC D4,G3,-,-
	SRCFILE "goatcontest.bas",2301
	DECLE 5147,0
	;[2302] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2302
	DECLE 16191,0
	;[2303] 	MUSIC C4,G3,-,M2
	SRCFILE "goatcontest.bas",2303
	DECLE 5145,512
	;[2304] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2304
	DECLE 16191,0
	;[2305] 	MUSIC B3,-,-,-
	SRCFILE "goatcontest.bas",2305
	DECLE 24,0
	;[2306] 	MUSIC C4,G3,-,-
	SRCFILE "goatcontest.bas",2306
	DECLE 5145,0
	;[2307] 	
	SRCFILE "goatcontest.bas",2307
	;[2308] 	MUSIC -,-,-,M1
	SRCFILE "goatcontest.bas",2308
	DECLE 0,256
	;[2309] 	MUSIC E4,-,-,-
	SRCFILE "goatcontest.bas",2309
	DECLE 29,0
	;[2310] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2310
	DECLE 63,0
	;[2311] 	MUSIC C4,-,-,-
	SRCFILE "goatcontest.bas",2311
	DECLE 25,0
	;[2312] 	MUSIC A3,C2,-,M2
	SRCFILE "goatcontest.bas",2312
	DECLE 278,512
	;[2313] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2313
	DECLE 63,0
	;[2314] 	MUSIC F3#,C2,-,-
	SRCFILE "goatcontest.bas",2314
	DECLE 275,0
	;[2315] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2315
	DECLE 63,0
	;[2316] 	
	SRCFILE "goatcontest.bas",2316
	;[2317] 	MUSIC D4,D2,-,M1
	SRCFILE "goatcontest.bas",2317
	DECLE 795,256
	;[2318] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2318
	DECLE 16191,0
	;[2319] 	MUSIC D4,D2,-,-
	SRCFILE "goatcontest.bas",2319
	DECLE 795,0
	;[2320] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2320
	DECLE 16191,0
	;[2321] 	MUSIC D4,D2,-,M2
	SRCFILE "goatcontest.bas",2321
	DECLE 795,512
	;[2322] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2322
	DECLE 16191,0
	;[2323] 	MUSIC D4,D2,-,-
	SRCFILE "goatcontest.bas",2323
	DECLE 795,0
	;[2324] 	MUSIC G4,G2,-,-
	SRCFILE "goatcontest.bas",2324
	DECLE 2080,0
	;[2325] 	
	SRCFILE "goatcontest.bas",2325
	;[2326] 	MUSIC S,S,-,M1
	SRCFILE "goatcontest.bas",2326
	DECLE 16191,256
	;[2327] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2327
	DECLE 63,0
	;[2328] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2328
	DECLE 63,0
	;[2329] 	MUSIC -,-,-,-
	SRCFILE "goatcontest.bas",2329
	DECLE 0,0
	;[2330] 	MUSIC -,-,-,M2
	SRCFILE "goatcontest.bas",2330
	DECLE 0,512
	;[2331] 	MUSIC -,-,-,-
	SRCFILE "goatcontest.bas",2331
	DECLE 0,0
	;[2332] 	MUSIC B2,-,-,- 'I
	SRCFILE "goatcontest.bas",2332
	DECLE 12,0
	;[2333] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2333
	DECLE 63,0
	;[2334] 	
	SRCFILE "goatcontest.bas",2334
	;[2335] 	MUSIC D3,G2,-,M1 'get
	SRCFILE "goatcontest.bas",2335
	DECLE 2063,256
	;[2336] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2336
	DECLE 16191,0
	;[2337] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2337
	DECLE 16191,0
	;[2338] 	MUSIC D3,G2,-,- 'such
	SRCFILE "goatcontest.bas",2338
	DECLE 2063,0
	;[2339] 	MUSIC S,S,-,M2
	SRCFILE "goatcontest.bas",2339
	DECLE 16191,512
	;[2340] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2340
	DECLE 16191,0
	;[2341] 	MUSIC D3,G2,-,- 'a 
	SRCFILE "goatcontest.bas",2341
	DECLE 2063,0
	;[2342] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2342
	DECLE 16191,0
	;[2343] 	
	SRCFILE "goatcontest.bas",2343
	;[2344] 	MUSIC D3,D2,-,M1 'thrill
	SRCFILE "goatcontest.bas",2344
	DECLE 783,256
	;[2345] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2345
	DECLE 16191,0
	;[2346] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2346
	DECLE 16191,0
	;[2347] 	MUSIC C3,-,-,- 'when
	SRCFILE "goatcontest.bas",2347
	DECLE 13,0
	;[2348] 	MUSIC S,-,-,M2
	SRCFILE "goatcontest.bas",2348
	DECLE 63,512
	;[2349] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2349
	DECLE 63,0
	;[2350] 	MUSIC C3,-,-,- 'you
	SRCFILE "goatcontest.bas",2350
	DECLE 13,0
	;[2351] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2351
	DECLE 63,0
	;[2352] 	
	SRCFILE "goatcontest.bas",2352
	;[2353] 	
	SRCFILE "goatcontest.bas",2353
	;[2354] 	MUSIC B2,D2,-,M1 'look
	SRCFILE "goatcontest.bas",2354
	DECLE 780,256
	;[2355] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2355
	DECLE 16191,0
	;[2356] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2356
	DECLE 16191,0
	;[2357] 	MUSIC A2,D2,-,- 'in
	SRCFILE "goatcontest.bas",2357
	DECLE 778,0
	;[2358] 	MUSIC S,S,-,M2
	SRCFILE "goatcontest.bas",2358
	DECLE 16191,512
	;[2359] 	MUSIC S,S,-,-	
	SRCFILE "goatcontest.bas",2359
	DECLE 16191,0
	;[2360] 	MUSIC F2#,D2,-,- 'my
	SRCFILE "goatcontest.bas",2360
	DECLE 775,0
	;[2361] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2361
	DECLE 16191,0
	;[2362] 	
	SRCFILE "goatcontest.bas",2362
	;[2363] 	MUSIC A2,-,-,M1 'eyes
	SRCFILE "goatcontest.bas",2363
	DECLE 10,256
	;[2364] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2364
	DECLE 63,0
	;[2365] 	MUSIC S,C2,-,-
	SRCFILE "goatcontest.bas",2365
	DECLE 319,0
	;[2366] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2366
	DECLE 16191,0
	;[2367] 	MUSIC -,C2,-,M2
	SRCFILE "goatcontest.bas",2367
	DECLE 256,512
	;[2368] 	MUSIC -,-,-,-
	SRCFILE "goatcontest.bas",2368
	DECLE 0,0
	;[2369] 	MUSIC B2,-,-,- 'I
	SRCFILE "goatcontest.bas",2369
	DECLE 12,0
	;[2370] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2370
	DECLE 63,0
	;[2371] 	
	SRCFILE "goatcontest.bas",2371
	;[2372] 	MUSIC D3,G2,-,M1 'get
	SRCFILE "goatcontest.bas",2372
	DECLE 2063,256
	;[2373] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2373
	DECLE 16191,0
	;[2374] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2374
	DECLE 16191,0
	;[2375] 	MUSIC D3,G2,-,- 'such
	SRCFILE "goatcontest.bas",2375
	DECLE 2063,0
	;[2376] 	MUSIC S,S,-,M2
	SRCFILE "goatcontest.bas",2376
	DECLE 16191,512
	;[2377] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2377
	DECLE 16191,0
	;[2378] 	MUSIC D3,G2,-,- 'a 
	SRCFILE "goatcontest.bas",2378
	DECLE 2063,0
	;[2379] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2379
	DECLE 16191,0
	;[2380] 	
	SRCFILE "goatcontest.bas",2380
	;[2381] 	MUSIC D3,D2,-,M1 'thrill
	SRCFILE "goatcontest.bas",2381
	DECLE 783,256
	;[2382] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2382
	DECLE 16191,0
	;[2383] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2383
	DECLE 16191,0
	;[2384] 	MUSIC C3,-,-,- 'when
	SRCFILE "goatcontest.bas",2384
	DECLE 13,0
	;[2385] 	MUSIC S,-,-,M2
	SRCFILE "goatcontest.bas",2385
	DECLE 63,512
	;[2386] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2386
	DECLE 63,0
	;[2387] 	MUSIC C3,-,-,- 'you
	SRCFILE "goatcontest.bas",2387
	DECLE 13,0
	;[2388] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2388
	DECLE 63,0
	;[2389] 	
	SRCFILE "goatcontest.bas",2389
	;[2390] 	MUSIC D3,D2,-,M1 'look
	SRCFILE "goatcontest.bas",2390
	DECLE 783,256
	;[2391] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2391
	DECLE 16191,0
	;[2392] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2392
	DECLE 16191,0
	;[2393] 	MUSIC E3,D2,-,- 'in
	SRCFILE "goatcontest.bas",2393
	DECLE 785,0
	;[2394] 	MUSIC S,S,-,M2
	SRCFILE "goatcontest.bas",2394
	DECLE 16191,512
	;[2395] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2395
	DECLE 16191,0
	;[2396] 	MUSIC D3,D2,-,- 'my
	SRCFILE "goatcontest.bas",2396
	DECLE 783,0
	;[2397] 	MUSIC S,S,-,-
	SRCFILE "goatcontest.bas",2397
	DECLE 16191,0
	;[2398] 	
	SRCFILE "goatcontest.bas",2398
	;[2399] 	MUSIC G3,-,-,M1 'eyes
	SRCFILE "goatcontest.bas",2399
	DECLE 20,256
	;[2400] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2400
	DECLE 63,0
	;[2401] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2401
	DECLE 63,0
	;[2402] 	MUSIC S,-,-,-
	SRCFILE "goatcontest.bas",2402
	DECLE 63,0
	;[2403] 	MUSIC -,-,-,M2
	SRCFILE "goatcontest.bas",2403
	DECLE 0,512
	;[2404] 	MUSIC -,-,-,-
	SRCFILE "goatcontest.bas",2404
	DECLE 0,0
	;[2405] 	MUSIC -,-,-,-
	SRCFILE "goatcontest.bas",2405
	DECLE 0,0
	;[2406] 	MUSIC -,-,-,-
	SRCFILE "goatcontest.bas",2406
	DECLE 0,0
	;[2407] 	
	SRCFILE "goatcontest.bas",2407
	;[2408] 	MUSIC REPEAT
	SRCFILE "goatcontest.bas",2408
	DECLE 253,0
	;[2409] 		
	SRCFILE "goatcontest.bas",2409
	;[2410] screen_spring:
	SRCFILE "goatcontest.bas",2410
	; SCREEN_SPRING
Q39:	;[2411] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 ' top row is for score and 1UP, no gfx here
	SRCFILE "goatcontest.bas",2411
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2412] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2412
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2413] 	
	SRCFILE "goatcontest.bas",2413
	;[2414] 	DATA $2000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2414
	DECLE 8192
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2415] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2415
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2416] 	
	SRCFILE "goatcontest.bas",2416
	;[2417] 	DATA $0000,$0000,$089D,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2417
	DECLE 0
	DECLE 0
	DECLE 2205
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2418] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2418
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2419] 	
	SRCFILE "goatcontest.bas",2419
	;[2420] 	DATA $0000,$0000,$0000,$089D,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2420
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2205
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2421] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2421
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2422] 	
	SRCFILE "goatcontest.bas",2422
	;[2423] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2423
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2424] 	DATA $0000,$0000,$089D,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2424
	DECLE 0
	DECLE 0
	DECLE 2205
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2425] 	
	SRCFILE "goatcontest.bas",2425
	;[2426] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2426
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2427] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2427
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2428] 	
	SRCFILE "goatcontest.bas",2428
	;[2429] 	DATA $0000,$0000,$0000,$0000,$089D,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2429
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2205
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2430] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2430
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2431] 	
	SRCFILE "goatcontest.bas",2431
	;[2432] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2432
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2433] 	DATA $0000,$0000,$0000,$089D,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2433
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2205
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2434] 	
	SRCFILE "goatcontest.bas",2434
	;[2435] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2435
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2436] 	DATA $0000,$089D,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2436
	DECLE 0
	DECLE 2205
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2437] 	
	SRCFILE "goatcontest.bas",2437
	;[2438] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2438
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2439] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2439
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2440] 	
	SRCFILE "goatcontest.bas",2440
	;[2441] 	DATA $0000,$089D,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2441
	DECLE 0
	DECLE 2205
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2442] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2442
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2443] 	
	SRCFILE "goatcontest.bas",2443
	;[2444] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2444
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2445] 	DATA $0000,$0000,$0000,$0000,$089D,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2445
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2205
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2446] 	
	SRCFILE "goatcontest.bas",2446
	;[2447] screen_fall:
	SRCFILE "goatcontest.bas",2447
	; SCREEN_FALL
Q40:	;[2448] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 ' top row is for score and 1UP, no gfx here
	SRCFILE "goatcontest.bas",2448
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2449] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2449
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2450] 	
	SRCFILE "goatcontest.bas",2450
	;[2451] 	DATA $2000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2451
	DECLE 8192
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2452] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2452
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2453] 	
	SRCFILE "goatcontest.bas",2453
	;[2454] 	DATA $0000,$0000,$1898,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2454
	DECLE 0
	DECLE 0
	DECLE 6296
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2455] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2455
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2456] 	
	SRCFILE "goatcontest.bas",2456
	;[2457] 	DATA $0000,$0000,$0000,$1898,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2457
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6296
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2458] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2458
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2459] 	
	SRCFILE "goatcontest.bas",2459
	;[2460] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2460
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2461] 	DATA $0000,$0000,$1898,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2461
	DECLE 0
	DECLE 0
	DECLE 6296
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2462] 	
	SRCFILE "goatcontest.bas",2462
	;[2463] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2463
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2464] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2464
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2465] 	
	SRCFILE "goatcontest.bas",2465
	;[2466] 	DATA $0000,$0000,$0000,$0000,$1898,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2466
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6296
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2467] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2467
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2468] 	
	SRCFILE "goatcontest.bas",2468
	;[2469] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2469
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2470] 	DATA $0000,$0000,$0000,$1898,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2470
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6296
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2471] 	
	SRCFILE "goatcontest.bas",2471
	;[2472] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2472
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2473] 	DATA $0000,$1898,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2473
	DECLE 0
	DECLE 6296
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2474] 	
	SRCFILE "goatcontest.bas",2474
	;[2475] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2475
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2476] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2476
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2477] 	
	SRCFILE "goatcontest.bas",2477
	;[2478] 	DATA $0000,$1898,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2478
	DECLE 0
	DECLE 6296
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2479] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2479
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2480] 	
	SRCFILE "goatcontest.bas",2480
	;[2481] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2481
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2482] 	DATA $0000,$0000,$0000,$0000,$1898,$0000,$088F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2482
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6296
	DECLE 0
	DECLE 2191
	DECLE 0
	DECLE 0
	DECLE 0
	;[2483] 	
	SRCFILE "goatcontest.bas",2483
	;[2484] screen_winter:
	SRCFILE "goatcontest.bas",2484
	; SCREEN_WINTER
Q41:	;[2485] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 ' top row is for score and 1UP, no gfx here
	SRCFILE "goatcontest.bas",2485
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2486] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2486
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2487] 	
	SRCFILE "goatcontest.bas",2487
	;[2488] 	DATA $2000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2488
	DECLE 8192
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2489] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0881,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2489
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2177
	DECLE 0
	DECLE 0
	DECLE 0
	;[2490] 	
	SRCFILE "goatcontest.bas",2490
	;[2491] 	DATA $0000,$0000,$1849,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2491
	DECLE 0
	DECLE 0
	DECLE 6217
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2492] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$1881,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2492
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6273
	DECLE 0
	DECLE 0
	DECLE 0
	;[2493] 	
	SRCFILE "goatcontest.bas",2493
	;[2494] 	DATA $0000,$0000,$0000,$1849,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2494
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6217
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2495] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0881,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2495
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2177
	DECLE 0
	DECLE 0
	DECLE 0
	;[2496] 	
	SRCFILE "goatcontest.bas",2496
	;[2497] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2497
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2498] 	DATA $0000,$0000,$1849,$0000,$0000,$0000,$1881,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2498
	DECLE 0
	DECLE 0
	DECLE 6217
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6273
	DECLE 0
	DECLE 0
	DECLE 0
	;[2499] 	
	SRCFILE "goatcontest.bas",2499
	;[2500] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2500
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2501] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0881,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2501
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2177
	DECLE 0
	DECLE 0
	DECLE 0
	;[2502] 	
	SRCFILE "goatcontest.bas",2502
	;[2503] 	DATA $0000,$0000,$0000,$0000,$1849,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2503
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6217
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2504] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$1881,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2504
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6273
	DECLE 0
	DECLE 0
	DECLE 0
	;[2505] 	
	SRCFILE "goatcontest.bas",2505
	;[2506] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2506
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2507] 	DATA $0000,$0000,$0000,$1849,$0000,$0000,$0881,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2507
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6217
	DECLE 0
	DECLE 0
	DECLE 2177
	DECLE 0
	DECLE 0
	DECLE 0
	;[2508] 	
	SRCFILE "goatcontest.bas",2508
	;[2509] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2509
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2510] 	DATA $0000,$1849,$0000,$0000,$0000,$0000,$1881,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2510
	DECLE 0
	DECLE 6217
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6273
	DECLE 0
	DECLE 0
	DECLE 0
	;[2511] 	
	SRCFILE "goatcontest.bas",2511
	;[2512] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2512
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2513] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0881,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2513
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2177
	DECLE 0
	DECLE 0
	DECLE 0
	;[2514] 	
	SRCFILE "goatcontest.bas",2514
	;[2515] 	DATA $0000,$1849,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2515
	DECLE 0
	DECLE 6217
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2516] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$1881,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2516
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6273
	DECLE 0
	DECLE 0
	DECLE 0
	;[2517] 	
	SRCFILE "goatcontest.bas",2517
	;[2518] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2518
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2519] 	DATA $0000,$0000,$0000,$0000,$1849,$0000,$0881,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2519
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6217
	DECLE 0
	DECLE 2177
	DECLE 0
	DECLE 0
	DECLE 0
	;[2520] 	
	SRCFILE "goatcontest.bas",2520
	;[2521] ' 53 bitmaps
	SRCFILE "goatcontest.bas",2521
	;[2522] titlescreen_bitmaps_0:
	SRCFILE "goatcontest.bas",2522
	; TITLESCREEN_BITMAPS_0
Q16:	;[2523] 	DATA $FFFF,$FEFE,$FDFD,$FBFB
	SRCFILE "goatcontest.bas",2523
	DECLE 65535
	DECLE 65278
	DECLE 65021
	DECLE 64507
	;[2524] 	DATA $FFFF,$8F3F,$FBE3,$FFF8
	SRCFILE "goatcontest.bas",2524
	DECLE 65535
	DECLE 36671
	DECLE 64483
	DECLE 65528
	;[2525] 	DATA $0000,$0000,$0000,$E080
	SRCFILE "goatcontest.bas",2525
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 57472
	;[2526] 	DATA $0000,$0000,$3F01,$BFC6
	SRCFILE "goatcontest.bas",2526
	DECLE 0
	DECLE 0
	DECLE 16129
	DECLE 49094
	;[2527] 	DATA $0000,$0000,$60C0,$D8B8
	SRCFILE "goatcontest.bas",2527
	DECLE 0
	DECLE 0
	DECLE 24768
	DECLE 55480
	;[2528] 	DATA $0000,$0000,$0000,$1F0F
	SRCFILE "goatcontest.bas",2528
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 7951
	;[2529] 	DATA $F7F7,$EFE7,$DFDB,$3FB7
	SRCFILE "goatcontest.bas",2529
	DECLE 63479
	DECLE 61415
	DECLE 57307
	DECLE 16311
	;[2530] 	DATA $FEE0,$DFFE,$FDF7,$FFFF
	SRCFILE "goatcontest.bas",2530
	DECLE 65248
	DECLE 57342
	DECLE 65015
	DECLE 65535
	;[2531] 	DATA $FFFF,$1CFF,$BFC3,$7FBF
	SRCFILE "goatcontest.bas",2531
	DECLE 65535
	DECLE 7423
	DECLE 49091
	DECLE 32703
	;[2532] 	DATA $3983,$FC7D,$FFFF,$FFFF
	SRCFILE "goatcontest.bas",2532
	DECLE 14723
	DECLE 64637
	DECLE 65535
	DECLE 65535
	;[2533] 	DATA $FFFF,$FFFF,$DF1F,$E4CB
	SRCFILE "goatcontest.bas",2533
	DECLE 65535
	DECLE 65535
	DECLE 57119
	DECLE 58571
	;[2534] 	DATA $FC1C,$DDF6,$BEDD,$FCF8
	SRCFILE "goatcontest.bas",2534
	DECLE 64540
	DECLE 56822
	DECLE 48861
	DECLE 64760
	;[2535] 	DATA $0E13,$9D05,$777B,$7BD7
	SRCFILE "goatcontest.bas",2535
	DECLE 3603
	DECLE 40197
	DECLE 30587
	DECLE 31703
	;[2536] 	DATA $FEC6,$B9FC,$7FFF,$7FEE
	SRCFILE "goatcontest.bas",2536
	DECLE 65222
	DECLE 47612
	DECLE 32767
	DECLE 32750
	;[2537] 	DATA $1C00,$FB27,$FEFF,$BFD5
	SRCFILE "goatcontest.bas",2537
	DECLE 7168
	DECLE 64295
	DECLE 65279
	DECLE 49109
	;[2538] 	DATA $FBFC,$E7F3,$DFED,$9FD7
	SRCFILE "goatcontest.bas",2538
	DECLE 64508
	DECLE 59379
	DECLE 57325
	DECLE 40919
	;[2539] titlescreen_bitmaps_1:
	SRCFILE "goatcontest.bas",2539
	; TITLESCREEN_BITMAPS_1
Q17:	;[2540] 	DATA $DFFF,$65B2,$C290,$80A4
	SRCFILE "goatcontest.bas",2540
	DECLE 57343
	DECLE 26034
	DECLE 49808
	DECLE 32932
	;[2541] 	DATA $01DF,$0203,$0804,$1008
	SRCFILE "goatcontest.bas",2541
	DECLE 479
	DECLE 515
	DECLE 2052
	DECLE 4104
	;[2542] 	DATA $0ABD,$0010,$0000,$0000 'first $val was $0AA4
	SRCFILE "goatcontest.bas",2542
	DECLE 2749
	DECLE 16
	DECLE 0
	DECLE 0
	;[2543] 	DATA $2589,$0001,$0024,$0008
	SRCFILE "goatcontest.bas",2543
	DECLE 9609
	DECLE 1
	DECLE 36
	DECLE 8
	;[2544] 	DATA $FFFF,$3FFF,$4F9F,$57EF
	SRCFILE "goatcontest.bas",2544
	DECLE 65535
	DECLE 16383
	DECLE 20383
	DECLE 22511
	;[2545] 	DATA $C7EF,$7933,$FFFE,$FFFF
	SRCFILE "goatcontest.bas",2545
	DECLE 51183
	DECLE 31027
	DECLE 65534
	DECLE 65535
	;[2546] 	DATA $FFFF,$FFFF,$EF1F,$F0E7
	SRCFILE "goatcontest.bas",2546
	DECLE 65535
	DECLE 65535
	DECLE 61215
	DECLE 61671
	;[2547] 	DATA $0000,$0203,$0404,$1018
	SRCFILE "goatcontest.bas",2547
	DECLE 0
	DECLE 515
	DECLE 1028
	DECLE 4120
	;[2548] 	DATA $77DE,$347E,$C060,$0000 'second $val was $B4FE
	SRCFILE "goatcontest.bas",2548
	DECLE 30686
	DECLE 13438
	DECLE 49248
	DECLE 0
	;[2549] 	DATA $8060,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2549
	DECLE 32864
	DECLE 0
	DECLE 0
	DECLE 0
	;[2550] 	DATA $010E,$1121,$0801,$0400
	SRCFILE "goatcontest.bas",2550
	DECLE 270
	DECLE 4385
	DECLE 2049
	DECLE 1024
	;[2551] 	DATA $FFFF,$FFFF,$7F7F,$0F3F
	SRCFILE "goatcontest.bas",2551
	DECLE 65535
	DECLE 65535
	DECLE 32639
	DECLE 3903
	;[2552] 	DATA $E6F8,$3FDF,$FFEF,$FFFF
	SRCFILE "goatcontest.bas",2552
	DECLE 59128
	DECLE 16351
	DECLE 65519
	DECLE 65535
	;[2553] 	DATA $FFFF,$FEFF,$E3F8,$1FEF
	SRCFILE "goatcontest.bas",2553
	DECLE 65535
	DECLE 65279
	DECLE 58360
	DECLE 8175
	;[2554] 	DATA $D2FF,$8F7C,$4823,$0000 'change this last value to $1200 for the original look of the leftmost mountain snow
	SRCFILE "goatcontest.bas",2554
	DECLE 54015
	DECLE 36732
	DECLE 18467
	DECLE 0
	;[2555] 	DATA $7F7F,$DE3F,$F3ED,$EC7D
	SRCFILE "goatcontest.bas",2555
	DECLE 32639
	DECLE 56895
	DECLE 62445
	DECLE 60541
	;[2556] titlescreen_bitmaps_2:
	SRCFILE "goatcontest.bas",2556
	; TITLESCREEN_BITMAPS_2
Q18:	;[2557] 	DATA $2020,$4040,$8080,$0080
	SRCFILE "goatcontest.bas",2557
	DECLE 8224
	DECLE 16448
	DECLE 32896
	DECLE 128
	;[2558] 	DATA $020F,$0001,$0000,$0000
	SRCFILE "goatcontest.bas",2558
	DECLE 527
	DECLE 1
	DECLE 0
	DECLE 0
	;[2559] 	DATA $00FF,$4220,$0830,$0306
	SRCFILE "goatcontest.bas",2559
	DECLE 255
	DECLE 16928
	DECLE 2096
	DECLE 774
	;[2560] 	DATA $4080,$0830,$0604,$0102
	SRCFILE "goatcontest.bas",2560
	DECLE 16512
	DECLE 2096
	DECLE 1540
	DECLE 258
	;[2561] 	DATA $0000,$0040,$0C10,$0100
	SRCFILE "goatcontest.bas",2561
	DECLE 0
	DECLE 64
	DECLE 3088
	DECLE 256
	;[2562] 	DATA $40FC,$0E30,$0106,$0000
	SRCFILE "goatcontest.bas",2562
	DECLE 16636
	DECLE 3632
	DECLE 262
	DECLE 0
	;[2563] 	DATA $8000,$6040,$063C,$0103
	SRCFILE "goatcontest.bas",2563
	DECLE 32768
	DECLE 24640
	DECLE 1596
	DECLE 259
	;[2564] 	DATA $0000,$0101,$0601,$1008
	SRCFILE "goatcontest.bas",2564
	DECLE 0
	DECLE 257
	DECLE 1537
	DECLE 4104
	;[2565] 	DATA $4020,$0080,$0000,$0000
	SRCFILE "goatcontest.bas",2565
	DECLE 16416
	DECLE 128
	DECLE 0
	DECLE 0
	;[2566] 	DATA $0000,$0040,$0C10,$0200
	SRCFILE "goatcontest.bas",2566
	DECLE 0
	DECLE 64
	DECLE 3088
	DECLE 512
	;[2567] 	DATA $30E0,$0D08,$0806,$1010
	SRCFILE "goatcontest.bas",2567
	DECLE 12512
	DECLE 3336
	DECLE 2054
	DECLE 4112
	;[2568] 	DATA $C0E0,$C7C7,$C7C7,$C0C0
	SRCFILE "goatcontest.bas",2568
	DECLE 49376
	DECLE 51143
	DECLE 51143
	DECLE 49344
	;[2569] 	DATA $0406,$FCFC,$C484,$0604
	SRCFILE "goatcontest.bas",2569
	DECLE 1030
	DECLE 64764
	DECLE 50308
	DECLE 1540
	;[2570] 	DATA $0000,$7C7C,$7C7C,$0000
	SRCFILE "goatcontest.bas",2570
	DECLE 0
	DECLE 31868
	DECLE 31868
	DECLE 0
	;[2571] 	DATA $40E0,$4047,$4740,$C747
	SRCFILE "goatcontest.bas",2571
	DECLE 16608
	DECLE 16455
	DECLE 18240
	DECLE 51015
	;[2572] 	DATA $040C,$07C7,$C707,$C7C7
	SRCFILE "goatcontest.bas",2572
	DECLE 1036
	DECLE 1991
	DECLE 50951
	DECLE 51143
	;[2573] titlescreen_bitmaps_3:
	SRCFILE "goatcontest.bas",2573
	; TITLESCREEN_BITMAPS_3
Q19:	;[2574] 	DATA $0000,$C7C7,$C7C7,$C7C7
	SRCFILE "goatcontest.bas",2574
	DECLE 0
	DECLE 51143
	DECLE 51143
	DECLE 51143
	;[2575] 	DATA $4060,$C7C7,$C7C7,$C7C7
	SRCFILE "goatcontest.bas",2575
	DECLE 16480
	DECLE 51143
	DECLE 51143
	DECLE 51143
	;[2576] 	DATA $040E,$C4C4,$C4C4,$C6C4
	SRCFILE "goatcontest.bas",2576
	DECLE 1038
	DECLE 50372
	DECLE 50372
	DECLE 50884
	;[2577] 	DATA $40E0,$4646,$4646,$C646
	SRCFILE "goatcontest.bas",2577
	DECLE 16608
	DECLE 17990
	DECLE 17990
	DECLE 50758
	;[2578] 	DATA $0101,$3838,$3838,$3838
	SRCFILE "goatcontest.bas",2578
	DECLE 257
	DECLE 14392
	DECLE 14392
	DECLE 14392
	;[2579] 	
	SRCFILE "goatcontest.bas",2579
	;[2580] 	
	SRCFILE "goatcontest.bas",2580
	;[2581] SkyFiller1:
	SRCFILE "goatcontest.bas",2581
	; SKYFILLER1
Q20:	;[2582] 	'filler right at cood 88x8 "bucket" - DOUBLE wide single high mob
	SRCFILE "goatcontest.bas",2582
	;[2583] 	BITMAP "11111000"
	SRCFILE "goatcontest.bas",2583
	;[2584] 	BITMAP "11110000"
	SRCFILE "goatcontest.bas",2584
	DECLE 61688
	;[2585] 	BITMAP "11110000"
	SRCFILE "goatcontest.bas",2585
	;[2586] 	BITMAP "01100000"
	SRCFILE "goatcontest.bas",2586
	DECLE 24816
	;[2587] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2587
	;[2588] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2588
	DECLE 0
	;[2589] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2589
	;[2590] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2590
	DECLE 0
	;[2591] 
	SRCFILE "goatcontest.bas",2591
	;[2592] 	'second from right filler at 72x0 single wide single high mob
	SRCFILE "goatcontest.bas",2592
	;[2593] 	BITMAP "11111111"
	SRCFILE "goatcontest.bas",2593
	;[2594] 	BITMAP "11111111"
	SRCFILE "goatcontest.bas",2594
	DECLE 65535
	;[2595] 	BITMAP "00111111"
	SRCFILE "goatcontest.bas",2595
	;[2596] 	BITMAP "00001111"
	SRCFILE "goatcontest.bas",2596
	DECLE 3903
	;[2597] 	BITMAP "00000011"
	SRCFILE "goatcontest.bas",2597
	;[2598] 	BITMAP "00000011"
	SRCFILE "goatcontest.bas",2598
	DECLE 771
	;[2599] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2599
	;[2600] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2600
	DECLE 0
	;[2601] 
	SRCFILE "goatcontest.bas",2601
	;[2602] 	'second from right filler at 64x0 single wide DOUBLE high mob
	SRCFILE "goatcontest.bas",2602
	;[2603] 	BITMAP "11111111"
	SRCFILE "goatcontest.bas",2603
	;[2604] 	BITMAP "11111110"
	SRCFILE "goatcontest.bas",2604
	DECLE 65279
	;[2605] 	BITMAP "11111100"
	SRCFILE "goatcontest.bas",2605
	;[2606] 	BITMAP "11111000"
	SRCFILE "goatcontest.bas",2606
	DECLE 63740
	;[2607] 	BITMAP "11110000"
	SRCFILE "goatcontest.bas",2607
	;[2608] 	BITMAP "11100000"
	SRCFILE "goatcontest.bas",2608
	DECLE 57584
	;[2609] 	BITMAP "11000000"
	SRCFILE "goatcontest.bas",2609
	;[2610] 	BITMAP "10000000"
	SRCFILE "goatcontest.bas",2610
	DECLE 32960
	;[2611] 
	SRCFILE "goatcontest.bas",2611
	;[2612] 	'second from right filler at 56x16 single wide single high mob
	SRCFILE "goatcontest.bas",2612
	;[2613] 	BITMAP "11111100"
	SRCFILE "goatcontest.bas",2613
	;[2614] 	BITMAP "11111000"
	SRCFILE "goatcontest.bas",2614
	DECLE 63740
	;[2615] 	BITMAP "11110000"
	SRCFILE "goatcontest.bas",2615
	;[2616] 	BITMAP "11100000"
	SRCFILE "goatcontest.bas",2616
	DECLE 57584
	;[2617] 	BITMAP "11100000"
	SRCFILE "goatcontest.bas",2617
	;[2618] 	BITMAP "11000000"
	SRCFILE "goatcontest.bas",2618
	DECLE 49376
	;[2619] 	BITMAP "11000000"
	SRCFILE "goatcontest.bas",2619
	;[2620] 	BITMAP "10000000"
	SRCFILE "goatcontest.bas",2620
	DECLE 32960
	;[2621] 
	SRCFILE "goatcontest.bas",2621
	;[2622] 	'second from right filler at 48x24 single wide DOUBLE high mob
	SRCFILE "goatcontest.bas",2622
	;[2623] 	BITMAP "11111111"
	SRCFILE "goatcontest.bas",2623
	;[2624] 	BITMAP "11111100"
	SRCFILE "goatcontest.bas",2624
	DECLE 64767
	;[2625] 	BITMAP "11111000"
	SRCFILE "goatcontest.bas",2625
	;[2626] 	BITMAP "11100000"
	SRCFILE "goatcontest.bas",2626
	DECLE 57592
	;[2627] 	BITMAP "11000000"
	SRCFILE "goatcontest.bas",2627
	;[2628] 	BITMAP "10000000"
	SRCFILE "goatcontest.bas",2628
	DECLE 32960
	;[2629] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2629
	;[2630] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2630
	DECLE 0
	;[2631] 
	SRCFILE "goatcontest.bas",2631
	;[2632] titlescreen_cards:
	SRCFILE "goatcontest.bas",2632
	; TITLESCREEN_CARDS
Q23:	;[2633] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$0807,$080F
	SRCFILE "goatcontest.bas",2633
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 2055
	DECLE 2063
	;[2634] 	DATA $1A10,$1200,$1200,$1A1F,$1A27,$1A2F,$1A1F,$1A27,$1200,$1200	
	SRCFILE "goatcontest.bas",2634
	DECLE 6672
	DECLE 4608
	DECLE 4608
	DECLE 6687
	DECLE 6695
	DECLE 6703
	DECLE 6687
	DECLE 6695
	DECLE 4608
	DECLE 4608
	;[2635] 	DATA $1A27,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$0837,$2600
	SRCFILE "goatcontest.bas",2635
	DECLE 6695
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 2103
	DECLE 9728
	;[2636] 	DATA $083F,$0847,$084F,$0857,$1A5F,$1A67,$1A6F,$1A5F,$1200,$1200	
	SRCFILE "goatcontest.bas",2636
	DECLE 2111
	DECLE 2119
	DECLE 2127
	DECLE 2135
	DECLE 6751
	DECLE 6759
	DECLE 6767
	DECLE 6751
	DECLE 4608
	DECLE 4608
	;[2637] 	DATA $1A5F,$1A77,$1A27,$1200,$1200,$1200,$1200,$087F,$1887,$1887
	SRCFILE "goatcontest.bas",2637
	DECLE 6751
	DECLE 6775
	DECLE 6695
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 2175
	DECLE 6279
	DECLE 6279
	;[2638] 	DATA $1888,$1897,$1897,$1898,$08A7,$1A6F,$1A6F,$1A6F,$1A5F,$1A77	
	SRCFILE "goatcontest.bas",2638
	DECLE 6280
	DECLE 6295
	DECLE 6295
	DECLE 6296
	DECLE 2215
	DECLE 6767
	DECLE 6767
	DECLE 6767
	DECLE 6751
	DECLE 6775
	;[2639] 	DATA $08AF,$08B7,$1A5F,$1200,$1200,$1200,$18B8,$18C7,$1000,$1000
	SRCFILE "goatcontest.bas",2639
	DECLE 2223
	DECLE 2231
	DECLE 6751
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6328
	DECLE 6343
	DECLE 4096
	DECLE 4096
	;[2640] 	DATA $18C8,$1000,$1000,$1000,$18D0,$08DF,$1AE7,$08EF,$08AF,$08AF	
	SRCFILE "goatcontest.bas",2640
	DECLE 6344
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6352
	DECLE 2271
	DECLE 6887
	DECLE 2287
	DECLE 2223
	DECLE 2223
	;[2641] 	DATA $18F7,$18F7,$08FF,$1A77,$1A27,$1A28,$1900,$1000,$1000,$1000
	SRCFILE "goatcontest.bas",2641
	DECLE 6391
	DECLE 6391
	DECLE 2303
	DECLE 6775
	DECLE 6695
	DECLE 6696
	DECLE 6400
	DECLE 4096
	DECLE 4096
	DECLE 4096
	;[2642] 	DATA $1000,$1000,$1000,$1000,$1000,$1908,$1910,$18C7,$18C7,$18C7	
	SRCFILE "goatcontest.bas",2642
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6408
	DECLE 6416
	DECLE 6343
	DECLE 6343
	DECLE 6343
	;[2643] 	DATA $1918,$1000,$1920,$1928,$1888,$18C8,$1000,$1000,$1000,$1000
	SRCFILE "goatcontest.bas",2643
	DECLE 6424
	DECLE 4096
	DECLE 6432
	DECLE 6440
	DECLE 6280
	DECLE 6344
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	;[2644] 	DATA $1000,$1000,$1000,$1000,$1000,$1920,$1000,$1918,$1000,$1000	
	SRCFILE "goatcontest.bas",2644
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6432
	DECLE 4096
	DECLE 6424
	DECLE 4096
	DECLE 4096
	;[2645] 	DATA $1000,$1930,$1000,$1938,$1940,$1000,$1000,$1000,$1000,$1000
	SRCFILE "goatcontest.bas",2645
	DECLE 4096
	DECLE 6448
	DECLE 4096
	DECLE 6456
	DECLE 6464
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	;[2646] 	DATA $1000,$1000,$1000,$1000,$1000,$1000,$1000,$1000,$1930,$1948	
	SRCFILE "goatcontest.bas",2646
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6448
	DECLE 6472
	;[2647] 	DATA $1000,$1000,$1950,$1940,$1000,$1000,$1000,$1000,$1000,$1000
	SRCFILE "goatcontest.bas",2647
	DECLE 4096
	DECLE 4096
	DECLE 6480
	DECLE 6464
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	;[2648] 	DATA $1000,$1000,$1000,$1000,$1000,$1000,$1000,$1920,$1000,$1000	
	SRCFILE "goatcontest.bas",2648
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6432
	DECLE 4096
	DECLE 4096
	;[2649] 	DATA $1000,$1000,$1000,$1000,$1000,$1000,$1000,$1000,$1000,$1000
	SRCFILE "goatcontest.bas",2649
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	;[2650] 	DATA $1000,$1000,$1000,$1000,$1000,$1000,$1000,$1000,$1000,$1000	
	SRCFILE "goatcontest.bas",2650
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	;[2651] 	DATA $2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200
	SRCFILE "goatcontest.bas",2651
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	;[2652] 	DATA $2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200	
	SRCFILE "goatcontest.bas",2652
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	;[2653] 	DATA $2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$095D,$0965
	SRCFILE "goatcontest.bas",2653
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 2397
	DECLE 2405
	;[2654] 	DATA $096D,$0975,$097D,$0985,$098D,$0995,$096D,$099D,$09A5,$2200
	SRCFILE "goatcontest.bas",2654
	DECLE 2413
	DECLE 2421
	DECLE 2429
	DECLE 2437
	DECLE 2445
	DECLE 2453
	DECLE 2413
	DECLE 2461
	DECLE 2469
	DECLE 8704
	;[2655] 	DATA $2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200
	SRCFILE "goatcontest.bas",2655
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	;[2656] 	DATA $2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200
	SRCFILE "goatcontest.bas",2656
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	;[2657] 	
	SRCFILE "goatcontest.bas",2657
	;[2658] gameover_goat_bitmaps_0:
	SRCFILE "goatcontest.bas",2658
	; GAMEOVER_GOAT_BITMAPS_0
Q82:	;[2659] 	DATA $E0F8,$80C0,$0000,$0703
	SRCFILE "goatcontest.bas",2659
	DECLE 57592
	DECLE 32960
	DECLE 0
	DECLE 1795
	;[2660] 	DATA $1F1F,$1F1F,$1E1E,$FEFE
	SRCFILE "goatcontest.bas",2660
	DECLE 7967
	DECLE 7967
	DECLE 7710
	DECLE 65278
	;[2661] 	DATA $0307,$0303,$0101,$0101
	SRCFILE "goatcontest.bas",2661
	DECLE 775
	DECLE 771
	DECLE 257
	DECLE 257
	;[2662] 	DATA $C1C3,$C0C1,$C0C0,$C0C0
	SRCFILE "goatcontest.bas",2662
	DECLE 49603
	DECLE 49345
	DECLE 49344
	DECLE 49344
	;[2663] 	DATA $C1E1,$81C1,$0181,$0101
	SRCFILE "goatcontest.bas",2663
	DECLE 49633
	DECLE 33217
	DECLE 385
	DECLE 257
	;[2664] 	DATA $8080,$8080,$8080,$8083
	SRCFILE "goatcontest.bas",2664
	DECLE 32896
	DECLE 32896
	DECLE 32896
	DECLE 32899
	;[2665] 	DATA $3F3F,$3F3F,$3E3E,$3EFE
	SRCFILE "goatcontest.bas",2665
	DECLE 16191
	DECLE 16191
	DECLE 15934
	DECLE 16126
	;[2666] 	DATA $80C0,$0000,$0000,$0C0C
	SRCFILE "goatcontest.bas",2666
	DECLE 32960
	DECLE 0
	DECLE 0
	DECLE 3084
	;[2667] 	DATA $78F0,$3838,$1C1C,$1E1C
	SRCFILE "goatcontest.bas",2667
	DECLE 30960
	DECLE 14392
	DECLE 7196
	DECLE 7708
	;[2668] 	DATA $1818,$1111,$1311,$0303
	SRCFILE "goatcontest.bas",2668
	DECLE 6168
	DECLE 4369
	DECLE 4881
	DECLE 771
	;[2669] 	DATA $3030,$3030,$3030,$30F0
	SRCFILE "goatcontest.bas",2669
	DECLE 12336
	DECLE 12336
	DECLE 12336
	DECLE 12528
	;[2670] 	DATA $030F,$0001,$0000,$6060
	SRCFILE "goatcontest.bas",2670
	DECLE 783
	DECLE 1
	DECLE 0
	DECLE 24672
	;[2671] 	DATA $0707,$8083,$F8E0,$FFFF
	SRCFILE "goatcontest.bas",2671
	DECLE 1799
	DECLE 32899
	DECLE 63712
	DECLE 65535
	;[2672] 	DATA $8C8C,$0C8C,$0808,$FFFF
	SRCFILE "goatcontest.bas",2672
	DECLE 35980
	DECLE 3212
	DECLE 2056
	DECLE 65535
	;[2673] 	DATA $6040,$0060,$B000,$FFFF
	SRCFILE "goatcontest.bas",2673
	DECLE 24640
	DECLE 96
	DECLE 45056
	DECLE 65535
	;[2674] 	DATA $C0C0,$C4C4,$4746,$FFFF
	SRCFILE "goatcontest.bas",2674
	DECLE 49344
	DECLE 50372
	DECLE 18246
	DECLE 65535
	;[2675] gameover_goat_bitmaps_1:
	SRCFILE "goatcontest.bas",2675
	; GAMEOVER_GOAT_BITMAPS_1
Q83:	;[2676] 	DATA $0101,$1111,$7131,$FFFF
	SRCFILE "goatcontest.bas",2676
	DECLE 257
	DECLE 4369
	DECLE 28977
	DECLE 65535
	;[2677] 	DATA $8380,$8383,$8080,$FFFF
	SRCFILE "goatcontest.bas",2677
	DECLE 33664
	DECLE 33667
	DECLE 32896
	DECLE 65535
	;[2678] 	DATA $FE3E,$FFFF,$3F3F,$FFFF
	SRCFILE "goatcontest.bas",2678
	DECLE 65086
	DECLE 65535
	DECLE 16191
	DECLE 65535
	;[2679] 	DATA $0C0C,$000C,$E180,$FFFF
	SRCFILE "goatcontest.bas",2679
	DECLE 3084
	DECLE 12
	DECLE 57728
	DECLE 65535
	;[2680] 	DATA $1E1E,$3F3F,$FF7F,$FFFF
	SRCFILE "goatcontest.bas",2680
	DECLE 7710
	DECLE 16191
	DECLE 65407
	DECLE 65535
	;[2681] 	DATA $0707,$0707,$8F0F,$FFFF
	SRCFILE "goatcontest.bas",2681
	DECLE 1799
	DECLE 1799
	DECLE 36623
	DECLE 65535
	;[2682] 	DATA $F030,$F0F0,$3030,$FFFF
	SRCFILE "goatcontest.bas",2682
	DECLE 61488
	DECLE 61680
	DECLE 12336
	DECLE 65535
	;[2683] 	DATA $0361,$0103,$6041,$FFF3
	SRCFILE "goatcontest.bas",2683
	DECLE 865
	DECLE 259
	DECLE 24641
	DECLE 65523
	;[2684] 	DATA $1C3C,$8E1C,$C78F,$C3C3
	SRCFILE "goatcontest.bas",2684
	DECLE 7228
	DECLE 36380
	DECLE 51087
	DECLE 50115
	;[2685] 	DATA $7FFF,$1F3F,$830F,$C181
	SRCFILE "goatcontest.bas",2685
	DECLE 32767
	DECLE 7999
	DECLE 33551
	DECLE 49537
	;[2686] 	DATA $FFFF,$FEFE,$FEFE,$FCFC
	SRCFILE "goatcontest.bas",2686
	DECLE 65535
	DECLE 65278
	DECLE 65278
	DECLE 64764
	;[2687] 	DATA $7FFF,$7F7F,$3F7F,$3F3F
	SRCFILE "goatcontest.bas",2687
	DECLE 32767
	DECLE 32639
	DECLE 16255
	DECLE 16191
	;[2688] 	DATA $F0E0,$FCF8,$FCFC,$FCFC
	SRCFILE "goatcontest.bas",2688
	DECLE 61664
	DECLE 64760
	DECLE 64764
	DECLE 64764
	;[2689] 	DATA $FFFF,$F1FF,$F1F1,$FFFF
	SRCFILE "goatcontest.bas",2689
	DECLE 65535
	DECLE 61951
	DECLE 61937
	DECLE 65535
	;[2690] 	DATA $7FFF,$3F3F,$3F3F,$0107
	SRCFILE "goatcontest.bas",2690
	DECLE 32767
	DECLE 16191
	DECLE 16191
	DECLE 263
	;[2691] 	DATA $FCFC,$FEFE,$FFFF,$FFFF
	SRCFILE "goatcontest.bas",2691
	DECLE 64764
	DECLE 65278
	DECLE 65535
	DECLE 65535
	;[2692] gameover_goat_bitmaps_2:
	SRCFILE "goatcontest.bas",2692
	; GAMEOVER_GOAT_BITMAPS_2
Q84:	;[2693] 	DATA $F0C0,$F8F8,$3FFB,$3F3F
	SRCFILE "goatcontest.bas",2693
	DECLE 61632
	DECLE 63736
	DECLE 16379
	DECLE 16191
	;[2694] 	DATA $FFFF,$80FF,$0000,$0000
	SRCFILE "goatcontest.bas",2694
	DECLE 65535
	DECLE 33023
	DECLE 0
	DECLE 0
	;[2695] 	DATA $FFFF,$01FF,$0000,$0000
	SRCFILE "goatcontest.bas",2695
	DECLE 65535
	DECLE 511
	DECLE 0
	DECLE 0
	;[2696] 	DATA $F8FC,$F0F0,$0020,$0000
	SRCFILE "goatcontest.bas",2696
	DECLE 63740
	DECLE 61680
	DECLE 32
	DECLE 0
	;[2697] 	DATA $FFFF,$FFFF,$F1FF,$F0F0
	SRCFILE "goatcontest.bas",2697
	DECLE 65535
	DECLE 65535
	DECLE 61951
	DECLE 61680
	;[2698] 	DATA $FFFF,$FEFF,$F8FC,$78F8
	SRCFILE "goatcontest.bas",2698
	DECLE 65535
	DECLE 65279
	DECLE 63740
	DECLE 30968
	;[2699] 	DATA $FFFF,$FFFF,$FFFF,$FCFE
	SRCFILE "goatcontest.bas",2699
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 64766
	;[2700] 	DATA $C0C0,$C0C0,$C0C0,$0000
	SRCFILE "goatcontest.bas",2700
	DECLE 49344
	DECLE 49344
	DECLE 49344
	DECLE 0
	;[2701] 	DATA $F0F0,$FCF0,$FEFE,$FFFF
	SRCFILE "goatcontest.bas",2701
	DECLE 61680
	DECLE 64752
	DECLE 65278
	DECLE 65535
	;[2702] 	DATA $CFC7,$FFEF,$FFFF,$3F7F
	SRCFILE "goatcontest.bas",2702
	DECLE 53191
	DECLE 65519
	DECLE 65535
	DECLE 16255
	;[2703] 	DATA $FCFC,$FCFC,$FCFC,$FEFC
	SRCFILE "goatcontest.bas",2703
	DECLE 64764
	DECLE 64764
	DECLE 64764
	DECLE 65276
	;[2704] 	DATA $FFFF,$FEFE,$FFFF,$FFFF
	SRCFILE "goatcontest.bas",2704
	DECLE 65535
	DECLE 65278
	DECLE 65535
	DECLE 65535
	;[2705] 	DATA $FFF0,$FFFF,$0080,$0000
	SRCFILE "goatcontest.bas",2705
	DECLE 65520
	DECLE 65535
	DECLE 128
	DECLE 0
	;[2706] 	DATA $FFFF,$3F7F,$8080,$8080
	SRCFILE "goatcontest.bas",2706
	DECLE 65535
	DECLE 16255
	DECLE 32896
	DECLE 32896
	;[2707] 	DATA $FCFF,$F8FC,$0303,$0303
	SRCFILE "goatcontest.bas",2707
	DECLE 64767
	DECLE 63740
	DECLE 771
	DECLE 771
	;[2708] 	DATA $1FFF,$1F0F,$FFFF,$FFFF
	SRCFILE "goatcontest.bas",2708
	DECLE 8191
	DECLE 7951
	DECLE 65535
	DECLE 65535
	;[2709] gameover_goat_bitmaps_3:
	SRCFILE "goatcontest.bas",2709
	; GAMEOVER_GOAT_BITMAPS_3
Q85:	;[2710] 	DATA $E0C0,$E0E0,$C0C0,$80C0
	SRCFILE "goatcontest.bas",2710
	DECLE 57536
	DECLE 57568
	DECLE 49344
	DECLE 32960
	;[2711] 	
	SRCFILE "goatcontest.bas",2711
	;[2712] 	BITMAP "00010000"	' star for above head (address 49)
	SRCFILE "goatcontest.bas",2712
	;[2713]  	BITMAP "00111000"	
	SRCFILE "goatcontest.bas",2713
	DECLE 14352
	;[2714]  	BITMAP "00010000"
	SRCFILE "goatcontest.bas",2714
	;[2715]  	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2715
	DECLE 16
	;[2716]  	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2716
	;[2717]  	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2717
	DECLE 0
	;[2718]  	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2718
	;[2719]  	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2719
	DECLE 0
	;[2720]  	
	SRCFILE "goatcontest.bas",2720
	;[2721]  	BITMAP "00101000"	' X for above head (address 50)
	SRCFILE "goatcontest.bas",2721
	;[2722]  	BITMAP "00010000"	
	SRCFILE "goatcontest.bas",2722
	DECLE 4136
	;[2723]  	BITMAP "00101000"
	SRCFILE "goatcontest.bas",2723
	;[2724]  	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2724
	DECLE 40
	;[2725]  	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2725
	;[2726]  	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2726
	DECLE 0
	;[2727]  	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2727
	;[2728]  	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2728
	DECLE 0
	;[2729] 	
	SRCFILE "goatcontest.bas",2729
	;[2730] gameover_goat_screen:
	SRCFILE "goatcontest.bas",2730
	; GAMEOVER_GOAT_SCREEN
Q86:	;[2731] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2731
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2732] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2732
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2733] 	DATA $0400,$0400,$0400,$0400,$0802,$080A,$0812,$081A,$0822,$082A
	SRCFILE "goatcontest.bas",2733
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 2050
	DECLE 2058
	DECLE 2066
	DECLE 2074
	DECLE 2082
	DECLE 2090
	;[2734] 	DATA $0832,$083A,$0842,$084A,$082A,$0852,$085A,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2734
	DECLE 2098
	DECLE 2106
	DECLE 2114
	DECLE 2122
	DECLE 2090
	DECLE 2130
	DECLE 2138
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2735] 	DATA $0400,$0400,$0400,$0400,$0862,$086A,$0872,$087A,$0882,$088A
	SRCFILE "goatcontest.bas",2735
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 2146
	DECLE 2154
	DECLE 2162
	DECLE 2170
	DECLE 2178
	DECLE 2186
	;[2736] 	DATA $0892,$089A,$08A2,$08AA,$088A,$08B2,$08BA,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2736
	DECLE 2194
	DECLE 2202
	DECLE 2210
	DECLE 2218
	DECLE 2186
	DECLE 2226
	DECLE 2234
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2737] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2737
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2738] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2738
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2739] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2739
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2740] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2740
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2741] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2741
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2742] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2742
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2743] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2743
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2744] 	DATA $1EC2,$1ECA,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2744
	DECLE 7874
	DECLE 7882
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2745] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$2ED2,$2EDA,$0400,$0400
	SRCFILE "goatcontest.bas",2745
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 11986
	DECLE 11994
	DECLE 1024
	DECLE 1024
	;[2746] 	DATA $2EE2,$1EEF,$2EF2,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2746
	DECLE 12002
	DECLE 7919
	DECLE 12018
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2747] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$2EFA,$0D07,$2F0A,$2F12
	SRCFILE "goatcontest.bas",2747
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 12026
	DECLE 3335
	DECLE 12042
	DECLE 12050
	;[2748] 	DATA $2F1A,$0D27,$0D2F,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2748
	DECLE 12058
	DECLE 3367
	DECLE 3375
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2749] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$2F32,$2F3A,$2600,$2600
	SRCFILE "goatcontest.bas",2749
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 12082
	DECLE 12090
	DECLE 9728
	DECLE 9728
	;[2750] 	DATA $2600,$0D47,$2F4A,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2750
	DECLE 9728
	DECLE 3399
	DECLE 12106
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2751] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$2F52,$0D5F,$2F62,$0D6F
	SRCFILE "goatcontest.bas",2751
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 12114
	DECLE 3423
	DECLE 12130
	DECLE 3439
	;[2752] 	DATA $0D77,$0D7F,$0D87,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2752
	DECLE 3447
	DECLE 3455
	DECLE 3463
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2753] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2753
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2754] 	DATA $0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400,$0400
	SRCFILE "goatcontest.bas",2754
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	;[2755] 
	SRCFILE "goatcontest.bas",2755
	;[2756] 	
	SRCFILE "goatcontest.bas",2756
	;[2757] ' 47 bitmaps
	SRCFILE "goatcontest.bas",2757
	;[2758] inter1_bitmaps_0:
	SRCFILE "goatcontest.bas",2758
	; INTER1_BITMAPS_0
Q94:	;[2759] 	DATA $6060,$6060,$6060,$6060
	SRCFILE "goatcontest.bas",2759
	DECLE 24672
	DECLE 24672
	DECLE 24672
	DECLE 24672
	;[2760] 	DATA $FFFF,$FFFF,$5FFF,$274F
	SRCFILE "goatcontest.bas",2760
	DECLE 65535
	DECLE 65535
	DECLE 24575
	DECLE 10063
	;[2761] 	DATA $0300,$0707,$0307,$0001
	SRCFILE "goatcontest.bas",2761
	DECLE 768
	DECLE 1799
	DECLE 775
	DECLE 1
	;[2762] 	DATA $6000,$F0F0,$E0F0,$80C0
	SRCFILE "goatcontest.bas",2762
	DECLE 24576
	DECLE 61680
	DECLE 57584
	DECLE 32960
	;[2763] 	DATA $8000,$C080,$7F7F,$FF7F
	SRCFILE "goatcontest.bas",2763
	DECLE 32768
	DECLE 49280
	DECLE 32639
	DECLE 65407
	;[2764] 	DATA $347C,$7F3F,$F2F6,$F0F0
	SRCFILE "goatcontest.bas",2764
	DECLE 13436
	DECLE 32575
	DECLE 62198
	DECLE 61680
	;[2765] 	DATA $2C3E,$FEFC,$4F6F,$0F0F
	SRCFILE "goatcontest.bas",2765
	DECLE 11326
	DECLE 65276
	DECLE 20335
	DECLE 3855
	;[2766] 	DATA $0100,$0301,$FEFE,$FFFE
	SRCFILE "goatcontest.bas",2766
	DECLE 256
	DECLE 769
	DECLE 65278
	DECLE 65534
	;[2767] 	DATA $F9F9,$D9D9,$00D9,$0000
	SRCFILE "goatcontest.bas",2767
	DECLE 63993
	DECLE 55769
	DECLE 217
	DECLE 0
	;[2768] 	DATA $B0B0,$B0B0,$00B0,$0000
	SRCFILE "goatcontest.bas",2768
	DECLE 45232
	DECLE 45232
	DECLE 176
	DECLE 0
	;[2769] 	DATA $4800,$1828,$0010,$0000
	SRCFILE "goatcontest.bas",2769
	DECLE 18432
	DECLE 6184
	DECLE 16
	DECLE 0
	;[2770] 	DATA $0000,$4854,$1038,$0000
	SRCFILE "goatcontest.bas",2770
	DECLE 0
	DECLE 18516
	DECLE 4152
	DECLE 0
	;[2771] 	DATA $0D0D,$0D0D,$000D,$0000
	SRCFILE "goatcontest.bas",2771
	DECLE 3341
	DECLE 3341
	DECLE 13
	DECLE 0
	;[2772] 	DATA $9F9F,$9B9B,$009B,$0000
	SRCFILE "goatcontest.bas",2772
	DECLE 40863
	DECLE 39835
	DECLE 155
	DECLE 0
	;[2773] 	DATA $0000,$0000,$0000,$FFFF
	SRCFILE "goatcontest.bas",2773
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 65535
	;[2774] 	DATA $6060,$6060,$6060,$FFFF
	SRCFILE "goatcontest.bas",2774
	DECLE 24672
	DECLE 24672
	DECLE 24672
	DECLE 65535
	;[2775] inter1_bitmaps_1:
	SRCFILE "goatcontest.bas",2775
	; INTER1_BITMAPS_1
Q95:	;[2776] 	DATA $0000,$0000,$0000,$E742
	SRCFILE "goatcontest.bas",2776
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 59202
	;[2777] 	DATA $0000,$0707,$0000,$0000
	SRCFILE "goatcontest.bas",2777
	DECLE 0
	DECLE 1799
	DECLE 0
	DECLE 0
	;[2778] 	DATA $7C3C,$FCFC,$FCFC,$FCFC
	SRCFILE "goatcontest.bas",2778
	DECLE 31804
	DECLE 64764
	DECLE 64764
	DECLE 64764
	;[2779] 	DATA $FFE7,$E7FF,$00E7,$E742
	SRCFILE "goatcontest.bas",2779
	DECLE 65511
	DECLE 59391
	DECLE 231
	DECLE 59202
	;[2780] 	DATA $FFFF,$3333,$3030,$0C0C
	SRCFILE "goatcontest.bas",2780
	DECLE 65535
	DECLE 13107
	DECLE 12336
	DECLE 3084
	;[2781] 	DATA $FFFF,$FFFF,$FFFF,$3F3F
	SRCFILE "goatcontest.bas",2781
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 16191
	;[2782] 	DATA $1E0F,$7B3D,$7B7A,$1E3D 'start of word balloon
	SRCFILE "goatcontest.bas",2782
	DECLE 7695
	DECLE 31549
	DECLE 31610
	DECLE 7741
	;[2783] 	DATA $16FF,$34F6,$54D6,$36DE 
	SRCFILE "goatcontest.bas",2783
	DECLE 5887
	DECLE 13558
	DECLE 21718
	DECLE 14046
	;[2784] 	DATA $B8FF,$1FB7,$1DBE,$BDBF 
	SRCFILE "goatcontest.bas",2784
	DECLE 47359
	DECLE 8119
	DECLE 7614
	DECLE 48575
	;[2785] 	DATA $E3FF,$565D,$E6DA,$C3FD
	SRCFILE "goatcontest.bas",2785
	DECLE 58367
	DECLE 22109
	DECLE 59098
	DECLE 50173
	;[2786] 	DATA $B0E0,$BCB8,$BCBC,$B0F8 'end of word baooon
	SRCFILE "goatcontest.bas",2786
	DECLE 45280
	DECLE 48312
	DECLE 48316
	DECLE 45304
	;[2787] 	DATA $1000,$0E08,$0303,$0000 'farmer arm
	SRCFILE "goatcontest.bas",2787
	DECLE 4096
	DECLE 3592
	DECLE 771
	DECLE 0
	;[2788] 	DATA $0C0C,$0C0C,$FCFC,$FCFC 'farmer torso
	SRCFILE "goatcontest.bas",2788
	DECLE 3084
	DECLE 3084
	DECLE 64764
	DECLE 64764
	;[2789] 	DATA $0000,$C040,$C0C0,$70E0 'big goat tail
	SRCFILE "goatcontest.bas",2789
	DECLE 0
	DECLE 49216
	DECLE 49344
	DECLE 28896
	;[2790] 	DATA $1F3F,$0F0F,$0F0F,$3F1F 'back of big goat head
	SRCFILE "goatcontest.bas",2790
	DECLE 7999
	DECLE 3855
	DECLE 3855
	DECLE 16159
	;[2791] 	DATA $F0E0,$3030,$FFFE,$FEFF 'front of big goat head
	SRCFILE "goatcontest.bas",2791
	DECLE 61664
	DECLE 12336
	DECLE 65534
	DECLE 65279
	;[2792] inter1_bitmaps_2:
	SRCFILE "goatcontest.bas",2792
	; INTER1_BITMAPS_2
Q96:	;[2793] 	DATA $010F,$0301,$0703,$000C 'left of word balloon tail
	SRCFILE "goatcontest.bas",2793
	DECLE 271
	DECLE 769
	DECLE 1795
	DECLE 12
	;[2794] 	DATA $F0FF,$C0E0,$0080,$0000 'right of word balloon tail
	SRCFILE "goatcontest.bas",2794
	DECLE 61695
	DECLE 49376
	DECLE 128
	DECLE 0
	;[2795] 	DATA $00FF,$0000,$0000,$0000 'bottom (x2) of word balloon
	SRCFILE "goatcontest.bas",2795
	DECLE 255
	DECLE 0
	DECLE 0
	DECLE 0
	;[2796] 	DATA $00E0,$0000,$0000,$0000 'last part of bottom of word baloon
	SRCFILE "goatcontest.bas",2796
	DECLE 224
	DECLE 0
	DECLE 0
	DECLE 0
	;[2797] 	DATA $1C1C,$1C1C,$1C1C,$1C1C
	SRCFILE "goatcontest.bas",2797
	DECLE 7196
	DECLE 7196
	DECLE 7196
	DECLE 7196
	;[2798] 	DATA $3F3F,$3F3F,$3F3F,$FF7F
	SRCFILE "goatcontest.bas",2798
	DECLE 16191
	DECLE 16191
	DECLE 16191
	DECLE 65407
	;[2799] 	DATA $3C3C,$040C,$0000,$0000
	SRCFILE "goatcontest.bas",2799
	DECLE 15420
	DECLE 1036
	DECLE 0
	DECLE 0
	;[2800] 	DATA $1C1C,$7C7C,$7C7C,$0000
	SRCFILE "goatcontest.bas",2800
	DECLE 7196
	DECLE 31868
	DECLE 31868
	DECLE 0
	;[2801] 	DATA $FFFF,$FFFF,$F3F3,$F3F3
	SRCFILE "goatcontest.bas",2801
	DECLE 65535
	DECLE 65535
	DECLE 62451
	DECLE 62451
	;[2802] 	DATA $C3C3,$C3C3,$C3C3,$C3C3
	SRCFILE "goatcontest.bas",2802
	DECLE 50115
	DECLE 50115
	DECLE 50115
	DECLE 50115
	;[2803] 	DATA $CFCF,$CFCF,$CFCF,$CFCF
	SRCFILE "goatcontest.bas",2803
	DECLE 53199
	DECLE 53199
	DECLE 53199
	DECLE 53199
	;[2804] 	DATA $FFE7,$E7FF,$00E7,$0000
	SRCFILE "goatcontest.bas",2804
	DECLE 65511
	DECLE 59391
	DECLE 231
	DECLE 0
	;[2805] 	DATA $F3F3,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2805
	DECLE 62451
	DECLE 0
	DECLE 0
	DECLE 0
	;[2806] 	DATA $C3C3,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2806
	DECLE 50115
	DECLE 0
	DECLE 0
	DECLE 0
	;[2807] 	DATA $CFCF,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2807
	DECLE 53199
	DECLE 0
	DECLE 0
	DECLE 0
	;[2808] 
	SRCFILE "goatcontest.bas",2808
	;[2809] 	BITMAP "00011000"   	'ms goat bow
	SRCFILE "goatcontest.bas",2809
	;[2810] 	BITMAP "00011100"	
	SRCFILE "goatcontest.bas",2810
	DECLE 7192
	;[2811] 	BITMAP "00101100"
	SRCFILE "goatcontest.bas",2811
	;[2812] 	BITMAP "11010000"
	SRCFILE "goatcontest.bas",2812
	DECLE 53292
	;[2813] 	BITMAP "11100000"
	SRCFILE "goatcontest.bas",2813
	;[2814] 	BITMAP "01100000"
	SRCFILE "goatcontest.bas",2814
	DECLE 24800
	;[2815] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2815
	;[2816] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2816
	DECLE 0
	;[2817] 	
	SRCFILE "goatcontest.bas",2817
	;[2818] inter1_bitmaps_3:
	SRCFILE "goatcontest.bas",2818
	; INTER1_BITMAPS_3
Q97:	;[2819] 	BITMAP "00111111"   	'whistle note
	SRCFILE "goatcontest.bas",2819
	;[2820] 	BITMAP "00100001"	
	SRCFILE "goatcontest.bas",2820
	DECLE 8511
	;[2821] 	BITMAP "00111111"
	SRCFILE "goatcontest.bas",2821
	;[2822] 	BITMAP "00100001"
	SRCFILE "goatcontest.bas",2822
	DECLE 8511
	;[2823] 	BITMAP "01100011"
	SRCFILE "goatcontest.bas",2823
	;[2824] 	BITMAP "11100111"
	SRCFILE "goatcontest.bas",2824
	DECLE 59235
	;[2825] 	BITMAP "01000010"
	SRCFILE "goatcontest.bas",2825
	;[2826] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2826
	DECLE 66
	;[2827] 	
	SRCFILE "goatcontest.bas",2827
	;[2828] 	BITMAP "00000111"   	'alt whistle note
	SRCFILE "goatcontest.bas",2828
	;[2829] 	BITMAP "00000100"	
	SRCFILE "goatcontest.bas",2829
	DECLE 1031
	;[2830] 	BITMAP "00000111"
	SRCFILE "goatcontest.bas",2830
	;[2831] 	BITMAP "00000100"
	SRCFILE "goatcontest.bas",2831
	DECLE 1031
	;[2832] 	BITMAP "00001100"
	SRCFILE "goatcontest.bas",2832
	;[2833] 	BITMAP "00011100"
	SRCFILE "goatcontest.bas",2833
	DECLE 7180
	;[2834] 	BITMAP "00001000"
	SRCFILE "goatcontest.bas",2834
	;[2835] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2835
	DECLE 8
	;[2836] 
	SRCFILE "goatcontest.bas",2836
	;[2837] 	BITMAP "00000000"   	'red eye
	SRCFILE "goatcontest.bas",2837
	;[2838] 	BITMAP "00000000"	
	SRCFILE "goatcontest.bas",2838
	DECLE 0
	;[2839] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2839
	;[2840] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2840
	DECLE 0
	;[2841] 	BITMAP "00001100"
	SRCFILE "goatcontest.bas",2841
	;[2842] 	BITMAP "00001100"
	SRCFILE "goatcontest.bas",2842
	DECLE 3084
	;[2843] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2843
	;[2844] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2844
	DECLE 0
	;[2845] 	
	SRCFILE "goatcontest.bas",2845
	;[2846] 	BITMAP "00000000"   	'black eyebrow 
	SRCFILE "goatcontest.bas",2846
	;[2847] 	BITMAP "00000000"	
	SRCFILE "goatcontest.bas",2847
	DECLE 0
	;[2848] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2848
	;[2849] 	BITMAP "00111100"
	SRCFILE "goatcontest.bas",2849
	DECLE 15360
	;[2850] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2850
	;[2851] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2851
	DECLE 0
	;[2852] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2852
	;[2853] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2853
	DECLE 0
	;[2854] 	
	SRCFILE "goatcontest.bas",2854
	;[2855] 	BITMAP "00011100"   	'question mark
	SRCFILE "goatcontest.bas",2855
	;[2856] 	BITMAP "00100010"	
	SRCFILE "goatcontest.bas",2856
	DECLE 8732
	;[2857] 	BITMAP "00000100"
	SRCFILE "goatcontest.bas",2857
	;[2858] 	BITMAP "00001000"
	SRCFILE "goatcontest.bas",2858
	DECLE 2052
	;[2859] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2859
	;[2860] 	BITMAP "00001000"
	SRCFILE "goatcontest.bas",2860
	DECLE 2048
	;[2861] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2861
	;[2862] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2862
	DECLE 0
	;[2863] 	
	SRCFILE "goatcontest.bas",2863
	;[2864] 	BITMAP "00001000"   	'exclamation point
	SRCFILE "goatcontest.bas",2864
	;[2865] 	BITMAP "00001000"	
	SRCFILE "goatcontest.bas",2865
	DECLE 2056
	;[2866] 	BITMAP "00001000"
	SRCFILE "goatcontest.bas",2866
	;[2867] 	BITMAP "00001000"
	SRCFILE "goatcontest.bas",2867
	DECLE 2056
	;[2868] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2868
	;[2869] 	BITMAP "00001000"
	SRCFILE "goatcontest.bas",2869
	DECLE 2048
	;[2870] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2870
	;[2871] 	BITMAP "00000000"
	SRCFILE "goatcontest.bas",2871
	DECLE 0
	;[2872] 	
	SRCFILE "goatcontest.bas",2872
	;[2873] inter1_cards1:
	SRCFILE "goatcontest.bas",2873
	; INTER1_CARDS1
Q99:	;[2874] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0801 vertical bar
	SRCFILE "goatcontest.bas",2874
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2875] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0871 horizontal bar
	SRCFILE "goatcontest.bas",2875
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2876] 
	SRCFILE "goatcontest.bas",2876
	;[2877] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0879 bars crossing point
	SRCFILE "goatcontest.bas",2877
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2878] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2878
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2879] 
	SRCFILE "goatcontest.bas",2879
	;[2880] 	DATA $0000,$0000,$1E08,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$1E08 goat horns
	SRCFILE "goatcontest.bas",2880
	DECLE 0
	DECLE 0
	DECLE 7688
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2881] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0812,$081A heart
	SRCFILE "goatcontest.bas",2881
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2882] 
	SRCFILE "goatcontest.bas",2882
	;[2883] 	DATA $0000,$0827,$082F,$0000,$0000,$0000,$0827,$082F,$0000,$0000 '$0827,$082F goat body top facing right
	SRCFILE "goatcontest.bas",2883
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	;[2884] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0837,$083F goat body top facing left
	SRCFILE "goatcontest.bas",2884
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2885] 
	SRCFILE "goatcontest.bas",2885
	;[2886] 	DATA $0000,$0847,$084F,$0855,$0000,$0000,$0847,$084F,$085D,$0000 '$0847,$084F goat body bot facing right
	SRCFILE "goatcontest.bas",2886
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 2133
	DECLE 0
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 2141
	DECLE 0
	;[2887] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0867,$086F goat body bot facing left 
	SRCFILE "goatcontest.bas",2887
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2888] 
	SRCFILE "goatcontest.bas",2888
	;[2889] 	DATA $0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871
	SRCFILE "goatcontest.bas",2889
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	;[2890] 	DATA $0879,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871
	SRCFILE "goatcontest.bas",2890
	DECLE 2169
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	;[2891] 
	SRCFILE "goatcontest.bas",2891
	;[2892] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2892
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2893] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2893
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2894] 
	SRCFILE "goatcontest.bas",2894
	;[2895] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2895
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2896] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2896
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2897] 
	SRCFILE "goatcontest.bas",2897
	;[2898] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2898
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2899] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2899
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2900] 
	SRCFILE "goatcontest.bas",2900
	;[2901] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2901
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2902] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2902
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2903] 
	SRCFILE "goatcontest.bas",2903
	;[2904] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2904
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2905] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2905
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2906] 
	SRCFILE "goatcontest.bas",2906
	;[2907] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2907
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2908] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2908
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2909] 	
	SRCFILE "goatcontest.bas",2909
	;[2910] 	
	SRCFILE "goatcontest.bas",2910
	;[2911] inter1_cards2:
	SRCFILE "goatcontest.bas",2911
	; INTER1_CARDS2
Q100:	;[2912] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0801 vertical bar
	SRCFILE "goatcontest.bas",2912
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2913] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0871 horizontal bar
	SRCFILE "goatcontest.bas",2913
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2914] 
	SRCFILE "goatcontest.bas",2914
	;[2915] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0879 bars crossing point
	SRCFILE "goatcontest.bas",2915
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2916] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2916
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2917] 
	SRCFILE "goatcontest.bas",2917
	;[2918] 	DATA $0000,$0000,$1E08,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$1E08 goat horns
	SRCFILE "goatcontest.bas",2918
	DECLE 0
	DECLE 0
	DECLE 7688
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2919] 	DATA $0801,$0000,$0000,$1E08,$0812,$081A,$0000,$0000,$0000,$0000 '$0812,$081A heart
	SRCFILE "goatcontest.bas",2919
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 7688
	DECLE 2066
	DECLE 2074
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2920] 
	SRCFILE "goatcontest.bas",2920
	;[2921] 	DATA $0000,$0827,$082F,$0000,$0000,$0000,$0827,$082F,$0000,$0000 '$0827,$082F goat body top facing right
	SRCFILE "goatcontest.bas",2921
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	;[2922] 	DATA $0801,$0000,$0827,$082F,$0000,$0000,$0837,$083F,$0000,$0000 '$0837,$083F goat body top facing left
	SRCFILE "goatcontest.bas",2922
	DECLE 2049
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	DECLE 2103
	DECLE 2111
	DECLE 0
	DECLE 0
	;[2923] 
	SRCFILE "goatcontest.bas",2923
	;[2924] 	DATA $0000,$0847,$084F,$0855,$0000,$0000,$0847,$084F,$085D,$0000 '$0847,$084F goat body bot facing right
	SRCFILE "goatcontest.bas",2924
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 2133
	DECLE 0
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 2141
	DECLE 0
	;[2925] 	DATA $0801,$0000,$0847,$084F,$0000,$0000,$0867,$086F,$0000,$0000 '$0867,$086F goat body bot facing left 
	SRCFILE "goatcontest.bas",2925
	DECLE 2049
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 0
	DECLE 0
	DECLE 2151
	DECLE 2159
	DECLE 0
	DECLE 0
	;[2926] 
	SRCFILE "goatcontest.bas",2926
	;[2927] 	DATA $0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871
	SRCFILE "goatcontest.bas",2927
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	;[2928] 	DATA $0879,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871
	SRCFILE "goatcontest.bas",2928
	DECLE 2169
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	;[2929] 
	SRCFILE "goatcontest.bas",2929
	;[2930] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2930
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2931] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2931
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2932] 
	SRCFILE "goatcontest.bas",2932
	;[2933] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2933
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2934] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2934
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2935] 
	SRCFILE "goatcontest.bas",2935
	;[2936] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2936
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2937] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2937
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2938] 
	SRCFILE "goatcontest.bas",2938
	;[2939] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2939
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2940] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2940
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2941] 
	SRCFILE "goatcontest.bas",2941
	;[2942] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2942
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2943] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2943
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2944] 
	SRCFILE "goatcontest.bas",2944
	;[2945] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2945
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2946] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2946
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2947] 	
	SRCFILE "goatcontest.bas",2947
	;[2948] 	
	SRCFILE "goatcontest.bas",2948
	;[2949] inter1_cards3:
	SRCFILE "goatcontest.bas",2949
	; INTER1_CARDS3
Q101:	;[2950] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0801 vertical bar
	SRCFILE "goatcontest.bas",2950
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2951] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0871 horizontal bar
	SRCFILE "goatcontest.bas",2951
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2952] 
	SRCFILE "goatcontest.bas",2952
	;[2953] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0879 bars crossing point
	SRCFILE "goatcontest.bas",2953
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2954] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2954
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2955] 
	SRCFILE "goatcontest.bas",2955
	;[2956] 	DATA $0000,$0000,$1E08,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$1E08 goat horns
	SRCFILE "goatcontest.bas",2956
	DECLE 0
	DECLE 0
	DECLE 7688
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2957] 	DATA $0801,$0000,$0000,$1E08,$0812,$081A,$0000,$0000,$0000,$0000 '$0812,$081A heart
	SRCFILE "goatcontest.bas",2957
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 7688
	DECLE 2066
	DECLE 2074
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2958] 
	SRCFILE "goatcontest.bas",2958
	;[2959] 	DATA $0000,$0827,$082F,$0000,$0000,$0000,$0827,$082F,$0000,$0000 '$0827,$082F goat body top facing right
	SRCFILE "goatcontest.bas",2959
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	;[2960] 	DATA $0801,$0000,$0827,$082F,$0000,$0000,$0837,$083F,$0000,$0000 '$0837,$083F goat body top facing left
	SRCFILE "goatcontest.bas",2960
	DECLE 2049
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	DECLE 2103
	DECLE 2111
	DECLE 0
	DECLE 0
	;[2961] 
	SRCFILE "goatcontest.bas",2961
	;[2962] 	DATA $0000,$0847,$084F,$0855,$0000,$0000,$0847,$084F,$085D,$0000 '$0847,$084F goat body bot facing right
	SRCFILE "goatcontest.bas",2962
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 2133
	DECLE 0
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 2141
	DECLE 0
	;[2963] 	DATA $0801,$0000,$0847,$084F,$0000,$0000,$0867,$086F,$0000,$0000 '$0867,$086F goat body bot facing left 
	SRCFILE "goatcontest.bas",2963
	DECLE 2049
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 0
	DECLE 0
	DECLE 2151
	DECLE 2159
	DECLE 0
	DECLE 0
	;[2964] 
	SRCFILE "goatcontest.bas",2964
	;[2965] 	DATA $0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871 'horizontal bar
	SRCFILE "goatcontest.bas",2965
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	;[2966] 	DATA $0879,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871
	SRCFILE "goatcontest.bas",2966
	DECLE 2169
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	;[2967] 
	SRCFILE "goatcontest.bas",2967
	;[2968] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0887,$0000,$0000,$0000 ' top of fence
	SRCFILE "goatcontest.bas",2968
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2183
	DECLE 0
	DECLE 0
	DECLE 0
	;[2969] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2969
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2970] 
	SRCFILE "goatcontest.bas",2970
	;[2971] 	DATA $0000,$0000,$0000,$0000,$088A,$0892,$089F,$0000,$0000,$0000 ' farmer starts here
	SRCFILE "goatcontest.bas",2971
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2186
	DECLE 2194
	DECLE 2207
	DECLE 0
	DECLE 0
	DECLE 0
	;[2972] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2972
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2973] 
	SRCFILE "goatcontest.bas",2973
	;[2974] 	DATA $0000,$0000,$1E08,$0000,$08DA,$08E2,$089F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2974
	DECLE 0
	DECLE 0
	DECLE 7688
	DECLE 0
	DECLE 2266
	DECLE 2274
	DECLE 2207
	DECLE 0
	DECLE 0
	DECLE 0
	;[2975] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2975
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2976] 
	SRCFILE "goatcontest.bas",2976
	;[2977] 	DATA $0000,$0827,$082F,$0000,$0000,$0922,$089F,$0000,$0837,$083F
	SRCFILE "goatcontest.bas",2977
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	DECLE 2338
	DECLE 2207
	DECLE 0
	DECLE 2103
	DECLE 2111
	;[2978] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2978
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2979] 
	SRCFILE "goatcontest.bas",2979
	;[2980] 	DATA $0000,$0847,$084F,$0000,$0000,$093A,$089F,$0000,$0867,$086F ' farmer ends here
	SRCFILE "goatcontest.bas",2980
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 0
	DECLE 0
	DECLE 2362
	DECLE 2207
	DECLE 0
	DECLE 2151
	DECLE 2159
	;[2981] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2981
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2982] 
	SRCFILE "goatcontest.bas",2982
	;[2983] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$095F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2983
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2399
	DECLE 0
	DECLE 0
	DECLE 0
	;[2984] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2984
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2985] 	
	SRCFILE "goatcontest.bas",2985
	;[2986] 	
	SRCFILE "goatcontest.bas",2986
	;[2987] inter1_cards4:
	SRCFILE "goatcontest.bas",2987
	; INTER1_CARDS4
Q103:	;[2988] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0801 vertical bar
	SRCFILE "goatcontest.bas",2988
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2989] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0871 horizontal bar
	SRCFILE "goatcontest.bas",2989
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2990] 
	SRCFILE "goatcontest.bas",2990
	;[2991] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$0879 bars crossing point
	SRCFILE "goatcontest.bas",2991
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2992] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",2992
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2993] 
	SRCFILE "goatcontest.bas",2993
	;[2994] 	DATA $0000,$0000,$1E08,$0000,$0000,$0000,$0000,$0000,$0000,$0000 '$1E08 goat horns
	SRCFILE "goatcontest.bas",2994
	DECLE 0
	DECLE 0
	DECLE 7688
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2995] 	DATA $0801,$0000,$0000,$1E08,$0812,$081A,$0000,$0000,$0000,$0000 '$0812,$081A heart
	SRCFILE "goatcontest.bas",2995
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 7688
	DECLE 2066
	DECLE 2074
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2996] 
	SRCFILE "goatcontest.bas",2996
	;[2997] 	DATA $0000,$0827,$082F,$0000,$0000,$0000,$0827,$082F,$0000,$0000 '$0827,$082F goat body top facing right
	SRCFILE "goatcontest.bas",2997
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	;[2998] 	DATA $0801,$0000,$0827,$082F,$0000,$0000,$0837,$083F,$0000,$0000 '$0837,$083F goat body top facing left
	SRCFILE "goatcontest.bas",2998
	DECLE 2049
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	DECLE 2103
	DECLE 2111
	DECLE 0
	DECLE 0
	;[2999] 
	SRCFILE "goatcontest.bas",2999
	;[3000] 	DATA $0000,$0847,$084F,$0855,$0000,$0000,$0847,$084F,$085D,$0000 '$0847,$084F goat body bot facing right
	SRCFILE "goatcontest.bas",3000
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 2133
	DECLE 0
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 2141
	DECLE 0
	;[3001] 	DATA $0801,$0000,$0847,$084F,$0000,$0000,$0867,$086F,$0000,$0000 '$0867,$086F goat body bot facing left 
	SRCFILE "goatcontest.bas",3001
	DECLE 2049
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 0
	DECLE 0
	DECLE 2151
	DECLE 2159
	DECLE 0
	DECLE 0
	;[3002] 
	SRCFILE "goatcontest.bas",3002
	;[3003] 	DATA $0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871
	SRCFILE "goatcontest.bas",3003
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	;[3004] 	DATA $0879,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871,$0871
	SRCFILE "goatcontest.bas",3004
	DECLE 2169
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	DECLE 2161
	;[3005] 
	SRCFILE "goatcontest.bas",3005
	;[3006] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0887,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",3006
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2183
	DECLE 0
	DECLE 0
	DECLE 0
	;[3007] 	DATA $0801,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",3007
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3008] 
	SRCFILE "goatcontest.bas",3008
	;[3009] 	DATA $0000,$0000,$0000,$0000,$088A,$0892,$089F,$0000,$0000,$0000 'top of word balloon
	SRCFILE "goatcontest.bas",3009
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2186
	DECLE 2194
	DECLE 2207
	DECLE 0
	DECLE 0
	DECLE 0
	;[3010] 	DATA $0801,$0000,$0000,$1EA0,$1EA8,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",3010
	DECLE 2049
	DECLE 0
	DECLE 0
	DECLE 7840
	DECLE 7848
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3011] 
	SRCFILE "goatcontest.bas",3011
	;[3012] 	DATA $0000,$0000,$1E08,$0000,$08DA,$08E2,$089F,$0000,$0000,$0000 'big goat face and bottom of word balloon
	SRCFILE "goatcontest.bas",3012
	DECLE 0
	DECLE 0
	DECLE 7688
	DECLE 0
	DECLE 2266
	DECLE 2274
	DECLE 2207
	DECLE 0
	DECLE 0
	DECLE 0
	;[3013] 	DATA $0801,$08EF,$0000,$08F7,$08FF,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",3013
	DECLE 2049
	DECLE 2287
	DECLE 0
	DECLE 2295
	DECLE 2303
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3014] 
	SRCFILE "goatcontest.bas",3014
	;[3015] 	DATA $0000,$0827,$082F,$0000,$0000,$0922,$089F,$0000,$0837,$083F
	SRCFILE "goatcontest.bas",3015
	DECLE 0
	DECLE 2087
	DECLE 2095
	DECLE 0
	DECLE 0
	DECLE 2338
	DECLE 2207
	DECLE 0
	DECLE 2103
	DECLE 2111
	;[3016] 	DATA $0801,$092F,$2600,$2600,$0937,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",3016
	DECLE 2049
	DECLE 2351
	DECLE 9728
	DECLE 9728
	DECLE 2359
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3017] 
	SRCFILE "goatcontest.bas",3017
	;[3018] 	DATA $0000,$0847,$084F,$0000,$0000,$093A,$089F,$0000,$0867,$086F
	SRCFILE "goatcontest.bas",3018
	DECLE 0
	DECLE 2119
	DECLE 2127
	DECLE 0
	DECLE 0
	DECLE 2362
	DECLE 2207
	DECLE 0
	DECLE 2151
	DECLE 2159
	;[3019] 	DATA $0801,$0947,$094F,$0957,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",3019
	DECLE 2049
	DECLE 2375
	DECLE 2383
	DECLE 2391
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3020] 
	SRCFILE "goatcontest.bas",3020
	;[3021] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$095F,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",3021
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2399
	DECLE 0
	DECLE 0
	DECLE 0
	;[3022] 	DATA $0801,$0967,$096F,$0977,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "goatcontest.bas",3022
	DECLE 2049
	DECLE 2407
	DECLE 2415
	DECLE 2423
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3023] 	
	SRCFILE "goatcontest.bas",3023
	;[3024] 	
	SRCFILE "goatcontest.bas",3024
	;[3025] 'voice data goes here
	SRCFILE "goatcontest.bas",3025
	;[3026] 	
	SRCFILE "goatcontest.bas",3026
	;[3027] bleat_voice:	
	SRCFILE "goatcontest.bas",3027
	; BLEAT_VOICE
Q115:	;[3028] 	VOICE MM,eh,eh,eh,eh,PA2,0
	SRCFILE "goatcontest.bas",3028
	DECLE _MM
	DECLE _EH
	DECLE _EH
	DECLE _EH
	DECLE _EH
	DECLE 4
	DECLE 0
	;[3029] 	
	SRCFILE "goatcontest.bas",3029
	;[3030] spring_voice:
	SRCFILE "goatcontest.bas",3030
	; SPRING_VOICE
Q106:	;[3031] 	VOICE SS,PP,RR1,IH,NG1,PA3,0
	SRCFILE "goatcontest.bas",3031
	DECLE _SS
	DECLE _PP
	DECLE _RR1
	DECLE _IH
	DECLE _NG1
	DECLE 3
	DECLE 0
	;[3032] 
	SRCFILE "goatcontest.bas",3032
	;[3033] summer_voice:
	SRCFILE "goatcontest.bas",3033
	; SUMMER_VOICE
Q108:	;[3034] 	VOICE SS,PA2,UH,MM,ER2,PA3,0
	SRCFILE "goatcontest.bas",3034
	DECLE _SS
	DECLE 4
	DECLE _UH
	DECLE _MM
	DECLE _ER2
	DECLE 3
	DECLE 0
	;[3035] 	
	SRCFILE "goatcontest.bas",3035
	;[3036] fall_voice:
	SRCFILE "goatcontest.bas",3036
	; FALL_VOICE
Q110:	;[3037] 	VOICE FF,AO,AO,LL,PA3,0
	SRCFILE "goatcontest.bas",3037
	DECLE _FF
	DECLE _AO
	DECLE _AO
	DECLE _LL
	DECLE 3
	DECLE 0
	;[3038] 
	SRCFILE "goatcontest.bas",3038
	;[3039] winter_voice:
	SRCFILE "goatcontest.bas",3039
	; WINTER_VOICE
Q112:	;[3040] 	VOICE WW,IH,NN1,TT1,ER2,PA3,0
	SRCFILE "goatcontest.bas",3040
	DECLE _WW
	DECLE _IH
	DECLE _NN1
	DECLE _TT1
	DECLE _ER2
	DECLE 3
	DECLE 0
	;ENDFILE
	SRCFILE "",0
	IF DEFINED __FEATURE.CFGVAR
		CFGVAR "voice" = 1
		CFGVAR "ecs" = 1
	ENDI
intybasic_music:	equ 1	; Forces to include music library
intybasic_voice:	equ 1	; Forces to include voice library
intybasic_ecs:	equ 1	; Forces to include ECS startup
intybasic_fastdiv:	equ 1	; Forces to include fast division/remainder
        ;
        ; Epilogue for IntyBASIC programs
        ; by Oscar Toledo G.  http://nanochess.org/
        ;
        ; Revision: Jan/30/2014. Moved GRAM code below MOB updates.
        ;                        Added comments.
        ; Revision: Feb/26/2014. Optimized access to collision registers
        ;                        per DZ-Jay suggestion. Added scrolling
        ;                        routines with optimization per intvnut
        ;                        suggestion. Added border/mask support.
        ; Revision: Apr/02/2014. Added support to set MODE (color stack
        ;                        or foreground/background), added support
        ;                        for SCREEN statement.
        ; Revision: Aug/19/2014. Solved bug in bottom scroll, moved an
        ;                        extra unneeded line.
        ; Revision: Aug/26/2014. Integrated music player and NTSC/PAL
        ;                        detection.
        ; Revision: Oct/24/2014. Adjust in some comments.
        ; Revision: Nov/13/2014. Integrated Joseph Zbiciak's routines
        ;                        for printing numbers.
        ; Revision: Nov/17/2014. Redesigned MODE support to use a single
        ;                        variable.
        ; Revision: Nov/21/2014. Added Intellivoice support routines made
        ;                        by Joseph Zbiciak.
	; Revision: Dec/11/2014. Optimized keypad decode routines.
	; Revision: Jan/25/2015. Added marker for insertion of ON FRAME GOSUB
	; Revision: Feb/17/2015. Allows to deactivate music player (PLAY NONE)
	; Revision: Apr/21/2015. Accelerates common case of keypad not pressed.
	;                        Added ECS ROM disable code.
	; Revision: Apr/22/2015. Added Joseph Zbiciak accelerated multiplication
	;                        routines.
	; Revision: Jun/04/2015. Optimized play_music (per GroovyBee suggestion)
	; Revision: Jul/25/2015. Added infinite loop at start to avoid crashing
	;                        with empty programs. Solved bug where _color
	;                        didn't started with white.
	; Revision: Aug/20/2015. Moved ECS mapper disable code so nothing gets
	;                        after it (GroovyBee 42K sample code)
	; Revision: Aug/21/2015. Added Joseph Zbiciak routines for JLP Flash
	;                        handling.
	; Revision: Aug/31/2015. Added CPYBLK2 for SCREEN fifth argument.
	; Revision: Sep/01/2015. Defined labels Q1 and Q2 as alias.

	;
	; Avoids empty programs to crash
	; 
stuck:	B stuck

	;
	; Copy screen helper for SCREEN wide statement
	;

CPYBLK2:	PROC
	MOVR R0,R3		; Offset
	MOVR R5,R2
	PULR R0
	PULR R1
	PULR R5
	PULR R4
	PSHR R2
	SUBR R1,R3

@@1:    PSHR R3
	MOVR R1,R3              ; Init line copy
@@2:    MVI@ R4,R2              ; Copy line
        MVO@ R2,R5
        DECR R3
        BNE @@2
        PULR R3                 ; Add offset to start in next line
        ADDR R3,R4
	SUBR R1,R5
        ADDI #20,R5
        DECR R0                 ; Count lines
        BNE @@1

	RETURN
	ENDP

        ;
        ; Copy screen helper for SCREEN statement
        ;
CPYBLK: PROC
        BEGIN
        MOVR R3,R4
        MOVR R2,R5

@@1:    MOVR R1,R3              ; Init line copy
@@2:    MVI@ R4,R2              ; Copy line
        MVO@ R2,R5
        DECR R3
        BNE @@2
        MVII #20,R3             ; Add offset to start in next line
        SUBR R1,R3
        ADDR R3,R4
        ADDR R3,R5
        DECR R0                 ; Count lines
        BNE @@1
	RETURN
        ENDP

        ;
        ; Wait for interruption
        ;
_wait:  PROC

    IF DEFINED intybasic_keypad
        MVI $01FF,R0
        COMR R0
        ANDI #$FF,R0
        CMP _cnt1_p0,R0
        BNE @@2
        CMP _cnt1_p1,R0
        BNE @@2
	TSTR R0		; Accelerates common case of key not pressed
	MVII #_keypad_table+13,R4
	BEQ @@4
        MVII #_keypad_table,R4
    REPEAT 6
        CMP@ R4,R0
        BEQ @@4
	CMP@ R4,R0
        BEQ @@4
    ENDR
	INCR R4
@@4:    SUBI #_keypad_table+1,R4
	MVO R4,_cnt1_key

@@2:    MVI _cnt1_p1,R1
        MVO R1,_cnt1_p0
        MVO R0,_cnt1_p1

        MVI $01FE,R0
        COMR R0
        ANDI #$FF,R0
        CMP _cnt2_p0,R0
        BNE @@5
        CMP _cnt2_p1,R0
        BNE @@5
	TSTR R0		; Accelerates common case of key not pressed
	MVII #_keypad_table+13,R4
	BEQ @@7
        MVII #_keypad_table,R4
    REPEAT 6
        CMP@ R4,R0
        BEQ @@7
	CMP@ R4,R0
	BEQ @@7
    ENDR

	INCR R4
@@7:    SUBI #_keypad_table+1,R4
	MVO R4,_cnt2_key

@@5:    MVI _cnt2_p1,R1
        MVO R1,_cnt2_p0
        MVO R0,_cnt2_p1
    ENDI

        CLRR    R0
        MVO     R0,_int         ; Clears waiting flag
@@1:    CMP     _int,  R0       ; Waits for change
        BEQ     @@1
        JR      R5              ; Returns
        ENDP

        ;
        ; Keypad table
        ;
_keypad_table:          PROC
        DECLE $48,$81,$41,$21,$82,$42,$22,$84,$44,$24,$88,$28
        ENDP

_pal1_vector:    PROC
        MVII #_pal2_vector,R0
        MVO R0,ISRVEC
        SWAP R0
        MVO R0,ISRVEC+1
        MVII #3,R0
        MVO R0,_ntsc
        JR R5
        ENDP

_pal2_vector:    PROC
        MVII #_int_vector,R0     ; Point to "real" interruption handler
        MVO R0,ISRVEC
        SWAP R0
        MVO R0,ISRVEC+1
        MVII #4,R0
        MVO R0,_ntsc
	CLRR R0
	CLRR R4
	MVII #$18,R1
@@1:	MVO@ R0,R4
	DECR R1
	BNE @@1
        JR R5
        ENDP

        ;
        ; Interruption routine
        ;
_int_vector:     PROC
        BEGIN

        MVO     R0,     $20     ; Activates display

    IF DEFINED intybasic_stack
	CMPI #$308,R6
	BNC @@vs
	MVI $21,R0	; Activates Color Stack mode
	CLRR R0
	MVO R0,$28
	MVO R0,$29
	MVO R0,$2A
	MVO R0,$2B
	MVII #@@vs1,R4
	MVII #$200,R5
	MVII #20,R1
@@vs2:	MVI@ R4,R0
	MVO@ R0,R5
	DECR R1
	BNE @@vs2
	RETURN

	; Stack Overflow message
@@vs1:	DECLE 0,0,0,$33*8+7,$54*8+7,$41*8+7,$43*8+7,$4B*8+7,$00*8+7
	DECLE $4F*8+7,$56*8+7,$45*8+7,$52*8+7,$46*8+7,$4C*8+7
	DECLE $4F*8+7,$57*8+7,0,0,0

@@vs:
    ENDI
        MVII    #1,     R0
        MVO     R0,     _int    ; Indicates interrupt happened

        MVI _mode_select,R0
        TSTR R0
        BEQ @@vi0
        CLRR R1
        MVO R1,_mode_select
        DECR R0
        BEQ @@vi14
        MVO R0,$21  ; Activates Foreground/Background mode
        B @@vi15

@@vi14: MVI $21,R0  ; Activates Color Stack mode
        MVI _color,R0
        MVO R0,$28
        SWAP R0
        MVO R0,$29
        SLR R0,2
        SLR R0,2
        MVO R0,$2A
        SWAP R0
        MVO R0,$2B
@@vi15: MVII #7,R0
        MVO R0,_color           ; Default color for PRINT "string"
@@vi0:
        MVI _border_color,R0
        MVO     R0,     $2C     ; Border color
        MVI _border_mask,R0
        MVO     R0,     $32     ; Border mask
        ;
        ; Save collision registers for further use and clear them
        ;
        MVII #$18,R4
        MVII #_col0,R5
        MVI@ R4,R0
        MVO@ R0,R5  ; _col0
        MVI@ R4,R0
        MVO@ R0,R5  ; _col1
        MVI@ R4,R0
        MVO@ R0,R5  ; _col2
        MVI@ R4,R0
        MVO@ R0,R5  ; _col3
        MVI@ R4,R0
        MVO@ R0,R5  ; _col4
        MVI@ R4,R0
        MVO@ R0,R5  ; _col5
        MVI@ R4,R0
        MVO@ R0,R5  ; _col6
        MVI@ R4,R0
        MVO@ R0,R5  ; _col7
        MVII #$18,R5
        CLRR R0
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        
    IF DEFINED intybasic_scroll

        ;
        ; Scrolling things
        ;
        MVI _scroll_x,R0
        MVO R0,$30
        MVI _scroll_y,R0
        MVO R0,$31
    ENDI

        ;
        ; Updates sprites (MOBs)
        ;
        MVII #_mobs,R4
        MVII #$0,R5     ; X-coordinates
        MVII #8,R1
@@vi2:  MVI@ R4,R0
        MVO@ R0,R5
        MVI@ R4,R0
        MVO@ R0,R5
        MVI@ R4,R0
        MVO@ R0,R5
        DECR R1
        BNE @@vi2

    IF DEFINED intybasic_music
     	MVI _ntsc,R0
        TSTR R0         ; PAL?
        BEQ @@vo97      ; Yes, always emit sound
	MVI _music_frame,R0
	INCR R0
	CMPI #6,R0
	BNE @@vo14
	CLRR R0
@@vo14:	MVO R0,_music_frame
	BEQ @@vo15
@@vo97:	CALL _emit_sound
@@vo15:
    ENDI

        ;
        ; Detect GRAM definition
        ;
        MVI _gram_bitmap,R4
        TSTR R4
        BEQ @@vi1
        MVI _gram_target,R1
        SLL R1,2
        SLL R1,1
        ADDI #$3800,R1
        MOVR R1,R5
        MVI _gram_total,R0
@@vi3:
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        DECR R0
        BNE @@vi3
        MVO R0,_gram_bitmap
@@vi1:
        MVI _gram2_bitmap,R4
        TSTR R4
        BEQ @@vii1
        MVI _gram2_target,R1
        SLL R1,2
        SLL R1,1
        ADDI #$3800,R1
        MOVR R1,R5
        MVI _gram2_total,R0
@@vii3:
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        DECR R0
        BNE @@vii3
        MVO R0,_gram2_bitmap
@@vii1:

    IF DEFINED intybasic_scroll
        ;
        ; Frame scroll support
        ;
        MVI _scroll_d,R0
        TSTR R0
        BEQ @@vi4
        CLRR R1
        MVO R1,_scroll_d
        DECR R0     ; Left
        BEQ @@vi5
        DECR R0     ; Right
        BEQ @@vi6
        DECR R0     ; Top
        BEQ @@vi7
        DECR R0     ; Bottom
        BEQ @@vi8
        B @@vi4

@@vi5:  MVII #$0200,R4
        MOVR R4,R5
        INCR R5
        MVII #12,R1
@@vi12: MVI@ R4,R2
        MVI@ R4,R3
        REPEAT 8
        MVO@ R2,R5
        MVI@ R4,R2
        MVO@ R3,R5
        MVI@ R4,R3
        ENDR
        MVO@ R2,R5
        MVI@ R4,R2
        MVO@ R3,R5
        MVO@ R2,R5
        INCR R4
        INCR R5
        DECR R1
        BNE @@vi12
        B @@vi4

@@vi6:  MVII #$0201,R4
        MVII #$0200,R5
        MVII #12,R1
@@vi11:
        REPEAT 19
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        INCR R4
        INCR R5
        DECR R1
        BNE @@vi11
        B @@vi4
    
        ;
        ; Complex routine to be ahead of STIC display
        ; Moves first the top 6 lines, saves intermediate line
        ; Then moves the bottom 6 lines and restores intermediate line
        ;
@@vi7:  MVII #$0264,R4
        MVII #5,R1
        MVII #_scroll_buffer,R5
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        SUBI #40,R4
        MOVR R4,R5
        ADDI #20,R5
@@vi10:
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        SUBI #40,R4
        SUBI #40,R5
        DECR R1
        BNE @@vi10
        MVII #$02C8,R4
        MVII #$02DC,R5
        MVII #5,R1
@@vi13:
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        SUBI #40,R4
        SUBI #40,R5
        DECR R1
        BNE @@vi13
        MVII #_scroll_buffer,R4
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        B @@vi4

@@vi8:  MVII #$0214,R4
        MVII #$0200,R5
        MVII #$DC/4,R1
@@vi9:  
        REPEAT 4
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        DECR R1
        BNE @@vi9
        B @@vi4

@@vi4:
    ENDI

    IF DEFINED intybasic_voice
        ;
        ; Intellivoice support
        ;
        CALL IV_ISR
    ENDI

        ;
        ; Random number generator
        ;
	CALL _next_random

    IF DEFINED intybasic_music
	; Generate sound for next frame
       	MVI _ntsc,R0
        TSTR R0         ; PAL?
        BEQ @@vo98      ; Yes, always generate sound
	MVI _music_frame,R0
	TSTR R0
	BEQ @@vo16
@@vo98: CALL _generate_music
@@vo16:
    ENDI

        ; Increase frame number
        MVI _frame,R0
        INCR R0
        MVO R0,_frame

	; This mark is for ON FRAME GOSUB support

        RETURN
        ENDP

	;
	; Generates the next random number
	;
_next_random:	PROC

MACRO _ROR
	RRC R0,1
	MOVR R0,R2
	SLR R2,2
	SLR R2,2
	ANDI #$0800,R2
	SLR R2,2
	SLR R2,2
	ANDI #$007F,R0
	XORR R2,R0
ENDM
        MVI _rand,R0
        SETC
        _ROR
        XOR _frame,R0
        _ROR
        XOR _rand,R0
        _ROR
        XORI #9,R0
        MVO R0,_rand
	JR R5
	ENDP

    IF DEFINED intybasic_music

        ;
        ; Music player, comes from my game Princess Quest for Intellivision
        ; so it's a practical tracker used in a real game ;) and with enough
        ; features.
        ;

        ; NTSC frequency for notes (based on 3.579545 mhz)
ntsc_note_table:    PROC
        ; Silence - 0
        DECLE 0
        ; Octave 2 - 1
        DECLE 1721,1621,1532,1434,1364,1286,1216,1141,1076,1017,956,909
        ; Octave 3 - 13
        DECLE 854,805,761,717,678,639,605,571,538,508,480,453
        ; Octave 4 - 25
        DECLE 427,404,380,360,339,321,302,285,270,254,240,226
        ; Octave 5 - 37
        DECLE 214,202,191,180,170,160,151,143,135,127,120,113
        ; Octave 6 - 49
        DECLE 107,101,95,90,85,80,76,71,67,64,60,57
        ; Octave 7 - 61
        ; Space for two notes more
	ENDP

        ; PAL frequency for notes (based on 4 mhz)
pal_note_table:    PROC
        ; Silence - 0
        DECLE 0
        ; Octava 2 - 1
        DECLE 1923,1812,1712,1603,1524,1437,1359,1276,1202,1136,1068,1016
        ; Octava 3 - 13
        DECLE 954,899,850,801,758,714,676,638,601,568,536,506
        ; Octava 4 - 25
        DECLE 477,451,425,402,379,358,338,319,301,284,268,253
        ; Octava 5 - 37
        DECLE 239,226,213,201,190,179,169,159,150,142,134,127
        ; Octava 6 - 49
        DECLE 120,113,106,100,95,89,84,80,75,71,67,63
        ; Octava 7 - 61
        ; Space for two notes more
	ENDP
    ENDI

        ;
        ; Music tracker init
        ;
_init_music:	PROC
    IF DEFINED intybasic_music
        MVI _ntsc,R0
        CMPI #1,R0
        MVII #ntsc_note_table,R0
        BEQ @@0
        MVII #pal_note_table,R0
@@0:    MVO R0,_music_table
        MVII #$38,R0	; $B8 blocks controllers o.O!
	MVO R0,_music_mix
        CLRR R0
    ELSE
	JR R5
    ENDI
	ENDP

    IF DEFINED intybasic_music
        ;
        ; Start music
        ; R0 = Pointer to music
        ;
_play_music:	PROC
	MOVR R0,R2
        MVII #1,R0
	MOVR R0,R3
	TSTR R2
	BEQ @@1
	MVI@ R2,R3
	INCR R2
@@1:	MVO R2,_music_start
	MVO R2,_music_p
	MVO R3,_music_t
	MVO R0,_music_tc
        JR R5

	ENDP

        ;
        ; Generate music
        ;
_generate_music:	PROC
	BEGIN
	MVI _music_mix,R0
	ANDI #$C0,R0
	XORI #$38,R0
	MVO R0,_music_mix
	CLRR R1			; Turn off volume for the three sound channels
	MVO R1,_music_vol1
	MVO R1,_music_vol2
	NOP
	MVO R1,_music_vol3
	MVI _music_tc,R3
	DECR R3
	MVO R3,_music_tc
	BNE @@6
	; R3 is zero from here up to @@6
	MVI _music_p,R4
@@15:	TSTR R4		; Silence?
	BEQ @@000	; Keep quiet
	MVI@ R4,R0
	MVI@ R4,R1
	MVI _music_t,R2
        CMPI #$FE,R0	; The end?
	BEQ @@000       ; Keep quiet
	CMPI #$FD,R0	; Repeat?
	BNE @@00
	MVI _music_start,R4
	B @@15

@@000:  MVII #1,R0
        MVO R0,_music_tc
        B @@0
        
@@00: 	MVO R2,_music_tc    ; Restart note time
     	MVO R4,_music_p
     	
	MOVR R0,R2
	ANDI #$FF,R2
	CMPI #$3F,R2	; Sustain note?
	BEQ @@1
	MOVR R2,R4
	ANDI #$3F,R4
	MVO R4,_music_n1	; Note
	MVO R3,_music_s1	; Waveform
	ANDI #$C0,R2
	MVO R2,_music_i1	; Instrument
	
@@1:	MOVR R0,R2
	SWAP R2
	ANDI #$FF,R2
	CMPI #$3F,R2	; Sustain note?
	BEQ @@2
	MOVR R2,R4
	ANDI #$3F,R4
	MVO R4,_music_n2	; Note
	MVO R3,_music_s2	; Waveform
	ANDI #$C0,R2
	MVO R2,_music_i2	; Instrument
	
@@2:	MOVR R1,R2
	ANDI #$FF,R2
	CMPI #$3F,R2	; Sustain note?
	BEQ @@3
	MOVR R2,R4
	ANDI #$3F,R4
	MVO R4,_music_n3	; Note
	MVO R3,_music_s3	; Waveform
	ANDI #$C0,R2
	MVO R2,_music_i3	; Instrument
	
@@3:	MOVR R1,R2
	SWAP R2
	MVO R2,_music_n4
	MVO R3,_music_s4
	
        ;
        ; Construct main voice
        ;
@@6:	MVI _music_n1,R3	; Read note
	TSTR R3		; There is note?
	BEQ @@7		; No, jump
	MVI _music_s1,R1
	MVI _music_i1,R2
	MOVR R1,R0
	CALL _note2freq
	MVO R3,_music_freq10	; Note in voice A
	SWAP R3
	MVO R3,_music_freq11
	MVO R1,_music_vol1
        ; Increase time for instrument waveform
	INCR R0
	CMPI #$18,R0
	BNE @@20
	SUBI #$08,R0
@@20:	MVO R0,_music_s1

@@7:	MVI _music_n2,R3	; Read note
	TSTR R3		; There is note?
	BEQ @@8		; No, jump
	MVI _music_s2,R1
	MVI _music_i2,R2
	MOVR R1,R0
	CALL _note2freq
	MVO R3,_music_freq20	; Note in voice B
	SWAP R3
	MVO R3,_music_freq21
	MVO R1,_music_vol2
        ; Increase time for instrument waveform
	INCR R0
	CMPI #$18,R0
	BNE @@21
	SUBI #$08,R0
@@21:	MVO R0,_music_s2

@@8:	MVI _music_n3,R3	; Read note
	TSTR R3		; There is note?
	BEQ @@9		; No, jump
	MVI _music_s3,R1
	MVI _music_i3,R2
	MOVR R1,R0
	CALL _note2freq
	MVO R3,_music_freq30	; Note in voice C
	SWAP R3
	MVO R3,_music_freq31
	MVO R1,_music_vol3
        ; Increase time for instrument waveform
	INCR R0
	CMPI #$18,R0
	BNE @@22
	SUBI #$08,R0
@@22:	MVO R0,_music_s3

@@9:	MVI _music_n4,R0	; Read drum
	DECR R0		; There is drum?
	BMI @@4		; No, jump
	MVI _music_s4,R1
	       		; 1 - Strong
	BNE @@5
	CMPI #3,R1
	BGE @@12
@@10:	MVII #5,R0
	MVO R0,_music_noise
	CALL _activate_drum
	B @@12

@@5:	DECR R0		;2 - Short
	BNE @@11
	TSTR R1
	BNE @@12
	MVII #8,R0
	MVO R0,_music_noise
	CALL _activate_drum
	B @@12

@@11:	;DECR R0	; 3 - Rolling
	;BNE @@12
	CMPI #2,R1
	BLT @@10
	MVI _music_t,R0
	SLR R0,1
	CMPR R0,R1
	BLT @@12
        ADDI #2,R0
	CMPR R0,R1
	BLT @@10
        ; Increase time for drum waveform
@@12:   INCR R1
	MVO R1,_music_s4
@@4:
@@0:	RETURN
	ENDP

        ;
	; Translates note number to frequency
        ; R3 = Note
        ; R1 = Position in waveform for instrument
        ; R2 = Instrument
        ;
_note2freq:	PROC
        ADD _music_table,R3
	MVI@ R3,R3
        SWAP R2
	BEQ _piano_instrument
	RLC R2,1
	BNC _clarinet_instrument
	BPL _flute_instrument
;	BMI _bass_instrument
	ENDP

        ;
        ; Generates a bass
        ;
_bass_instrument:	PROC
	SLL R3,2	; Lower 2 octaves
	ADDI #_bass_volume,R1
	MVI@ R1,R1	; Bass effect
	JR R5
	ENDP

_bass_volume:	PROC
        DECLE 12,13,14,14,13,12,12,12
        DECLE 11,11,12,12,11,11,12,12
	DECLE 11,11,12,12,11,11,12,12
	ENDP

        ;
        ; Generates a piano
        ; R3 = Frequency
        ; R1 = Waveform position
        ;
        ; Output:
        ; R3 = Frequency.
        ; R1 = Volume.
        ;
_piano_instrument:	PROC
	ADDI #_piano_volume,R1
	MVI@ R1,R1
	JR R5
	ENDP

_piano_volume:	PROC
        DECLE 14,13,13,12,12,11,11,10
        DECLE 10,9,9,8,8,7,7,6
        DECLE 6,6,7,7,6,6,5,5
	ENDP

        ;
        ; Generate a clarinet
        ; R3 = Frequency
        ; R1 = Waveform position
        ;
        ; Output:
        ; R3 = Frequency
        ; R1 = Volume
        ;
_clarinet_instrument:	PROC
	ADDI #_clarinet_vibrato,R1
	ADD@ R1,R3
	CLRC
	RRC R3,1	; Duplicates frequency
	ADCR R3
        ADDI #_clarinet_volume-_clarinet_vibrato,R1
	MVI@ R1,R1
	JR R5
	ENDP

_clarinet_vibrato:	PROC
        DECLE 0,0,0,0
        DECLE -2,-4,-2,0
        DECLE 2,4,2,0
        DECLE -2,-4,-2,0
        DECLE 2,4,2,0
        DECLE -2,-4,-2,0
	ENDP

_clarinet_volume:	PROC
        DECLE 13,14,14,13,13,12,12,12
        DECLE 11,11,11,11,12,12,12,12
        DECLE 11,11,11,11,12,12,12,12
	ENDP

        ;
        ; Generates a flute
        ; R3 = Frequency
        ; R1 = Waveform position
        ;
        ; Output:
        ; R3 = Frequency
        ; R1 = Volume
        ;
_flute_instrument:	PROC
	ADDI #_flute_vibrato,R1
	ADD@ R1,R3
	ADDI #_flute_volume-_flute_vibrato,R1
	MVI@ R1,R1
	JR R5
	ENDP

_flute_vibrato:	PROC
        DECLE 0,0,0,0
        DECLE 0,1,2,1
        DECLE 0,1,2,1
        DECLE 0,1,2,1
        DECLE 0,1,2,1
        DECLE 0,1,2,1
	ENDP
                 
_flute_volume:	PROC
        DECLE 10,12,13,13,12,12,12,12
        DECLE 11,11,11,11,10,10,10,10
        DECLE 11,11,11,11,10,10,10,10
	ENDP

        ;
        ; Emits sound
        ;
_emit_sound:	PROC
        MOVR R5,R1
	MVI _music_mode,R2
	TSTR R2
	BEQ @@2
	MVII #_music_freq10,R4
	MVII #$01F0,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	CMPI #1,R2
	BEQ @@1
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
        JR R1

@@1:	INCR R4
	ADDI #2,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R4
	ADDI #2,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
@@2:    JR R1
	ENDP

        ;
        ; Activates drum
        ;
_activate_drum:	PROC
	MVI _music_vol1,R0
	TSTR R0
	BNE @@1
        MVII #11,R0
	MVO R0,_music_vol1
	MVI _music_mix,R0
	ANDI #$F6,R0
	XORI #$01,R0
	MVO R0,_music_mix
	JR R5

@@1:    MVI _music_vol2,R0
	TSTR R0
	BNE @@2
        MVII #11,R0
	MVO R0,_music_vol2
	MVI _music_mix,R0
	ANDI #$ED,R0
	XORI #$02,R0
	MVO R0,_music_mix
	JR R5

@@2:    MVI _music_mode,R0
        CMPI #2,R0
        BNE @@3
        MVI _music_vol3,R0
	TSTR R0
	BNE @@3
        MVII #11,R0
	MVO R0,_music_vol3
	MVI _music_mix,R0
	ANDI #$DB,R0
	XORI #$04,R0
	MVO R0,_music_mix
	JR R5

@@3:    MVI _music_mix,R0
        ANDI #$EF,R0
	MVO R0,_music_mix
	JR R5

	ENDP

    ENDI
    
    IF DEFINED intybasic_numbers

	;
	; Following code from as1600 libraries, prnum16.asm
        ; Public domain by Joseph Zbiciak
	;

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- Joseph Zbiciak, 2008                                     *;
;* ======================================================================== *;

;; ======================================================================== ;;
;;  _PW10                                                                   ;;
;;      Lookup table holding the first 5 powers of 10 (1 thru 10000) as     ;;
;;      16-bit numbers.                                                     ;;
;; ======================================================================== ;;
_PW10   PROC    ; 0 thru 10000
        DECLE   10000, 1000, 100, 10, 1, 0
        ENDP

;; ======================================================================== ;;
;;  PRNUM16.l     -- Print an unsigned 16-bit number left-justified.        ;;
;;  PRNUM16.b     -- Print an unsigned 16-bit number with leading blanks.   ;;
;;  PRNUM16.z     -- Print an unsigned 16-bit number with leading zeros.    ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak  <im14u2c AT globalcrossing DOT net>                 ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      30-Mar-2003 Initial complete revision                               ;;
;;                                                                          ;;
;;  INPUTS for all variants                                                 ;;
;;      R0  Number to print.                                                ;;
;;      R2  Width of field.  Ignored by PRNUM16.l.                          ;;
;;      R3  Format word, added to digits to set the color.                  ;;
;;          Note:  Bit 15 MUST be cleared when building with PRNUM32.       ;;
;;      R4  Pointer to location on screen to print number                   ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0  Zeroed                                                          ;;
;;      R1  Unmodified                                                      ;;
;;      R2  Unmodified                                                      ;;
;;      R3  Unmodified                                                      ;;
;;      R4  Points to first character after field.                          ;;
;;                                                                          ;;
;;  DESCRIPTION                                                             ;;
;;      These routines print unsigned 16-bit numbers in a field up to 5     ;;
;;      positions wide.  The number is printed either in left-justified     ;;
;;      or right-justified format.  Right-justified numbers are padded      ;;
;;      with leading blanks or leading zeros.  Left-justified numbers       ;;
;;      are not padded on the right.                                        ;;
;;                                                                          ;;
;;      This code handles fields wider than 5 characters, padding with      ;;
;;      zeros or blanks as necessary.                                       ;;
;;                                                                          ;;
;;              Routine      Value(hex)     Field        Output             ;;
;;              ----------   ----------   ----------   ----------           ;;
;;              PRNUM16.l      $0045         n/a        "69"                ;;
;;              PRNUM16.b      $0045          4         "  69"              ;;
;;              PRNUM16.b      $0045          6         "    69"            ;;
;;              PRNUM16.z      $0045          4         "0069"              ;;
;;              PRNUM16.z      $0045          6         "000069"            ;;
;;                                                                          ;;
;;  TECHNIQUES                                                              ;;
;;      This routine uses repeated subtraction to divide the number         ;;
;;      to display by various powers of 10.  This is cheaper than a         ;;
;;      full divide, at least when the input number is large.  It's         ;;
;;      also easier to get right.  :-)                                      ;;
;;                                                                          ;;
;;      The printing routine first pads out fields wider than 5 spaces      ;;
;;      with zeros or blanks as requested.  It then scans the power-of-10   ;;
;;      table looking for the first power of 10 that is <= the number to    ;;
;;      display.  While scanning for this power of 10, it outputs leading   ;;
;;      blanks or zeros, if requested.  This eliminates "leading digit"     ;;
;;      logic from the main digit loop.                                     ;;
;;                                                                          ;;
;;      Once in the main digit loop, we discover the value of each digit    ;;
;;      by repeated subtraction.  We build up our digit value while         ;;
;;      subtracting the power-of-10 repeatedly.  We iterate until we go     ;;
;;      a step too far, and then we add back on power-of-10 to restore      ;;
;;      the remainder.                                                      ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      The left-justified variant ignores field width.                     ;;
;;                                                                          ;;
;;      The code is fully reentrant.                                        ;;
;;                                                                          ;;
;;      This code does not handle numbers which are too large to be         ;;
;;      displayed in the provided field.  If the number is too large,       ;;
;;      non-digit characters will be displayed in the initial digit         ;;
;;      position.  Also, the run time of this routine may get excessively   ;;
;;      large, depending on the magnitude of the overflow.                  ;;
;;                                                                          ;;
;;      When using with PRNUM32, one must either include PRNUM32 before     ;;
;;      this function, or define the symbol _WITH_PRNUM32.  PRNUM32         ;;
;;      needs a tiny bit of support from PRNUM16 to handle numbers in       ;;
;;      the range 65536...99999 correctly.                                  ;;
;;                                                                          ;;
;;  CODESIZE                                                                ;;
;;      73 words, including power-of-10 table                               ;;
;;      80 words, if compiled with PRNUM32.                                 ;;
;;                                                                          ;;
;;      To save code size, you can define the following symbols to omit     ;;
;;      some variants:                                                      ;;
;;                                                                          ;;
;;          _NO_PRNUM16.l:   Disables PRNUM16.l.  Saves 10 words            ;;
;;          _NO_PRNUM16.b:   Disables PRNUM16.b.  Saves 3 words.            ;;
;;                                                                          ;;
;;      Defining both symbols saves 17 words total, because it omits        ;;
;;      some code shared by both routines.                                  ;;
;;                                                                          ;;
;;  STACK USAGE                                                             ;;
;;      This function uses up to 4 words of stack space.                    ;;
;; ======================================================================== ;;

PRNUM16 PROC

    
        ;; ---------------------------------------------------------------- ;;
        ;;  PRNUM16.l:  Print unsigned, left-justified.                     ;;
        ;; ---------------------------------------------------------------- ;;
@@l:    PSHR    R5              ; save return address
@@l1:   MVII    #$1,    R5      ; set R5 to 1 to counteract screen ptr update
                                ; in the 'find initial power of 10' loop
        PSHR    R2
        MVII    #5,     R2      ; force effective field width to 5.
        B       @@z2

        ;; ---------------------------------------------------------------- ;;
        ;;  PRNUM16.b:  Print unsigned with leading blanks.                 ;;
        ;; ---------------------------------------------------------------- ;;
@@b:    PSHR    R5
@@b1:   CLRR    R5              ; let the blank loop do its thing
        INCR    PC              ; skip the PSHR R5

        ;; ---------------------------------------------------------------- ;;
        ;;  PRNUM16.z:  Print unsigned with leading zeros.                  ;;
        ;; ---------------------------------------------------------------- ;;
@@z:    PSHR    R5
@@z1:   PSHR    R2
@@z2:   PSHR    R1

        ;; ---------------------------------------------------------------- ;;
        ;;  Find the initial power of 10 to use for display.                ;;
        ;;  Note:  For fields wider than 5, fill the extra spots above 5    ;;
        ;;  with blanks or zeros as needed.                                 ;;
        ;; ---------------------------------------------------------------- ;;
        MVII    #_PW10+5,R1     ; Point to end of power-of-10 table
        SUBR    R2,     R1      ; Subtract the field width to get right power
        PSHR    R3              ; save format word

        CMPI    #2,     R5      ; are we leading with zeros?
        BNC     @@lblnk         ; no:  then do the loop w/ blanks

        CLRR    R5              ; force R5==0
        ADDI    #$80,   R3      ; yes: do the loop with zeros
        B       @@lblnk
    

@@llp   MVO@    R3,     R4      ; print a blank/zero

        SUBR    R5,     R4      ; rewind pointer if needed.

        INCR    R1              ; get next power of 10
@@lblnk DECR    R2              ; decrement available digits
        BEQ     @@ldone
        CMPI    #5,     R2      ; field too wide?
        BGE     @@llp           ; just force blanks/zeros 'till we're narrower.
        CMP@    R1,     R0      ; Is this power of 10 too big?
        BNC     @@llp           ; Yes:  Put a blank and go to next

@@ldone PULR    R3              ; restore format word

        ;; ---------------------------------------------------------------- ;;
        ;;  The digit loop prints at least one digit.  It discovers digits  ;;
        ;;  by repeated subtraction.                                        ;;
        ;; ---------------------------------------------------------------- ;;
@@digit TSTR    R0              ; If the number is zero, print zero and leave
        BNEQ    @@dig1          ; no: print the number

        MOVR    R3,     R5      ;\    
        ADDI    #$80,   R5      ; |-- print a 0 there.
        MVO@    R5,     R4      ;/    
        B       @@done

@@dig1:
    
@@nxdig MOVR    R3,     R5      ; save display format word
@@cont: ADDI    #$80-8, R5      ; start our digit as one just before '0'
@@spcl:
 
        ;; ---------------------------------------------------------------- ;;
        ;;  Divide by repeated subtraction.  This divide is constructed     ;;
        ;;  to go "one step too far" and then back up.                      ;;
        ;; ---------------------------------------------------------------- ;;
@@div:  ADDI    #8,     R5      ; increment our digit
        SUB@    R1,     R0      ; subtract power of 10
        BC      @@div           ; loop until we go too far
        ADD@    R1,     R0      ; add back the extra power of 10.

        MVO@    R5,     R4      ; display the digit.

        INCR    R1              ; point to next power of 10
        DECR    R2              ; any room left in field?
        BPL     @@nxdig         ; keep going until R2 < 0.

@@done: PULR    R1              ; restore R1
        PULR    R2              ; restore R2
        PULR    PC              ; return

        ENDP
        
    ENDI

    IF DEFINED intybasic_voice
;;==========================================================================;;
;;  SP0256-AL2 Allophones                                                   ;;
;;                                                                          ;;
;;  This file contains the allophone set that was obtained from an          ;;
;;  SP0256-AL2.  It is being provided for your convenience.                 ;;
;;                                                                          ;;
;;  The directory "al2" contains a series of assembly files, each one       ;;
;;  containing a single allophone.  This series of files may be useful in   ;;
;;  situations where space is at a premium.                                 ;;
;;                                                                          ;;
;;  Consult the Archer SP0256-AL2 documentation (under doc/programming)     ;;
;;  for more information about SP0256-AL2's allophone library.              ;;
;;                                                                          ;;
;; ------------------------------------------------------------------------ ;;
;;                                                                          ;;
;;  Copyright information:                                                  ;;
;;                                                                          ;;
;;  The allophone data below was extracted from the SP0256-AL2 ROM image.   ;;
;;  The SP0256-AL2 allophones are NOT in the public domain, nor are they    ;;
;;  placed under the GNU General Public License.  This program is           ;;
;;  distributed in the hope that it will be useful, but WITHOUT ANY         ;;
;;  WARRANTY; without even the implied warranty of MERCHANTABILITY or       ;;
;;  FITNESS FOR A PARTICULAR PURPOSE.                                       ;;
;;                                                                          ;;
;;  Microchip, Inc. retains the copyright to the data and algorithms        ;;
;;  contained in the SP0256-AL2.  This speech data is distributed with      ;;
;;  explicit permission from Microchip, Inc.  All such redistributions      ;;
;;  must retain this notice of copyright.                                   ;;
;;                                                                          ;;
;;  No copyright claims are made on this data by the author(s) of SDK1600.  ;;
;;  Please see http://spatula-city.org/~im14u2c/sp0256-al2/ for details.    ;;
;;                                                                          ;;
;;==========================================================================;;

;; ------------------------------------------------------------------------ ;;
_AA:
    DECLE   _AA.end - _AA - 1
    DECLE   $0318, $014C, $016F, $02CE, $03AF, $015F, $01B1, $008E
    DECLE   $0088, $0392, $01EA, $024B, $03AA, $039B, $000F, $0000
_AA.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_AE1:
    DECLE   _AE1.end - _AE1 - 1
    DECLE   $0118, $038E, $016E, $01FC, $0149, $0043, $026F, $036E
    DECLE   $01CC, $0005, $0000
_AE1.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_AO:
    DECLE   _AO.end - _AO - 1
    DECLE   $0018, $010E, $016F, $0225, $00C6, $02C4, $030F, $0160
    DECLE   $024B, $0005, $0000
_AO.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_AR:
    DECLE   _AR.end - _AR - 1
    DECLE   $0218, $010C, $016E, $001E, $000B, $0091, $032F, $00DE
    DECLE   $018B, $0095, $0003, $0238, $0027, $01E0, $03E8, $0090
    DECLE   $0003, $01C7, $0020, $03DE, $0100, $0190, $01CA, $02AB
    DECLE   $00B7, $004A, $0386, $0100, $0144, $02B6, $0024, $0320
    DECLE   $0011, $0041, $01DF, $0316, $014C, $016E, $001E, $00C4
    DECLE   $02B2, $031E, $0264, $02AA, $019D, $01BE, $000B, $00F0
    DECLE   $006A, $01CE, $00D6, $015B, $03B5, $03E4, $0000, $0380
    DECLE   $0007, $0312, $03E8, $030C, $016D, $02EE, $0085, $03C2
    DECLE   $03EC, $0283, $024A, $0005, $0000
_AR.end:  ; 69 decles
;; ------------------------------------------------------------------------ ;;
_AW:
    DECLE   _AW.end - _AW - 1
    DECLE   $0010, $01CE, $016E, $02BE, $0375, $034F, $0220, $0290
    DECLE   $008A, $026D, $013F, $01D5, $0316, $029F, $02E2, $018A
    DECLE   $0170, $0035, $00BD, $0000, $0000
_AW.end:  ; 21 decles
;; ------------------------------------------------------------------------ ;;
_AX:
    DECLE   _AX.end - _AX - 1
    DECLE   $0218, $02CD, $016F, $02F5, $0386, $00C2, $00CD, $0094
    DECLE   $010C, $0005, $0000
_AX.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_AY:
    DECLE   _AY.end - _AY - 1
    DECLE   $0110, $038C, $016E, $03B7, $03B3, $02AF, $0221, $009E
    DECLE   $01AA, $01B3, $00BF, $02E7, $025B, $0354, $00DA, $017F
    DECLE   $018A, $03F3, $00AF, $02D5, $0356, $027F, $017A, $01FB
    DECLE   $011E, $01B9, $03E5, $029F, $025A, $0076, $0148, $0124
    DECLE   $003D, $0000
_AY.end:  ; 34 decles
;; ------------------------------------------------------------------------ ;;
_BB1:
    DECLE   _BB1.end - _BB1 - 1
    DECLE   $0318, $004C, $016C, $00FB, $00C7, $0144, $002E, $030C
    DECLE   $010E, $018C, $01DC, $00AB, $00C9, $0268, $01F7, $021D
    DECLE   $01B3, $0098, $0000
_BB1.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_BB2:
    DECLE   _BB2.end - _BB2 - 1
    DECLE   $00F4, $0046, $0062, $0200, $0221, $03E4, $0087, $016F
    DECLE   $02A6, $02B7, $0212, $0326, $0368, $01BF, $0338, $0196
    DECLE   $0002
_BB2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_CH:
    DECLE   _CH.end - _CH - 1
    DECLE   $00F5, $0146, $0052, $0000, $032A, $0049, $0032, $02F2
    DECLE   $02A5, $0000, $026D, $0119, $0124, $00F6, $0000
_CH.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_DD1:
    DECLE   _DD1.end - _DD1 - 1
    DECLE   $0318, $034C, $016E, $0397, $01B9, $0020, $02B1, $008E
    DECLE   $0349, $0291, $01D8, $0072, $0000
_DD1.end:  ; 13 decles
;; ------------------------------------------------------------------------ ;;
_DD2:
    DECLE   _DD2.end - _DD2 - 1
    DECLE   $00F4, $00C6, $00F2, $0000, $0129, $00A6, $0246, $01F3
    DECLE   $02C6, $02B7, $028E, $0064, $0362, $01CF, $0379, $01D5
    DECLE   $0002
_DD2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_DH1:
    DECLE   _DH1.end - _DH1 - 1
    DECLE   $0018, $034F, $016D, $030B, $0306, $0363, $017E, $006A
    DECLE   $0164, $019E, $01DA, $00CB, $00E8, $027A, $03E8, $01D7
    DECLE   $0173, $00A1, $0000
_DH1.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_DH2:
    DECLE   _DH2.end - _DH2 - 1
    DECLE   $0119, $034C, $016D, $030B, $0306, $0363, $017E, $006A
    DECLE   $0164, $019E, $01DA, $00CB, $00E8, $027A, $03E8, $01D7
    DECLE   $0173, $00A1, $0000
_DH2.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_EH:
    DECLE   _EH.end - _EH - 1
    DECLE   $0218, $02CD, $016F, $0105, $014B, $0224, $02CF, $0274
    DECLE   $014C, $0005, $0000
_EH.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_EL:
    DECLE   _EL.end - _EL - 1
    DECLE   $0118, $038D, $016E, $011C, $008B, $03D2, $030F, $0262
    DECLE   $006C, $019D, $01CC, $022B, $0170, $0078, $03FE, $0018
    DECLE   $0183, $03A3, $010D, $016E, $012E, $00C6, $00C3, $0300
    DECLE   $0060, $000D, $0005, $0000
_EL.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_ER1:
    DECLE   _ER1.end - _ER1 - 1
    DECLE   $0118, $034C, $016E, $001C, $0089, $01C3, $034E, $03E6
    DECLE   $00AB, $0095, $0001, $0000, $03FC, $0381, $0000, $0188
    DECLE   $01DA, $00CB, $00E7, $0048, $03A6, $0244, $016C, $01A8
    DECLE   $03E4, $0000, $0002, $0001, $00FC, $01DA, $02E4, $0000
    DECLE   $0002, $0008, $0200, $0217, $0164, $0000, $000E, $0038
    DECLE   $0014, $01EA, $0264, $0000, $0002, $0048, $01EC, $02F1
    DECLE   $03CC, $016D, $021E, $0048, $00C2, $034E, $036A, $000D
    DECLE   $008D, $000B, $0200, $0047, $0022, $03A8, $0000, $0000
_ER1.end:  ; 64 decles
;; ------------------------------------------------------------------------ ;;
_ER2:
    DECLE   _ER2.end - _ER2 - 1
    DECLE   $0218, $034C, $016E, $001C, $0089, $01C3, $034E, $03E6
    DECLE   $00AB, $0095, $0001, $0000, $03FC, $0381, $0000, $0190
    DECLE   $01D8, $00CB, $00E7, $0058, $01A6, $0244, $0164, $02A9
    DECLE   $0024, $0000, $0000, $0007, $0201, $02F8, $02E4, $0000
    DECLE   $0002, $0001, $00FC, $02DA, $0024, $0000, $0002, $0008
    DECLE   $0200, $0217, $0024, $0000, $000E, $0038, $0014, $03EA
    DECLE   $03A4, $0000, $0002, $0048, $01EC, $03F1, $038C, $016D
    DECLE   $021E, $0048, $00C2, $034E, $036A, $000D, $009D, $0003
    DECLE   $0200, $0047, $0022, $03A8, $0000, $0000
_ER2.end:  ; 70 decles
;; ------------------------------------------------------------------------ ;;
_EY:
    DECLE   _EY.end - _EY - 1
    DECLE   $0310, $038C, $016E, $02A7, $00BB, $0160, $0290, $0094
    DECLE   $01CA, $03A9, $00C1, $02D7, $015B, $01D4, $03CE, $02FF
    DECLE   $00EA, $03E7, $0041, $0277, $025B, $0355, $03C9, $0103
    DECLE   $02EA, $03E4, $003F, $0000
_EY.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_FF:
    DECLE   _FF.end - _FF - 1
    DECLE   $0119, $03C8, $0000, $00A7, $0094, $0138, $01C6, $0000
_FF.end:  ; 8 decles
;; ------------------------------------------------------------------------ ;;
_GG1:
    DECLE   _GG1.end - _GG1 - 1
    DECLE   $00F4, $00C6, $00C2, $0200, $0015, $03FE, $0283, $01FD
    DECLE   $01E6, $00B7, $030A, $0364, $0331, $017F, $033D, $0215
    DECLE   $0002
_GG1.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_GG2:
    DECLE   _GG2.end - _GG2 - 1
    DECLE   $00F4, $0106, $0072, $0300, $0021, $0308, $0039, $0173
    DECLE   $00C6, $00B7, $037E, $03A3, $0319, $0177, $0036, $0217
    DECLE   $0002
_GG2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_GG3:
    DECLE   _GG3.end - _GG3 - 1
    DECLE   $00F8, $0146, $00F2, $0100, $0132, $03A8, $0055, $01F5
    DECLE   $00A6, $02B7, $0291, $0326, $0368, $0167, $023A, $01C6
    DECLE   $0002
_GG3.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_HH1:
    DECLE   _HH1.end - _HH1 - 1
    DECLE   $0218, $01C9, $0000, $0095, $0127, $0060, $01D6, $0213
    DECLE   $0002, $01AE, $033E, $01A0, $03C4, $0122, $0001, $0218
    DECLE   $01E4, $03FD, $0019, $0000
_HH1.end:  ; 20 decles
;; ------------------------------------------------------------------------ ;;
_HH2:
    DECLE   _HH2.end - _HH2 - 1
    DECLE   $0218, $00CB, $0000, $0086, $000F, $0240, $0182, $031A
    DECLE   $02DB, $0008, $0293, $0067, $00BD, $01E0, $0092, $000C
    DECLE   $0000
_HH2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_IH:
    DECLE   _IH.end - _IH - 1
    DECLE   $0118, $02CD, $016F, $0205, $0144, $02C3, $00FE, $031A
    DECLE   $000D, $0005, $0000
_IH.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_IY:
    DECLE   _IY.end - _IY - 1
    DECLE   $0318, $02CC, $016F, $0008, $030B, $01C3, $0330, $0178
    DECLE   $002B, $019D, $01F6, $018B, $01E1, $0010, $020D, $0358
    DECLE   $015F, $02A4, $02CC, $016F, $0109, $030B, $0193, $0320
    DECLE   $017A, $034C, $009C, $0017, $0001, $0200, $03C1, $0020
    DECLE   $00A7, $001D, $0001, $0104, $003D, $0040, $01A7, $01CA
    DECLE   $018B, $0160, $0078, $01F6, $0343, $01C7, $0090, $0000
_IY.end:  ; 48 decles
;; ------------------------------------------------------------------------ ;;
_JH:
    DECLE   _JH.end - _JH - 1
    DECLE   $0018, $0149, $0001, $00A4, $0321, $0180, $01F4, $039A
    DECLE   $02DC, $023C, $011A, $0047, $0200, $0001, $018E, $034E
    DECLE   $0394, $0356, $02C1, $010C, $03FD, $0129, $00B7, $01BA
    DECLE   $0000
_JH.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_KK1:
    DECLE   _KK1.end - _KK1 - 1
    DECLE   $00F4, $00C6, $00D2, $0000, $023A, $03E0, $02D1, $02E5
    DECLE   $0184, $0200, $0041, $0210, $0188, $00C5, $0000
_KK1.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_KK2:
    DECLE   _KK2.end - _KK2 - 1
    DECLE   $021D, $023C, $0211, $003C, $0180, $024D, $0008, $032B
    DECLE   $025B, $002D, $01DC, $01E3, $007A, $0000
_KK2.end:  ; 14 decles
;; ------------------------------------------------------------------------ ;;
_KK3:
    DECLE   _KK3.end - _KK3 - 1
    DECLE   $00F7, $0046, $01D2, $0300, $0131, $006C, $006E, $00F1
    DECLE   $00E4, $0000, $025A, $010D, $0110, $01F9, $014A, $0001
    DECLE   $00B5, $01A2, $00D8, $01CE, $0000
_KK3.end:  ; 21 decles
;; ------------------------------------------------------------------------ ;;
_LL:
    DECLE   _LL.end - _LL - 1
    DECLE   $0318, $038C, $016D, $029E, $0333, $0260, $0221, $0294
    DECLE   $01C4, $0299, $025A, $00E6, $014C, $012C, $0031, $0000
_LL.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_MM:
    DECLE   _MM.end - _MM - 1
    DECLE   $0210, $034D, $016D, $03F5, $00B0, $002E, $0220, $0290
    DECLE   $03CE, $02B6, $03AA, $00F3, $00CF, $015D, $016E, $0000
_MM.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_NG1:
    DECLE   _NG1.end - _NG1 - 1
    DECLE   $0118, $03CD, $016E, $00DC, $032F, $01BF, $01E0, $0116
    DECLE   $02AB, $029A, $0358, $01DB, $015B, $01A7, $02FD, $02B1
    DECLE   $03D2, $0356, $0000
_NG1.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_NN1:
    DECLE   _NN1.end - _NN1 - 1
    DECLE   $0318, $03CD, $016C, $0203, $0306, $03C3, $015F, $0270
    DECLE   $002A, $009D, $000D, $0248, $01B4, $0120, $01E1, $00C8
    DECLE   $0003, $0040, $0000, $0080, $015F, $0006, $0000
_NN1.end:  ; 23 decles
;; ------------------------------------------------------------------------ ;;
_NN2:
    DECLE   _NN2.end - _NN2 - 1
    DECLE   $0018, $034D, $016D, $0203, $0306, $03C3, $015F, $0270
    DECLE   $002A, $0095, $0003, $0248, $01B4, $0120, $01E1, $0090
    DECLE   $000B, $0040, $0000, $0080, $015F, $019E, $01F6, $028B
    DECLE   $00E0, $0266, $03F6, $01D8, $0143, $01A8, $0024, $00C0
    DECLE   $0080, $0000, $01E6, $0321, $0024, $0260, $000A, $0008
    DECLE   $03FE, $0000, $0000
_NN2.end:  ; 43 decles
;; ------------------------------------------------------------------------ ;;
_OR2:
    DECLE   _OR2.end - _OR2 - 1
    DECLE   $0218, $018C, $016D, $02A6, $03AB, $004F, $0301, $0390
    DECLE   $02EA, $0289, $0228, $0356, $01CF, $02D5, $0135, $007D
    DECLE   $02B5, $02AF, $024A, $02E2, $0153, $0167, $0333, $02A9
    DECLE   $02B3, $039A, $0351, $0147, $03CD, $0339, $02DA, $0000
_OR2.end:  ; 32 decles
;; ------------------------------------------------------------------------ ;;
_OW:
    DECLE   _OW.end - _OW - 1
    DECLE   $0310, $034C, $016E, $02AE, $03B1, $00CF, $0304, $0192
    DECLE   $018A, $022B, $0041, $0277, $015B, $0395, $03D1, $0082
    DECLE   $03CE, $00B6, $03BB, $02DA, $0000
_OW.end:  ; 21 decles
;; ------------------------------------------------------------------------ ;;
_OY:
    DECLE   _OY.end - _OY - 1
    DECLE   $0310, $014C, $016E, $02A6, $03AF, $00CF, $0304, $0192
    DECLE   $03CA, $01A8, $007F, $0155, $02B4, $027F, $00E2, $036A
    DECLE   $031F, $035D, $0116, $01D5, $02F4, $025F, $033A, $038A
    DECLE   $014F, $01B5, $03D5, $0297, $02DA, $03F2, $0167, $0124
    DECLE   $03FB, $0001
_OY.end:  ; 34 decles
;; ------------------------------------------------------------------------ ;;
_PA1:
    DECLE   _PA1.end - _PA1 - 1
    DECLE   $00F1, $0000
_PA1.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA2:
    DECLE   _PA2.end - _PA2 - 1
    DECLE   $00F4, $0000
_PA2.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA3:
    DECLE   _PA3.end - _PA3 - 1
    DECLE   $00F7, $0000
_PA3.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA4:
    DECLE   _PA4.end - _PA4 - 1
    DECLE   $00FF, $0000
_PA4.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA5:
    DECLE   _PA5.end - _PA5 - 1
    DECLE   $031D, $003F, $0000
_PA5.end:  ; 3 decles
;; ------------------------------------------------------------------------ ;;
_PP:
    DECLE   _PP.end - _PP - 1
    DECLE   $00FD, $0106, $0052, $0000, $022A, $03A5, $0277, $035F
    DECLE   $0184, $0000, $0055, $0391, $00EB, $00CF, $0000
_PP.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_RR1:
    DECLE   _RR1.end - _RR1 - 1
    DECLE   $0118, $01CD, $016C, $029E, $0171, $038E, $01E0, $0190
    DECLE   $0245, $0299, $01AA, $02E2, $01C7, $02DE, $0125, $00B5
    DECLE   $02C5, $028F, $024E, $035E, $01CB, $02EC, $0005, $0000
_RR1.end:  ; 24 decles
;; ------------------------------------------------------------------------ ;;
_RR2:
    DECLE   _RR2.end - _RR2 - 1
    DECLE   $0218, $03CC, $016C, $030C, $02C8, $0393, $02CD, $025E
    DECLE   $008A, $019D, $01AC, $02CB, $00BE, $0046, $017E, $01C2
    DECLE   $0174, $00A1, $01E5, $00E0, $010E, $0007, $0313, $0017
    DECLE   $0000
_RR2.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_SH:
    DECLE   _SH.end - _SH - 1
    DECLE   $0218, $0109, $0000, $007A, $0187, $02E0, $03F6, $0311
    DECLE   $0002, $0126, $0242, $0161, $03E9, $0219, $016C, $0300
    DECLE   $0013, $0045, $0124, $0005, $024C, $005C, $0182, $03C2
    DECLE   $0001
_SH.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_SS:
    DECLE   _SS.end - _SS - 1
    DECLE   $0218, $01CA, $0001, $0128, $001C, $0149, $01C6, $0000
_SS.end:  ; 8 decles
;; ------------------------------------------------------------------------ ;;
_TH:
    DECLE   _TH.end - _TH - 1
    DECLE   $0019, $0349, $0000, $00C6, $0212, $01D8, $01CA, $0000
_TH.end:  ; 8 decles
;; ------------------------------------------------------------------------ ;;
_TT1:
    DECLE   _TT1.end - _TT1 - 1
    DECLE   $00F6, $0046, $0142, $0100, $0042, $0088, $027E, $02EF
    DECLE   $01A4, $0200, $0049, $0290, $00FC, $00E8, $0000
_TT1.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_TT2:
    DECLE   _TT2.end - _TT2 - 1
    DECLE   $00F5, $00C6, $01D2, $0100, $0335, $00E9, $0042, $027A
    DECLE   $02A4, $0000, $0062, $01D1, $014C, $03EA, $02EC, $01E0
    DECLE   $0007, $03A7, $0000
_TT2.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_UH:
    DECLE   _UH.end - _UH - 1
    DECLE   $0018, $034E, $016E, $01FF, $0349, $00D2, $003C, $030C
    DECLE   $008B, $0005, $0000
_UH.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_UW1:
    DECLE   _UW1.end - _UW1 - 1
    DECLE   $0318, $014C, $016F, $029E, $03BD, $03BD, $0271, $0212
    DECLE   $0325, $0291, $016A, $027B, $014A, $03B4, $0133, $0001
_UW1.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_UW2:
    DECLE   _UW2.end - _UW2 - 1
    DECLE   $0018, $034E, $016E, $02F6, $0107, $02C2, $006D, $0090
    DECLE   $03AC, $01A4, $01DC, $03AB, $0128, $0076, $03E6, $0119
    DECLE   $014F, $03A6, $03A5, $0020, $0090, $0001, $02EE, $00BB
    DECLE   $0000
_UW2.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_VV:
    DECLE   _VV.end - _VV - 1
    DECLE   $0218, $030D, $016C, $010B, $010B, $0095, $034F, $03E4
    DECLE   $0108, $01B5, $01BE, $028B, $0160, $00AA, $03E4, $0106
    DECLE   $00EB, $02DE, $014C, $016E, $00F6, $0107, $00D2, $00CD
    DECLE   $0296, $00E4, $0006, $0000
_VV.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_WH:
    DECLE   _WH.end - _WH - 1
    DECLE   $0218, $00C9, $0000, $0084, $038E, $0147, $03A4, $0195
    DECLE   $0000, $012E, $0118, $0150, $02D1, $0232, $01B7, $03F1
    DECLE   $0237, $01C8, $03B1, $0227, $01AE, $0254, $0329, $032D
    DECLE   $01BF, $0169, $019A, $0307, $0181, $028D, $0000
_WH.end:  ; 31 decles
;; ------------------------------------------------------------------------ ;;
_WW:
    DECLE   _WW.end - _WW - 1
    DECLE   $0118, $034D, $016C, $00FA, $02C7, $0072, $03CC, $0109
    DECLE   $000B, $01AD, $019E, $016B, $0130, $0278, $01F8, $0314
    DECLE   $017E, $029E, $014D, $016D, $0205, $0147, $02E2, $001A
    DECLE   $010A, $026E, $0004, $0000
_WW.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_XR2:
    DECLE   _XR2.end - _XR2 - 1
    DECLE   $0318, $034C, $016E, $02A6, $03BB, $002F, $0290, $008E
    DECLE   $004B, $0392, $01DA, $024B, $013A, $01DA, $012F, $00B5
    DECLE   $02E5, $0297, $02DC, $0372, $014B, $016D, $0377, $00E7
    DECLE   $0376, $038A, $01CE, $026B, $02FA, $01AA, $011E, $0071
    DECLE   $00D5, $0297, $02BC, $02EA, $01C7, $02D7, $0135, $0155
    DECLE   $01DD, $0007, $0000
_XR2.end:  ; 43 decles
;; ------------------------------------------------------------------------ ;;
_YR:
    DECLE   _YR.end - _YR - 1
    DECLE   $0318, $03CC, $016E, $0197, $00FD, $0130, $0270, $0094
    DECLE   $0328, $0291, $0168, $007E, $01CC, $02F5, $0125, $02B5
    DECLE   $00F4, $0298, $01DA, $03F6, $0153, $0126, $03B9, $00AB
    DECLE   $0293, $03DB, $0175, $01B9, $0001
_YR.end:  ; 29 decles
;; ------------------------------------------------------------------------ ;;
_YY1:
    DECLE   _YY1.end - _YY1 - 1
    DECLE   $0318, $01CC, $016E, $0015, $00CB, $0263, $0320, $0078
    DECLE   $01CE, $0094, $001F, $0040, $0320, $03BF, $0230, $00A7
    DECLE   $000F, $01FE, $03FC, $01E2, $00D0, $0089, $000F, $0248
    DECLE   $032B, $03FD, $01CF, $0001, $0000
_YY1.end:  ; 29 decles
;; ------------------------------------------------------------------------ ;;
_YY2:
    DECLE   _YY2.end - _YY2 - 1
    DECLE   $0318, $01CC, $016E, $0015, $00CB, $0263, $0320, $0078
    DECLE   $01CE, $0094, $001F, $0040, $0320, $03BF, $0230, $00A7
    DECLE   $000F, $01FE, $03FC, $01E2, $00D0, $0089, $000F, $0248
    DECLE   $032B, $03FD, $01CF, $0199, $01EE, $008B, $0161, $0232
    DECLE   $0004, $0318, $01A7, $0198, $0124, $03E0, $0001, $0001
    DECLE   $030F, $0027, $0000
_YY2.end:  ; 43 decles
;; ------------------------------------------------------------------------ ;;
_ZH:
    DECLE   _ZH.end - _ZH - 1
    DECLE   $0310, $014D, $016E, $00C3, $03B9, $01BF, $0241, $0012
    DECLE   $0163, $00E1, $0000, $0080, $0084, $023F, $003F, $0000
_ZH.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_ZZ:
    DECLE   _ZZ.end - _ZZ - 1
    DECLE   $0218, $010D, $016F, $0225, $0351, $00B5, $02A0, $02EE
    DECLE   $00E9, $014D, $002C, $0360, $0008, $00EC, $004C, $0342
    DECLE   $03D4, $0156, $0052, $0131, $0008, $03B0, $01BE, $0172
    DECLE   $0000
_ZZ.end:  ; 25 decles

;;==========================================================================;;
;;                                                                          ;;
;;  Copyright information:                                                  ;;
;;                                                                          ;;
;;  The above allophone data was extracted from the SP0256-AL2 ROM image.   ;;
;;  The SP0256-AL2 allophones are NOT in the public domain, nor are they    ;;
;;  placed under the GNU General Public License.  This program is           ;;
;;  distributed in the hope that it will be useful, but WITHOUT ANY         ;;
;;  WARRANTY; without even the implied warranty of MERCHANTABILITY or       ;;
;;  FITNESS FOR A PARTICULAR PURPOSE.                                       ;;
;;                                                                          ;;
;;  Microchip, Inc. retains the copyright to the data and algorithms        ;;
;;  contained in the SP0256-AL2.  This speech data is distributed with      ;;
;;  explicit permission from Microchip, Inc.  All such redistributions      ;;
;;  must retain this notice of copyright.                                   ;;
;;                                                                          ;;
;;  No copyright claims are made on this data by the author(s) of SDK1600.  ;;
;;  Please see http://spatula-city.org/~im14u2c/sp0256-al2/ for details.    ;;
;;                                                                          ;;
;;==========================================================================;;

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- Joseph Zbiciak, 2008                                     *;
;* ======================================================================== *;

;; ======================================================================== ;;
;;  INTELLIVOICE DRIVER ROUTINES                                            ;;
;;  Written in 2002 by Joe Zbiciak <intvnut AT gmail.com>                   ;;
;;  http://spatula-city.org/~im14u2c/intv/                                  ;;
;; ======================================================================== ;;

;; ======================================================================== ;;
;;  GLOBAL VARIABLES USED BY THESE ROUTINES                                 ;;
;;                                                                          ;;
;;  Note that some of these routines may use one or more global variables.  ;;
;;  If you use these routines, you will need to allocate the appropriate    ;;
;;  space in either 16-bit or 8-bit memory as appropriate.  Each global     ;;
;;  variable is listed with the routines which use it and the required      ;;
;;  memory width.                                                           ;;
;;                                                                          ;;
;;  Example declarations for these routines are shown below, commented out. ;;
;;  You should uncomment these and add them to your program to make use of  ;;
;;  the routine that needs them.  Make sure to assign these variables to    ;;
;;  locations that aren't used for anything else.                           ;;
;; ======================================================================== ;;

                        ; Used by       Req'd Width     Description
                        ;-----------------------------------------------------
;IV.QH      EQU $110    ; IV_xxx        8-bit           Voice queue head
;IV.QT      EQU $111    ; IV_xxx        8-bit           Voice queue tail
;IV.Q       EQU $112    ; IV_xxx        8-bit           Voice queue  (8 bytes)
;IV.FLEN    EQU $11A    ; IV_xxx        8-bit           Length of FIFO data
;IV.FPTR    EQU $320    ; IV_xxx        16-bit          Current FIFO ptr.
;IV.PPTR    EQU $321    ; IV_xxx        16-bit          Current Phrase ptr.

;; ======================================================================== ;;
;;  MEMORY USAGE                                                            ;;
;;                                                                          ;;
;;  These routines implement a queue of "pending phrases" that will be      ;;
;;  played by the Intellivoice.  The user calls IV_PLAY to enqueue a        ;;
;;  phrase number.  Phrase numbers indicate either a RESROM sample or       ;;
;;  a compiled in phrase to be spoken.                                      ;;
;;                                                                          ;;
;;  The user must compose an "IV_PHRASE_TBL", which is composed of          ;;
;;  pointers to phrases to be spoken.  Phrases are strings of pointers      ;;
;;  and RESROM triggers, terminated by a NUL.                               ;;
;;                                                                          ;;
;;  Phrase numbers 1 through 42 are RESROM samples.  Phrase numbers         ;;
;;  43 through 255 index into the IV_PHRASE_TBL.                            ;;
;;                                                                          ;;
;;  SPECIAL NOTES                                                           ;;
;;                                                                          ;;
;;  Bit 7 of IV.QH and IV.QT is used to denote whether the Intellivoice     ;;
;;  is present.  If Intellivoice is present, this bit is clear.             ;;
;;                                                                          ;;
;;  Bit 6 of IV.QT is used to denote that we still need to do an ALD $00    ;;
;;  for FIFO'd voice data.                                                  ;;
;; ======================================================================== ;;
            

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_INIT     Initialize the Intellivoice                             ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_INIT                                                      ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0      0 if Intellivoice found, -1 if not.                         ;;
;;                                                                          ;;
;;  DESCRIPTION                                                             ;;
;;      Resets Intellivoice, determines if it is actually there, and        ;;
;;      then initializes the IV structure.                                  ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;

IV_INIT     PROC
            MVII    #$0400, R0          ;
            MVO     R0,     $0081       ; Reset the Intellivoice

            MVI     $0081,  R0          ; \
            RLC     R0,     2           ;  |-- See if we detect Intellivoice
            BOV     @@no_ivoice         ; /    once we've reset it.

            CLRR    R0                  ; 
            MVO     R0,     IV.FPTR     ; No data for FIFO
            MVO     R0,     IV.PPTR     ; No phrase being spoken
            MVO     R0,     IV.QH       ; Clear our queue
            MVO     R0,     IV.QT       ; Clear our queue
            JR      R5                  ; Done!

@@no_ivoice:
            CLRR    R0
            MVO     R0,     IV.FPTR     ; No data for FIFO
            MVO     R0,     IV.PPTR     ; No phrase being spoken
            DECR    R0
            MVO     R0,     IV.QH       ; Set queue to -1 ("No Intellivoice")
            MVO     R0,     IV.QT       ; Set queue to -1 ("No Intellivoice")
            JR      R5                  ; Done!
            ENDP

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_ISR      Interrupt service routine to feed Intellivoice          ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_ISR                                                       ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0, R1, R4 trashed.                                                 ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      Call this from your main interrupt service routine.                 ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_ISR      PROC
            ;; ------------------------------------------------------------ ;;
            ;;  Check for Intellivoice.  Leave if none present.             ;;
            ;; ------------------------------------------------------------ ;;
            MVI     IV.QT,  R1          ; Get queue tail
            SWAP    R1,     2
            BPL     @@ok                ; Bit 7 set? If yes: No Intellivoice
@@ald_busy:
@@leave     JR      R5                  ; Exit if no Intellivoice.

     
            ;; ------------------------------------------------------------ ;;
            ;;  Check to see if we pump samples into the FIFO.
            ;; ------------------------------------------------------------ ;;
@@ok:       MVI     IV.FPTR, R4         ; Get FIFO data pointer
            TSTR    R4                  ; is it zero?
            BEQ     @@no_fifodata       ; Yes:  No data for FIFO.
@@fifo_fill:
            MVI     $0081,  R0          ; Read speech FIFO ready bit
            SLLC    R0,     1           ; 
            BC      @@fifo_busy     

            MVI@    R4,     R0          ; Get next word
            MVO     R0,     $0081       ; write it to the FIFO

            MVI     IV.FLEN, R0         ;\
            DECR    R0                  ; |-- Decrement our FIFO'd data length
            MVO     R0,     IV.FLEN     ;/
            BEQ     @@last_fifo         ; If zero, we're done w/ FIFO
            MVO     R4,     IV.FPTR     ; Otherwise, save new pointer
            B       @@fifo_fill         ; ...and keep trying to load FIFO

@@last_fifo MVO     R0,     IV.FPTR     ; done with FIFO loading.
                                        ; fall into ALD processing.


            ;; ------------------------------------------------------------ ;;
            ;;  Try to do an Address Load.  We do this in two settings:     ;;
            ;;   -- We have no FIFO data to load.                           ;;
            ;;   -- We've loaded as much FIFO data as we can, but we        ;;
            ;;      might have an address load command to send for it.      ;;
            ;; ------------------------------------------------------------ ;;
@@fifo_busy:
@@no_fifodata:
            MVI     $0080,  R0          ; Read LRQ bit from ALD register
            SLLC    R0,     1
            BNC     @@ald_busy          ; LRQ is low, meaning we can't ALD.
                                        ; So, leave.

            ;; ------------------------------------------------------------ ;;
            ;;  We can do an address load (ALD) on the SP0256.  Give FIFO   ;;
            ;;  driven ALDs priority, since we already started the FIFO     ;;
            ;;  load.  The "need ALD" bit is stored in bit 6 of IV.QT.      ;;
            ;; ------------------------------------------------------------ ;;
            ANDI    #$40,   R1          ; Is "Need FIFO ALD" bit set?
            BEQ     @@no_fifo_ald
            XOR     IV.QT,  R1          ;\__ Clear the "Need FIFO ALD" bit.
            MVO     R1,     IV.QT       ;/
            CLRR    R1
            MVO     R1,     $80         ; Load a 0 into ALD (trigger FIFO rd.)
            JR      R5                  ; done!

            ;; ------------------------------------------------------------ ;;
            ;;  We don't need to ALD on behalf of the FIFO.  So, we grab    ;;
            ;;  the next thing off our phrase list.                         ;;
            ;; ------------------------------------------------------------ ;;
@@no_fifo_ald:
            MVI     IV.PPTR, R4         ; Get phrase pointer.
            TSTR    R4                  ; Is it zero?
            BEQ     @@next_phrase       ; Yes:  Get next phrase from queue.

            MVI@    R4,     R0
            TSTR    R0                  ; Is it end of phrase?
            BNEQ    @@process_phrase    ; !=0:  Go do it.

            MVO     R0,     IV.PPTR     ; 
@@next_phrase:
            MVI     IV.QT,  R1          ; reload queue tail (was trashed above)
            MOVR    R1,     R0          ; copy QT to R0 so we can increment it
            ANDI    #$7,    R1          ; Mask away flags in queue head
            CMP     IV.QH,  R1          ; Is it same as queue tail?
            BEQ     @@leave             ; Yes:  No more speech for now.

            INCR    R0
            ANDI    #$F7,   R0          ; mask away the possible 'carry'
            MVO     R0,     IV.QT       ; save updated queue tail

            ADDI    #IV.Q,  R1          ; Index into queue
            MVI@    R1,     R4          ; get next value from queue
            CMPI    #43,    R4          ; Is it a RESROM or Phrase?
            BNC     @@play_resrom_r4
@@new_phrase:
;            ADDI    #IV_PHRASE_TBL - 43, R4 ; Index into phrase table
;            MVI@    R4,     R4          ; Read from phrase table
            MVO     R4,     IV.PPTR
            JR      R5                  ; we'll get to this phrase next time.

@@play_resrom_r4:
            MVO     R4,     $0080       ; Just ALD it
            JR      R5                  ; and leave.

            ;; ------------------------------------------------------------ ;;
            ;;  We're in the middle of a phrase, so continue interpreting.  ;;
            ;; ------------------------------------------------------------ ;;
@@process_phrase:
            
            MVO     R4,     IV.PPTR     ; save new phrase pointer
            CMPI    #43,    R0          ; Is it a RESROM cue?
            BC      @@play_fifo         ; Just ALD it and leave.
@@play_resrom_r0
            MVO     R0,     $0080       ; Just ALD it
            JR      R5                  ; and leave.
@@play_fifo:
            MVI     IV.FPTR,R1          ; Make sure not to stomp existing FIFO
            TSTR    R1                  ; data.
            BEQ     @@new_fifo_ok
            DECR    R4                  ; Oops, FIFO data still playing,
            MVO     R4,     IV.PPTR     ; so rewind.
            JR      R5                  ; and leave.

@@new_fifo_ok:
            MOVR    R0,     R4          ;
            MVI@    R4,     R0          ; Get chunk length
            MVO     R0,     IV.FLEN     ; Init FIFO chunk length
            MVO     R4,     IV.FPTR     ; Init FIFO pointer
            MVI     IV.QT,  R0          ;\
            XORI    #$40,   R0          ; |- Set "Need ALD" bit in QT
            MVO     R0,     IV.QT       ;/

  IF 1      ; debug code                ;\
            ANDI    #$40,   R0          ; |   Debug code:  We should only
            BNEQ    @@qtok              ; |-- be here if "Need FIFO ALD" 
            HLT     ;BUG!!              ; |   was already clear.         
@@qtok                                  ;/    
  ENDI
            JR      R5                  ; leave.

            ENDP


;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_PLAY     Play a voice sample sequence.                           ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY                                                      ;;
;;      R5      Invocation record, followed by return address.              ;;
;;                  1 DECLE    Phrase number to play.                       ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY.1                                                    ;;
;;      R0      Address of phrase to play.                                  ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0, R1  trashed                                                     ;;
;;      Z==0    if item not successfully queued.                            ;;
;;      Z==1    if successfully queued.                                     ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This code will drop phrases if the queue is full.                   ;;
;;      Phrase numbers 1..42 are RESROM samples.  43..255 will index        ;;
;;      into the user-supplied IV_PHRASE_TBL.  43 will refer to the         ;;
;;      first entry, 44 to the second, and so on.  Phrase 0 is undefined.   ;;
;;                                                                          ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_PLAY     PROC
            MVI@    R5,     R0

@@1:        ; alternate entry point
            MVI     IV.QT,  R1          ; Get queue tail
            SWAP    R1,     2           ;\___ Leave if "no Intellivoice"
            BMI     @@leave             ;/    bit it set.
@@ok:       
            DECR    R1                  ;\
            ANDI    #$7,    R1          ; |-- See if we still have room
            CMP     IV.QH,  R1          ;/
            BEQ     @@leave             ; Leave if we're full

@@2:        MVI     IV.QH,  R1          ; Get our queue head pointer
            PSHR    R1                  ;\
            INCR    R1                  ; |
            ANDI    #$F7,   R1          ; |-- Increment it, removing
            MVO     R1,     IV.QH       ; |   carry but preserving flags.
            PULR    R1                  ;/

            ADDI    #IV.Q,  R1          ;\__ Store phrase to queue
            MVO@    R0,     R1          ;/

@@leave:    JR      R5                  ; Leave.
            ENDP

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_PLAYW    Play a voice sample sequence.  Wait for queue room.     ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY                                                      ;;
;;      R5      Invocation record, followed by return address.              ;;
;;                  1 DECLE    Phrase number to play.                       ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY.1                                                    ;;
;;      R0      Address of phrase to play.                                  ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0, R1  trashed                                                     ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This code will wait for a queue slot to open if queue is full.      ;;
;;      Phrase numbers 1..42 are RESROM samples.  43..255 will index        ;;
;;      into the user-supplied IV_PHRASE_TBL.  43 will refer to the         ;;
;;      first entry, 44 to the second, and so on.  Phrase 0 is undefined.   ;;
;;                                                                          ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_PLAYW    PROC
            MVI@    R5,     R0

@@1:        ; alternate entry point
            MVI     IV.QT,  R1          ; Get queue tail
            SWAP    R1,     2           ;\___ Leave if "no Intellivoice"
            BMI     IV_PLAY.leave       ;/    bit it set.
@@ok:       
            DECR    R1                  ;\
            ANDI    #$7,    R1          ; |-- See if we still have room
            CMP     IV.QH,  R1          ;/
            BEQ     @@1                 ; wait for room
            B       IV_PLAY.2

            ENDP

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_WAIT     Wait for voice queue to empty.                          ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_WAIT                                                      ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0      trashed.                                                    ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This waits until the Intellivoice is nearly completely quiescent.   ;;
;;      Some voice data may still be spoken from the last triggered         ;;
;;      phrase.  To truly wait for *that* to be spoken, speak a 'pause'     ;;
;;      (eg. RESROM.pa1) and then call IV_WAIT.                             ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_WAIT     PROC
            MVI     IV.QH,  R0
            SWAP    R0                  ;\___ test bit 7, leave if set.
            SWAP    R0                  ;/    (SWAP2 corrupts upper byte.)
            BMI     @@leave

            ; Wait for queue to drain.
@@q_loop:   CMP     IV.QT,  R0
            BNEQ    @@q_loop

            ; Wait for FIFO and LRQ to say ready.
@@s_loop:   MVI     $81,    R0          ; Read FIFO status.  0 == ready.
            COMR    R0
            AND     $80,    R0          ; Merge w/ ALD status.  1 == ready
            TSTR    R0
            BPL     @@s_loop            ; if bit 15 == 0, not ready.
            
@@leave:    JR      R5
            ENDP

;; ======================================================================== ;;
;;  End of File:  ivoice.asm                                                ;;
;; ======================================================================== ;;

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- Joseph Zbiciak, 2008                                     *;
;* ======================================================================== *;

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_SAYNUM16 Say a 16-bit unsigned number using RESROM digits        ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      16-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_INIT                                                      ;;
;;      R0      Number to "speak"                                           ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;                                                                          ;;
;;  DESCRIPTION                                                             ;;
;;      "Says" a 16-bit number using IV_PLAYW to queue up the phrase.       ;;
;;      Because the number may be built from several segments, it could     ;;
;;      easily eat up the queue.  I believe the longest number will take    ;;
;;      7 queue entries -- that is, fill the queue.  Thus, this code        ;;
;;      could block, waiting for slots in the queue.                        ;;
;; ======================================================================== ;;

IV_SAYNUM16 PROC
            PSHR    R5

            TSTR    R0
            BEQ     @@zero          ; Special case:  Just say "zero"

            ;; ------------------------------------------------------------ ;;
            ;;  First, try to pull off 'thousands'.  We call ourselves      ;;
            ;;  recursively to play the the number of thousands.            ;;
            ;; ------------------------------------------------------------ ;;
            CLRR    R1
@@thloop:   INCR    R1
            SUBI    #1000,  R0
            BC      @@thloop

            ADDI    #1000,  R0
            PSHR    R0
            DECR    R1
            BEQ     @@no_thousand

            CALL    IV_SAYNUM16.recurse

            CALL    IV_PLAYW
            DECLE   36  ; THOUSAND
            
@@no_thousand
            PULR    R1

            ;; ------------------------------------------------------------ ;;
            ;;  Now try to play hundreds.                                   ;;
            ;; ------------------------------------------------------------ ;;
            MVII    #7-1, R0    ; ZERO
            CMPI    #100,   R1
            BNC     @@no_hundred

@@hloop:    INCR    R0
            SUBI    #100,   R1
            BC      @@hloop
            ADDI    #100,   R1

            PSHR    R1

            CALL    IV_PLAYW.1

            CALL    IV_PLAYW
            DECLE   35  ; HUNDRED

            PULR    R1
            B       @@notrecurse    ; skip "PSHR R5"
@@recurse:  PSHR    R5              ; recursive entry point for 'thousand'

@@no_hundred:
@@notrecurse:
            MOVR    R1,     R0
            BEQ     @@leave

            SUBI    #20,    R1
            BNC     @@teens

            MVII    #27-1, R0   ; TWENTY
@@tyloop    INCR    R0
            SUBI    #10,    R1
            BC      @@tyloop
            ADDI    #10,    R1

            PSHR    R1
            CALL    IV_PLAYW.1

            PULR    R0
            TSTR    R0
            BEQ     @@leave

@@teens:
@@zero:     ADDI    #7, R0  ; ZERO

            CALL    IV_PLAYW.1

@@leave     PULR    PC
            ENDP

;; ======================================================================== ;;
;;  End of File:  saynum16.asm                                              ;;
;; ======================================================================== ;;

    ENDI

        IF DEFINED intybasic_flash

;; ======================================================================== ;;
;;  JLP "Save Game" support                                                 ;;
;; ======================================================================== ;;
JF.first    EQU     $8023
JF.last     EQU     $8024
JF.addr     EQU     $8025
JF.row      EQU     $8026
                   
JF.wrcmd    EQU     $802D
JF.rdcmd    EQU     $802E
JF.ercmd    EQU     $802F
JF.wrkey    EQU     $C0DE
JF.rdkey    EQU     $DEC0
JF.erkey    EQU     $BEEF

JF.write:   DECLE   JF.wrcmd,   JF.wrkey    ; Copy JLP RAM to flash row  
JF.read:    DECLE   JF.rdcmd,   JF.rdkey    ; Copy flash row to JLP RAM  
JF.erase:   DECLE   JF.ercmd,   JF.erkey    ; Erase flash sector 

;; ======================================================================== ;;
;;  JF.INIT         Copy JLP save-game support routine to System RAM        ;;
;; ======================================================================== ;;
JF.INIT     PROC
            PSHR    R5            
            MVII    #@@__code,  R5
            MVII    #JF.SYSRAM, R4
            REPEAT  5       
            MVI@    R5,         R0      ; \_ Copy code fragment to System RAM
            MVO@    R0,         R4      ; /
            ENDR
            PULR    PC

            ;; === start of code that will run from RAM
@@__code:   MVO@    R0,         R1      ; JF.SYSRAM + 0: initiate command
            ADD@    R1,         PC      ; JF.SYSRAM + 1: Wait for JLP to return
            JR      R5                  ; JF.SYSRAM + 2:
            MVO@    R2,         R2      ; JF.SYSRAM + 3: \__ simple ISR
            JR      R5                  ; JF.SYSRAM + 4: /
            ;; === end of code that will run from RAM
            ENDP

;; ======================================================================== ;;
;;  JF.CMD          Issue a JLP Flash command                               ;;
;;                                                                          ;;
;;  INPUT                                                                   ;;
;;      R0  Slot number to operate on                                       ;;
;;      R1  Address to copy to/from in JLP RAM                              ;;
;;      @R5 Command to invoke:                                              ;;
;;                                                                          ;;
;;              JF.write -- Copy JLP RAM to Flash                           ;;
;;              JF.read  -- Copy Flash to JLP RAM                           ;;
;;              JF.erase -- Erase flash sector                              ;;
;;                                                                          ;;
;;  OUTPUT                                                                  ;;
;;      R0 - R4 not modified.  (Saved and restored across call)             ;;
;;      JLP command executed                                                ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This code requires two short routines in the console's System RAM.  ;;
;;      It also requires that the system stack reside in System RAM.        ;;
;;      Because an interrupt may occur during the code's execution, there   ;;
;;      must be sufficient stack space to service the interrupt (8 words).  ;;
;;                                                                          ;;
;;      The code also relies on the fact that the EXEC ISR dispatch does    ;;
;;      not modify R2.  This allows us to initialize R2 for the ISR ahead   ;;
;;      of time, rather than in the ISR.                                    ;;
;; ======================================================================== ;;
JF.CMD      PROC

            MVO     R4,         JF.SV.R4    ; \
            MVII    #JF.SV.R0,  R4          ;  |
            MVO@    R0,         R4          ;  |- Save registers, but not on
            MVO@    R1,         R4          ;  |  the stack.  (limit stack use)
            MVO@    R2,         R4          ; /

            MVI@    R5,         R4          ; Get command to invoke

            MVO     R5,         JF.SV.R5    ; save return address

            DIS
            MVO     R1,         JF.addr     ; \_ Save SG arguments in JLP
            MVO     R0,         JF.row      ; /
                                          
            MVI@    R4,         R1          ; Get command address
            MVI@    R4,         R0          ; Get unlock word
                                          
            MVII    #$100,      R4          ; \
            SDBD                            ;  |_ Save old ISR in save area
            MVI@    R4,         R2          ;  |
            MVO     R2,         JF.SV.ISR   ; /
                                          
            MVII    #JF.SYSRAM + 3, R2      ; \
            MVO     R2,         $100        ;  |_ Set up new ISR in RAM
            SWAP    R2                      ;  |
            MVO     R2,         $101        ; / 
                                          
            MVII    #$20,       R2          ; Address of STIC handshake
            JSRE    R5,  JF.SYSRAM          ; Invoke the command
                                          
            MVI     JF.SV.ISR,  R2          ; \
            MVO     R2,         $100        ;  |_ Restore old ISR 
            SWAP    R2                      ;  |
            MVO     R2,         $101        ; /
                                          
            MVII    #JF.SV.R0,  R5          ; \
            MVI@    R5,         R0          ;  |
            MVI@    R5,         R1          ;  |- Restore registers
            MVI@    R5,         R2          ;  |
            MVI@    R5,         R4          ; /
            MVI@    R5,         PC          ; Return

            ENDP


        ENDI

	IF DEFINED intybasic_fastmult

; Quarter Square Multiplication
; Assembly code by Joe Zbiciak, 2015
; Released to public domain.

QSQR8_TBL:  PROC
            DECLE   $3F80, $3F01, $3E82, $3E04, $3D86, $3D09, $3C8C, $3C10
            DECLE   $3B94, $3B19, $3A9E, $3A24, $39AA, $3931, $38B8, $3840
            DECLE   $37C8, $3751, $36DA, $3664, $35EE, $3579, $3504, $3490
            DECLE   $341C, $33A9, $3336, $32C4, $3252, $31E1, $3170, $3100
            DECLE   $3090, $3021, $2FB2, $2F44, $2ED6, $2E69, $2DFC, $2D90
            DECLE   $2D24, $2CB9, $2C4E, $2BE4, $2B7A, $2B11, $2AA8, $2A40
            DECLE   $29D8, $2971, $290A, $28A4, $283E, $27D9, $2774, $2710
            DECLE   $26AC, $2649, $25E6, $2584, $2522, $24C1, $2460, $2400
            DECLE   $23A0, $2341, $22E2, $2284, $2226, $21C9, $216C, $2110
            DECLE   $20B4, $2059, $1FFE, $1FA4, $1F4A, $1EF1, $1E98, $1E40
            DECLE   $1DE8, $1D91, $1D3A, $1CE4, $1C8E, $1C39, $1BE4, $1B90
            DECLE   $1B3C, $1AE9, $1A96, $1A44, $19F2, $19A1, $1950, $1900
            DECLE   $18B0, $1861, $1812, $17C4, $1776, $1729, $16DC, $1690
            DECLE   $1644, $15F9, $15AE, $1564, $151A, $14D1, $1488, $1440
            DECLE   $13F8, $13B1, $136A, $1324, $12DE, $1299, $1254, $1210
            DECLE   $11CC, $1189, $1146, $1104, $10C2, $1081, $1040, $1000
            DECLE   $0FC0, $0F81, $0F42, $0F04, $0EC6, $0E89, $0E4C, $0E10
            DECLE   $0DD4, $0D99, $0D5E, $0D24, $0CEA, $0CB1, $0C78, $0C40
            DECLE   $0C08, $0BD1, $0B9A, $0B64, $0B2E, $0AF9, $0AC4, $0A90
            DECLE   $0A5C, $0A29, $09F6, $09C4, $0992, $0961, $0930, $0900
            DECLE   $08D0, $08A1, $0872, $0844, $0816, $07E9, $07BC, $0790
            DECLE   $0764, $0739, $070E, $06E4, $06BA, $0691, $0668, $0640
            DECLE   $0618, $05F1, $05CA, $05A4, $057E, $0559, $0534, $0510
            DECLE   $04EC, $04C9, $04A6, $0484, $0462, $0441, $0420, $0400
            DECLE   $03E0, $03C1, $03A2, $0384, $0366, $0349, $032C, $0310
            DECLE   $02F4, $02D9, $02BE, $02A4, $028A, $0271, $0258, $0240
            DECLE   $0228, $0211, $01FA, $01E4, $01CE, $01B9, $01A4, $0190
            DECLE   $017C, $0169, $0156, $0144, $0132, $0121, $0110, $0100
            DECLE   $00F0, $00E1, $00D2, $00C4, $00B6, $00A9, $009C, $0090
            DECLE   $0084, $0079, $006E, $0064, $005A, $0051, $0048, $0040
            DECLE   $0038, $0031, $002A, $0024, $001E, $0019, $0014, $0010
            DECLE   $000C, $0009, $0006, $0004, $0002, $0001, $0000
@@mid:
            DECLE   $0000, $0000, $0001, $0002, $0004, $0006, $0009, $000C
            DECLE   $0010, $0014, $0019, $001E, $0024, $002A, $0031, $0038
            DECLE   $0040, $0048, $0051, $005A, $0064, $006E, $0079, $0084
            DECLE   $0090, $009C, $00A9, $00B6, $00C4, $00D2, $00E1, $00F0
            DECLE   $0100, $0110, $0121, $0132, $0144, $0156, $0169, $017C
            DECLE   $0190, $01A4, $01B9, $01CE, $01E4, $01FA, $0211, $0228
            DECLE   $0240, $0258, $0271, $028A, $02A4, $02BE, $02D9, $02F4
            DECLE   $0310, $032C, $0349, $0366, $0384, $03A2, $03C1, $03E0
            DECLE   $0400, $0420, $0441, $0462, $0484, $04A6, $04C9, $04EC
            DECLE   $0510, $0534, $0559, $057E, $05A4, $05CA, $05F1, $0618
            DECLE   $0640, $0668, $0691, $06BA, $06E4, $070E, $0739, $0764
            DECLE   $0790, $07BC, $07E9, $0816, $0844, $0872, $08A1, $08D0
            DECLE   $0900, $0930, $0961, $0992, $09C4, $09F6, $0A29, $0A5C
            DECLE   $0A90, $0AC4, $0AF9, $0B2E, $0B64, $0B9A, $0BD1, $0C08
            DECLE   $0C40, $0C78, $0CB1, $0CEA, $0D24, $0D5E, $0D99, $0DD4
            DECLE   $0E10, $0E4C, $0E89, $0EC6, $0F04, $0F42, $0F81, $0FC0
            DECLE   $1000, $1040, $1081, $10C2, $1104, $1146, $1189, $11CC
            DECLE   $1210, $1254, $1299, $12DE, $1324, $136A, $13B1, $13F8
            DECLE   $1440, $1488, $14D1, $151A, $1564, $15AE, $15F9, $1644
            DECLE   $1690, $16DC, $1729, $1776, $17C4, $1812, $1861, $18B0
            DECLE   $1900, $1950, $19A1, $19F2, $1A44, $1A96, $1AE9, $1B3C
            DECLE   $1B90, $1BE4, $1C39, $1C8E, $1CE4, $1D3A, $1D91, $1DE8
            DECLE   $1E40, $1E98, $1EF1, $1F4A, $1FA4, $1FFE, $2059, $20B4
            DECLE   $2110, $216C, $21C9, $2226, $2284, $22E2, $2341, $23A0
            DECLE   $2400, $2460, $24C1, $2522, $2584, $25E6, $2649, $26AC
            DECLE   $2710, $2774, $27D9, $283E, $28A4, $290A, $2971, $29D8
            DECLE   $2A40, $2AA8, $2B11, $2B7A, $2BE4, $2C4E, $2CB9, $2D24
            DECLE   $2D90, $2DFC, $2E69, $2ED6, $2F44, $2FB2, $3021, $3090
            DECLE   $3100, $3170, $31E1, $3252, $32C4, $3336, $33A9, $341C
            DECLE   $3490, $3504, $3579, $35EE, $3664, $36DA, $3751, $37C8
            DECLE   $3840, $38B8, $3931, $39AA, $3A24, $3A9E, $3B19, $3B94
            DECLE   $3C10, $3C8C, $3D09, $3D86, $3E04, $3E82, $3F01, $3F80
            DECLE   $4000, $4080, $4101, $4182, $4204, $4286, $4309, $438C
            DECLE   $4410, $4494, $4519, $459E, $4624, $46AA, $4731, $47B8
            DECLE   $4840, $48C8, $4951, $49DA, $4A64, $4AEE, $4B79, $4C04
            DECLE   $4C90, $4D1C, $4DA9, $4E36, $4EC4, $4F52, $4FE1, $5070
            DECLE   $5100, $5190, $5221, $52B2, $5344, $53D6, $5469, $54FC
            DECLE   $5590, $5624, $56B9, $574E, $57E4, $587A, $5911, $59A8
            DECLE   $5A40, $5AD8, $5B71, $5C0A, $5CA4, $5D3E, $5DD9, $5E74
            DECLE   $5F10, $5FAC, $6049, $60E6, $6184, $6222, $62C1, $6360
            DECLE   $6400, $64A0, $6541, $65E2, $6684, $6726, $67C9, $686C
            DECLE   $6910, $69B4, $6A59, $6AFE, $6BA4, $6C4A, $6CF1, $6D98
            DECLE   $6E40, $6EE8, $6F91, $703A, $70E4, $718E, $7239, $72E4
            DECLE   $7390, $743C, $74E9, $7596, $7644, $76F2, $77A1, $7850
            DECLE   $7900, $79B0, $7A61, $7B12, $7BC4, $7C76, $7D29, $7DDC
            DECLE   $7E90, $7F44, $7FF9, $80AE, $8164, $821A, $82D1, $8388
            DECLE   $8440, $84F8, $85B1, $866A, $8724, $87DE, $8899, $8954
            DECLE   $8A10, $8ACC, $8B89, $8C46, $8D04, $8DC2, $8E81, $8F40
            DECLE   $9000, $90C0, $9181, $9242, $9304, $93C6, $9489, $954C
            DECLE   $9610, $96D4, $9799, $985E, $9924, $99EA, $9AB1, $9B78
            DECLE   $9C40, $9D08, $9DD1, $9E9A, $9F64, $A02E, $A0F9, $A1C4
            DECLE   $A290, $A35C, $A429, $A4F6, $A5C4, $A692, $A761, $A830
            DECLE   $A900, $A9D0, $AAA1, $AB72, $AC44, $AD16, $ADE9, $AEBC
            DECLE   $AF90, $B064, $B139, $B20E, $B2E4, $B3BA, $B491, $B568
            DECLE   $B640, $B718, $B7F1, $B8CA, $B9A4, $BA7E, $BB59, $BC34
            DECLE   $BD10, $BDEC, $BEC9, $BFA6, $C084, $C162, $C241, $C320
            DECLE   $C400, $C4E0, $C5C1, $C6A2, $C784, $C866, $C949, $CA2C
            DECLE   $CB10, $CBF4, $CCD9, $CDBE, $CEA4, $CF8A, $D071, $D158
            DECLE   $D240, $D328, $D411, $D4FA, $D5E4, $D6CE, $D7B9, $D8A4
            DECLE   $D990, $DA7C, $DB69, $DC56, $DD44, $DE32, $DF21, $E010
            DECLE   $E100, $E1F0, $E2E1, $E3D2, $E4C4, $E5B6, $E6A9, $E79C
            DECLE   $E890, $E984, $EA79, $EB6E, $EC64, $ED5A, $EE51, $EF48
            DECLE   $F040, $F138, $F231, $F32A, $F424, $F51E, $F619, $F714
            DECLE   $F810, $F90C, $FA09, $FB06, $FC04, $FD02, $FE01
            ENDP

; R0 = R0 * R1, where R0 and R1 are unsigned 8-bit values
; Destroys R1, R4
qs_mpy8:    PROC
            MOVR    R0,             R4      ;   6
            ADDI    #QSQR8_TBL.mid, R1      ;   8
            ADDR    R1,             R4      ;   6   a + b
            SUBR    R0,             R1      ;   6   a - b
@@ok:       MVI@    R4,             R0      ;   8
            SUB@    R1,             R0      ;   8
            JR      R5                      ;   7
                                            ;----
                                            ;  49
            ENDP
            

; R1 = R0 * R1, where R0 and R1 are 16-bit values
; destroys R0, R2, R3, R4, R5
qs_mpy16:   PROC
            PSHR    R5                  ;   9
                                   
            ; Unpack lo/hi
            MOVR    R0,         R2      ;   6   
            ANDI    #$FF,       R0      ;   8   R0 is lo(a)
            XORR    R0,         R2      ;   6   
            SWAP    R2                  ;   6   R2 is hi(a)

            MOVR    R1,         R3      ;   6   R3 is orig 16-bit b
            ANDI    #$FF,       R1      ;   8   R1 is lo(b)
            MOVR    R1,         R5      ;   6   R5 is lo(b)
            XORR    R1,         R3      ;   6   
            SWAP    R3                  ;   6   R3 is hi(b)
                                        ;----
                                        ;  67
                                        
            ; lo * lo                   
            MOVR    R0,         R4      ;   6   R4 is lo(a)
            ADDI    #QSQR8_TBL.mid, R1  ;   8
            ADDR    R1,         R4      ;   6   R4 = lo(a) + lo(b)
            SUBR    R0,         R1      ;   6   R1 = lo(a) - lo(b)
                                        
@@pos_ll:   MVI@    R4,         R4      ;   8   R4 = qstbl[lo(a)+lo(b)]
            SUB@    R1,         R4      ;   8   R4 = lo(a)*lo(b)
                                        ;----
                                        ;  42
                                        ;  67 (carried forward)
                                        ;----
                                        ; 109
                                       
            ; lo * hi                  
            MOVR    R0,         R1      ;   6   R0 = R1 = lo(a)
            ADDI    #QSQR8_TBL.mid, R3  ;   8
            ADDR    R3,         R1      ;   6   R1 = hi(b) + lo(a)
            SUBR    R0,         R3      ;   6   R3 = hi(b) - lo(a)
                                       
@@pos_lh:   MVI@    R1,         R1      ;   8   R1 = qstbl[hi(b)-lo(a)]
            SUB@    R3,         R1      ;   8   R1 = lo(a)*hi(b)
                                        ;----
                                        ;  42
                                        ; 109 (carried forward)
                                        ;----
                                        ; 151
                                       
            ; hi * lo                  
            MOVR    R5,         R0      ;   6   R5 = R0 = lo(b)
            ADDI    #QSQR8_TBL.mid, R2  ;   8
            ADDR    R2,         R5      ;   6   R3 = hi(a) + lo(b)
            SUBR    R0,         R2      ;   6   R2 = hi(a) - lo(b)
                                       
@@pos_hl:   ADD@    R5,         R1      ;   8   \_ R1 = lo(a)*hi(b)+hi(a)*lo(b)
            SUB@    R2,         R1      ;   8   /
                                        ;----
                                        ;  42
                                        ; 151 (carried forward)
                                        ;----
                                        ; 193
                                       
            SWAP    R1                  ;   6   \_ shift upper product left 8
            ANDI    #$FF00,     R1      ;   8   /
            ADDR    R4,         R1      ;   6   final product
            PULR    PC                  ;  12
                                        ;----
                                        ;  32
                                        ; 193 (carried forward)
                                        ;----
                                        ; 225
            ENDP

	ENDI

	IF DEFINED intybasic_fastdiv

; Fast unsigned division/remainder
; Assembly code by Oscar Toledo G. Jul/10/2015
; Released to public domain.

	; Ultrafast unsigned division/remainder operation
	; Entry: R0 = Dividend
	;        R1 = Divisor
	; Output: R0 = Quotient
	;         R2 = Remainder
	; Worst case: 6 + 6 + 9 + 496 = 517 cycles
	; Best case: 6 + (6 + 7) * 16 = 214 cycles

uf_udiv16:	PROC
	CLRR R2		; 6
	SLLC R0,1	; 6
	BC @@1		; 7/9
	SLLC R0,1	; 6
	BC @@2		; 7/9
	SLLC R0,1	; 6
	BC @@3		; 7/9
	SLLC R0,1	; 6
	BC @@4		; 7/9
	SLLC R0,1	; 6
	BC @@5		; 7/9
	SLLC R0,1	; 6
	BC @@6		; 7/9
	SLLC R0,1	; 6
	BC @@7		; 7/9
	SLLC R0,1	; 6
	BC @@8		; 7/9
	SLLC R0,1	; 6
	BC @@9		; 7/9
	SLLC R0,1	; 6
	BC @@10		; 7/9
	SLLC R0,1	; 6
	BC @@11		; 7/9
	SLLC R0,1	; 6
	BC @@12		; 7/9
	SLLC R0,1	; 6
	BC @@13		; 7/9
	SLLC R0,1	; 6
	BC @@14		; 7/9
	SLLC R0,1	; 6
	BC @@15		; 7/9
	SLLC R0,1	; 6
	BC @@16		; 7/9
	JR R5

@@1:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@2:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@3:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@4:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@5:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@6:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@7:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@8:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@9:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@10:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@11:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@12:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@13:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@14:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@15:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@16:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
	JR R5
	
	ENDP

	ENDI

	IF DEFINED intybasic_ecs
	ORG $4800	; Available up to $4FFF

        ; Disable ECS ROMs so that they don't conflict with us
        MVII    #$2A5F, R0
        MVO     R0,     $2FFF
        MVII    #$7A5F, R0
        MVO     R0,     $7FFF
        MVII    #$EA5F, R0
        MVO     R0,     $EFFF

        B       $1041       ; resume boot

	ENDI

        ORG $200,$200,"-RWB"

Q2:	; Reserved label for #BACKTAB

	ORG $319,$319,"-RWB"
        ;
        ; 16-bits variables
	; Note IntyBASIC variables grow up starting in $308.
        ;
        IF DEFINED intybasic_voice
IV.Q:      RMB 8    ; IV_xxx        16-bit          Voice queue  (8 words)
IV.FPTR:   RMB 1    ; IV_xxx        16-bit          Current FIFO ptr.
IV.PPTR:   RMB 1    ; IV_xxx        16-bit          Current Phrase ptr.
        ENDI

        ORG $323,$323,"-RWB"

_scroll_buffer: RMB 20  ; Sometimes this is unused
_music_table:	RMB 1	; Note table
_music_start:	RMB 1	; Start of music
_music_p:	RMB 1	; Pointer to music
_frame:         RMB 1   ; Current frame
_read:          RMB 1   ; Pointer to DATA
_gram_bitmap:   RMB 1   ; Bitmap for definition
_gram2_bitmap:  RMB 1   ; Secondary bitmap for definition
_screen:    RMB 1       ; Pointer to current screen position
_color:     RMB 1       ; Current color

Q1:			; Reserved label for #MOBSHADOW
_mobs:      RMB 3*8     ; MOB buffer

_col0:      RMB 1       ; Collision status for MOB0
_col1:      RMB 1       ; Collision status for MOB1
_col2:      RMB 1       ; Collision status for MOB2
_col3:      RMB 1       ; Collision status for MOB3
_col4:      RMB 1       ; Collision status for MOB4
_col5:      RMB 1       ; Collision status for MOB5
_col6:      RMB 1       ; Collision status for MOB6
_col7:      RMB 1       ; Collision status for MOB7

SCRATCH:    ORG $100,$100,"-RWBN"
        ;
        ; 8-bits variables
        ;
ISRVEC:     RMB 2       ; Pointer to ISR vector (required by Intellivision ROM)
_int:       RMB 1       ; Signals interrupt received
_ntsc:      RMB 1       ; Signals NTSC Intellivision
_rand:      RMB 1       ; Pseudo-random value
_gram_target:   RMB 1   ; Contains GRAM card number
_gram_total:    RMB 1   ; Contains total GRAM cards for definition
_gram2_target:  RMB 1   ; Contains GRAM card number
_gram2_total:   RMB 1   ; Contains total GRAM cards for definition
_mode_select:   RMB 1   ; Graphics mode selection
_border_color:  RMB 1   ; Border color
_border_mask:   RMB 1   ; Border mask
    IF DEFINED intybasic_keypad
_cnt1_p0:   RMB 1       ; Debouncing 1
_cnt1_p1:   RMB 1       ; Debouncing 2
_cnt1_key:  RMB 1       ; Currently pressed key
_cnt2_p0:   RMB 1       ; Debouncing 1
_cnt2_p1:   RMB 1       ; Debouncing 2
_cnt2_key:  RMB 1       ; Currently pressed key
    ENDI
    IF DEFINED intybasic_scroll
_scroll_x:  RMB 1       ; Scroll X offset
_scroll_y:  RMB 1       ; Scroll Y offset
_scroll_d:  RMB 1       ; Scroll direction
    ENDI
    IF DEFINED intybasic_music
_music_mode: RMB 1      ; Music mode (0= Not using PSG, 1= Simple, 2= Full)
_music_frame: RMB 1     ; Music frame (for 50 hz fixed)
_music_tc:  RMB 1       ; Time counter
_music_t:   RMB 1       ; Time base
_music_i1:  RMB 1       ; Instrument 1 
_music_s1:  RMB 1       ; Sample pointer 1
_music_n1:  RMB 1       ; Note 1
_music_i2:  RMB 1       ; Instrument 2
_music_s2:  RMB 1       ; Sample pointer 2
_music_n2:  RMB 1       ; Note 2
_music_i3:  RMB 1       ; Instrument 3
_music_s3:  RMB 1       ; Sample pointer 3
_music_n3:  RMB 1       ; Note 3
_music_s4:  RMB 1       ; Sample pointer 4
_music_n4:  RMB 1       ; Note 4 (really it's drum)

_music_freq10:	RMB 1   ; Low byte frequency A
_music_freq20:	RMB 1   ; Low byte frequency B
_music_freq30:	RMB 1   ; Low byte frequency C
_music_freq11:	RMB 1   ; High byte frequency A
_music_freq21:	RMB 1   ; High byte frequency B
_music_freq31:	RMB 1   ; High byte frequency C
_music_mix:	RMB 1   ; Mixer
_music_noise:	RMB 1   ; Noise
_music_vol1:	RMB 1   ; Volume A
_music_vol2:	RMB 1   ; Volume B
_music_vol3:	RMB 1   ; Volume C
    ENDI
    IF DEFINED intybasic_voice
IV.QH:     RMB 1    ; IV_xxx        8-bit           Voice queue head
IV.QT:     RMB 1    ; IV_xxx        8-bit           Voice queue tail
IV.FLEN:   RMB 1    ; IV_xxx        8-bit           Length of FIFO data
    ENDI


V25:	RMB 1	; BUTTONFLAG
V34:	RMB 1	; C1
V49:	RMB 1	; COLOR
V56:	RMB 1	; DELAY
V39:	RMB 1	; DIV
V9:	RMB 1	; FARMERMOVE
V5:	RMB 1	; FLIPCOOLDOWN
V4:	RMB 1	; FLIPTIMER
V24:	RMB 1	; GOATFLIP
V6:	RMB 1	; GOATWALK
V52:	RMB 1	; HEARTY
V32:	RMB 1	; I
V53:	RMB 1	; J
V18:	RMB 1	; LEVEL
V17:	RMB 1	; LIVES
V3:	RMB 1	; MOVETIMER
V20:	RMB 1	; OBJ4SPEED
V21:	RMB 1	; OBJ5SPEED
V22:	RMB 1	; OBJ6SPEED
V23:	RMB 1	; OBJ7SPEED
V30:	RMB 1	; OBJBASEADDR
V11:	RMB 1	; OBJHIT
V10:	RMB 1	; OBJLIVE
V47:	RMB 1	; OBJPICK
V33:	RMB 1	; P1X
V45:	RMB 1	; P1Y
V43:	RMB 1	; P2X
V44:	RMB 1	; P2Y
V50:	RMB 1	; P3X
V51:	RMB 1	; P3Y
V8:	RMB 1	; RANDSEED
V48:	RMB 1	; ROCKHITBOT
V16:	RMB 1	; SCOREFACTOR
V41:	RMB 1	; SEGDIV
V42:	RMB 1	; SMALLSCORE
V46:	RMB 1	; SMALLSCORETEMP
V40:	RMB 1	; SMALLSTAGESCORE
V2:	RMB 1	; SPRITETIMER
V19:	RMB 1	; STAGE
V54:	RMB 1	; X_OFF
V55:	RMB 1	; Y_OFF
Q9:	RMB 6	; OBJ4MOV
Q10:	RMB 6	; OBJ5MOV
Q11:	RMB 6	; OBJ6MOV
Q12:	RMB 6	; OBJ7MOV
Q6:	RMB 4	; OBJTYPE
Q7:	RMB 4	; OBJX
Q8:	RMB 4	; OBJY
Q13:	RMB 6	; P1MOV
Q14:	RMB 6	; P2MOV
_SCRATCH:	EQU $

SYSTEM:	ORG $2F0, $2F0, "-RWBN"
STACK:	RMB 24
V29:	RMB 1	; #FARMERSPRITE
V31:	RMB 1	; #GOAT1COLOR
V26:	RMB 1	; #GOAT1SPRITE
V27:	RMB 1	; #GOAT2SPRITE
V28:	RMB 1	; #GOAT3SPRITE
V7:	RMB 1	; #IDLETIMER
V35:	RMB 1	; #OBJ4SPRITE
V36:	RMB 1	; #OBJ5SPRITE
V37:	RMB 1	; #OBJ6SPRITE
V15:	RMB 1	; #POINTS
V38:	RMB 1	; #ROCKSPRITE
V12:	RMB 1	; #SCORE
V13:	RMB 1	; #SCORE1K
V1:	RMB 1	; #STAGESCORE
V14:	RMB 1	; #TOPSCORE
_SYSTEM:	EQU $
